(***********************************************************************

                    Mathematica-Compatible Notebook

This notebook can be used on any computer system with Mathematica 4.0,
MathReader 4.0, or any compatible application. The data for the notebook 
starts with the line containing stars above.

To get the notebook into a Mathematica-compatible application, do one of 
the following:

* Save the data starting with the line of stars above into a file
  with a name ending in .nb, then open the file inside the application;

* Copy the data starting with the line of stars above to the
  clipboard, then use the Paste menu command inside the application.

Data for notebooks contains only printable 7-bit ASCII and can be
sent directly in email or through ftp in text mode.  Newlines can be
CR, LF or CRLF (Unix, Macintosh or MS-DOS style).

NOTE: If you modify the data for this notebook not in a Mathematica-
compatible application, you must delete the line below containing the 
word CacheID, otherwise Mathematica-compatible applications may try to 
use invalid cache data.

For more information on notebooks and Mathematica-compatible 
applications, contact Wolfram Research:
  web: http://www.wolfram.com
  email: info@wolfram.com
  phone: +1-217-398-0700 (U.S.)

Notebook reader applications are available free of charge from 
Wolfram Research.
***********************************************************************)

(*CacheID: 232*)


(*NotebookFileLineBreakTest
NotebookFileLineBreakTest*)
(*NotebookOptionsPosition[   1226240,      22791]*)
(*NotebookOutlinePosition[   1229134,      22871]*)
(*  CellTagsIndexPosition[   1229090,      22867]*)
(*WindowFrame->Normal*)



Notebook[{

Cell[CellGroupData[{
Cell["Partitions and Sums of Integer Powers", "Title",
  TextAlignment->Left,
  TextJustification->0],

Cell["by Jaime Rangel-Mondrag\[OAcute]n", "Author",
  TextAlignment->Left,
  TextJustification->0],

Cell["\<\
Facultad de Inform\[AAcute]tica
Universidad Aut\[OAcute]noma de Quer\[EAcute]taro
Divisi\[OAcute]n de Estudios de Posgrado

Centro Universitario
Cerro de las Campanas s/n
C.P. 76010 Quer\[EAcute]taro, Qro. 
Mexico

jrangel@sunserver.uaq.mx

Copyright  \[Copyright]August, 2000, UAQ, Facultad de Inform\[AAcute]tica\
\>", "Caption",
  TextAlignment->Left,
  TextJustification->0],

Cell[TextData[StyleBox["Permission is hereby granted to reproduce part or all \
of this file for any purpose other than direct profit providing that the \
source is acknowledged.\n",
  FontColor->RGBColor[0, 0, 1]]], "Quote",
  TextAlignment->Left,
  TextJustification->0],

Cell[BoxData[
    \(Off[General::"\<spell\>", General::"\<spell1\>"]\)], "Input",
  InitializationCell->True],

Cell["\<\


Two numbers (not necessarily different) are chosen 
from the range of positive numbers greater than 1 and 
not greater than 20. Only the sum of the two numbers is 
given to mathematician S. Only the product of the two is
 given to mathematician P.
On the telephone S says to P, \"I see no way you can 
determine my sum.\"
An hour later P calls him back to say, \"I know your sum.\"
Later S calls P again to report, \"now I know your product.\"
What are the two numbers?
    
Martin Gardner, December 1979\
\>", "Commentary",
  TextAlignment->Right,
  TextJustification->0],

Cell[CellGroupData[{

Cell["Acknowledgements", "Section 1"],

Cell["\<\
This work was finished at Wolfram Research Inc., in Champaign IL, USA, while \
the author was spending two months as a Visiting Scholar. Their assistance \
and enthusiastic support is gratefully acknowledged. My thanks are also given \
for the continuous support received from the University of Queretaro in \
Mexico.\
\>", "Text"]
}, Open  ]],

Cell[CellGroupData[{

Cell["Introduction. ", "Section"],

Cell["\<\
A partition of a positive integer number is a finite nonincreasing sequence \
of numbers adding up to that number. Take, for instance, the following \
\"proof without words\" diagram illustrating the fact that any square number \
is a sum of odd numbers, where we can see that 1+3+5+7+9+11 is a partition of \
36 in odd parts.\
\>", "Text"],

Cell[CellGroupData[{

Cell[BoxData[{
    \(li[n_] := 
      Table[{Line[{{0, i}, {i, i}, {i, 0}}]}, {i, 
          n}]\), "\[IndentingNewLine]", 
    \(ci[n_] := 
      Table[{RGBColor[i\/n, j\/n, \(i\ j\)\/n\^2], 
          Disk[{i - 0.5, j - 0.5}, 0.35]}, {i, n}, {j, 
          n}]\), "\[IndentingNewLine]", 
    \(\(Show[Graphics[{li[6], ci[6]}], 
        AspectRatio \[Rule] Automatic];\)\)}], "Input"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.15873 0.0238095 0.15873 [
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
0 g
.5 Mabswid
[ ] 0 setdash
.02381 .18254 m
.18254 .18254 L
.18254 .02381 L
s
.02381 .34127 m
.34127 .34127 L
.34127 .02381 L
s
.02381 .5 m
.5 .5 L
.5 .02381 L
s
.02381 .65873 m
.65873 .65873 L
.65873 .02381 L
s
.02381 .81746 m
.81746 .81746 L
.81746 .02381 L
s
.02381 .97619 m
.97619 .97619 L
.97619 .02381 L
s
.167 .167 .028 r
.10317 .10317 m
.10317 .10317 .05556 0 365.73 arc
F
.167 .333 .056 r
.10317 .2619 m
.10317 .2619 .05556 0 365.73 arc
F
.167 .5 .083 r
.10317 .42063 m
.10317 .42063 .05556 0 365.73 arc
F
.167 .667 .111 r
.10317 .57937 m
.10317 .57937 .05556 0 365.73 arc
F
.167 .833 .139 r
.10317 .7381 m
.10317 .7381 .05556 0 365.73 arc
F
.167 1 .167 r
.10317 .89683 m
.10317 .89683 .05556 0 365.73 arc
F
.333 .167 .056 r
.2619 .10317 m
.2619 .10317 .05556 0 365.73 arc
F
.333 .333 .111 r
.2619 .2619 m
.2619 .2619 .05556 0 365.73 arc
F
.333 .5 .167 r
.2619 .42063 m
.2619 .42063 .05556 0 365.73 arc
F
.333 .667 .222 r
.2619 .57937 m
.2619 .57937 .05556 0 365.73 arc
F
.333 .833 .278 r
.2619 .7381 m
.2619 .7381 .05556 0 365.73 arc
F
.333 1 .333 r
.2619 .89683 m
.2619 .89683 .05556 0 365.73 arc
F
.5 .167 .083 r
.42063 .10317 m
.42063 .10317 .05556 0 365.73 arc
F
.5 .333 .167 r
.42063 .2619 m
.42063 .2619 .05556 0 365.73 arc
F
.5 .5 .25 r
.42063 .42063 m
.42063 .42063 .05556 0 365.73 arc
F
.5 .667 .333 r
.42063 .57937 m
.42063 .57937 .05556 0 365.73 arc
F
.5 .833 .417 r
.42063 .7381 m
.42063 .7381 .05556 0 365.73 arc
F
.5 1 .5 r
.42063 .89683 m
.42063 .89683 .05556 0 365.73 arc
F
.667 .167 .111 r
.57937 .10317 m
.57937 .10317 .05556 0 365.73 arc
F
.667 .333 .222 r
.57937 .2619 m
.57937 .2619 .05556 0 365.73 arc
F
.667 .5 .333 r
.57937 .42063 m
.57937 .42063 .05556 0 365.73 arc
F
.667 .667 .444 r
.57937 .57937 m
.57937 .57937 .05556 0 365.73 arc
F
.667 .833 .556 r
.57937 .7381 m
.57937 .7381 .05556 0 365.73 arc
F
.667 1 .667 r
.57937 .89683 m
.57937 .89683 .05556 0 365.73 arc
F
.833 .167 .139 r
.7381 .10317 m
.7381 .10317 .05556 0 365.73 arc
F
.833 .333 .278 r
.7381 .2619 m
.7381 .2619 .05556 0 365.73 arc
F
.833 .5 .417 r
.7381 .42063 m
.7381 .42063 .05556 0 365.73 arc
F
.833 .667 .556 r
.7381 .57937 m
.7381 .57937 .05556 0 365.73 arc
F
.833 .833 .694 r
.7381 .7381 m
.7381 .7381 .05556 0 365.73 arc
F
.833 1 .833 r
.7381 .89683 m
.7381 .89683 .05556 0 365.73 arc
F
1 .167 .167 r
.89683 .10317 m
.89683 .10317 .05556 0 365.73 arc
F
1 .333 .333 r
.89683 .2619 m
.89683 .2619 .05556 0 365.73 arc
F
1 .5 .5 r
.89683 .42063 m
.89683 .42063 .05556 0 365.73 arc
F
1 .667 .667 r
.89683 .57937 m
.89683 .57937 .05556 0 365.73 arc
F
1 .833 .833 r
.89683 .7381 m
.89683 .7381 .05556 0 365.73 arc
F
1 1 1 r
.89683 .89683 m
.89683 .89683 .05556 0 365.73 arc
F
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 288},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0001J1000`40O003h00Oof]JJF]J0000of]j
JeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmk
JeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]j
JeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmk
JeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]j
JeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmk
JeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]j
JeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmk
JeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]j
JeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_N`00J6]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[
FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][
FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[
FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg/1
JeX00?m[FVU[FP000?m_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]j
JeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmk
JeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]j
JeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmk
JeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]j
JeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmk
JeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]j
JeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmk
JeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgX006Q[FVmkJeY[NV]JKg][
FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[
FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][
FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[
FVmkJeY[NV]JKg][FV]j0F]J003oJeYYJeX0003oJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmk
JeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]j
JeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmk
JeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]j
JeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmk
JeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]j
JeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmk
JeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]j
JeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmk
001XJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][
FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[
FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][
FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_N`5[FP00of]JJF]J0000ofmkJeY[NV]JKg][FV]j
JeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmk
JeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]j
JeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmk
JeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]j
JeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmk
JeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]j
JeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmk
JeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]j
JeY_Nf]JJgY[FVmkJeY[NP00J6]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[
FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][
FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[
FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgX1JeX00?m[FVU[FP00
0?m[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]j
JeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmk
JeY[NV]JKg][FV]j001_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]j
JeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmk
JeY[NV]J001[FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]j
JeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmk
001[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]j
JeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]J001[FVmk
JeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg/006Q[FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][
FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]j001_Nf]JJgY[
FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][
FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]J001[FV]jJeY_Nf]JJgY[
FVmk0F]J0011JeX00`00JeY[FP0fJeX00`00JeY[FP0fJeX00`00JeY[FP0fJeX00`00JeY[FP0fJeX0
0`00JeY[FP0fJeX00`00JeY[FP07JeX0003oKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_
Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[
NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_N`00JgY[FVmkJeY[NV]JKg][FV]jJeY_
Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[
NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FP00JeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_
Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[
NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NP00Kg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_
Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[
NV]JKg][FV]jJeY_Nf]JJgY[FP00JeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]j001X
JeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmk
JeY[NV]JKg][FV]jJeY_N`00JgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]j
JeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmk
JeY[NV]JKg][FP00JeY_Nf]JJgY[FVmkJeY[NP5[FP00@F]J00<006]JJeX0=V]J00<006]JJeX0=V]J
00<006]JJeX0=V]J00<006]JJeX0=V]J00<006]JJeX0=V]J00<006]JJeX01f]J0000of]jJeY_Nf]J
JgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]J
Kg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]J
JgX006mkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]J
Kg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeX006]J
JgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]J
Kg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg/006]jJeY_Nf]J
JgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]J
Kg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeX006]JKg][FV]jJeY_Nf]J
JgY[FVmkJeY[NV]JKg][FV]jJeY_N`00J6]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[
NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgX006mkJeY[NV]JKg][FV]jJeY_
Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[
NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeX006]JJgY[FVmkJeY[NV]JKg/1JeX0045[
FP03001[FV]J03I[FP03001[FV]J03I[FP03001[FV]J03I[FP03001[FV]J03I[FP03001[FV]J03I[
FP03001[FV]J00M[FP000?m_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][
FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[
FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmk001[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][
FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[
FVmkJeY[NV]JKg][FV]jJeY_Nf]J001[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][
FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[
FVmkJeY[NV]JKg][FV]j001_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][
FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[
FVmkJeY[NV]J001[FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgX006Q[FVmkJeY[NV]J
Kg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]J
JgY[FVmk001[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]J
Kg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]J
001[FVmkJeY[NV]JKg][FV]j0F]J0011JeX00`00JeY[FP0fJeX00`00JeY[FP0fJeX00`00JeY[FP0f
JeX00`00JeY[FP0fJeX00`00JeY[FP0fJeX00`00JeY[FP07JeX0003oJgY[FVmkJeY[NV]JKg][FV]j
JeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmk
JeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NP00Kg][FV]j
JeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmk
JeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FP00JeY[NV]JKg][FV]j
JeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmk
JeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_N`00JgY[FVmkJeY[NV]JKg][FV]j
JeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmk
JeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FP00JeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]j
JeY_Nf]JJgY[FVmk001XJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[
FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NP00Kg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][
FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[
FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FP00JeY[NV]JKg][FV]jJeY_N`5[FP00@F]J00<006]JJeX0
=V]J00<006]JJeX0=V]J00<006]JJeX0=V]J00<006]JJeX0=V]J00<006]JJeX0=V]J00<006]JJeX0
1f]J0000ofmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[
NV]JKg][FQBQ480DXA215:4@P1BQ484DXA205:4@PABQ481_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_
Nf]JJgY[FVmkJeY[NV]JKg/006]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[
NRB1::4TPBRQ984XXBB1::4TPBRQ984XXBB1::5[FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_
Nf]JJgY[FVmkJeX006]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FSbR?84l
XSR1?:8lPCbR>84lXSb1?:8hPCbR?85[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_
Nf]JJgX006mkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Ne22E:=@PUBSD89D
Xe22E:=@PUBSD89DXe22E:=[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeX0
06]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NP00J6]JKg][FVRTI8=XY6B3J:ATPfRT
I8=XY6B3J:ATPfRTI8=_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg/006]j
JeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NWb4O:ElQ7bUO8AlYGb4O:ElQ7bU
O8AlYGb4O:E[FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeX006]JKg][FV]j
JeY_Nf]JJgX1JeX001][FP0C4:4@PA2Q484@XA214:4@PA2Q484@XA214:4@PA2Q484@XA214:404f]J
00<006]JJeX046]J01<TPBRQ:84XXBB1::4XPBRQ984XXBR1::4TPBRQ:84XXBB1::4XP@0CJeX00`00
JeY[FP0@JeX04cbR?88lXSb1?:8lPSbR?84lXSb2?:8lPCbR?88lXSb1?:8lPSbR01=[FP03001[FV]J
011[FP0CD89@Xe22D:=@PU2SD89@Xe22D:=@PU2SD89@Xe22D:=@PU2SD8804f]J00<006]JJeX046]J
01=XY6B3J:=XPfRTI8=XXfR3J:ATPfRSJ8=XY6B3J:=XPfRTI8=XX`0CJeX00`00JeY[FP0?JeX057bT
O8AlY7b4O:AlQ7bTO8AlY7b4O:AlQ7bTO8AlY7b4O:AlQ7bTO8@CJeX00`00JeY[FP07JeX0003oJgY[
FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgX@P1BQ484DXA205:4@
PABQ480DXA215:4@P1BQ484DXA205:4@PABQ480DXF]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[
FVmkJeY[NP00Kg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeXXXBB1::4TPBRQ984XXBB1::4T
PBRQ984XXBB1::4TPBRQ984XXBB1::4TPF]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[
FP00JeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg/lPCbR>84lXSb1?:8hPCbR?84lXSR1?:8l
PCbR>84lXSb1?:8hPCbR?84lXV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_N`00JgY[
FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeYDXe22E:=@PUBSD89DXe22E:=@PUBSD89DXe22E:=@
PUBSD89DXe22E:=@PVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FP00JeY_Nf]JJgY[
FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgYTPfRT001XI8=XY6B3J:ATPfRTI8=XY6B3J:ATPfRTI8=XY6B3
J:ATPfRTI8=XY6]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NP00Kg][FV]jJeY_Nf]J
JgY[FVmkJeY[NV]JKg][FV]jJeYlYGb4O:ElQ7bUO8AlYGb4O:ElQ7bUO8AlYGb4O:ElQ7bUO8AlYGb4
O:ElQ6]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FP00JeY[NV]JKg][FV]jJeY_N`5[
FP0066]J01T@PA2Q484@XA214:4@PA2Q484@XA214:4@PA2Q484@XA214:4@PA2Q484@XA214:4@P@0@
JeX00`00JeY[FP0=JeX06BRQ984XXBR1::4TPBRQ:84XXBB1::4XPBRQ984XXBR1::4TPBRQ:84XXBB1
::4XPBRQ011[FP03001[FV]J00e[FP0I?84lXSb2?:8lPCbR?88lXSb1?:8lPSbR?84lXSb2?:8lPCbR
?88lXSb1?:8lPSbR?84046]J00<006]JJeX03F]J01U@Xe22D:=@PU2SD89@Xe22D:=@PU2SD89@Xe22
D:=@PU2SD89@Xe22D:=@PU2SD89@X`0@JeX00`00JeY[FP0=JeX06FR3J:ATPfRSJ8=XY6B3J:=XPfRT
I8=XXfR3J:ATPfRSJ8=XY6B3J:=XPfRTI8=XXfR3011[FP03001[FV]J00e[FP0IO:AlQ7bTO8AlY7b4
O:AlQ7bTO8AlY7b4O:AlQ7bTO8AlY7b4O:AlQ7bTO8AlY7b4O:@046]J00<006]JJeX01f]J0000ofmk
JeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgX@P1BQ484DXA205:4@PABQ
480DXA215:4@P1BQ484DXA205:4@PABQ480DXA215:4@P1BQ485[NV]JKg][FV]jJeY_Nf]JJgY[FVmk
JeY[NV]JKg/006]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeXXXBB1::4TPBRQ984XXBB1::4TPBRQ
984XXBB1::4TPBRQ984XXBB1::4TPBRQ984XXBB1::5[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmk
JeX006]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg/lPCbR>84lXSb1?:8hPCbR?84lXSR1?:8lPCbR
>84lXSb1?:8hPCbR?84lXSR1?:8lPCbR>85_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgX006mk
JeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeYDXe22E:=@PUBSD89DXe22E:=@PUBSD89DXe22E:=@PUBS
D89DXe22E:=@PUBSD89DXe22E:=[FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeX006]JJgY[FVmk
JeY[NV]JKg][FV]jJeY_Nf]JJgYTPfRTI8=XY000J6B3J:ATPfRTI8=XY6B3J:ATPfRTI8=XY6B3J:AT
PfRTI8=XY6B3J:ATPfRTI8=[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg/006]jJeY_Nf]JJgY[
FVmkJeY[NV]JKg][FV]jJeYlYGb4O:ElQ7bUO8AlYGb4O:ElQ7bUO8AlYGb4O:ElQ7bUO8AlYGb4O:El
Q7bUO8AlYGb4O:E[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeX006]JKg][FV]jJeY_Nf]JJgX1
JeX001I[FP0M484@XA214:4@PA2Q484@XA214:4@PA2Q484@XA214:4@PA2Q484@XA214:4@PA2Q484@
XA214:4@P@0>JeX00`00JeY[FP0;JeX07BRQ984XXBR1::4TPBRQ:84XXBB1::4XPBRQ984XXBR1::4T
PBRQ:84XXBB1::4XPBRQ984XXBR1::403V]J00<006]JJeX02f]J01dlPCbR?88lXSb1?:8lPSbR?84l
XSb2?:8lPCbR?88lXSb1?:8lPSbR?84lXSb2?:8lPCbR?88lXSb100i[FP03001[FV]J00][FP0MD:=@
PU2SD89@Xe22D:=@PU2SD89@Xe22D:=@PU2SD89@Xe22D:=@PU2SD89@Xe22D:=@PU2SD89@X`0>JeX0
0`00JeY[FP0;JeX07FR3J:ATPfRSJ8=XY6B3J:=XPfRTI8=XXfR3J:ATPfRSJ8=XY6B3J:=XPfRTI8=X
XfR3J:ATPfRSJ8<03V]J00<006]JJeX02f]J01elY7b4O:AlQ7bTO8AlY7b4O:AlQ7bTO8AlY7b4O:Al
Q7bTO8AlY7b4O:AlQ7bTO8AlY7b4O:AlQ7bT00i[FP03001[FV]J00M[FP000?m[NV]JKg][FV]jJeY_
Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgX@P1BQ484DXA205:4@PABQ480DXA215:4@P1BQ484D
XA205:4@PABQ480DXA215:4@P1BQ484DXA205:4@PF]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]j001_
Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeXXXBB1::4TPBRQ984XXBB1::4TPBRQ984XXBB1::4TPBRQ984X
XBB1::4TPBRQ984XXBB1::4TPBRQ984XXF]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]J001[FV]jJeY_
Nf]JJgY[FVmkJeY[NV]JKg/lPCbR>84lXSb1?:8hPCbR?84lXSR1?:8lPCbR>84lXSb1?:8hPCbR?84l
XSR1?:8lPCbR>84lXSb1?:8hPFmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmk001[NV]JKg][FV]jJeY_
Nf]JJgY[FVmkJeYDXe22E:=@PUBSD89DXe22E:=@PUBSD89DXe22E:=@PUBSD89DXe22E:=@PUBSD89D
Xe22E:=@PUBSD89DXf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]J001[FVmkJeY[NV]JKg][FV]jJeY_
Nf]JJgYTPfRTI8=XY6B3J:@006QTPfRTI8=XY6B3J:ATPfRTI8=XY6B3J:ATPfRTI8=XY6B3J:ATPfRT
I8=XY6B3J:ATPf]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]j001_Nf]JJgY[FVmkJeY[NV]JKg][FV]j
JeYlYGb4O:ElQ7bUO8AlYGb4O:ElQ7bUO8AlYGb4O:ElQ7bUO8AlYGb4O:ElQ7bUO8AlYGb4O:ElQ7bU
O8AlYF]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]J001[FV]jJeY_Nf]JJgY[FVmk0F]J000EJeX0812Q
484@XA214:4@PA2Q484@XA214:4@PA2Q484@XA214:4@PA2Q484@XA214:4@PA2Q484@XA214:4@PA2Q
484<JeX00`00JeY[FP0:JeX082B1::4XPBRQ984XXBR1::4TPBRQ:84XXBB1::4XPBRQ984XXBR1::4T
PBRQ:84XXBB1::4XPBRQ984XXBR1::4<JeX00`00JeY[FP09JeX08Cb1?:8lPSbR?84lXSb2?:8lPCbR
?88lXSb1?:8lPSbR?84lXSb2?:8lPCbR?88lXSb1?:8lPSbR?84lXSb2?:8lP@0<JeX00`00JeY[FP09
JeX08E2SD89@Xe22D:=@PU2SD89@Xe22D:=@PU2SD89@Xe22D:=@PU2SD89@Xe22D:=@PU2SD89@Xe22
D:=@PU2SD89@X`0<JeX00`00JeY[FP09JeX08FR3J:ATPfRSJ8=XY6B3J:=XPfRTI8=XXfR3J:ATPfRS
J8=XY6B3J:=XPfRTI8=XXfR3J:ATPfRSJ8=XY6B3J:=XP`0<JeX00`00JeY[FP09JeX08GbTO8AlY7b4
O:AlQ7bTO8AlY7b4O:AlQ7bTO8AlY7b4O:AlQ7bTO8AlY7b4O:AlQ7bTO8AlY7b4O:AlQ7bTO8AlY00<
JeX00`00JeY[FP07JeX0003oKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FQBQ
484DXA205:4@PABQ480DXA215:4@P1BQ484DXA205:4@PABQ480DXA215:4@P1BQ484DXA205:4@PABQ
480DXA21JgY[FVmkJeY[NV]JKg][FV]jJeY_N`00JgY[FVmkJeY[NV]JKg][FV]jJeY_NbB1::4TPBRQ
984XXBB1::4TPBRQ984XXBB1::4TPBRQ984XXBB1::4TPBRQ984XXBB1::4TPBRQ984XXBB1::4TPBRQ
JeY_Nf]JJgY[FVmkJeY[NV]JKg][FP00JeY_Nf]JJgY[FVmkJeY[NV]JKg/lPCbR>84lXSb1?:8hPCbR
?84lXSR1?:8lPCbR>84lXSb1?:8hPCbR?84lXSR1?:8lPCbR>84lXSb1?:8hPCbR?84lXSR1Kg][FV]j
JeY_Nf]JJgY[FVmkJeY[NP00Kg][FV]jJeY_Nf]JJgY[FVmkJeYDXe22E:=@PUBSD89DXe22E:=@PUBS
D89DXe22E:=@PUBSD89DXe22E:=@PUBSD89DXe22E:=@PUBSD89DXe22E:=@PUBSJeY[NV]JKg][FV]j
JeY_Nf]JJgY[FP00JeY[NV]JKg][FV]jJeY_Nf]JJgYTPfRTI8=XY6B3J:ATPfRT001XI8=XY6B3J:AT
PfRTI8=XY6B3J:ATPfRTI8=XY6B3J:ATPfRTI8=XY6B3J:ATPfRTI8=XY6B3JgY[FVmkJeY[NV]JKg][
FV]jJeY_N`00JgY[FVmkJeY[NV]JKg][FV]jJeYlYGb4O:ElQ7bUO8AlYGb4O:ElQ7bUO8AlYGb4O:El
Q7bUO8AlYGb4O:ElQ7bUO8AlYGb4O:ElQ7bUO8AlYGb4O:ElQ7bUJeY_Nf]JJgY[FVmkJeY[NV]JKg][
FP00JeY_Nf]JJgY[FVmkJeY[NP5[FP0056]J028@PA2Q484@XA214:4@PA2Q484@XA214:4@PA2Q484@
XA214:4@PA2Q484@XA214:4@PA2Q484@XA214:4@PA2Q484@X@][FP03001[FV]J00U[FP0R::4XPBRQ
984XXBR1::4TPBRQ:84XXBB1::4XPBRQ984XXBR1::4TPBRQ:84XXBB1::4XPBRQ984XXBR1::4TPBRQ
:84;JeX00`00JeY[FP08JeX08cbR?88lXSb1?:8lPSbR?84lXSb2?:8lPCbR?88lXSb1?:8lPSbR?84l
XSb2?:8lPCbR?88lXSb1?:8lPSbR?84lXSb2?:802f]J00<006]JJeX026]J02=@PU2SD89@Xe22D:=@
PU2SD89@Xe22D:=@PU2SD89@Xe22D:=@PU2SD89@Xe22D:=@PU2SD89@Xe22D:=@PU2SD89@Xe2200][
FP03001[FV]J00Q[FP0SJ:ATPfRSJ8=XY6B3J:=XPfRTI8=XXfR3J:ATPfRSJ8=XY6B3J:=XPfRTI8=X
XfR3J:ATPfRSJ8=XY6B3J:=XPfRTI8=XX`0;JeX00`00JeY[FP08JeX08gb4O:AlQ7bTO8AlY7b4O:Al
Q7bTO8AlY7b4O:AlQ7bTO8AlY7b4O:AlQ7bTO8AlY7b4O:AlQ7bTO8AlY7b4O:AlQ7bTO8@02f]J00<0
06]JJeX01f]J0000of]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmk484DXA205:4@
PABQ480DXA215:4@P1BQ484DXA205:4@PABQ480DXA215:4@P1BQ484DXA205:4@PABQ480DXA215:4@
P1BQJeY[NV]JKg][FV]jJeY_Nf]JJgX006mkJeY[NV]JKg][FV]jJeY_Nf]J::4TPBRQ984XXBB1::4T
PBRQ984XXBB1::4TPBRQ984XXBB1::4TPBRQ984XXBB1::4TPBRQ984XXBB1::4TPBRQ984XXBB1JgY[
FVmkJeY[NV]JKg][FV]jJeX006]JJgY[FVmkJeY[NV]JKg][FV]j>84lXSb1?:8hPCbR?84lXSR1?:8l
PCbR>84lXSb1?:8hPCbR?84lXSR1?:8lPCbR>84lXSb1?:8hPCbR?84lXSR1?:8lPCbRJeY_Nf]JJgY[
FVmkJeY[NV]JKg/006]jJeY_Nf]JJgY[FVmkJeY[NV]JE:=@PUBSD89DXe22E:=@PUBSD89DXe22E:=@
PUBSD89DXe22E:=@PUBSD89DXe22E:=@PUBSD89DXe22E:=@PUBSD89DXe22Kg][FV]jJeY_Nf]JJgY[
FVmkJeX006]JKg][FV]jJeY_Nf]JJgY[FVmkI8=XY6B3J:ATPfRTI8=XY000J6B3J:ATPfRTI8=XY6B3
J:ATPfRTI8=XY6B3J:ATPfRTI8=XY6B3J:ATPfRTI8=XY6B3J:ATPfRTJeY[NV]JKg][FV]jJeY_Nf]J
JgX006mkJeY[NV]JKg][FV]jJeY_Ngb4O:ElQ7bUO8AlYGb4O:ElQ7bUO8AlYGb4O:ElQ7bUO8AlYGb4
O:ElQ7bUO8AlYGb4O:ElQ7bUO8AlYGb4O:ElQ7bUO8AlYGb4JgY[FVmkJeY[NV]JKg][FV]jJeX006]J
JgY[FVmkJeY[NV]JKg/1JeX001=[FP0T4:4@PA2Q484@XA214:4@PA2Q484@XA214:4@PA2Q484@XA21
4:4@PA2Q484@XA214:4@PA2Q484@XA214:4@PA2Q484@XA212V]J00<006]JJeX026]J02@XPBRQ984X
XBR1::4TPBRQ:84XXBB1::4XPBRQ984XXBR1::4TPBRQ:84XXBB1::4XPBRQ984XXBR1::4TPBRQ:84X
XBB1::4:JeX00`00JeY[FP08JeX093bR?84lXSb2?:8lPCbR?88lXSb1?:8lPSbR?84lXSb2?:8lPCbR
?88lXSb1?:8lPSbR?84lXSb2?:8lPCbR?88lXSb1?:8lPPY[FP03001[FV]J00Q[FP0TD89@Xe22D:=@
PU2SD89@Xe22D:=@PU2SD89@Xe22D:=@PU2SD89@Xe22D:=@PU2SD89@Xe22D:=@PU2SD89@Xe22D:=@
PU2S2V]J00<006]JJeX026]J02AXXfR3J:ATPfRSJ8=XY6B3J:=XPfRTI8=XXfR3J:ATPfRSJ8=XY6B3
J:=XPfRTI8=XXfR3J:ATPfRSJ8=XY6B3J:=XPfRTI8<:JeX00`00JeY[FP07JeX09GbTO8AlY7b4O:Al
Q7bTO8AlY7b4O:AlQ7bTO8AlY7b4O:AlQ7bTO8AlY7b4O:AlQ7bTO8AlY7b4O:AlQ7bTO8AlY7b4O:Al
Q7bT00Y[FP03001[FV]J00M[FP000?m_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeXD
XA205:4@PABQ480DXA215:4@P1BQ484DXA205:4@PABQ480DXA215:4@P1BQ484DXA205:4@PABQ480D
XA215:4@P1BQ484DXA20Kg][FV]jJeY_Nf]JJgY[FVmk001[NV]JKg][FV]jJeY_Nf]JJgXTPBRQ984X
XBB1::4TPBRQ984XXBB1::4TPBRQ984XXBB1::4TPBRQ984XXBB1::4TPBRQ984XXBB1::4TPBRQ984X
XBB1::4TPBRQJeY[NV]JKg][FV]jJeY_Nf]J001[FVmkJeY[NV]JKg][FV]jJeXlXSb1?:8hPCbR?84l
XSR1?:8lPCbR>84lXSb1?:8hPCbR?84lXSR1?:8lPCbR>84lXSb1?:8hPCbR?84lXSR1?:8lPCbR>84l
XSb1JgY[FVmkJeY[NV]JKg][FV]j001_Nf]JJgY[FVmkJeY[NV]JKg]@PUBSD89DXe22E:=@PUBSD89D
Xe22E:=@PUBSD89DXe22E:=@PUBSD89DXe22E:=@PUBSD89DXe22E:=@PUBSD89DXe22E:=@PUBSJeY_
Nf]JJgY[FVmkJeY[NV]J001[FV]jJeY_Nf]JJgY[FVmkJeYXY6B3J:ATPfRTI8=XY6B3J:@006QTPfRT
I8=XY6B3J:ATPfRTI8=XY6B3J:ATPfRTI8=XY6B3J:ATPfRTI8=XY6B3J:ATPfRTI8=XY6B3Kg][FV]j
JeY_Nf]JJgY[FVmk001[NV]JKg][FV]jJeY_Nf]JJgYlQ7bUO8AlYGb4O:ElQ7bUO8AlYGb4O:ElQ7bU
O8AlYGb4O:ElQ7bUO8AlYGb4O:ElQ7bUO8AlYGb4O:ElQ7bUO8AlYGb4O:ElQ7bUJeY[NV]JKg][FV]j
JeY_Nf]J001[FVmkJeY[NV]JKg][FV]j0F]J000BJeX09Q214:4@PA2Q484@XA214:4@PA2Q484@XA21
4:4@PA2Q484@XA214:4@PA2Q484@XA214:4@PA2Q484@XA214:4@PA2Q484@XA214:49JeX00`00JeY[
FP07JeX09RRQ984XXBR1::4TPBRQ:84XXBB1::4XPBRQ984XXBR1::4TPBRQ:84XXBB1::4XPBRQ984X
XBR1::4TPBRQ:84XXBB1::4XPBRQ9849JeX00`00JeY[FP07JeX09Sb1?:8lPSbR?84lXSb2?:8lPCbR
?88lXSb1?:8lPSbR?84lXSb2?:8lPCbR?88lXSb1?:8lPSbR?84lXSb2?:8lPCbR?88lXSb1?:89JeX0
0`00JeY[FP07JeX09U2SD89@Xe22D:=@PU2SD89@Xe22D:=@PU2SD89@Xe22D:=@PU2SD89@Xe22D:=@
PU2SD89@Xe22D:=@PU2SD89@Xe22D:=@PU2SD889JeX00`00JeY[FP07JeX09VR3J:ATPfRSJ8=XY6B3
J:=XPfRTI8=XXfR3J:ATPfRSJ8=XY6B3J:=XPfRTI8=XXfR3J:ATPfRSJ8=XY6B3J:=XPfRTI8=XXfR3
J:@9JeX00`00JeY[FP07JeX09WbTO8AlY7b4O:AlQ7bTO8AlY7b4O:AlQ7bTO8AlY7b4O:AlQ7bTO8Al
Y7b4O:AlQ7bTO8AlY7b4O:AlQ7bTO8AlY7b4O:AlQ7bTO8@9JeX00`00JeY[FP07JeX0003oJgY[FVmk
JeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NQ205:4@PABQ480DXA215:4@P1BQ484DXA205:4@PABQ
480DXA215:4@P1BQ484DXA205:4@PABQ480DXA215:4@P1BQ484DXA205:4@PF]jJeY_Nf]JJgY[FVmk
JeY[NP00Kg][FV]jJeY_Nf]JJgY[FRRQ984XXBB1::4TPBRQ984XXBB1::4TPBRQ984XXBB1::4TPBRQ
984XXBB1::4TPBRQ984XXBB1::4TPBRQ984XXBB1::4TPBRQ984XXF]JKg][FV]jJeY_Nf]JJgY[FP00
JeY[NV]JKg][FV]jJeY_Ncb1?:8hPCbR?84lXSR1?:8lPCbR>84lXSb1?:8hPCbR?84lXSR1?:8lPCbR
>84lXSb1?:8hPCbR?84lXSR1?:8lPCbR>84lXSb1?:8hPFmkJeY[NV]JKg][FV]jJeY_N`00JgY[FVmk
JeY[NV]JKg][FUBSD89DXe22E:=@PUBSD89DXe22E:=@PUBSD89DXe22E:=@PUBSD89DXe22E:=@PUBS
D89DXe22E:=@PUBSD89DXe22E:=@PUBSD89DXf]JJgY[FVmkJeY[NV]JKg][FP00JeY_Nf]JJgY[FVmk
JeY[NVB3J:ATPfRTI8=XY6B3J:ATPfRT001XI8=XY6B3J:ATPfRTI8=XY6B3J:ATPfRTI8=XY6B3J:AT
PfRTI8=XY6B3J:ATPfRTI8=XY6B3J:ATPf]jJeY_Nf]JJgY[FVmkJeY[NP00Kg][FV]jJeY_Nf]JJgY[
FWbUO8AlYGb4O:ElQ7bUO8AlYGb4O:ElQ7bUO8AlYGb4O:ElQ7bUO8AlYGb4O:ElQ7bUO8AlYGb4O:El
Q7bUO8AlYGb4O:ElQ7bUO8AlYF]JKg][FV]jJeY_Nf]JJgY[FP00JeY[NV]JKg][FV]jJeY_N`5[FP00
4F]J02L@XA214:4@PA2Q484@XA214:4@PA2Q484@XA214:4@PA2Q484@XA214:4@PA2Q484@XA214:4@
PA2Q484@XA214:4@PA2Q484@XA214:402F]J00<006]JJeX01V]J02LTPBRQ:84XXBB1::4XPBRQ984X
XBR1::4TPBRQ:84XXBB1::4XPBRQ984XXBR1::4TPBRQ:84XXBB1::4XPBRQ984XXBR1::4TPBRQ:840
2F]J00<006]JJeX01V]J02LlXSb2?:8lPCbR?88lXSb1?:8lPSbR?84lXSb2?:8lPCbR?88lXSb1?:8l
PSbR?84lXSb2?:8lPCbR?88lXSb1?:8lPSbR?84lXSb2?:802F]J00<006]JJeX01V]J02M@PU2SD89@
Xe22D:=@PU2SD89@Xe22D:=@PU2SD89@Xe22D:=@PU2SD89@Xe22D:=@PU2SD89@Xe22D:=@PU2SD89@
Xe22D:=@PU2SD8802F]J00<006]JJeX01V]J02MXY6B3J:=XPfRTI8=XXfR3J:ATPfRSJ8=XY6B3J:=X
PfRTI8=XXfR3J:ATPfRSJ8=XY6B3J:=XPfRTI8=XXfR3J:ATPfRSJ8=XY6B3J:<02F]J00<006]JJeX0
1V]J02MlQ7bTO8AlY7b4O:AlQ7bTO8AlY7b4O:AlQ7bTO8AlY7b4O:AlQ7bTO8AlY7b4O:AlQ7bTO8Al
Y7b4O:AlQ7bTO8AlY7b4O:AlQ7bTO8@02F]J00<006]JJeX01f]J0000ofmkJeY[NV]JKg][FV]jJeY_
Nf]JJgY[FVmkJeY[NV]JKg/@PABQ480DXA215:4@P1BQ484DXA205:4@PABQ480DXA215:4@P1BQ484D
XA205:4@PABQ480DXA215:4@P1BQ484DXA205:4@PABQ481_Nf]JJgY[FVmkJeY[NV]JKg/006]jJeY_
Nf]JJgY[FVmkJeXXXBB1::4TPBRQ984XXBB1::4TPBRQ984XXBB1::4TPBRQ984XXBB1::4TPBRQ984X
XBB1::4TPBRQ984XXBB1::4TPBRQ984XXBB1::5[FV]jJeY_Nf]JJgY[FVmkJeX006]JKg][FV]jJeY_
Nf]JJgXhPCbR?84lXSR1?:8lPCbR>84lXSb1?:8hPCbR?84lXSR1?:8lPCbR>84lXSb1?:8hPCbR?84l
XSR1?:8lPCbR>84lXSb1?:8hPCbR?85[NV]JKg][FV]jJeY_Nf]JJgX006mkJeY[NV]JKg][FV]jJeYD
Xe22E:=@PUBSD89DXe22E:=@PUBSD89DXe22E:=@PUBSD89DXe22E:=@PUBSD89DXe22E:=@PUBSD89D
Xe22E:=@PUBSD89DXe22E:=[FVmkJeY[NV]JKg][FV]jJeX006]JJgY[FVmkJeY[NV]JKg]TPfRTI8=X
Y6B3J:ATPfRTI8=XY000J6B3J:ATPfRTI8=XY6B3J:ATPfRTI8=XY6B3J:ATPfRTI8=XY6B3J:ATPfRT
I8=XY6B3J:ATPfRTI8=_Nf]JJgY[FVmkJeY[NV]JKg/006]jJeY_Nf]JJgY[FVmkJeYlYGb4O:ElQ7bU
O8AlYGb4O:ElQ7bUO8AlYGb4O:ElQ7bUO8AlYGb4O:ElQ7bUO8AlYGb4O:ElQ7bUO8AlYGb4O:ElQ7bU
O8AlYGb4O:E[FV]jJeY_Nf]JJgY[FVmkJeX006]JKg][FV]jJeY_Nf]JJgX1JeX0015[FP0W4:4@PA2Q
484@XA214:4@PA2Q484@XA214:4@PA2Q484@XA214:4@PA2Q484@XA214:4@PA2Q484@XA214:4@PA2Q
484@XA214:4@PA2Q00U[FP03001[FV]J00I[FP0W:84XXBB1::4XPBRQ984XXBR1::4TPBRQ:84XXBB1
::4XPBRQ984XXBR1::4TPBRQ:84XXBB1::4XPBRQ984XXBR1::4TPBRQ:84XXBB100U[FP03001[FV]J
00I[FP0W?:8lPCbR?88lXSb1?:8lPSbR?84lXSb2?:8lPCbR?88lXSb1?:8lPSbR?84lXSb2?:8lPCbR
?88lXSb1?:8lPSbR?84lXSb2?:8lPCbR00U[FP03001[FV]J00I[FP0WD89@Xe22D:=@PU2SD89@Xe22
D:=@PU2SD89@Xe22D:=@PU2SD89@Xe22D:=@PU2SD89@Xe22D:=@PU2SD89@Xe22D:=@PU2SD89@Xe22
00U[FP03001[FV]J00I[FP0WJ:=XPfRTI8=XXfR3J:ATPfRSJ8=XY6B3J:=XPfRTI8=XXfR3J:ATPfRS
J8=XY6B3J:=XPfRTI8=XXfR3J:ATPfRSJ8=XY6B3J:=XPfRT00U[FP03001[FV]J00I[FP0WO8AlY7b4
O:AlQ7bTO8AlY7b4O:AlQ7bTO8AlY7b4O:AlQ7bTO8AlY7b4O:AlQ7bTO8AlY7b4O:AlQ7bTO8AlY7b4
O:AlQ7bTO8AlY7b400U[FP03001[FV]J00M[FP000?m[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]J
Kg][FV]j480DXA215:4@P1BQ484DXA205:4@PABQ480DXA215:4@P1BQ484DXA205:4@PABQ480DXA21
5:4@P1BQ484DXA205:4@PABQ480DXA21JgY[FVmkJeY[NV]JKg][FV]j001_Nf]JJgY[FVmkJeY[NV]J
::4TPBRQ984XXBB1::4TPBRQ984XXBB1::4TPBRQ984XXBB1::4TPBRQ984XXBB1::4TPBRQ984XXBB1
::4TPBRQ984XXBB1::4TPBRQJeY_Nf]JJgY[FVmkJeY[NV]J001[FV]jJeY_Nf]JJgY[FVmk?84lXSR1
?:8lPCbR>84lXSb1?:8hPCbR?84lXSR1?:8lPCbR>84lXSb1?:8hPCbR?84lXSR1?:8lPCbR>84lXSb1
?:8hPCbR?84lXSR1Kg][FV]jJeY_Nf]JJgY[FVmk001[NV]JKg][FV]jJeY_Nf]JE:=@PUBSD89DXe22
E:=@PUBSD89DXe22E:=@PUBSD89DXe22E:=@PUBSD89DXe22E:=@PUBSD89DXe22E:=@PUBSD89DXe22
E:=@PUBSJeY[NV]JKg][FV]jJeY_Nf]J001[FVmkJeY[NV]JKg][FV]jI8=XY6B3J:ATPfRTI8=XY6B3
J:@006QTPfRTI8=XY6B3J:ATPfRTI8=XY6B3J:ATPfRTI8=XY6B3J:ATPfRTI8=XY6B3J:ATPfRTI8=X
Y6B3JgY[FVmkJeY[NV]JKg][FV]j001_Nf]JJgY[FVmkJeY[NV]JO:ElQ7bUO8AlYGb4O:ElQ7bUO8Al
YGb4O:ElQ7bUO8AlYGb4O:ElQ7bUO8AlYGb4O:ElQ7bUO8AlYGb4O:ElQ7bUO8AlYGb4O:ElQ7bUJeY_
Nf]JJgY[FVmkJeY[NV]J001[FV]jJeY_Nf]JJgY[FVmk0F]J000AJeX09a2Q484@XA214:4@PA2Q484@
XA214:4@PA2Q484@XA214:4@PA2Q484@XA214:4@PA2Q484@XA214:4@PA2Q484@XA214:4@PA2Q484@
X@09JeX00`00JeY[FP06JeX09bB1::4XPBRQ984XXBR1::4TPBRQ:84XXBB1::4XPBRQ984XXBR1::4T
PBRQ:84XXBB1::4XPBRQ984XXBR1::4TPBRQ:84XXBB1::4XP@09JeX00`00JeY[FP06JeX09cbR?88l
XSb1?:8lPSbR?84lXSb2?:8lPCbR?88lXSb1?:8lPSbR?84lXSb2?:8lPCbR?88lXSb1?:8lPSbR?84l
XSb2?:8lPCbR?88lXP09JeX00`00JeY[FP06JeX09e22D:=@PU2SD89@Xe22D:=@PU2SD89@Xe22D:=@
PU2SD89@Xe22D:=@PU2SD89@Xe22D:=@PU2SD89@Xe22D:=@PU2SD89@Xe22D:=@PP09JeX00`00JeY[
FP06JeX09fRTI8=XXfR3J:ATPfRSJ8=XY6B3J:=XPfRTI8=XXfR3J:ATPfRSJ8=XY6B3J:=XPfRTI8=X
XfR3J:ATPfRSJ8=XY6B3J:=XPfRTI8=XX`09JeX00`00JeY[FP06JeX09gb4O:AlQ7bTO8AlY7b4O:Al
Q7bTO8AlY7b4O:AlQ7bTO8AlY7b4O:AlQ7bTO8AlY7b4O:AlQ7bTO8AlY7b4O:AlQ7bTO8AlY7b4O:Al
Q009JeX00`00JeY[FP07JeX0003oKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Na215:4@
P1BQ484DXA205:4@PABQ480DXA215:4@P1BQ484DXA205:4@PABQ480DXA215:4@P1BQ484DXA205:4@
PABQ480DXA215:4@P6mkJeY[NV]JKg][FV]jJeY_N`00JgY[FVmkJeY[NV]JKg][FRRQ984XXBB1::4T
PBRQ984XXBB1::4TPBRQ984XXBB1::4TPBRQ984XXBB1::4TPBRQ984XXBB1::4TPBRQ984XXBB1::4T
PBRQ984XXF]JJgY[FVmkJeY[NV]JKg][FP00JeY_Nf]JJgY[FVmkJeY[NSR1?:8lPCbR>84lXSb1?:8h
PCbR?84lXSR1?:8lPCbR>84lXSb1?:8hPCbR?84lXSR1?:8lPCbR>84lXSb1?:8hPCbR?84lXSR1?:8l
PF]jJeY_Nf]JJgY[FVmkJeY[NP00Kg][FV]jJeY_Nf]JJgY[FUBSD89DXe22E:=@PUBSD89DXe22E:=@
PUBSD89DXe22E:=@PUBSD89DXe22E:=@PUBSD89DXe22E:=@PUBSD89DXe22E:=@PUBSD89DXf]JKg][
FV]jJeY_Nf]JJgY[FP00JeY[NV]JKg][FV]jJeY_NfB3J:ATPfRTI8=XY6B3J:ATPfRT001XI8=XY6B3
J:ATPfRTI8=XY6B3J:ATPfRTI8=XY6B3J:ATPfRTI8=XY6B3J:ATPfRTI8=XY6B3J:ATPfmkJeY[NV]J
Kg][FV]jJeY_N`00JgY[FVmkJeY[NV]JKg][FWbUO8AlYGb4O:ElQ7bUO8AlYGb4O:ElQ7bUO8AlYGb4
O:ElQ7bUO8AlYGb4O:ElQ7bUO8AlYGb4O:ElQ7bUO8AlYGb4O:ElQ7bUO8AlYF]JJgY[FVmkJeY[NV]J
Kg][FP00JeY_Nf]JJgY[FVmkJeY[NP5[FP004F]J02L@XA214:4@PA2Q484@XA214:4@PA2Q484@XA21
4:4@PA2Q484@XA214:4@PA2Q484@XA214:4@PA2Q484@XA214:4@PA2Q484@XA214:402F]J00<006]J
JeX01V]J02LXPBRQ984XXBR1::4TPBRQ:84XXBB1::4XPBRQ984XXBR1::4TPBRQ:84XXBB1::4XPBRQ
984XXBR1::4TPBRQ:84XXBB1::4XPBRQ98402F]J00<006]JJeX01V]J02LlXSb1?:8lPSbR?84lXSb2
?:8lPCbR?88lXSb1?:8lPSbR?84lXSb2?:8lPCbR?88lXSb1?:8lPSbR?84lXSb2?:8lPCbR?88lXSb1
?:802F]J00<006]JJeX01V]J02M@PU2SD89@Xe22D:=@PU2SD89@Xe22D:=@PU2SD89@Xe22D:=@PU2S
D89@Xe22D:=@PU2SD89@Xe22D:=@PU2SD89@Xe22D:=@PU2SD8802F]J00<006]JJeX01V]J02MXXfR3
J:ATPfRSJ8=XY6B3J:=XPfRTI8=XXfR3J:ATPfRSJ8=XY6B3J:=XPfRTI8=XXfR3J:ATPfRSJ8=XY6B3
J:=XPfRTI8=XXfR3J:@02F]J00<006]JJeX01V]J02MlQ7bTO8AlY7b4O:AlQ7bTO8AlY7b4O:AlQ7bT
O8AlY7b4O:AlQ7bTO8AlY7b4O:AlQ7bTO8AlY7b4O:AlQ7bTO8AlY7b4O:AlQ7bTO8@02F]J00<006]J
JeX01f]J0000of]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgX@P1BQ484DXA205:4@PABQ
480DXA215:4@P1BQ484DXA205:4@PABQ480DXA215:4@P1BQ484DXA205:4@PABQ480DXA215:4@P1BQ
485[NV]JKg][FV]jJeY_Nf]JJgX006mkJeY[NV]JKg][FV]jJeXXXBB1::4TPBRQ984XXBB1::4TPBRQ
984XXBB1::4TPBRQ984XXBB1::4TPBRQ984XXBB1::4TPBRQ984XXBB1::4TPBRQ984XXBB1::5[FVmk
JeY[NV]JKg][FV]jJeX006]JJgY[FVmkJeY[NV]JKg/lPCbR>84lXSb1?:8hPCbR?84lXSR1?:8lPCbR
>84lXSb1?:8hPCbR?84lXSR1?:8lPCbR>84lXSb1?:8hPCbR?84lXSR1?:8lPCbR>85_Nf]JJgY[FVmk
JeY[NV]JKg/006]jJeY_Nf]JJgY[FVmkJeYDXe22E:=@PUBSD89DXe22E:=@PUBSD89DXe22E:=@PUBS
D89DXe22E:=@PUBSD89DXe22E:=@PUBSD89DXe22E:=@PUBSD89DXe22E:=[FV]jJeY_Nf]JJgY[FVmk
JeX006]JKg][FV]jJeY_Nf]JJgYTPfRTI8=XY6B3J:ATPfRTI8=XY000J6B3J:ATPfRTI8=XY6B3J:AT
PfRTI8=XY6B3J:ATPfRTI8=XY6B3J:ATPfRTI8=XY6B3J:ATPfRTI8=[NV]JKg][FV]jJeY_Nf]JJgX0
06mkJeY[NV]JKg][FV]jJeYlYGb4O:ElQ7bUO8AlYGb4O:ElQ7bUO8AlYGb4O:ElQ7bUO8AlYGb4O:El
Q7bUO8AlYGb4O:ElQ7bUO8AlYGb4O:ElQ7bUO8AlYGb4O:E[FVmkJeY[NV]JKg][FV]jJeX006]JJgY[
FVmkJeY[NV]JKg/1JeX0015[FP0W4:4@PA2Q484@XA214:4@PA2Q484@XA214:4@PA2Q484@XA214:4@
PA2Q484@XA214:4@PA2Q484@XA214:4@PA2Q484@XA214:4@PA2Q00U[FP03001[FV]J00I[FP0W984X
XBR1::4TPBRQ:84XXBB1::4XPBRQ984XXBR1::4TPBRQ:84XXBB1::4XPBRQ984XXBR1::4TPBRQ:84X
XBB1::4XPBRQ984XXBR100U[FP03001[FV]J00I[FP0W?:8lPSbR?84lXSb2?:8lPCbR?88lXSb1?:8l
PSbR?84lXSb2?:8lPCbR?88lXSb1?:8lPSbR?84lXSb2?:8lPCbR?88lXSb1?:8lPSbR00U[FP03001[
FV]J00I[FP0WD89@Xe22D:=@PU2SD89@Xe22D:=@PU2SD89@Xe22D:=@PU2SD89@Xe22D:=@PU2SD89@
Xe22D:=@PU2SD89@Xe22D:=@PU2SD89@Xe2200U[FP03001[FV]J00I[FP0WJ:ATPfRSJ8=XY6B3J:=X
PfRTI8=XXfR3J:ATPfRSJ8=XY6B3J:=XPfRTI8=XXfR3J:ATPfRSJ8=XY6B3J:=XPfRTI8=XXfR3J:AT
PfRS00U[FP03001[FV]J00I[FP0WO8AlY7b4O:AlQ7bTO8AlY7b4O:AlQ7bTO8AlY7b4O:AlQ7bTO8Al
Y7b4O:AlQ7bTO8AlY7b4O:AlQ7bTO8AlY7b4O:AlQ7bTO8AlY7b400U[FP03001[FV]J00M[FP000?m_
Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeXDXA205:4@PABQ480DXA215:4@P1BQ484D
XA205:4@PABQ480DXA215:4@P1BQ484DXA205:4@PABQ480DXA215:4@P1BQ484DXA20Kg][FV]jJeY_
Nf]JJgY[FVmk001[NV]JKg][FV]jJeY_Nf]JJgXTPBRQ984XXBB1::4TPBRQ984XXBB1::4TPBRQ984X
XBB1::4TPBRQ984XXBB1::4TPBRQ984XXBB1::4TPBRQ984XXBB1::4TPBRQJeY[NV]JKg][FV]jJeY_
Nf]J001[FVmkJeY[NV]JKg][FV]jJeXlXSb1?:8hPCbR?84lXSR1?:8lPCbR>84lXSb1?:8hPCbR?84l
XSR1?:8lPCbR>84lXSb1?:8hPCbR?84lXSR1?:8lPCbR>84lXSb1JgY[FVmkJeY[NV]JKg][FV]j001_
Nf]JJgY[FVmkJeY[NV]JKg]@PUBSD89DXe22E:=@PUBSD89DXe22E:=@PUBSD89DXe22E:=@PUBSD89D
Xe22E:=@PUBSD89DXe22E:=@PUBSD89DXe22E:=@PUBSJeY_Nf]JJgY[FVmkJeY[NV]J001[FV]jJeY_
Nf]JJgY[FVmkJeYXY6B3J:ATPfRTI8=XY6B3J:@006QTPfRTI8=XY6B3J:ATPfRTI8=XY6B3J:ATPfRT
I8=XY6B3J:ATPfRTI8=XY6B3J:ATPfRTI8=XY6B3Kg][FV]jJeY_Nf]JJgY[FVmk001[NV]JKg][FV]j
JeY_Nf]JJgYlQ7bUO8AlYGb4O:ElQ7bUO8AlYGb4O:ElQ7bUO8AlYGb4O:ElQ7bUO8AlYGb4O:ElQ7bU
O8AlYGb4O:ElQ7bUO8AlYGb4O:ElQ7bUJeY[NV]JKg][FV]jJeY_Nf]J001[FVmkJeY[NV]JKg][FV]j
0F]J000BJeX09Q214:4@PA2Q484@XA214:4@PA2Q484@XA214:4@PA2Q484@XA214:4@PA2Q484@XA21
4:4@PA2Q484@XA214:4@PA2Q484@XA214:49JeX00`00JeY[FP07JeX09RRQ984XXBR1::4TPBRQ:84X
XBB1::4XPBRQ984XXBR1::4TPBRQ:84XXBB1::4XPBRQ984XXBR1::4TPBRQ:84XXBB1::4XPBRQ9849
JeX00`00JeY[FP07JeX09Sb1?:8lPSbR?84lXSb2?:8lPCbR?88lXSb1?:8lPSbR?84lXSb2?:8lPCbR
?88lXSb1?:8lPSbR?84lXSb2?:8lPCbR?88lXSb1?:89JeX00`00JeY[FP07JeX09U2SD89@Xe22D:=@
PU2SD89@Xe22D:=@PU2SD89@Xe22D:=@PU2SD89@Xe22D:=@PU2SD89@Xe22D:=@PU2SD89@Xe22D:=@
PU2SD889JeX00`00JeY[FP07JeX09VR3J:ATPfRSJ8=XY6B3J:=XPfRTI8=XXfR3J:ATPfRSJ8=XY6B3
J:=XPfRTI8=XXfR3J:ATPfRSJ8=XY6B3J:=XPfRTI8=XXfR3J:@9JeX00`00JeY[FP07JeX09WbTO8Al
Y7b4O:AlQ7bTO8AlY7b4O:AlQ7bTO8AlY7b4O:AlQ7bTO8AlY7b4O:AlQ7bTO8AlY7b4O:AlQ7bTO8Al
Y7b4O:AlQ7bTO8@9JeX00`00JeY[FP07JeX0003oJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmk
JeY[NV]JKg/@PABQ480DXA215:4@P1BQ484DXA205:4@PABQ480DXA215:4@P1BQ484DXA205:4@PABQ
480DXA215:4@P1BQ484DXA205:5[FV]jJeY_Nf]JJgY[FVmkJeY[NP00Kg][FV]jJeY_Nf]JJgY[FVmk
JeXXXBB1::4TPBRQ984XXBB1::4TPBRQ984XXBB1::4TPBRQ984XXBB1::4TPBRQ984XXBB1::4TPBRQ
984XXBB1::4TPBRQ985[NV]JKg][FV]jJeY_Nf]JJgY[FP00JeY[NV]JKg][FV]jJeY_Nf]JJgXhPCbR
?84lXSR1?:8lPCbR>84lXSb1?:8hPCbR?84lXSR1?:8lPCbR>84lXSb1?:8hPCbR?84lXSR1?:8lPCbR
>84lXSb1?:9[FVmkJeY[NV]JKg][FV]jJeY_N`00JgY[FVmkJeY[NV]JKg][FV]jJeYDXe22E:=@PUBS
D89DXe22E:=@PUBSD89DXe22E:=@PUBSD89DXe22E:=@PUBSD89DXe22E:=@PUBSD89DXe22E:=@PUBS
D89_Nf]JJgY[FVmkJeY[NV]JKg][FP00JeY_Nf]JJgY[FVmkJeY[NV]JKg]TPfRTI8=XY6B3J:ATPfRT
001XI8=XY6B3J:ATPfRTI8=XY6B3J:ATPfRTI8=XY6B3J:ATPfRTI8=XY6B3J:ATPfRTI8=XY6B3J:A[
FV]jJeY_Nf]JJgY[FVmkJeY[NP00Kg][FV]jJeY_Nf]JJgY[FVmkO8AlYGb4O:ElQ7bUO8AlYGb4O:El
Q7bUO8AlYGb4O:ElQ7bUO8AlYGb4O:ElQ7bUO8AlYGb4O:ElQ7bUO8AlYGb4O:ElQ7bUO8A[NV]JKg][
FV]jJeY_Nf]JJgY[FP00JeY[NV]JKg][FV]jJeY_N`5[FP004f]J02@@XA214:4@PA2Q484@XA214:4@
PA2Q484@XA214:4@PA2Q484@XA214:4@PA2Q484@XA214:4@PA2Q484@XA214:4@PA2Q484:JeX00`00
JeY[FP08JeX092R1::4TPBRQ:84XXBB1::4XPBRQ984XXBR1::4TPBRQ:84XXBB1::4XPBRQ984XXBR1
::4TPBRQ:84XXBB1::4XPBRQ984XX@Y[FP03001[FV]J00Q[FP0T?:8lPCbR?88lXSb1?:8lPSbR?84l
XSb2?:8lPCbR?88lXSb1?:8lPSbR?84lXSb2?:8lPCbR?88lXSb1?:8lPSbR?84lXSb22V]J00<006]J
JeX026]J02A@PU2SD89@Xe22D:=@PU2SD89@Xe22D:=@PU2SD89@Xe22D:=@PU2SD89@Xe22D:=@PU2S
D89@Xe22D:=@PU2SD89@Xe22D:<:JeX00`00JeY[FP08JeX096RSJ8=XY6B3J:=XPfRTI8=XXfR3J:AT
PfRSJ8=XY6B3J:=XPfRTI8=XXfR3J:ATPfRSJ8=XY6B3J:=XPfRTI8=XXfR3J:ATP`Y[FP03001[FV]J
00M[FP0UO:AlQ7bTO8AlY7b4O:AlQ7bTO8AlY7b4O:AlQ7bTO8AlY7b4O:AlQ7bTO8AlY7b4O:AlQ7bT
O8AlY7b4O:AlQ7bTO8AlY7b4O:@02V]J00<006]JJeX01f]J0000ofmkJeY[NV]JKg][FV]jJeY_Nf]J
JgY[FVmkJeY[NV]JKg][FV]jJeXDXA215:4@P1BQ484DXA205:4@PABQ480DXA215:4@P1BQ484DXA20
5:4@PABQ480DXA215:4@P1BQ484DXA205:4@PF]jJeY_Nf]JJgY[FVmkJeY[NV]JKg/006]jJeY_Nf]J
JgY[FVmkJeY[NV]JKg/TPBRQ984XXBB1::4TPBRQ984XXBB1::4TPBRQ984XXBB1::4TPBRQ984XXBB1
::4TPBRQ984XXBB1::4TPBRQ984XXF]JKg][FV]jJeY_Nf]JJgY[FVmkJeX006]JKg][FV]jJeY_Nf]J
JgY[FVmk?84lXSR1?:8lPCbR>84lXSb1?:8hPCbR?84lXSR1?:8lPCbR>84lXSb1?:8hPCbR?84lXSR1
?:8lPCbR>84lXSb1?:8hPFmkJeY[NV]JKg][FV]jJeY_Nf]JJgX006mkJeY[NV]JKg][FV]jJeY_Nf]J
E:=@PUBSD89DXe22E:=@PUBSD89DXe22E:=@PUBSD89DXe22E:=@PUBSD89DXe22E:=@PUBSD89DXe22
E:=@PUBSD89DXf]JJgY[FVmkJeY[NV]JKg][FV]jJeX006]JJgY[FVmkJeY[NV]JKg][FV]jI8=XY6B3
J:ATPfRTI8=XY000J6B3J:ATPfRTI8=XY6B3J:ATPfRTI8=XY6B3J:ATPfRTI8=XY6B3J:ATPfRTI8=X
Y6B3J:ATPf]jJeY_Nf]JJgY[FVmkJeY[NV]JKg/006]jJeY_Nf]JJgY[FVmkJeY[NV]JO:ElQ7bUO8Al
YGb4O:ElQ7bUO8AlYGb4O:ElQ7bUO8AlYGb4O:ElQ7bUO8AlYGb4O:ElQ7bUO8AlYGb4O:ElQ7bUO8Al
YF]JKg][FV]jJeY_Nf]JJgY[FVmkJeX006]JKg][FV]jJeY_Nf]JJgX1JeX001A[FP0R484@XA214:4@
PA2Q484@XA214:4@PA2Q484@XA214:4@PA2Q484@XA214:4@PA2Q484@XA214:4@PA2Q484@XA214:4;
JeX00`00JeY[FP09JeX08RRQ:84XXBB1::4XPBRQ984XXBR1::4TPBRQ:84XXBB1::4XPBRQ984XXBR1
::4TPBRQ:84XXBB1::4XPBRQ984XXBR12f]J00<006]JJeX026]J02<lXSb2?:8lPCbR?88lXSb1?:8l
PSbR?84lXSb2?:8lPCbR?88lXSb1?:8lPSbR?84lXSb2?:8lPCbR?88lXSb1?:8lPSbR00][FP03001[
FV]J00Q[FP0SD89@Xe22D:=@PU2SD89@Xe22D:=@PU2SD89@Xe22D:=@PU2SD89@Xe22D:=@PU2SD89@
Xe22D:=@PU2SD89@Xe22D:=@PP0;JeX00`00JeY[FP08JeX08fRTI8=XXfR3J:ATPfRSJ8=XY6B3J:=X
PfRTI8=XXfR3J:ATPfRSJ8=XY6B3J:=XPfRTI8=XXfR3J:ATPfRSJ8=XY6B3J:<02f]J00<006]JJeX0
26]J02=lQ7bTO8AlY7b4O:AlQ7bTO8AlY7b4O:AlQ7bTO8AlY7b4O:AlQ7bTO8AlY7b4O:AlQ7bTO8Al
Y7b4O:AlQ7bTO8AlY7b400][FP03001[FV]J00M[FP000?m[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[
NV]JKg][FV]jJeY_Nf]JJgX@P1BQ484DXA205:4@PABQ480DXA215:4@P1BQ484DXA205:4@PABQ480D
XA215:4@P1BQ484DXA205:4@PABQJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]j001_Nf]JJgY[FVmkJeY[
NV]JKg][FV]jJeXXXBB1::4TPBRQ984XXBB1::4TPBRQ984XXBB1::4TPBRQ984XXBB1::4TPBRQ984X
XBB1::4TPBRQ984XXBB1Kg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]J001[FV]jJeY_Nf]JJgY[FVmkJeY[
NV]J?:8lPCbR>84lXSb1?:8hPCbR?84lXSR1?:8lPCbR>84lXSb1?:8hPCbR?84lXSR1?:8lPCbR>84l
XSb1?:8hPCbRJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmk001[NV]JKg][FV]jJeY_Nf]JJgY[FVmkD89D
Xe22E:=@PUBSD89DXe22E:=@PUBSD89DXe22E:=@PUBSD89DXe22E:=@PUBSD89DXe22E:=@PUBSD89D
Xe22JgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]J001[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJ:ATPfRTI8=X
Y6B3J:@006QTPfRTI8=XY6B3J:ATPfRTI8=XY6B3J:ATPfRTI8=XY6B3J:ATPfRTI8=XY6B3J:ATPfRT
JeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]j001_Nf]JJgY[FVmkJeY[NV]JKg][FV]jO8AlYGb4O:ElQ7bU
O8AlYGb4O:ElQ7bUO8AlYGb4O:ElQ7bUO8AlYGb4O:ElQ7bUO8AlYGb4O:ElQ7bUO8AlYGb4Kg][FV]j
JeY_Nf]JJgY[FVmkJeY[NV]J001[FV]jJeY_Nf]JJgY[FVmk0F]J000EJeX07a2Q484@XA214:4@PA2Q
484@XA214:4@PA2Q484@XA214:4@PA2Q484@XA214:4@PA2Q484@XA214:4@PA2Q00e[FP03001[FV]J
00Y[FP0O984XXBR1::4TPBRQ:84XXBB1::4XPBRQ984XXBR1::4TPBRQ:84XXBB1::4XPBRQ984XXBR1
::4TPBRQ:8403F]J00<006]JJeX02V]J01llXSb2?:8lPCbR?88lXSb1?:8lPSbR?84lXSb2?:8lPCbR
?88lXSb1?:8lPSbR?84lXSb2?:8lPCbR?88lXP0=JeX00`00JeY[FP0:JeX07e22D:=@PU2SD89@Xe22
D:=@PU2SD89@Xe22D:=@PU2SD89@Xe22D:=@PU2SD89@Xe22D:=@PU2SD89@Xe2200e[FP03001[FV]J
00Y[FP0OJ:ATPfRSJ8=XY6B3J:=XPfRTI8=XXfR3J:ATPfRSJ8=XY6B3J:=XPfRTI8=XXfR3J:ATPfRS
J8=XY6B3J:<03F]J00<006]JJeX02V]J01mlQ7bTO8AlY7b4O:AlQ7bTO8AlY7b4O:AlQ7bTO8AlY7b4
O:AlQ7bTO8AlY7b4O:AlQ7bTO8AlY7b4O:AlQ00=JeX00`00JeY[FP07JeX0003oKg][FV]jJeY_Nf]J
JgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeXDXA205:4@PABQ480DXA215:4@P1BQ484DXA20
5:4@PABQ480DXA215:4@P1BQ484DXA205:4@PABQJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_N`00
JgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgXTPBRQ984XXBB1::4TPBRQ984XXBB1::4TPBRQ984XXBB1
::4TPBRQ984XXBB1::4TPBRQ984XXBB1Kg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FP00JeY_Nf]J
JgY[FVmkJeY[NV]JKg][FV]jJeXlXSb1?:8hPCbR?84lXSR1?:8lPCbR>84lXSb1?:8hPCbR?84lXSR1
?:8lPCbR>84lXSb1?:8hPCbRJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NP00Kg][FV]jJeY_Nf]J
JgY[FVmkJeY[NV]JKg]@PUBSD89DXe22E:=@PUBSD89DXe22E:=@PUBSD89DXe22E:=@PUBSD89DXe22
E:=@PUBSD89DXe22JgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FP00JeY[NV]JKg][FV]jJeY_Nf]J
JgY[FVmkJeYXY6B3J:ATPfRT001XI8=XY6B3J:ATPfRTI8=XY6B3J:ATPfRTI8=XY6B3J:ATPfRTI8=X
Y6B3J:ATPfRTJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_N`00JgY[FVmkJeY[NV]JKg][FV]jJeY_
Nf]JJgYlQ7bUO8AlYGb4O:ElQ7bUO8AlYGb4O:ElQ7bUO8AlYGb4O:ElQ7bUO8AlYGb4O:ElQ7bUO8Al
YGb4Kg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FP00JeY_Nf]JJgY[FVmkJeY[NP5[FP005f]J01/@
XA214:4@PA2Q484@XA214:4@PA2Q484@XA214:4@PA2Q484@XA214:4@PA2Q484@XA214:403f]J00<0
06]JJeX036]J01/TPBRQ:84XXBB1::4XPBRQ984XXBR1::4TPBRQ:84XXBB1::4XPBRQ984XXBR1::4T
PBRQ:8403f]J00<006]JJeX036]J01/lXSb2?:8lPCbR?88lXSb1?:8lPSbR?84lXSb2?:8lPCbR?88l
XSb1?:8lPSbR?84lXSb2?:803f]J00<006]JJeX036]J01]@PU2SD89@Xe22D:=@PU2SD89@Xe22D:=@
PU2SD89@Xe22D:=@PU2SD89@Xe22D:=@PU2SD8803f]J00<006]JJeX036]J01]XY6B3J:=XPfRTI8=X
XfR3J:ATPfRSJ8=XY6B3J:=XPfRTI8=XXfR3J:ATPfRSJ8=XY6B3J:<03f]J00<006]JJeX036]J01]l
Q7bTO8AlY7b4O:AlQ7bTO8AlY7b4O:AlQ7bTO8AlY7b4O:AlQ7bTO8AlY7b4O:AlQ7bTO8@03f]J00<0
06]JJeX01f]J0000of]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][
FQBQ480DXA215:4@P1BQ484DXA205:4@PABQ480DXA215:4@P1BQ484DXA205:4@PABQJeY_Nf]JJgY[
FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgX006mkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NRB1::4T
PBRQ984XXBB1::4TPBRQ984XXBB1::4TPBRQ984XXBB1::4TPBRQ984XXBB1Kg][FV]jJeY_Nf]JJgY[
FVmkJeY[NV]JKg][FV]jJeX006]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FSbR?84lXSR1?:8l
PCbR>84lXSb1?:8hPCbR?84lXSR1?:8lPCbR>84lXSb1?:8hPCbRJeY[NV]JKg][FV]jJeY_Nf]JJgY[
FVmkJeY[NV]JKg/006]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Ne22E:=@PUBSD89DXe22E:=@
PUBSD89DXe22E:=@PUBSD89DXe22E:=@PUBSD89DXe22JgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[
FVmkJeX006]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FVRTI8=XY000J6B3J:ATPfRTI8=XY6B3
J:ATPfRTI8=XY6B3J:ATPfRTI8=XY6B3J:ATPfRTJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]J
JgX006mkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NWb4O:ElQ7bUO8AlYGb4O:ElQ7bUO8AlYGb4
O:ElQ7bUO8AlYGb4O:ElQ7bUO8AlYGb4Kg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeX006]J
JgY[FVmkJeY[NV]JKg/1JeX001U[FP0F4:4@PA2Q484@XA214:4@PA2Q484@XA214:4@PA2Q484@XA21
4:4@PA2Q484BJeX00`00JeY[FP0>JeX05RB1::4XPBRQ984XXBR1::4TPBRQ:84XXBB1::4XPBRQ984X
XBR1::4TPBRQ4V]J00<006]JJeX03V]J01HlXSb2?:8lPCbR?88lXSb1?:8lPSbR?84lXSb2?:8lPCbR
?88lXSb1?:8lPQ9[FP03001[FV]J00i[FP0FD89@Xe22D:=@PU2SD89@Xe22D:=@PU2SD89@Xe22D:=@
PU2SD89@Xe22D:<BJeX00`00JeY[FP0>JeX05VRTI8=XXfR3J:ATPfRSJ8=XY6B3J:=XPfRTI8=XXfR3
J:ATPfRSJ8=XY6B34V]J00<006]JJeX03V]J01IlQ7bTO8AlY7b4O:AlQ7bTO8AlY7b4O:AlQ7bTO8Al
Y7b4O:AlQ7bTO8AlY19[FP03001[FV]J00M[FP000?m_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]J
JgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgX@P1BQ484DXA205:4@PABQ480DXA215:4@P1BQ484DXA20
5:4@PF]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmk001[NV]JKg][FV]jJeY_Nf]J
JgY[FVmkJeY[NV]JKg][FV]jJeXXXBB1::4TPBRQ984XXBB1::4TPBRQ984XXBB1::4TPBRQ984XXF]J
Kg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]J001[FVmkJeY[NV]JKg][FV]jJeY_Nf]J
JgY[FVmkJeY[NV]JKg/lPCbR>84lXSb1?:8hPCbR?84lXSR1?:8lPCbR>84lXSb1?:8hPFmkJeY[NV]J
Kg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]j001_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]J
JgY[FVmkJeYDXe22E:=@PUBSD89DXe22E:=@PUBSD89DXe22E:=@PUBSD89DXf]JJgY[FVmkJeY[NV]J
Kg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]J001[FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]J
JgX006QTPfRTI8=XY6B3J:ATPfRTI8=XY6B3J:ATPfRTI8=XY6B3J:ATPf]jJeY_Nf]JJgY[FVmkJeY[
NV]JKg][FV]jJeY_Nf]JJgY[FVmk001[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jO8Al
YGb4O:ElQ7bUO8AlYGb4O:ElQ7bUO8AlYGb4O:ElQ7bUO8AlYF]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[
NV]JKg][FV]jJeY_Nf]J001[FVmkJeY[NV]JKg][FV]j0F]J000LJeX041214:4@PA2Q484@XA214:4@
PA2Q484@XA214:4@PA2Q5F]J00<006]JJeX04F]J010XXBR1::4TPBRQ:84XXBB1::4XPBRQ984XXBR1
::4TPAE[FP03001[FV]J015[FP0@?88lXSb1?:8lPSbR?84lXSb2?:8lPCbR?88lXSb1?:8EJeX00`00
JeY[FP0AJeX0452SD89@Xe22D:=@PU2SD89@Xe22D:=@PU2SD89@Xe225F]J00<006]JJeX04F]J011T
PfRSJ8=XY6B3J:=XPfRTI8=XXfR3J:ATPfRSJ8=XY1E[FP03001[FV]J015[FP0@O:AlQ7bTO8AlY7b4
O:AlQ7bTO8AlY7b4O:AlQ7bTO8@EJeX00`00JeY[FP07JeX0003oJgY[FVmkJeY[NV]JKg][FV]jJeY_
Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FQBQ480DXA215:4@P1BQ484D
XA20Kg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NP00Kg][FV]jJeY_
Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NRB1::4TPBRQ984XXBB1::4TPBRQJeY[
NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FP00JeY[NV]JKg][FV]jJeY_
Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FSbR?84lXSR1?:8lPCbR>84lXSb1JgY[FVmkJeY[
NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_N`00JgY[FVmkJeY[NV]JKg][FV]jJeY_
Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Ne22E:=@PUBSD89DXe22E:=@PUBSJeY_Nf]JJgY[FVmkJeY[
NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FP00JeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_
Nf]JJgY[FVmk001XJeY[NV]JKg][FVRTI8=XY6B3J:ATPfRTI8=XY6B3Kg][FV]jJeY_Nf]JJgY[FVmk
JeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NP00Kg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]j
JeY_Nf]JJgY[FVmkJeY[NWb4O:ElQ7bUO8AlYGb4O:ElQ7bUJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmk
JeY[NV]JKg][FV]jJeY_Nf]JJgY[FP00JeY[NV]JKg][FV]jJeY_N`5[FP00@F]J00<006]JJeX0=V]J
00<006]JJeX0=V]J00<006]JJeX0=V]J00<006]JJeX0=V]J00<006]JJeX0=V]J00<006]JJeX01f]J
0000ofmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]J
Kg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]J
JgY[FVmkJeY[NV]JKg/006]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]J
Kg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]J
JgY[FVmkJeX006]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]J
Kg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]J
JgX006mkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]J
Kg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeX006]J
JgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NP00J6]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[
NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg/006]jJeY_
Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[
NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeX006]JKg][FV]jJeY_
Nf]JJgX1JeX0045[FP03001[FV]J03I[FP03001[FV]J03I[FP03001[FV]J03I[FP03001[FV]J03I[
FP03001[FV]J03I[FP03001[FV]J00M[FP000?m[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][
FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[
FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]j001_Nf]JJgY[FVmkJeY[NV]JKg][
FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[
FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]J001[FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][
FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[
FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmk001[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][
FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[
FVmkJeY[NV]JKg][FV]jJeY_Nf]J001[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg/0
06Q[FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]J
JgY[FVmkJeY[NV]JKg][FV]j001_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]J
Kg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]J
JgY[FVmkJeY[NV]J001[FV]jJeY_Nf]JJgY[FVmk0F]J0011JeX00`00JeY[FP0fJeX00`00JeY[FP0f
JeX00`00JeY[FP0fJeX00`00JeY[FP0fJeX00`00JeY[FP0fJeX00`00JeY[FP07JeX0003oKg][FV]j
JeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmk
JeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]j
JeY_N`00JgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmk
JeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FP00
JeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmk
JeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NP00Kg][FV]j
JeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmk
JeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FP00JeY[NV]JKg][FV]j
JeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]j001XJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[
FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_N`00JgY[FVmkJeY[NV]JKg][
FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[
FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FP00JeY_Nf]JJgY[FVmkJeY[NP5[FP00
@F]J00<006]JJeX0=V]J00<006]JJeX0=V]J00<006]JJeX0=V]J00<006]JJeX0=V]J00<006]JJeX0
=V]J00<006]JJeX01f]J0000of]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[
NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_
Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgX006mkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[
NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_
Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeX006]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[
NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_
Nf]JJgY[FVmkJeY[NV]JKg/006]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[
NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_
Nf]JJgY[FVmkJeX006]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_N`00J6]JJgY[FVmk
JeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]j
JeY_Nf]JJgX006mkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmk
JeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]j
JeX006]JJgY[FVmkJeY[NV]JKg/1JeX000Q[FSX003Q[FP03001[FV]J03I[FP03001[FV]J03I[FP03
001[FV]J03I[FP03001[FV]J03I[FP03001[FV]J00M[FP000?m_Nf]JJgY[FVmkJeY[NV]JKg][FV]j
JeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmk
JeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]j
JeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmk
JeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]J001[FVmkJeY[NV]JKg][FV]j
JeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmk
JeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]j001_Nf]JJgY[FVmkJeY[NV]JKg][FV]j
JeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmk
JeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]J001[FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]j
JeY_Nf]JJgX006Q[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[
FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmk001[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][
FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[
FVmkJeY[NV]JKg][FV]jJeY_Nf]J001[FVmkJeY[NV]JKg][FV]j0F]J001jJeX00`00JeY[FP0fJeX0
0`00JeY[FP0fJeX00`00JeY[FP0fJeX00`00JeY[FP0fJeX00`00JeY[FP07JeX0003oJgY[FVmkJeY[
NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_
Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[
NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_
Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FP00JeY[
NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_
Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_N`00JgY[FVmkJeY[
NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_
Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FP00JeY_Nf]JJgY[FVmkJeY[
NV]JKg][FV]jJeY_Nf]JJgY[FVmk001XJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]j
JeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NP00Kg][FV]jJeY_Nf]JJgY[FVmk
JeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]j
JeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FP00JeY[NV]JKg][FV]jJeY_N`5[FP00NV]J
00<006]JJeX0=V]J00<006]JJeX0=V]J00<006]JJeX0=V]J00<006]JJeX0=V]J00<006]JJeX01f]J
0000ofmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]J
Kg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]J
JgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]J
Kg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]J
JgY[FVmkJeX006]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]J
Kg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]J
JgX006mkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]J
Kg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeX006]J
JgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NP00J6]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[
NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg/006]jJeY_
Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[
NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeX006]JKg][FV]jJeY_
Nf]JJgX1JeX007Y[FP03001[FV]J03I[FP03001[FV]J03I[FP03001[FV]J03I[FP03001[FV]J03I[
FP03001[FV]J00M[FP000?m[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[
FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][
FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[
FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][
FV]jJeY_Nf]JJgY[FVmkJeY[NV]J001[FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[
FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][
FV]jJeY_Nf]JJgY[FVmk001[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[
FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][
FV]jJeY_Nf]J001[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg/006Q[FV]jJeY_Nf]J
JgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]J
Kg][FV]j001_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]J
JgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]J
001[FV]jJeY_Nf]JJgY[FVmk0F]J001jJeX00`00JeY[FP0fJeX00`00JeY[FP0fJeX00`00JeY[FP0f
JeX00`00JeY[FP0fJeX00`00JeY[FP07JeX0003oKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]j
JeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmk
JeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]j
JeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmk
JeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FP00JeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]j
JeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmk
JeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NP00Kg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]j
JeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmk
JeY[NV]JKg][FV]jJeY_Nf]JJgY[FP00JeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]j
001XJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[
FVmkJeY[NV]JKg][FV]jJeY_N`00JgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][
FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[
FVmkJeY[NV]JKg][FP00JeY_Nf]JJgY[FVmkJeY[NP5[FP007V]J3Q51:f]J00hY@bE2:D<Y@RU39D8Y
@bU2:D<U@RU3:D8Y@bE25F]J00<006]JJeX04f]J3Se45F]J00<006]JJeX04f]J3U565F]J00<006]J
JeX04f]J0VU800EUB6U8JDQYB6E800=YB004IDQYB6U8JDPEJeX00`00JeY[FP0CJeX00ge:ODUmBP02
ODX01Ge9ODYmBWe:ODT00ge:00=mBF]JJeX04f]J00<006]JJeX01f]J0000of]jJeY_Nf]JJgY[FVmk
JeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Na515D4A@AE14D4E@A515D4A@AE1
4D4E@A515D4A@AE14D4E@A51Kg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmk
JeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FRU39D8Y@bE2:D<U@RU39D8Y@bE2:D<U@RU3
9D8Y@bE2:D<U@RU3JeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeX006]JJgY[FVmk
JeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NSU4?DDmA3e5>D@mACe4?DDiA3e5?D@mACU4?DDmA3e5
>D@mACe4JgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg/006]jJeY_Nf]JJgY[FVmk
JeY[NV]JKg][FV]jJeY_Nf]JJgY[FUE6DDIEAU56EDIAAUE6DDIEAU56EDIAAUE6DDIEAU56EDIAAUE6
JeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeX006]JKg][FV]jJeY_Nf]JJgY[FVmk
JeY[NV]JKg][FV]jJeY_N`00J6E8JDQUAfU8IDQYB6E7JDQUB6U8IDMYB6E8JDQUAfU8IDQYB6E7Kg][
FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgX006mkJeY[NV]JKg][FV]jJeY_Nf]JJgY[
FVmkJeY[NV]JKg]mBGe:ODUmBWe9ODYmBGe:ODUmBWe9ODYmBGe:ODUmBWe9ODYmBGe:JeY[NV]JKg][
FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeX006]JJgY[FVmkJeY[NV]JKg/1JeX001U[FQHA@B=[
FP0F9D8Y@bU2:D<U@RU3:D8Y@bE2:D<Y@RU39D8Y@bU2:D<U@RU3:D8Y@bE2:D<BJeX00`00JeY[FP0>
JeXF?D@BJeX00`00JeY[FP0>JeXFDDHBJeX00`00JeY[FP0>JeX00fU8IDQYB002JDP01FE8JDQYB6U8
IDP00fU800EUB6U8JDQYB6E800=YB003IDQ[FV]J011[FP03001[FV]J00i[FP05ODUmBWe:ODYmB@03
ODX01Ge9ODYmBWe:ODT00ge:00ImBGe:ODYmBWe9ODXBJeX00`00JeY[FP07JeX0003oKg][FV]jJeY_
Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]J5D4A@AE14D4E@A515D4A@AE14D4E
@A515D4A@AE14D4E@A515D4A@AE14D4E@A515D5[FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_
Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmk9D8Y@bE2:D<U@RU39D8Y@bE2:D<U@RU39D8Y
@bE2:D<U@RU39D8Y@bE2:D<U@RU39D9[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FP00JeY_
Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]J?DDiA3e5?D@mACU4?DDmA3e5>D@mACe4?DDiA3e5?D@m
ACU4?DDmA3e5>D@mACe4?DE[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NP00Kg][FV]jJeY_
Nf]JJgY[FVmkJeY[NV]JKg][FV]jDDIEAU56EDIAAUE6DDIEAU56EDIAAUE6DDIEAU56EDIAAUE6DDIE
AU56EDIAAUE6DDI_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FP00JeY[NV]JKg][FV]jJeY_
Nf]JJgY[FVmkJeY[NV]JJDQUB6U8001XIDMYB6E8JDQUAfU8IDQYB6E7JDQUB6U8IDMYB6E8JDQUAfU8
IDQYB6E7JDQ[FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_N`00JgY[FVmkJeY[NV]JKg][FV]j
JeY_Nf]JJgY[FVmkODUmBWe9ODYmBGe:ODUmBWe9ODYmBGe:ODUmBWe9ODYmBGe:ODUmBWe9ODYmBGe:
ODU[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FP00JeY_Nf]JJgY[FVmkJeY[NP5[FP005f]J
6a517V]J01/U@RU3:D8Y@bE2:D<Y@RU39D8Y@bU2:D<U@RU3:D8Y@bE2:D<Y@RU39D8Y@bU2:D<U@RU3
:D803f]J00<006]JJeX036]J6ce43f]J00<006]JJeX036]J6e563f]J00<006]JJeX036]J00=YB6E8
JDP00VU800EUB6U8JDQYB6E800=YB005IDQYB6U8JDQUB003JDP01VE8JDQYB6U8IDQYB0m[FP03001[
FV]J00a[FP05ODUmBWe:ODYmB@03ODX01Ge9ODYmBWe:ODT00ge:00EmBGe:ODYmBWe900=mBP03ODUm
BWe:00m[FP03001[FV]J00M[FP000?m[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_
Nf]JJgY[FQE14D4E@A515D4A@AE14D4E@A515D4A@AE14D4E@A515D4A@AE14D4E@A515D4A@AE14D4E
@A515D5[FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_
NbE2:D<U@RU39D8Y@bE2:D<U@RU39D8Y@bE2:D<U@RU39D8Y@bE2:D<U@RU39D8Y@bE2:D<U@RU39D9[
NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]J001[FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FSe5>D@m
ACe4?DDiA3e5?D@mACU4?DDmA3e5>D@mACe4?DDiA3e5?D@mACU4?DDmA3e5>D@mACe4?DE[FVmkJeY[
NV]JKg][FV]jJeY_Nf]JJgY[FVmk001[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NU56EDIAAUE6DDIE
AU56EDIAAUE6DDIEAU56EDIAAUE6DDIEAU56EDIAAUE6DDIEAU56EDIAAUE6DDI_Nf]JJgY[FVmkJeY[
NV]JKg][FV]jJeY_Nf]J001[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVU8IDQYB6E7JDP006QUB6U8
IDMYB6E8JDQUAfU8IDQYB6E7JDQUB6U8IDMYB6E8JDQUAfU8IDQYB6E7JDQ[FV]jJeY_Nf]JJgY[FVmk
JeY[NV]JKg][FV]j001_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nge9ODYmBGe:ODUmBWe9ODYmBGe:
ODUmBWe9ODYmBGe:ODUmBWe9ODYmBGe:ODUmBWe9ODYmBGe:ODU[NV]JKg][FV]jJeY_Nf]JJgY[FVmk
JeY[NV]J001[FV]jJeY_Nf]JJgY[FVmk0F]J000EJeXO4D4JJeX07bE2:D<Y@RU39D8Y@bU2:D<U@RU3
:D8Y@bE2:D<Y@RU39D8Y@bU2:D<U@RU3:D8Y@bE2:D<Y@RU39D8Y@bU200e[FP03001[FV]J00Y[FQlm
A0e[FP03001[FV]J00Y[FQmAAPe[FP03001[FV]J00Y[FP03JDQUB6U8009YB005IDQYB6U8JDQUB003
JDP01FE8JDQYB6U8IDP00fU800EUB6U8JDQYB6E800=YB003IDQYB6]J00a[FP03001[FV]J00Y[FP05
ODUmBWe:ODYmB@03ODX01Ge9ODYmBWe:ODT00ge:00EmBGe:ODYmBWe900=mBP05ODUmBWe:ODYmB@02
ODX=JeX00`00JeY[FP07JeX0003oKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[
FVmk4D4E@A515D4A@AE14D4E@A515D4A@AE14D4E@A515D4A@AE14D4E@A515D4A@AE14D4E@A515D4A
@AE14D4E@F]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]J:D<U
@RU39D8Y@bE2:D<U@RU39D8Y@bE2:D<U@RU39D8Y@bE2:D<U@RU39D8Y@bE2:D<U@RU39D8Y@bE2:D<U
@V]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FP00JeY_Nf]JJgY[FVmkJeY[NV]JKg][FSe5>D@mACe4?DDi
A3e5?D@mACU4?DDmA3e5>D@mACe4?DDiA3e5?D@mACU4?DDmA3e5>D@mACe4?DDiA3e5?D@mAF]JKg][
FV]jJeY_Nf]JJgY[FVmkJeY[NP00Kg][FV]jJeY_Nf]JJgY[FVmkJeY[NU56EDIAAUE6DDIEAU56EDIA
AUE6DDIEAU56EDIAAUE6DDIEAU56EDIAAUE6DDIEAU56EDIAAUE6DDIEAU56EDIAAVmkJeY[NV]JKg][
FV]jJeY_Nf]JJgY[FP00JeY[NV]JKg][FV]jJeY_Nf]JJgY[FVU8IDQYB6E7JDQUB6U8001XIDMYB6E8
JDQUAfU8IDQYB6E7JDQUB6U8IDMYB6E8JDQUAfU8IDQYB6E7JDQUB6U8IDMYB6]JJgY[FVmkJeY[NV]J
Kg][FV]jJeY_N`00JgY[FVmkJeY[NV]JKg][FV]jJeY_Nge9ODYmBGe:ODUmBWe9ODYmBGe:ODUmBWe9
ODYmBGe:ODUmBWe9ODYmBGe:ODUmBWe9ODYmBGe:ODUmBWe9ODYmBF]jJeY_Nf]JJgY[FVmkJeY[NV]J
Kg][FP00JeY_Nf]JJgY[FVmkJeY[NP5[FP0056]J8Q515f]J028Y@bU2:D<U@RU3:D8Y@bE2:D<Y@RU3
9D8Y@bU2:D<U@RU3:D8Y@bE2:D<Y@RU39D8Y@bU2:D<U@RU3:D8Y@bE2:D<Y@P][FP03001[FV]J00Q[
FR<mA0][FP03001[FV]J00Q[FR=AAP][FP03001[FV]J00Q[FP03JDQUB6U8009YB005IDQYB6U8JDQU
B003JDP01FE8JDQYB6U8IDP00fU800EUB6U8JDQYB6E800=YB006IDQYB6U8JDQUB6U82f]J00<006]J
JeX026]J00EmBGe:ODYmBWe900=mBP05ODUmBWe:ODYmB@03ODX01Ge9ODYmBWe:ODT00ge:00EmBGe:
ODYmBWe900=mBP03ODUmBWe:00][FP03001[FV]J00M[FP000?m[NV]JKg][FV]jJeY_Nf]JJgY[FVmk
JeY[NV]JKg][FV]jJeY_Nf]J5D4A@AE14D4E@A515D4A@AE14D4E@A515D4A@AE14D4E@A515D4A@AE1
4D4E@A515D4A@AE14D4E@A515D4A@AE14D5_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmk
JeY[NV]JKg][FV]j9D8Y@bE2:D<U@RU39D8Y@bE2:D<U@RU39D8Y@bE2:D<U@RU39D8Y@bE2:D<U@RU3
9D8Y@bE2:D<U@RU39D8Y@bE2:D=[FV]jJeY_Nf]JJgY[FVmkJeY[NV]J001[FV]jJeY_Nf]JJgY[FVmk
JeY[NSU4?DDmA3e5>D@mACe4?DDiA3e5?D@mACU4?DDmA3e5>D@mACe4?DDiA3e5?D@mACU4?DDmA3e5
>D@mACe4?DDiA3e5?DA[NV]JKg][FV]jJeY_Nf]JJgY[FVmk001[NV]JKg][FV]jJeY_Nf]JJgY[FUE6
DDIEAU56EDIAAUE6DDIEAU56EDIAAUE6DDIEAU56EDIAAUE6DDIEAU56EDIAAUE6DDIEAU56EDIAAUE6
DDIEAU56EDI[FVmkJeY[NV]JKg][FV]jJeY_Nf]J001[FVmkJeY[NV]JKg][FV]jJeY_NfE8JDQUAfU8
IDQYB6E7JDP006QUB6U8IDMYB6E8JDQUAfU8IDQYB6E7JDQUB6U8IDMYB6E8JDQUAfU8IDQYB6E7JDQU
B6U8IDM_Nf]JJgY[FVmkJeY[NV]JKg][FV]j001_Nf]JJgY[FVmkJeY[NV]JKg][FWe:ODUmBWe9ODYm
BGe:ODUmBWe9ODYmBGe:ODUmBWe9ODYmBGe:ODUmBWe9ODYmBGe:ODUmBWe9ODYmBGe:ODUmBWe9ODY[
FV]jJeY_Nf]JJgY[FVmkJeY[NV]J001[FV]jJeY_Nf]JJgY[FVmk0F]J000CJeXT4D4EJeX092U2:D<U
@RU3:D8Y@bE2:D<Y@RU39D8Y@bU2:D<U@RU3:D8Y@bE2:D<Y@RU39D8Y@bU2:D<U@RU3:D8Y@bE2:D<Y
@RU39D8Y@`Y[FP03001[FV]J00Q[FR@mA0Y[FP03001[FV]J00Q[FRAAAPY[FP03001[FV]J00Q[FP=Y
B005IDQYB6U8JDQUB003JDP01FE8JDQYB6U8IDP00fU800EUB6U8JDQYB6E800=YB005IDQYB6U8JDQU
B003JDP00fE8JeY[FP08JeX00`00JeY[FP07JeX3ODX01Ge9ODYmBWe:ODT00ge:00EmBGe:ODYmBWe9
00=mBP05ODUmBWe:ODYmB@03ODX01Ge9ODYmBWe:ODT00ge:00=mBGe:JeX02F]J00<006]JJeX01f]J
0000ofmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]j4D4E@A515D4A@AE14D4E@A51
5D4A@AE14D4E@A515D4A@AE14D4E@A515D4A@AE14D4E@A515D4A@AE14D4E@A515D4A@AE1JeY_Nf]J
JgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]J:D<U@RU39D8Y@bE2:D<U@RU39D8Y@bE2
:D<U@RU39D8Y@bE2:D<U@RU39D8Y@bE2:D<U@RU39D8Y@bE2:D<U@RU39D8Y@bE2Kg][FV]jJeY_Nf]J
JgY[FVmkJeX006]JKg][FV]jJeY_Nf]JJgY[FVmk?D@mACU4?DDmA3e5>D@mACe4?DDiA3e5?D@mACU4
?DDmA3e5>D@mACe4?DDiA3e5?D@mACU4?DDmA3e5>D@mACe4?DDiA3e5JeY[NV]JKg][FV]jJeY_Nf]J
JgX006mkJeY[NV]JKg][FV]jJeY_Nf]JEDIAAUE6DDIEAU56EDIAAUE6DDIEAU56EDIAAUE6DDIEAU56
EDIAAUE6DDIEAU56EDIAAUE6DDIEAU56EDIAAUE6DDIEAU56JgY[FVmkJeY[NV]JKg][FV]jJeX006]J
JgY[FVmkJeY[NV]JKg][FV]jIDMYB6E8JDQUAfU8IDQYB000J6E7JDQUB6U8IDMYB6E8JDQUAfU8IDQY
B6E7JDQUB6U8IDMYB6E8JDQUAfU8IDQYB6E7JDQUB6U8JeY_Nf]JJgY[FVmkJeY[NV]JKg/006]jJeY_
Nf]JJgY[FVmkJeY[NWe9ODYmBGe:ODUmBWe9ODYmBGe:ODUmBWe9ODYmBGe:ODUmBWe9ODYmBGe:ODUm
BWe9ODYmBGe:ODUmBWe9ODYmBGe:ODUmBWe9Kg][FV]jJeY_Nf]JJgY[FVmkJeX006]JKg][FV]jJeY_
Nf]JJgX1JeX0019[FRHA@A=[FP0V:D<U@RU3:D8Y@bE2:D<Y@RU39D8Y@bU2:D<U@RU3:D8Y@bE2:D<Y
@RU39D8Y@bU2:D<U@RU3:D8Y@bE2:D<Y@RU39D8Y@bU2:D<U@PU[FP03001[FV]J00M[FRHmA0U[FP03
001[FV]J00M[FRIAAPU[FP03001[FV]J00M[FP9YB005IDQYB6U8JDQUB003JDP01FE8JDQYB6U8IDP0
0fU800EUB6U8JDQYB6E800=YB005IDQYB6U8JDQUB003JDP016E8JDQYB6U82F]J00<006]JJeX01f]J
00=mBWe9ODX00We:00EmBGe:ODYmBWe900=mBP05ODUmBWe:ODYmB@03ODX01Ge9ODYmBWe:ODT00ge:
00EmBGe:ODYmBWe900=mBP03ODU[FV]J00M[FP03001[FV]J00M[FP000?m[NV]JKg][FV]jJeY_Nf]J
JgY[FVmkJeY[NV]JKg][FV]jJeXE@A515D4A@AE14D4E@A515D4A@AE14D4E@A515D4A@AE14D4E@A51
5D4A@AE14D4E@A515D4A@AE14D4E@A515D4A@AE14D4E@A51JgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]J
JgY[FVmkJeY[NV]JKg/U@RU39D8Y@bE2:D<U@RU39D8Y@bE2:D<U@RU39D8Y@bE2:D<U@RU39D8Y@bE2
:D<U@RU39D8Y@bE2:D<U@RU39D8Y@bE2:D<U@RU3JeY_Nf]JJgY[FVmkJeY[NV]J001[FV]jJeY_Nf]J
JgY[FVmkJeXmACU4?DDmA3e5>D@mACe4?DDiA3e5?D@mACU4?DDmA3e5>D@mACe4?DDiA3e5?D@mACU4
?DDmA3e5>D@mACe4?DDiA3e5?D@mACU4Kg][FV]jJeY_Nf]JJgY[FVmk001[NV]JKg][FV]jJeY_Nf]J
JgYAAUE6DDIEAU56EDIAAUE6DDIEAU56EDIAAUE6DDIEAU56EDIAAUE6DDIEAU56EDIAAUE6DDIEAU56
EDIAAUE6DDIEAU56EDIAAUE6JeY[NV]JKg][FV]jJeY_Nf]J001[FVmkJeY[NV]JKg][FV]jJeYYB6E8
JDQUAfU8IDQYB6E7JDP006QUB6U8IDMYB6E8JDQUAfU8IDQYB6E7JDQUB6U8IDMYB6E8JDQUAfU8IDQY
B6E7JDQUB6U8IDMYB6E8JgY[FVmkJeY[NV]JKg][FV]j001_Nf]JJgY[FVmkJeY[NV]JKg]mBGe:ODUm
BWe9ODYmBGe:ODUmBWe9ODYmBGe:ODUmBWe9ODYmBGe:ODUmBWe9ODYmBGe:ODUmBWe9ODYmBGe:ODUm
BWe9ODYmBGe:JeY_Nf]JJgY[FVmkJeY[NV]J001[FV]jJeY_Nf]JJgY[FVmk0F]J000AJeXW4D4BJeX0
9bE2:D<Y@RU39D8Y@bU2:D<U@RU3:D8Y@bE2:D<Y@RU39D8Y@bU2:D<U@RU3:D8Y@bE2:D<Y@RU39D8Y
@bU2:D<U@RU3:D8Y@bE2:D<Y@P09JeX00`00JeY[FP06JeXW?D@9JeX00`00JeY[FP06JeXWDDH9JeX0
0`00JeY[FP06JeX00fU8IDQYB002JDP01FE8JDQYB6U8IDP00fU800EUB6U8JDQYB6E800=YB005IDQY
B6U8JDQUB003JDP01FE8JDQYB6U8IDP00fU800=UB6U8JeX026]J00<006]JJeX01V]J00EmBGe:ODYm
BWe900=mBP05ODUmBWe:ODYmB@03ODX01Ge9ODYmBWe:ODT00ge:00EmBGe:ODYmBWe900=mBP05ODUm
BWe:ODYmB@02ODX9JeX00`00JeY[FP07JeX0003oKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]j
JeY_Na515D4A@AE14D4E@A515D4A@AE14D4E@A515D4A@AE14D4E@A515D4A@AE14D4E@A515D4A@AE1
4D4E@A515D4A@AE14D4E@A515D4A@FmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FRU3
9D8Y@bE2:D<U@RU39D8Y@bE2:D<U@RU39D8Y@bE2:D<U@RU39D8Y@bE2:D<U@RU39D8Y@bE2:D<U@RU3
9D8Y@bE2:D<U@RU39D8Y@f]JJgY[FVmkJeY[NV]JKg][FP00JeY_Nf]JJgY[FVmkJeY[NSU4?DDmA3e5
>D@mACe4?DDiA3e5?D@mACU4?DDmA3e5>D@mACe4?DDiA3e5?D@mACU4?DDmA3e5>D@mACe4?DDiA3e5
?D@mACU4?DDmA6]jJeY_Nf]JJgY[FVmkJeY[NP00Kg][FV]jJeY_Nf]JJgY[FUE6DDIEAU56EDIAAUE6
DDIEAU56EDIAAUE6DDIEAU56EDIAAUE6DDIEAU56EDIAAUE6DDIEAU56EDIAAUE6DDIEAU56EDIAAUE6
DDIEAV]JKg][FV]jJeY_Nf]JJgY[FP00JeY[NV]JKg][FV]jJeY_NfE8JDQUAfU8IDQYB6E7JDQUB6U8
001XIDMYB6E8JDQUAfU8IDQYB6E7JDQUB6U8IDMYB6E8JDQUAfU8IDQYB6E7JDQUB6U8IDMYB6E8JDQU
AfmkJeY[NV]JKg][FV]jJeY_N`00JgY[FVmkJeY[NV]JKg][FWe:ODUmBWe9ODYmBGe:ODUmBWe9ODYm
BGe:ODUmBWe9ODYmBGe:ODUmBWe9ODYmBGe:ODUmBWe9ODYmBGe:ODUmBWe9ODYmBGe:ODUmBV]JJgY[
FVmkJeY[NV]JKg][FP00JeY_Nf]JJgY[FVmkJeY[NP5[FP004F]J9a514V]J02LY@RU39D8Y@bU2:D<U
@RU3:D8Y@bE2:D<Y@RU39D8Y@bU2:D<U@RU3:D8Y@bE2:D<Y@RU39D8Y@bU2:D<U@RU3:D8Y@bE2:D<Y
@RU39D802F]J00<006]JJeX01V]J9ce42F]J00<006]JJeX01V]J9e562F]J00<006]JJeX01V]J0fU8
00EUB6U8JDQYB6E800=YB005IDQYB6U8JDQUB003JDP01FE8JDQYB6U8IDP00fU800EUB6U8JDQYB6E8
00=YB004IDQYB6U8JDP9JeX00`00JeY[FP06JeX2ODX01Ge9ODYmBWe:ODT00ge:00EmBGe:ODYmBWe9
00=mBP05ODUmBWe:ODYmB@03ODX01Ge9ODYmBWe:ODT00ge:00EmBGe:ODYmBWe900U[FP03001[FV]J
00M[FP000?m[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]j4D4E@A515D4A@AE14D4E@A51
5D4A@AE14D4E@A515D4A@AE14D4E@A515D4A@AE14D4E@A515D4A@AE14D4E@A515D4A@AE14D4E@A51
JgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]J:D<U@RU39D8Y@bE2:D<U@RU39D8Y@bE2
:D<U@RU39D8Y@bE2:D<U@RU39D8Y@bE2:D<U@RU39D8Y@bE2:D<U@RU39D8Y@bE2:D<U@RU3JeY_Nf]J
JgY[FVmkJeY[NV]J001[FV]jJeY_Nf]JJgY[FVmk?D@mACU4?DDmA3e5>D@mACe4?DDiA3e5?D@mACU4
?DDmA3e5>D@mACe4?DDiA3e5?D@mACU4?DDmA3e5>D@mACe4?DDiA3e5?D@mACU4Kg][FV]jJeY_Nf]J
JgY[FVmk001[NV]JKg][FV]jJeY_Nf]JEDIAAUE6DDIEAU56EDIAAUE6DDIEAU56EDIAAUE6DDIEAU56
EDIAAUE6DDIEAU56EDIAAUE6DDIEAU56EDIAAUE6DDIEAU56EDIAAUE6JeY[NV]JKg][FV]jJeY_Nf]J
001[FVmkJeY[NV]JKg][FV]jIDMYB6E8JDQUAfU8IDQYB6E7JDP006QUB6U8IDMYB6E8JDQUAfU8IDQY
B6E7JDQUB6U8IDMYB6E8JDQUAfU8IDQYB6E7JDQUB6U8IDMYB6E8JgY[FVmkJeY[NV]JKg][FV]j001_
Nf]JJgY[FVmkJeY[NV]JODYmBGe:ODUmBWe9ODYmBGe:ODUmBWe9ODYmBGe:ODUmBWe9ODYmBGe:ODUm
BWe9ODYmBGe:ODUmBWe9ODYmBGe:ODUmBWe9ODYmBGe:JeY_Nf]JJgY[FVmkJeY[NV]J001[FV]jJeY_
Nf]JJgY[FVmk0F]J000AJeXW4D4BJeX09bE2:D<Y@RU39D8Y@bU2:D<U@RU3:D8Y@bE2:D<Y@RU39D8Y
@bU2:D<U@RU3:D8Y@bE2:D<Y@RU39D8Y@bU2:D<U@RU3:D8Y@bE2:D<Y@P09JeX00`00JeY[FP06JeXW
?D@9JeX00`00JeY[FP06JeXWDDH9JeX00`00JeY[FP06JeX00fU8IDQYB002JDP01FE8JDQYB6U8IDP0
0fU800EUB6U8JDQYB6E800=YB005IDQYB6U8JDQUB003JDP01FE8JDQYB6U8IDP00fU800=UB6U8JeX0
26]J00<006]JJeX01V]J00EmBGe:ODYmBWe900=mBP05ODUmBWe:ODYmB@03ODX01Ge9ODYmBWe:ODT0
0ge:00EmBGe:ODYmBWe900=mBP05ODUmBWe:ODYmB@02ODX9JeX00`00JeY[FP07JeX0003oKg][FV]j
JeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Na515D4A@AE14D4E@A515D4A@AE14D4E@A515D4A@AE1
4D4E@A515D4A@AE14D4E@A515D4A@AE14D4E@A515D4A@AE14D4E@A515D4A@FmkJeY[NV]JKg][FV]j
JeY_Nf]JJgY[FVmkJeY[NV]JKg][FRU39D8Y@bE2:D<U@RU39D8Y@bE2:D<U@RU39D8Y@bE2:D<U@RU3
9D8Y@bE2:D<U@RU39D8Y@bE2:D<U@RU39D8Y@bE2:D<U@RU39D8Y@f]JJgY[FVmkJeY[NV]JKg][FP00
JeY_Nf]JJgY[FVmkJeY[NSU4?DDmA3e5>D@mACe4?DDiA3e5?D@mACU4?DDmA3e5>D@mACe4?DDiA3e5
?D@mACU4?DDmA3e5>D@mACe4?DDiA3e5?D@mACU4?DDmA6]jJeY_Nf]JJgY[FVmkJeY[NP00Kg][FV]j
JeY_Nf]JJgY[FUE6DDIEAU56EDIAAUE6DDIEAU56EDIAAUE6DDIEAU56EDIAAUE6DDIEAU56EDIAAUE6
DDIEAU56EDIAAUE6DDIEAU56EDIAAUE6DDIEAV]JKg][FV]jJeY_Nf]JJgY[FP00JeY[NV]JKg][FV]j
JeY_NfE8JDQUAfU8IDQYB6E7JDQUB6U8001XIDMYB6E8JDQUAfU8IDQYB6E7JDQUB6U8IDMYB6E8JDQU
AfU8IDQYB6E7JDQUB6U8IDMYB6E8JDQUAfmkJeY[NV]JKg][FV]jJeY_N`00JgY[FVmkJeY[NV]JKg][
FWe:ODUmBWe9ODYmBGe:ODUmBWe9ODYmBGe:ODUmBWe9ODYmBGe:ODUmBWe9ODYmBGe:ODUmBWe9ODYm
BGe:ODUmBWe9ODYmBGe:ODUmBV]JJgY[FVmkJeY[NV]JKg][FP00JeY_Nf]JJgY[FVmkJeY[NP5[FP00
4F]J9a514V]J02LY@RU39D8Y@bU2:D<U@RU3:D8Y@bE2:D<Y@RU39D8Y@bU2:D<U@RU3:D8Y@bE2:D<Y
@RU39D8Y@bU2:D<U@RU3:D8Y@bE2:D<Y@RU39D802F]J00<006]JJeX01V]J9ce42F]J00<006]JJeX0
1V]J9e562F]J00<006]JJeX01V]J0fU800EUB6U8JDQYB6E800=YB005IDQYB6U8JDQUB003JDP01FE8
JDQYB6U8IDP00fU800EUB6U8JDQYB6E800=YB004IDQYB6U8JDP9JeX00`00JeY[FP06JeX2ODX01Ge9
ODYmBWe:ODT00ge:00EmBGe:ODYmBWe900=mBP05ODUmBWe:ODYmB@03ODX01Ge9ODYmBWe:ODT00ge:
00EmBGe:ODYmBWe900U[FP03001[FV]J00M[FP000?m[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]J
Kg][FV]j4D4E@A515D4A@AE14D4E@A515D4A@AE14D4E@A515D4A@AE14D4E@A515D4A@AE14D4E@A51
5D4A@AE14D4E@A515D4A@AE14D4E@A51JgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]J
:D<U@RU39D8Y@bE2:D<U@RU39D8Y@bE2:D<U@RU39D8Y@bE2:D<U@RU39D8Y@bE2:D<U@RU39D8Y@bE2
:D<U@RU39D8Y@bE2:D<U@RU3JeY_Nf]JJgY[FVmkJeY[NV]J001[FV]jJeY_Nf]JJgY[FVmk?D@mACU4
?DDmA3e5>D@mACe4?DDiA3e5?D@mACU4?DDmA3e5>D@mACe4?DDiA3e5?D@mACU4?DDmA3e5>D@mACe4
?DDiA3e5?D@mACU4Kg][FV]jJeY_Nf]JJgY[FVmk001[NV]JKg][FV]jJeY_Nf]JEDIAAUE6DDIEAU56
EDIAAUE6DDIEAU56EDIAAUE6DDIEAU56EDIAAUE6DDIEAU56EDIAAUE6DDIEAU56EDIAAUE6DDIEAU56
EDIAAUE6JeY[NV]JKg][FV]jJeY_Nf]J001[FVmkJeY[NV]JKg][FV]jIDMYB6E8JDQUAfU8IDQYB6E7
JDP006QUB6U8IDMYB6E8JDQUAfU8IDQYB6E7JDQUB6U8IDMYB6E8JDQUAfU8IDQYB6E7JDQUB6U8IDMY
B6E8JgY[FVmkJeY[NV]JKg][FV]j001_Nf]JJgY[FVmkJeY[NV]JODYmBGe:ODUmBWe9ODYmBGe:ODUm
BWe9ODYmBGe:ODUmBWe9ODYmBGe:ODUmBWe9ODYmBGe:ODUmBWe9ODYmBGe:ODUmBWe9ODYmBGe:JeY_
Nf]JJgY[FVmkJeY[NV]J001[FV]jJeY_Nf]JJgY[FVmk0F]J000AJeXW4D4BJeX09bE2:D<Y@RU39D8Y
@bU2:D<U@RU3:D8Y@bE2:D<Y@RU39D8Y@bU2:D<U@RU3:D8Y@bE2:D<Y@RU39D8Y@bU2:D<U@RU3:D8Y
@bE2:D<Y@P09JeX00`00JeY[FP06JeXW?D@9JeX00`00JeY[FP06JeXWDDH9JeX00`00JeY[FP06JeX0
0fU8IDQYB002JDP01FE8JDQYB6U8IDP00fU800EUB6U8JDQYB6E800=YB005IDQYB6U8JDQUB003JDP0
1FE8JDQYB6U8IDP00fU800=UB6U8JeX026]J00<006]JJeX01V]J00EmBGe:ODYmBWe900=mBP05ODUm
BWe:ODYmB@03ODX01Ge9ODYmBWe:ODT00ge:00EmBGe:ODYmBWe900=mBP05ODUmBWe:ODYmB@02ODX9
JeX00`00JeY[FP07JeX0003oKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Na515D4A@AE1
4D4E@A515D4A@AE14D4E@A515D4A@AE14D4E@A515D4A@AE14D4E@A515D4A@AE14D4E@A515D4A@AE1
4D4E@A515D4A@FmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FRU39D8Y@bE2:D<U@RU3
9D8Y@bE2:D<U@RU39D8Y@bE2:D<U@RU39D8Y@bE2:D<U@RU39D8Y@bE2:D<U@RU39D8Y@bE2:D<U@RU3
9D8Y@f]JJgY[FVmkJeY[NV]JKg][FP00JeY_Nf]JJgY[FVmkJeY[NSU4?DDmA3e5>D@mACe4?DDiA3e5
?D@mACU4?DDmA3e5>D@mACe4?DDiA3e5?D@mACU4?DDmA3e5>D@mACe4?DDiA3e5?D@mACU4?DDmA6]j
JeY_Nf]JJgY[FVmkJeY[NP00Kg][FV]jJeY_Nf]JJgY[FUE6DDIEAU56EDIAAUE6DDIEAU56EDIAAUE6
DDIEAU56EDIAAUE6DDIEAU56EDIAAUE6DDIEAU56EDIAAUE6DDIEAU56EDIAAUE6DDIEAV]JKg][FV]j
JeY_Nf]JJgY[FP00JeY[NV]JKg][FV]jJeY_NfE8JDQUAfU8IDQYB6E7JDQUB6U8001XIDMYB6E8JDQU
AfU8IDQYB6E7JDQUB6U8IDMYB6E8JDQUAfU8IDQYB6E7JDQUB6U8IDMYB6E8JDQUAfmkJeY[NV]JKg][
FV]jJeY_N`00JgY[FVmkJeY[NV]JKg][FWe:ODUmBWe9ODYmBGe:ODUmBWe9ODYmBGe:ODUmBWe9ODYm
BGe:ODUmBWe9ODYmBGe:ODUmBWe9ODYmBGe:ODUmBWe9ODYmBGe:ODUmBV]JJgY[FVmkJeY[NV]JKg][
FP00JeY_Nf]JJgY[FVmkJeY[NP5[FP004V]J9Q514f]J02HY@bE2:D<Y@RU39D8Y@bU2:D<U@RU3:D8Y
@bE2:D<Y@RU39D8Y@bU2:D<U@RU3:D8Y@bE2:D<Y@RU39D8Y@bU2:D<U@RU3:D8Y@bE22F]J00<006]J
JeX01f]J9Se42F]J00<006]JJeX01f]J9U562F]J00<006]JJeX01f]J0VU800EUB6U8JDQYB6E800=Y
B005IDQYB6U8JDQUB003JDP01FE8JDQYB6U8IDP00fU800EUB6U8JDQYB6E800=YB004IDQYB6U8JDP9
JeX00`00JeY[FP07JeX00ge:ODUmBP02ODX01Ge9ODYmBWe:ODT00ge:00EmBGe:ODYmBWe900=mBP05
ODUmBWe:ODYmB@03ODX01Ge9ODYmBWe:ODT00ge:00=mBF]JJeX01f]J00<006]JJeX01f]J0000of]j
JeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FQE14D4E@A515D4A@AE14D4E@A515D4A@AE1
4D4E@A515D4A@AE14D4E@A515D4A@AE14D4E@A515D4A@AE14D4E@A515D4A@AE14D5[NV]JKg][FV]j
JeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_NbE2:D<U@RU39D8Y@bE2:D<U@RU39D8Y@bE2:D<U@RU3
9D8Y@bE2:D<U@RU39D8Y@bE2:D<U@RU39D8Y@bE2:D<U@RU39D8Y@bE2:D=[FVmkJeY[NV]JKg][FV]j
JeX006]JJgY[FVmkJeY[NV]JKg][FSe5>D@mACe4?DDiA3e5?D@mACU4?DDmA3e5>D@mACe4?DDiA3e5
?D@mACU4?DDmA3e5>D@mACe4?DDiA3e5?D@mACU4?DDmA3e5>DA_Nf]JJgY[FVmkJeY[NV]JKg/006]j
JeY_Nf]JJgY[FVmkJeY[NU56EDIAAUE6DDIEAU56EDIAAUE6DDIEAU56EDIAAUE6DDIEAU56EDIAAUE6
DDIEAU56EDIAAUE6DDIEAU56EDIAAUE6DDIEAU56EDI[FV]jJeY_Nf]JJgY[FVmkJeX006]JKg][FV]j
JeY_Nf]JJgY[FVU8IDQYB6E7JDQUB6U8IDMYB000J6E8JDQUAfU8IDQYB6E7JDQUB6U8IDMYB6E8JDQU
AfU8IDQYB6E7JDQUB6U8IDMYB6E8JDQUAfU8IDQ[NV]JKg][FV]jJeY_Nf]JJgX006mkJeY[NV]JKg][
FV]jJeY_Nge9ODYmBGe:ODUmBWe9ODYmBGe:ODUmBWe9ODYmBGe:ODUmBWe9ODYmBGe:ODUmBWe9ODYm
BGe:ODUmBWe9ODYmBGe:ODUmBWe9ODY[FVmkJeY[NV]JKg][FV]jJeX006]JJgY[FVmkJeY[NV]JKg/1
JeX001=[FR@A@AE[FP0T:D8Y@bE2:D<Y@RU39D8Y@bU2:D<U@RU3:D8Y@bE2:D<Y@RU39D8Y@bU2:D<U
@RU3:D8Y@bE2:D<Y@RU39D8Y@bU2:D<U@RU32V]J00<006]JJeX026]J93e42V]J00<006]JJeX026]J
95562V]J00<006]JJeX026]J0fU800EUB6U8JDQYB6E800=YB005IDQYB6U8JDQUB003JDP01FE8JDQY
B6U8IDP00fU800EUB6U8JDQYB6E800=YB003IDQ[FV]J00Q[FP03001[FV]J00M[FP=mBP05ODUmBWe:
ODYmB@03ODX01Ge9ODYmBWe:ODT00ge:00EmBGe:ODYmBWe900=mBP05ODUmBWe:ODYmB@03ODX00ge9
ODY[FP09JeX00`00JeY[FP07JeX0003oKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]J
JgXA@AE14D4E@A515D4A@AE14D4E@A515D4A@AE14D4E@A515D4A@AE14D4E@A515D4A@AE14D4E@A51
5D4A@AE14D4E@A515D5[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeXY@bE2
:D<U@RU39D8Y@bE2:D<U@RU39D8Y@bE2:D<U@RU39D8Y@bE2:D<U@RU39D8Y@bE2:D<U@RU39D8Y@bE2
:D<U@RU39D9_Nf]JJgY[FVmkJeY[NV]JKg][FP00JeY_Nf]JJgY[FVmkJeY[NV]JKg/mA3e5>D@mACe4
?DDiA3e5?D@mACU4?DDmA3e5>D@mACe4?DDiA3e5?D@mACU4?DDmA3e5>D@mACe4?DDiA3e5?D@mACU4
?DE[FV]jJeY_Nf]JJgY[FVmkJeY[NP00Kg][FV]jJeY_Nf]JJgY[FVmkJeYEAU56EDIAAUE6DDIEAU56
EDIAAUE6DDIEAU56EDIAAUE6DDIEAU56EDIAAUE6DDIEAU56EDIAAUE6DDIEAU56EDIAAUE6DDI[NV]J
Kg][FV]jJeY_Nf]JJgY[FP00JeY[NV]JKg][FV]jJeY_Nf]JJgYUAfU8IDQYB6E7JDQUB6U8001XIDMY
B6E8JDQUAfU8IDQYB6E7JDQUB6U8IDMYB6E8JDQUAfU8IDQYB6E7JDQUB6U8IDMYB6E8JDQ[FVmkJeY[
NV]JKg][FV]jJeY_N`00JgY[FVmkJeY[NV]JKg][FV]jODUmBWe9ODYmBGe:ODUmBWe9ODYmBGe:ODUm
BWe9ODYmBGe:ODUmBWe9ODYmBGe:ODUmBWe9ODYmBGe:ODUmBWe9ODYmBGe:ODU_Nf]JJgY[FVmkJeY[
NV]JKg][FP00JeY_Nf]JJgY[FVmkJeY[NP5[FP0056]J8Q515f]J028Y@bU2:D<U@RU3:D8Y@bE2:D<Y
@RU39D8Y@bU2:D<U@RU3:D8Y@bE2:D<Y@RU39D8Y@bU2:D<U@RU3:D8Y@bE2:D<Y@P][FP03001[FV]J
00Q[FR<mA0][FP03001[FV]J00Q[FR=AAP][FP03001[FV]J00Q[FP03JDQUB6U8009YB005IDQYB6U8
JDQUB003JDP01FE8JDQYB6U8IDP00fU800EUB6U8JDQYB6E800=YB006IDQYB6U8JDQUB6U82f]J00<0
06]JJeX026]J00EmBGe:ODYmBWe900=mBP05ODUmBWe:ODYmB@03ODX01Ge9ODYmBWe:ODT00ge:00Em
BGe:ODYmBWe900=mBP03ODUmBWe:00][FP03001[FV]J00M[FP000?m[NV]JKg][FV]jJeY_Nf]JJgY[
FVmkJeY[NV]JKg][FV]jJeY_Nf]J5D4A@AE14D4E@A515D4A@AE14D4E@A515D4A@AE14D4E@A515D4A
@AE14D4E@A515D4A@AE14D4E@A515D4A@AE14D5_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[
FVmkJeY[NV]JKg][FV]j9D8Y@bE2:D<U@RU39D8Y@bE2:D<U@RU39D8Y@bE2:D<U@RU39D8Y@bE2:D<U
@RU39D8Y@bE2:D<U@RU39D8Y@bE2:D=[FV]jJeY_Nf]JJgY[FVmkJeY[NV]J001[FV]jJeY_Nf]JJgY[
FVmkJeY[NSU4?DDmA3e5>D@mACe4?DDiA3e5?D@mACU4?DDmA3e5>D@mACe4?DDiA3e5?D@mACU4?DDm
A3e5>D@mACe4?DDiA3e5?DA[NV]JKg][FV]jJeY_Nf]JJgY[FVmk001[NV]JKg][FV]jJeY_Nf]JJgY[
FUE6DDIEAU56EDIAAUE6DDIEAU56EDIAAUE6DDIEAU56EDIAAUE6DDIEAU56EDIAAUE6DDIEAU56EDIA
AUE6DDIEAU56EDI[FVmkJeY[NV]JKg][FV]jJeY_Nf]J001[FVmkJeY[NV]JKg][FV]jJeY_NfE8JDQU
AfU8IDQYB6E7JDP006QUB6U8IDMYB6E8JDQUAfU8IDQYB6E7JDQUB6U8IDMYB6E8JDQUAfU8IDQYB6E7
JDQUB6U8IDM_Nf]JJgY[FVmkJeY[NV]JKg][FV]j001_Nf]JJgY[FVmkJeY[NV]JKg][FWe:ODUmBWe9
ODYmBGe:ODUmBWe9ODYmBGe:ODUmBWe9ODYmBGe:ODUmBWe9ODYmBGe:ODUmBWe9ODYmBGe:ODUmBWe9
ODY[FV]jJeY_Nf]JJgY[FVmkJeY[NV]J001[FV]jJeY_Nf]JJgY[FVmk0F]J000EJeXP4D4IJeX082E2
:D<Y@RU39D8Y@bU2:D<U@RU3:D8Y@bE2:D<Y@RU39D8Y@bU2:D<U@RU3:D8Y@bE2:D<Y@RU39D8Y@bU2
:D<<JeX00`00JeY[FP09JeXQ?D@<JeX00`00JeY[FP09JeXQDDH<JeX00`00JeY[FP09JeX2JDP01FE8
JDQYB6U8IDP00fU800EUB6U8JDQYB6E800=YB005IDQYB6U8JDQUB003JDP01FE8JDQYB6U8IDP00VU8
36]J00<006]JJeX02F]J00=mBWe9ODX00We:00EmBGe:ODYmBWe900=mBP05ODUmBWe:ODYmB@03ODX0
1Ge9ODYmBWe:ODT00ge:00AmBGe:ODYmBPa[FP03001[FV]J00M[FP000?m_Nf]JJgY[FVmkJeY[NV]J
Kg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg/A@AE14D4E@A515D4A@AE14D4E@A515D4A@AE14D4E@A51
5D4A@AE14D4E@A515D4A@AE14D4E@A515D4A@FmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]J
Kg][FV]jJeY_Nf]JJgY[FVmkJeXY@bE2:D<U@RU39D8Y@bE2:D<U@RU39D8Y@bE2:D<U@RU39D8Y@bE2
:D<U@RU39D8Y@bE2:D<U@RU39D8Y@f]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]J001[FVmkJeY[NV]J
Kg][FV]jJeY_Nf]JJgXiA3e5?D@mACU4?DDmA3e5>D@mACe4?DDiA3e5?D@mACU4?DDmA3e5>D@mACe4
?DDiA3e5?D@mACU4?DDmA6]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]j001_Nf]JJgY[FVmkJeY[NV]J
Kg][FV]jJeYEAU56EDIAAUE6DDIEAU56EDIAAUE6DDIEAU56EDIAAUE6DDIEAU56EDIAAUE6DDIEAU56
EDIAAUE6DDIEAV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]J001[FV]jJeY_Nf]JJgY[FVmkJeY[NV]J
Kg]UB6U8IDMYB6E8JDP006QUAfU8IDQYB6E7JDQUB6U8IDMYB6E8JDQUAfU8IDQYB6E7JDQUB6U8IDMY
B6E8JDQUAfmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmk001[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeYm
BWe9ODYmBGe:ODUmBWe9ODYmBGe:ODUmBWe9ODYmBGe:ODUmBWe9ODYmBGe:ODUmBWe9ODYmBGe:ODUm
BV]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]J001[FVmkJeY[NV]JKg][FV]j0F]J000FJeXM4D4LJeX0
7BU39D8Y@bU2:D<U@RU3:D8Y@bE2:D<Y@RU39D8Y@bU2:D<U@RU3:D8Y@bE2:D<Y@RU39D8Y@bU2:D<0
3V]J00<006]JJeX02f]J7Ce43V]J00<006]JJeX02f]J7E563V]J00<006]JJeX02f]J0VU800EUB6U8
JDQYB6E800=YB005IDQYB6U8JDQUB003JDP01FE8JDQYB6U8IDP00fU800=UB6U8JDP03V]J00<006]J
JeX02f]J00=mBWe9ODX00We:00EmBGe:ODYmBWe900=mBP05ODUmBWe:ODYmB@03ODX01Ge9ODYmBWe:
ODT00ge:3V]J00<006]JJeX01f]J0000of]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[
FVmkJeY[NV]JKg/A@AE14D4E@A515D4A@AE14D4E@A515D4A@AE14D4E@A515D4A@AE14D4E@A515D4A
@AE14D5_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[
FVmkJeXY@bE2:D<U@RU39D8Y@bE2:D<U@RU39D8Y@bE2:D<U@RU39D8Y@bE2:D<U@RU39D8Y@bE2:D=[
FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeX006]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgXi
A3e5?D@mACU4?DDmA3e5>D@mACe4?DDiA3e5?D@mACU4?DDmA3e5>D@mACe4?DDiA3e5?DA[NV]JKg][
FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg/006]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeYEAU56EDIA
AUE6DDIEAU56EDIAAUE6DDIEAU56EDIAAUE6DDIEAU56EDIAAUE6DDIEAU56EDI[FVmkJeY[NV]JKg][
FV]jJeY_Nf]JJgY[FVmkJeX006]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg]UB6U8IDMYB000J6E8
JDQUAfU8IDQYB6E7JDQUB6U8IDMYB6E8JDQUAfU8IDQYB6E7JDQUB6U8IDM_Nf]JJgY[FVmkJeY[NV]J
Kg][FV]jJeY_Nf]JJgX006mkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeYmBWe9ODYmBGe:ODUmBWe9
ODYmBGe:ODUmBWe9ODYmBGe:ODUmBWe9ODYmBGe:ODUmBWe9ODY[FV]jJeY_Nf]JJgY[FVmkJeY[NV]J
Kg][FV]jJeX006]JJgY[FVmkJeY[NV]JKg/1JeX001Q[FQTA@B1[FP0I:D<U@RU3:D8Y@bE2:D<Y@RU3
9D8Y@bU2:D<U@RU3:D8Y@bE2:D<Y@RU39D8Y@bU2:D<046]J00<006]JJeX03F]J6Ce446]J00<006]J
JeX03F]J6E5646]J00<006]JJeX03F]J0VU800EUB6U8JDQYB6E800=YB005IDQYB6U8JDQUB003JDP0
1FE8JDQYB6U8IDP00VU846]J00<006]JJeX03F]J00=mBWe9ODX00We:00EmBGe:ODYmBWe900=mBP05
ODUmBWe:ODYmB@03ODX017e9ODYmBWe:46]J00<006]JJeX01f]J0000ofmkJeY[NV]JKg][FV]jJeY_
Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmk4D4E@A515D4A@AE14D4E@A515D4A@AE14D4E
@A515D4A@AE14D4E@A515D5[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_
Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]J:D<U@RU39D8Y@bE2:D<U@RU39D8Y@bE2:D<U@RU39D8Y
@bE2:D<U@RU39D9_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeX006]JKg][FV]jJeY_
Nf]JJgY[FVmkJeY[NV]JKg][FV]j>D@mACe4?DDiA3e5?D@mACU4?DDmA3e5>D@mACe4?DDiA3e5?D@m
ACU4?DE[FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgX006mkJeY[NV]JKg][FV]jJeY_
Nf]JJgY[FVmkJeY[NV]JEDIAAUE6DDIEAU56EDIAAUE6DDIEAU56EDIAAUE6DDIEAU56EDIAAUE6DDI[
NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeX006]JJgY[FVmkJeY[NV]JKg][FV]jJeY_
Nf]JJgY[FVmkIDQYB000J6E7JDQUB6U8IDMYB6E8JDQUAfU8IDQYB6E7JDQUB6U8IDMYB6E8JDQ[FVmk
JeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg/006]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]j
JeY_Nf]JODYmBGe:ODUmBWe9ODYmBGe:ODUmBWe9ODYmBGe:ODUmBWe9ODYmBGe:ODU_Nf]JJgY[FVmk
JeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeX006]JKg][FV]jJeY_Nf]JJgX1JeX001][FQ<A@BI[FP0C
9D8Y@bU2:D<U@RU3:D8Y@bE2:D<Y@RU39D8Y@bU2:D<U@RU3:D804f]J00<006]JJeX046]J4ce44f]J
00<006]JJeX046]J4e564f]J00<006]JJeX046]J00=YB6E8JDP00VU800EUB6U8JDQYB6E800=YB006
IDQYB6U8JDQUB6U84f]J00<006]JJeX03f]J00=mBWe9ODX00We:00EmBGe:ODYmBWe900=mBP05ODUm
BWe:ODYmB@02ODXCJeX00`00JeY[FP07JeX0003oJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmk
JeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeXE@A515D4A@AE14D4E@A515D4A@AE14D4E@A515D4A@F]j
JeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmk
JeY[NV]JKg][FV]jJeY_Nf]JJgXU@RU39D8Y@bE2:D<U@RU39D8Y@bE2:D<U@RU39D8Y@f]JKg][FV]j
JeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FP00JeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmk
JeY[NV]JKg][FV]jJeXmACe4?DDiA3e5?D@mACU4?DDmA3e5>D@mACe4?DDiA6mkJeY[NV]JKg][FV]j
JeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_N`00JgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmk
JeY[NV]JKg]AAUE6DDIEAU56EDIAAUE6DDIEAU56EDIAAUE6DDIEAV]JJgY[FVmkJeY[NV]JKg][FV]j
JeY_Nf]JJgY[FVmkJeY[NV]JKg][FP00JeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmk
001XJeYYB6E7JDQUB6U8IDMYB6E8JDQUAfU8IDQYB6E7JDQUB6]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][
FV]jJeY_Nf]JJgY[FVmkJeY[NP00Kg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgYm
BGe:ODUmBWe9ODYmBGe:ODUmBWe9ODYmBGe:ODUmBV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][
FV]jJeY_Nf]JJgY[FP00JeY[NV]JKg][FV]jJeY_N`5[FP0086]J2Q51;f]J00XY@bE2:D<Y@RU39D8Y
@bU2:D<U@QM[FP03001[FV]J01E[FPXmA1M[FP03001[FV]J01E[FPYAAQM[FP03001[FV]J01E[FP9Y
B005IDQYB6U8JDQUB003JDPGJeX00`00JeY[FP0EJeX00ge:ODUmBP02ODX01Ge9ODYmBWe:ODT05f]J
00<006]JJeX01f]J0000ofmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]J
JgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]J
Kg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]J
JgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]J
Kg][FV]jJeY_Nf]JJgY[FVmkJeX006]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]J
JgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]J
Kg][FV]jJeY_Nf]JJgX006mkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]J
JgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]J
Kg][FV]jJeX006]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NP00J6]JKg][FV]jJeY_
Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[
NV]JKg/006]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_
Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeX0
06]JKg][FV]jJeY_Nf]JJgX1JeX007Y[FP03001[FV]J03I[FP03001[FV]J03I[FP03001[FV]J03I[
FP03001[FV]J03I[FP03001[FV]J00M[FP000?m[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][
FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[
FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][
FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[
FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]J001[FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][
FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[
FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmk001[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][
FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[
FVmkJeY[NV]JKg][FV]jJeY_Nf]J001[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg/0
06Q[FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]J
JgY[FVmkJeY[NV]JKg][FV]j001_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]J
Kg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]J
JgY[FVmkJeY[NV]J001[FV]jJeY_Nf]JJgY[FVmk0F]J001jJeX00`00JeY[FP0fJeX00`00JeY[FP0f
JeX00`00JeY[FP0fJeX00`00JeY[FP0fJeX00`00JeY[FP07JeX0003oKg][FV]jJeY_Nf]JJgY[FVmk
JeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]j
JeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmk
JeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]j
JeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FP00JeY_Nf]JJgY[FVmk
JeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]j
JeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NP00Kg][FV]jJeY_Nf]JJgY[FVmk
JeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]j
JeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FP00JeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmk
JeY[NV]JKg][FV]j001XJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][
FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_N`00JgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[
FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][
FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FP00JeY_Nf]JJgY[FVmkJeY[NP5[FP00NV]J00<006]JJeX0
=V]J00<006]JJeX0=V]J00<006]JJeX0=V]J00<006]JJeX0=V]J00<006]JJeX01f]J0000of]jJeY_
Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[
NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_
Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[
NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeX0
06]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[
NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg/006]jJeY_
Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[
NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeX006]JKg][FV]jJeY_
Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_N`00J6]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmk
JeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgX006mkJeY[NV]JKg][FV]j
JeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmk
JeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeX006]JJgY[FVmkJeY[NV]JKg/1JeX0
07Y[FP03001[FV]J03I[FP03001[FV]J03I[FP03001[FV]J03I[FP03001[FV]J03I[FP03001[FV]J
00M[FP0000Q_Nf]JJgY[FVmkJeY[NV]JL`000>a[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[
NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_
Nf]JJgY[FVmkJeY[NV]JKg][FV]j001_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[
NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_
Nf]JJgY[FVmkJeY[NV]J001[FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[
NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_
Nf]JJgY[FVmk001[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[
NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_
Nf]J001[FVmkJeY[NV]JKg][FV]j0F]J002cJeX00`00JeY[FP0fJeX00`00JeY[FP0fJeX00`00JeY[
FP0fJeX00`00JeY[FP07JeX0003oJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][
FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[
FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][
FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[
FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][
FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[
FVmkJeY[NV]JKg][FV]jJeY_N`00JgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][
FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[
FVmkJeY[NV]JKg][FP00JeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmk001XJeY[NV]J
Kg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]J
JgY[FVmkJeY[NP00Kg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]J
Kg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]J
JgY[FP00JeY[NV]JKg][FV]jJeY_N`5[FP00/f]J00<006]JJeX0=V]J00<006]JJeX0=V]J00<006]J
JeX0=V]J00<006]JJeX01f]J0000ofmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]j
JeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmk
JeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]j
JeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmk
JeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]j
JeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmk
JeY[NV]JKg][FV]jJeY_Nf]JJgX006mkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]j
JeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmk
JeY[NV]JKg][FV]jJeX006]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NP00J6]JKg][
FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[
FVmkJeY[NV]JKg/006]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][
FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[
FVmkJeX006]JKg][FV]jJeY_Nf]JJgX1JeX00;=[FP03001[FV]J03I[FP03001[FV]J03I[FP03001[
FV]J03I[FP03001[FV]J00M[FP000?m[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_
Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[
NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_
Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[
NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_
Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[
NV]JKg][FV]jJeY_Nf]JJgY[FVmk001[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_
Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[
NV]JKg][FV]jJeY_Nf]J001[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg/006Q[FV]j
JeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmk
JeY[NV]JKg][FV]j001_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]j
JeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmk
JeY[NV]J001[FV]jJeY_Nf]JJgY[FVmk0F]J002cJeX00`00JeY[FP0fJeX00`00JeY[FP0fJeX00`00
JeY[FP0fJeX00`00JeY[FP07JeX0003oKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]J
JgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]J
Kg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]J
JgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]J
Kg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]J
JgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]J
Kg][FV]jJeY_Nf]JJgY[FVmkJeY[NP00Kg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]J
JgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]J
Kg][FV]jJeY_Nf]JJgY[FP00JeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]j001XJeY_
Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[
NV]JKg][FV]jJeY_N`00JgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_
Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[
NV]JKg][FP00JeY_Nf]JJgY[FVmkJeY[NP5[FP00/f]J00<006]JJeX0=V]J00<006]JJeX0=V]J00<0
06]JJeX0=V]J00<006]JJeX01f]J0000TV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[
FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FQGR4N4EhQ7Q5N8AhAGR4N4EhQ7Q5N8AhAGR4N5[NV]JKg][
FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[
FVmkJeY[NV]JKg][FV]jJeY_NbGT:NDUi2WU9N@YiBGT:NDUi2WU9N@YiBGT:NE[FVmkJeY[NV]JKg][
FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[
FVmkJeY[NV]JKg][FSgW>NH3?NL01CWV?NLmicgW>NH00cgW09hiiVmkJeY[NV]JKg][FV]jJeY_Nf]J
JgY[FVmkJeY[NV]JKg][FV]jJeY_N`00JgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]J
Kg][FV]jDNUEjU7YENYAjEGZDNUEjU7YENYAjEGZDNUEjV]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]J
JgY[FVmkJeY[NV]JKg][FP00JeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]J
JNeUk6W]INaYkFG/JNeUk6W]INaYkFG/JNeUk6]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]J
JgY[FVmkJeY[NP00Kg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmk0Wg_00Em
kWg_ONmmkgg^00=mk`0RONimkgg_ONm[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][
FV]jJeX006]JJgY[FVmkJeY[NV]JKg/1JeX001][FP<AhP054N4AhQ7R4N8Ah@034N801A7Q4N8AhQ7R
4N400a7R9V]J0RWT00DUi2WT:N@Yi2GT00<Yi0059N@Yi2WT:N@Ui003:N@00bGTJeY[FP0TJeXC?NLC
JeX00`00JeY[FP0@JeX01E7YDNYAjU7ZDNT00e7Z00EAjE7ZDNYAjU7Y00=AjP03DNUAjU7Z01=[FP03
001[FV]J011[FP=Yk005INaYk6W/JNaUk003JN`01FG/JNaYk6W/IN`00fW/4f]J00<006]JJeX03f]J
57g_4f]J00<006]JJeX01f]J0000S6mkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]j
JeY_Nf]JJgY[FVmk4N4EhQ7Q5N8AhAGR4N4EhQ7Q5N8AhAGR4N4EhQ7Q5N8AhAGR4N4EhQ7Q5N9[FVmk
JeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]j
JeY_Nf]J:NDUi2WU9N@YiBGT:NDUi2WU9N@YiBGT:NDUi2WU9N@YiBGT:NDUi2WU9NA_Nf]JJgY[FVmk
JeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]j
>NH3?NL01CWV?NLmicgW>NH00cgW00DiiSgW?NLmicWV00<mi`2I>NHmif]JJgY[FVmkJeY[NV]JKg][
FV]jJeY_Nf]JJgY[FVmkJeY[NP00Kg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeYEjU7YENYA
jEGZDNUEjU7YENYAjEGZDNUEjU7YENYAjEGZDNUEjU7YENYAjF]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][
FV]jJeY_Nf]JJgY[FP00JeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg]Uk6W]INaYkFG/JNeU
k6W]INaYkFG/JNeUk6W]INaYkFG/JNeUk6W]INaYkF]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][
FV]jJeY_N`00JgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeYmkgg^00=mk`05ONimkgg_ONmm
kP03ONl01Gg^ONmmkgg_ONh00gg_01amkVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][
FP00JeY_Nf]JJgY[FVmkJeY[NP5[FP0066]J00DAhA7R4N8AhQ7Q00<AhP054N4AhQ7R4N8Ah@034N80
1A7Q4N8AhQ7R4N400a7R00<AhF]JJeX07V]J0bWT00DUi2WT:N@Yi2GT00<Yi0059N@Yi2WT:N@Ui003
:N@01RGT:N@Yi2WT9N@Yi21[FQTmia1[FP03001[FV]J00e[FP03DNYAjE7Z009AjP05DNUAjU7ZDNYA
j@03DNX01E7YDNYAjU7ZDNT00e7Z00AAjE7ZDNYAjQ1[FP03001[FV]J00e[FP05INaYk6W/JNaUk003
JN`01FG/JNaYk6W/IN`00fW/00EUk6W/JNaYk6G/00=Yk003INa[FV]J00i[FP03001[FV]J00e[FQUm
ka1[FP03001[FV]J00M[FP0008Y[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]J
JgY[FVmk4N4EhQ7Q5N8AhAGR4N4EhQ7Q5N8AhAGR4N4EhQ7Q5N8AhAGR4N4EhQ7Q5N8AhAGR4N4EhQ7Q
Kg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]J
:NDUi2WU9N@YiBGT:NDUi2WU9N@YiBGT:NDUi2WU9N@YiBGT:NDUi2WU9N@YiBGT:NDUi2WUJeY[NV]J
Kg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]j>NH3?NL0
1CWV?NLmicgW>NH00cgW00DiiSgW?NLmicWV00<mi`05>NHmicgW?NLiiP02?NL0TV]jJeY_Nf]JJgY[
FVmkJeY[NV]JKg][FV]jJeY_N`00JgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FUGZDNUEjU7YENYA
jEGZDNUEjU7YENYAjEGZDNUEjU7YENYAjEGZDNUEjU7YENYAjEGZDNUEjV]JKg][FV]jJeY_Nf]JJgY[
FVmkJeY[NV]JKg][FP00JeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_NfG/JNeUk6W]INaYkFG/JNeU
k6W]INaYkFG/JNeUk6W]INaYkFG/JNeUk6W]INaYkFG/JNeUk6mkJeY[NV]JKg][FV]jJeY_Nf]JJgY[
FVmkJeY[NP00Kg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FWg_ONh3ONl01Gg^ONmmkgg_ONh00gg_
00EmkWg_ONmmkgg^00=mk`0NONimkgg_ONmmkWg_JeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]J
001[FV]jJeY_Nf]JJgY[FVmk0F]J000FJeX01A7Q4N8AhQ7R4N400a7R00DAhA7R4N8AhQ7Q00<AhP05
4N4AhQ7R4N8Ah@034N801A7Q4N8AhQ7R4N4076]J0bWT00DUi2WT:N@Yi2GT00<Yi0059N@Yi2WT:N@U
i003:N@01BGT:N@Yi2WT9N@00bWT00<Ui2WTJeX06f]J7CgW3V]J00<006]JJeX02f]J00=AjU7YDNX0
0U7Z00EAjE7ZDNYAjU7Y00=AjP05DNUAjU7ZDNYAj@03DNX01E7YDNYAjU7ZDNT00e7Z3V]J00<006]J
JeX02f]J00EUk6W/JNaYk6G/00=Yk005INaYk6W/JNaUk003JN`01FG/JNaYk6W/IN`00fW/00EUk6W/
JNaYk6G/00i[FP03001[FV]J00][FQemk`i[FP03001[FV]J00M[FP0008Q_Nf]JJgY[FVmkJeY[NV]J
Kg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg/AhAGR4N4EhQ7Q5N8AhAGR4N4EhQ7Q5N8AhAGR4N4EhQ7Q
5N8AhAGR4N4EhQ7Q5N8AhAGR4N4EhQ7Q5N8AhFmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]J
Kg][FV]jJeY_Nf]JJgY[FVmkJeXYiBGT:NDUi2WU9N@YiBGT:NDUi2WU9N@YiBGT:NDUi2WU9N@YiBGT
:NDUi2WU9N@YiBGT:NDUi2WU9N@YiF]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]J
Kg][FV]jJeY_Nf]JJgXiiP<mi`05>NHmicgW?NLiiP03?NL01CWV?NLmicgW>NH00cgW00DiiSgW?NLm
icWV00<mi`2A>NHmicgWJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgX006mkJeY[NV]JKg][FV]jJeY_
Nf]JJgY[FUGZDNUEjU7YENYAjEGZDNUEjU7YENYAjEGZDNUEjU7YENYAjEGZDNUEjU7YENYAjEGZDNUE
jU7YENYAjEGZJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeX006]JJgY[FVmkJeY[NV]JKg][FV]jJeY_
NfG/JNeUk6W]INaYkFG/JNeUk6W]INaYkFG/JNeUk6W]INaYkFG/JNeUk6W]INaYkFG/JNeUk6W]INaY
kFG/Kg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg/006]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FWg_ONh0
0gg_00EmkWg_ONmmkgg^00=mk`05ONimkgg_ONmmkP03ONl01Gg^ONmmkgg_ONh00gg_01QmkWg_JeY[
NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeX006]JKg][FV]jJeY_Nf]JJgX1JeX001E[FP<AhP054N4AhQ7R
4N8Ah@034N801A7Q4N8AhQ7R4N400a7R00DAhA7R4N8AhQ7Q00<AhP054N4AhQ7R4N8Ah@0IJeX2:N@0
1BGT:N@Yi2WT9N@00bWT00DUi2WT:N@Yi2GT00<Yi0059N@Yi2WT:N@Ui003:N@01RGT:N@Yi2WT9N@Y
i1Q[FR4mi`a[FP03001[FV]J00U[FP03DNYAjE7Z009AjP05DNUAjU7ZDNYAj@03DNX01E7YDNYAjU7Z
DNT00e7Z00EAjE7ZDNYAjU7Y00=AjP04DNUAjU7ZDNX<JeX00`00JeY[FP09JeX01FG/JNaYk6W/IN`0
0fW/00EUk6W/JNaYk6G/00=Yk005INaYk6W/JNaUk003JN`01FG/JNaYk6W/IN`00fW/00=Uk6]JJeX0
2V]J00<006]JJeX02F]J8Gg_36]J00<006]JJeX01f]J0000QV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][
FV]jJeY_Nf]JJgY[FVmkJeXEhQ7Q5N8AhAGR4N4EhQ7Q5N8AhAGR4N4EhQ7Q5N8AhAGR4N4EhQ7Q5N8A
hAGR4N4EhQ7Q5N8AhAGR4N4EhQ7Q5N8AhFmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][
FV]jJeY_Nf]JJgXUi2WU9N@YiBGT:NDUi2WU9N@YiBGT:NDUi2WU9N@YiBGT:NDUi2WU9N@YiBGT:NDU
i2WU9N@YiBGT:NDUi2WU9N@YiF]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][
FV]j>NH3?NL01CWV?NLmicgW>NH00cgW00DiiSgW?NLmicWV00<mi`05>NHmicgW?NLiiP03?NL01CWV
?NLmicgW>NH00SgW08Y[NV]JKg][FV]jJeY_Nf]JJgY[FVmk001[NV]JKg][FV]jJeY_Nf]JJgY[FUGZ
DNUEjU7YENYAjEGZDNUEjU7YENYAjEGZDNUEjU7YENYAjEGZDNUEjU7YENYAjEGZDNUEjU7YENYAjEGZ
DNUEjU7YENY[FVmkJeY[NV]JKg][FV]jJeY_Nf]J001[FVmkJeY[NV]JKg][FV]jJeY_NfG/JNeUk6W]
INaYkFG/JNeUk6W]INaYkFG/JNeUk6W]INaYkFG/JNeUk6W]INaYkFG/JNeUk6W]INaYkFG/JNeUk6W]
INa_Nf]JJgY[FVmkJeY[NV]JKg][FV]j001_Nf]JJgY[FVmkJeY[NV]JKg][FWg_ONh3ONl01Gg^ONmm
kgg_ONh00gg_00EmkWg_ONmmkgg^00=mk`05ONimkgg_ONmmkP03ONl06Wg^ONmmkgg_ONimkf]JJgY[
FVmkJeY[NV]JKg][FV]jJeX006]JJgY[FVmkJeY[NV]JKg/1JeX001A[FP8AhP054N4AhQ7R4N8Ah@03
4N801A7Q4N8AhQ7R4N400a7R00DAhA7R4N8AhQ7Q00<AhP054N4AhQ7R4N8Ah@034N8GJeX00bWT9N@Y
i002:N@01BGT:N@Yi2WT9N@00bWT00DUi2WT:N@Yi2GT00<Yi0059N@Yi2WT:N@Ui003:N@01BGT:N@Y
i2WT9N@05V]J8cgW2f]J00<006]JJeX026]J00EAjE7ZDNYAjU7Y00=AjP05DNUAjU7ZDNYAj@03DNX0
1E7YDNYAjU7ZDNT00e7Z00EAjE7ZDNYAjU7Y00=AjP03DNUAjU7Z00][FP03001[FV]J00Q[FP=Yk005
INaYk6W/JNaUk003JN`01FG/JNaYk6W/IN`00fW/00EUk6W/JNaYk6G/00=Yk005INaYk6W/JNaUk003
JN`;JeX00`00JeY[FP08JeXSONl;JeX00`00JeY[FP07JeX00025Kg][FV]jJeY_Nf]JJgY[FVmkJeY[
NV]JKg][FV]jJeY_Nf]JJgXAhAGR4N4EhQ7Q5N8AhAGR4N4EhQ7Q5N8AhAGR4N4EhQ7Q5N8AhAGR4N4E
hQ7Q5N8AhAGR4N4EhQ7Q5N8AhAGR4N4EhQ7Q5N9[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[
NV]JKg][FV]jJeXYiBGT:NDUi2WU9N@YiBGT:NDUi2WU9N@YiBGT:NDUi2WU9N@YiBGT:NDUi2WU9N@Y
iBGT:NDUi2WU9N@YiBGT:NDUi2WU9NA_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[
NV]JKg/00SgW00DiiSgW?NLmicWV00<mi`05>NHmicgW?NLiiP03?NL01CWV?NLmicgW>NH00cgW00Di
iSgW?NLmicWV00<mi`29>NHmif]JJgY[FVmkJeY[NV]JKg][FV]j001_Nf]JJgY[FVmkJeY[NV]JKg][
FUGZDNUEjU7YENYAjEGZDNUEjU7YENYAjEGZDNUEjU7YENYAjEGZDNUEjU7YENYAjEGZDNUEjU7YENYA
jEGZDNUEjU7YENYAjF]jJeY_Nf]JJgY[FVmkJeY[NV]J001[FV]jJeY_Nf]JJgY[FVmkJeY[NVG/JNeU
k6W]INaYkFG/JNeUk6W]INaYkFG/JNeUk6W]INaYkFG/JNeUk6W]INaYkFG/JNeUk6W]INaYkFG/JNeU
k6W]INaYkF]JKg][FV]jJeY_Nf]JJgY[FVmk001[NV]JKg][FV]jJeY_Nf]JJgYmkP03ONl01Gg^ONmm
kgg_ONh00gg_00EmkWg_ONmmkgg^00=mk`05ONimkgg_ONmmkP03ONl01Gg^ONmmkgg_ONh00gg_01Am
kVmkJeY[NV]JKg][FV]jJeY_Nf]J001[FVmkJeY[NV]JKg][FV]j0F]J000CJeX00a7R4N4AhP024N80
1A7Q4N8AhQ7R4N400a7R00DAhA7R4N8AhQ7Q00<AhP054N4AhQ7R4N8Ah@034N801A7Q4N8AhQ7R4N40
0Q7R5F]J00DUi2WT:N@Yi2GT00<Yi0059N@Yi2WT:N@Ui003:N@01BGT:N@Yi2WT9N@00bWT00DUi2WT
:N@Yi2GT00<Yi0049N@Yi2WT:N@EJeXT?NL:JeX00`00JeY[FP08JeX2DNX01E7YDNYAjU7ZDNT00e7Z
00EAjE7ZDNYAjU7Y00=AjP05DNUAjU7ZDNYAj@03DNX01E7YDNYAjU7ZDNT00e7Z00=AjE7ZJeX02F]J
00<006]JJeX026]J00=Yk6G/JN`00VW/00EUk6W/JNaYk6G/00=Yk005INaYk6W/JNaUk003JN`01FG/
JNaYk6W/IN`00fW/00EUk6W/JNaYk6G/009Yk0Y[FP03001[FV]J00M[FREmk`Y[FP03001[FV]J00M[
FP0008I[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeXEhQ7Q5N8AhAGR4N4EhQ7Q5N8A
hAGR4N4EhQ7Q5N8AhAGR4N4EhQ7Q5N8AhAGR4N4EhQ7Q5N8AhAGR4N4EhQ7Q5N8AhAGR4N4EhQ7QJgY[
FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg/Ui2WU9N@YiBGT:NDUi2WU9N@YiBGT:NDU
i2WU9N@YiBGT:NDUi2WU9N@YiBGT:NDUi2WU9N@YiBGT:NDUi2WU9N@YiBGT:NDUi2WUJeY_Nf]JJgY[
FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeXmicWV0cgW00DiiSgW?NLmicWV00<mi`05>NHmicgW
?NLiiP03?NL01CWV?NLmicgW>NH00cgW00DiiSgW?NLmicWV00<mi`26>NI_Nf]JJgY[FVmkJeY[NV]J
Kg/006]jJeY_Nf]JJgY[FVmkJeY[NU7YENYAjEGZDNUEjU7YENYAjEGZDNUEjU7YENYAjEGZDNUEjU7Y
ENYAjEGZDNUEjU7YENYAjEGZDNUEjU7YENYAjEGZDNUEjU7YENY[FV]jJeY_Nf]JJgY[FVmkJeX006]J
Kg][FV]jJeY_Nf]JJgY[FVW]INaYkFG/JNeUk6W]INaYkFG/JNeUk6W]INaYkFG/JNeUk6W]INaYkFG/
JNeUk6W]INaYkFG/JNeUk6W]INaYkFG/JNeUk6W]INa[NV]JKg][FV]jJeY_Nf]JJgX006mkJeY[NV]J
Kg][FV]jJeY_N`9mk`05ONimkgg_ONmmkP03ONl01Gg^ONmmkgg_ONh00gg_00EmkWg_ONmmkgg^00=m
k`05ONimkgg_ONmmkP03ONl05Wg^ONmmkgg_JeY_Nf]JJgY[FVmkJeY[NV]J001[FV]jJeY_Nf]JJgY[
FVmk0F]J000BJeX01A7Q4N8AhQ7R4N400a7R00DAhA7R4N8AhQ7Q00<AhP054N4AhQ7R4N8Ah@034N80
1A7Q4N8AhQ7R4N400a7R00HAhA7R4N8AhQ7Q4N8CJeX3:N@01BGT:N@Yi2WT9N@00bWT00DUi2WT:N@Y
i2GT00<Yi0059N@Yi2WT:N@Ui003:N@01BGT:N@Yi2WT9N@00bWT00<Ui2WT:N@04f]J9SgW2F]J00<0
06]JJeX01f]J00=AjU7YDNX00U7Z00EAjE7ZDNYAjU7Y00=AjP05DNUAjU7ZDNYAj@03DNX01E7YDNYA
jU7ZDNT00e7Z00EAjE7ZDNYAjU7Y00=AjP03DNU[FV]J00M[FP03001[FV]J00M[FP05INaYk6W/JNaU
k003JN`01FG/JNaYk6W/IN`00fW/00EUk6W/JNaYk6G/00=Yk005INaYk6W/JNaUk003JN`01VG/JNaY
k6W/INaYk0U[FP03001[FV]J00M[FRImk`U[FP03001[FV]J00M[FP0008A_Nf]JJgY[FVmkJeY[NV]J
Kg][FV]jJeY_Nf]JJgY[FVmk4N4EhQ7Q5N8AhAGR4N4EhQ7Q5N8AhAGR4N4EhQ7Q5N8AhAGR4N4EhQ7Q
5N8AhAGR4N4EhQ7Q5N8AhAGR4N4EhQ7Q5N8AhAGR4N4EhQ7QKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]J
Kg][FV]jJeY_Nf]J:NDUi2WU9N@YiBGT:NDUi2WU9N@YiBGT:NDUi2WU9N@YiBGT:NDUi2WU9N@YiBGT
:NDUi2WU9N@YiBGT:NDUi2WU9N@YiBGT:NDUi2WUJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]J
Kg][FV]j>NH3?NL01CWV?NLmicgW>NH00cgW00DiiSgW?NLmicWV00<mi`05>NHmicgW?NLiiP03?NL0
1CWV?NLmicgW>NH00cgW08TiiSgW?NM[NV]JKg][FV]jJeY_Nf]JJgX006mkJeY[NV]JKg][FV]jJeYE
jU7YENYAjEGZDNUEjU7YENYAjEGZDNUEjU7YENYAjEGZDNUEjU7YENYAjEGZDNUEjU7YENYAjEGZDNUE
jU7YENYAjEGZDNUEjU7YENY[FVmkJeY[NV]JKg][FV]jJeX006]JJgY[FVmkJeY[NV]JKg]Uk6W]INaY
kFG/JNeUk6W]INaYkFG/JNeUk6W]INaYkFG/JNeUk6W]INaYkFG/JNeUk6W]INaYkFG/JNeUk6W]INaY
kFG/JNeUk6W]INa_Nf]JJgY[FVmkJeY[NV]JKg/006]jJeY_Nf]JJgY[FVmkJeYmkgg^00=mk`05ONim
kgg_ONmmkP03ONl01Gg^ONmmkgg_ONh00gg_00EmkWg_ONmmkgg^00=mk`05ONimkgg_ONmmkP03ONl0
57g^ONm[FV]jJeY_Nf]JJgY[FVmkJeX006]JKg][FV]jJeY_Nf]JJgX1JeX0015[FP<AhP054N4AhQ7R
4N8Ah@034N801A7Q4N8AhQ7R4N400a7R00DAhA7R4N8AhQ7Q00<AhP054N4AhQ7R4N8Ah@034N80117Q
4N8AhQ7R4V]J0RWT00DUi2WT:N@Yi2GT00<Yi0059N@Yi2WT:N@Ui003:N@01BGT:N@Yi2WT9N@00bWT
00DUi2WT:N@Yi2GT00<Yi0059N@Yi2WT:N@Ui00BJeXW?NL9JeX00`00JeY[FP06JeX01E7YDNYAjU7Z
DNT00e7Z00EAjE7ZDNYAjU7Y00=AjP05DNUAjU7ZDNYAj@03DNX01E7YDNYAjU7ZDNT00e7Z00EAjE7Z
DNYAjU7Y009AjPU[FP03001[FV]J00I[FP=Yk005INaYk6W/JNaUk003JN`01FG/JNaYk6W/IN`00fW/
00EUk6W/JNaYk6G/00=Yk005INaYk6W/JNaUk003JN`016G/JNaYk6W/2F]J00<006]JJeX01V]J9gg_
2F]J00<006]JJeX01f]J0000Pf]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgXAhAGR4N4E
hQ7Q5N8AhAGR4N4EhQ7Q5N8AhAGR4N4EhQ7Q5N8AhAGR4N4EhQ7Q5N8AhAGR4N4EhQ7Q5N8AhAGR4N4E
hQ7Q5N8AhAGR4N5[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeXYiBGT:NDUi2WU9N@Y
iBGT:NDUi2WU9N@YiBGT:NDUi2WU9N@YiBGT:NDUi2WU9N@YiBGT:NDUi2WU9N@YiBGT:NDUi2WU9N@Y
iBGT:NE[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg/00SgW00DiiSgW?NLmicWV00<m
i`05>NHmicgW?NLiiP03?NL01CWV?NLmicgW>NH00cgW00DiiSgW?NLmicWV00<mi`29>NHmicgW?NLi
iVmkJeY[NV]JKg][FV]jJeY_N`00JgY[FVmkJeY[NV]JKg][FUGZDNUEjU7YENYAjEGZDNUEjU7YENYA
jEGZDNUEjU7YENYAjEGZDNUEjU7YENYAjEGZDNUEjU7YENYAjEGZDNUEjU7YENYAjEGZDNUEjV]JJgY[
FVmkJeY[NV]JKg][FP00JeY_Nf]JJgY[FVmkJeY[NVG/JNeUk6W]INaYkFG/JNeUk6W]INaYkFG/JNeU
k6W]INaYkFG/JNeUk6W]INaYkFG/JNeUk6W]INaYkFG/JNeUk6W]INaYkFG/JNeUk6]jJeY_Nf]JJgY[
FVmkJeY[NP00Kg][FV]jJeY_Nf]JJgY[FP03ONl01Gg^ONmmkgg_ONh00gg_00EmkWg_ONmmkgg^00=m
k`05ONimkgg_ONmmkP03ONl01Gg^ONmmkgg_ONh00gg_01ImkWg_ONmmkf]JKg][FV]jJeY_Nf]JJgY[
FP00JeY[NV]JKg][FV]jJeY_N`5[FP004F]J00<AhQ7Q4N800Q7R00DAhA7R4N8AhQ7Q00<AhP054N4A
hQ7R4N8Ah@034N801A7Q4N8AhQ7R4N400a7R00DAhA7R4N8AhQ7Q00<AhP034N4AhV]J015[FP059N@Y
i2WT:N@Ui003:N@01BGT:N@Yi2WT9N@00bWT00DUi2WT:N@Yi2GT00<Yi0059N@Yi2WT:N@Ui003:N@0
1BGT:N@Yi2WT9N@00RWT4V]J9cgW2F]J00<006]JJeX01V]J0U7Z00EAjE7ZDNYAjU7Y00=AjP05DNUA
jU7ZDNYAj@03DNX01E7YDNYAjU7ZDNT00e7Z00EAjE7ZDNYAjU7Y00=AjP05DNUAjU7ZDNYAj@09JeX0
0`00JeY[FP06JeX00fW/INaYk002JN`01FG/JNaYk6W/IN`00fW/00EUk6W/JNaYk6G/00=Yk005INaY
k6W/JNaUk003JN`01FG/JNaYk6W/IN`00fW/00=Uk6W/JeX026]J00<006]JJeX01V]J9gg_2F]J00<0
06]JJeX01f]J0000Q6mkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg/AhAGR4N4EhQ7Q5N8A
hAGR4N4EhQ7Q5N8AhAGR4N4EhQ7Q5N8AhAGR4N4EhQ7Q5N8AhAGR4N4EhQ7Q5N8AhAGR4N4EhQ7Q5N8A
hAGR4N5_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeXYiBGT:NDUi2WU9N@YiBGT:NDU
i2WU9N@YiBGT:NDUi2WU9N@YiBGT:NDUi2WU9N@YiBGT:NDUi2WU9N@YiBGT:NDUi2WU9N@YiBGT:NE[
FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgXiiP<mi`05>NHmicgW?NLiiP03?NL01CWV
?NLmicgW>NH00cgW00DiiSgW?NLmicWV00<mi`05>NHmicgW?NLiiP03?NL0RCWV?NLmif]jJeY_Nf]J
JgY[FVmkJeY[NP00Kg][FV]jJeY_Nf]JJgY[FUGZDNUEjU7YENYAjEGZDNUEjU7YENYAjEGZDNUEjU7Y
ENYAjEGZDNUEjU7YENYAjEGZDNUEjU7YENYAjEGZDNUEjU7YENYAjEGZDNUEjV]JKg][FV]jJeY_Nf]J
JgY[FP00JeY[NV]JKg][FV]jJeY_NfG/JNeUk6W]INaYkFG/JNeUk6W]INaYkFG/JNeUk6W]INaYkFG/
JNeUk6W]INaYkFG/JNeUk6W]INaYkFG/JNeUk6W]INaYkFG/JNeUk6mkJeY[NV]JKg][FV]jJeY_N`00
JgY[FVmkJeY[NV]JKg][FWg_ONh00gg_00EmkWg_ONmmkgg^00=mk`05ONimkgg_ONmmkP03ONl01Gg^
ONmmkgg_ONh00gg_00EmkWg_ONmmkgg^00=mk`0DONimkf]JJgY[FVmkJeY[NV]JKg][FP00JeY_Nf]J
JgY[FVmkJeY[NP5[FP004F]J0a7R00DAhA7R4N8AhQ7Q00<AhP054N4AhQ7R4N8Ah@034N801A7Q4N8A
hQ7R4N400a7R00DAhA7R4N8AhQ7Q00<AhP044N4AhQ7R4N8BJeX2:N@01BGT:N@Yi2WT9N@00bWT00DU
i2WT:N@Yi2GT00<Yi0059N@Yi2WT:N@Ui003:N@01BGT:N@Yi2WT9N@00bWT00DUi2WT:N@Yi2GT019[
FRLmi`U[FP03001[FV]J00I[FP05DNUAjU7ZDNYAj@03DNX01E7YDNYAjU7ZDNT00e7Z00EAjE7ZDNYA
jU7Y00=AjP05DNUAjU7ZDNYAj@03DNX01E7YDNYAjU7ZDNT00U7Z2F]J00<006]JJeX01V]J0fW/00EU
k6W/JNaYk6G/00=Yk005INaYk6W/JNaUk003JN`01FG/JNaYk6W/IN`00fW/00EUk6W/JNaYk6G/00=Y
k004INaYk6W/JN`9JeX00`00JeY[FP06JeXWONl9JeX00`00JeY[FP07JeX00023JgY[FVmkJeY[NV]J
Kg][FV]jJeY_Nf]JJgY[FVmkJeY[NQ7Q5N8AhAGR4N4EhQ7Q5N8AhAGR4N4EhQ7Q5N8AhAGR4N4EhQ7Q
5N8AhAGR4N4EhQ7Q5N8AhAGR4N4EhQ7Q5N8AhAGR4N4EhQ7Q5N8AhF]jJeY_Nf]JJgY[FVmkJeY[NV]J
Kg][FV]jJeY_Nf]JJgY[FRWU9N@YiBGT:NDUi2WU9N@YiBGT:NDUi2WU9N@YiBGT:NDUi2WU9N@YiBGT
:NDUi2WU9N@YiBGT:NDUi2WU9N@YiBGT:NDUi2WU9N@YiF]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]J
Kg][FV]jJeY_N`02?NL01CWV?NLmicgW>NH00cgW00DiiSgW?NLmicWV00<mi`05>NHmicgW?NLiiP03
?NL01CWV?NLmicgW>NH00cgW08TiiSgW?NLmicWVKg][FV]jJeY_Nf]JJgY[FVmk001[NV]JKg][FV]j
JeY_Nf]JENYAjEGZDNUEjU7YENYAjEGZDNUEjU7YENYAjEGZDNUEjU7YENYAjEGZDNUEjU7YENYAjEGZ
DNUEjU7YENYAjEGZDNUEjU7YENYAjEGZJeY[NV]JKg][FV]jJeY_Nf]J001[FVmkJeY[NV]JKg][FV]j
INaYkFG/JNeUk6W]INaYkFG/JNeUk6W]INaYkFG/JNeUk6W]INaYkFG/JNeUk6W]INaYkFG/JNeUk6W]
INaYkFG/JNeUk6W]INaYkFG/JgY[FVmkJeY[NV]JKg][FV]j001_Nf]JJgY[FVmkJeY[NV]J00=mk`05
ONimkgg_ONmmkP03ONl01Gg^ONmmkgg_ONh00gg_00EmkWg_ONmmkgg^00=mk`05ONimkgg_ONmmkP03
ONl05Wg^ONmmkgg_JeY_Nf]JJgY[FVmkJeY[NV]J001[FV]jJeY_Nf]JJgY[FVmk0F]J000AJeX00a7R
4N4AhP024N801A7Q4N8AhQ7R4N400a7R00DAhA7R4N8AhQ7Q00<AhP054N4AhQ7R4N8Ah@034N801A7Q
4N8AhQ7R4N400a7R00<AhA7RJeX04F]J00DUi2WT:N@Yi2GT00<Yi0059N@Yi2WT:N@Ui003:N@01BGT
:N@Yi2WT9N@00bWT00DUi2WT:N@Yi2GT00<Yi0059N@Yi2WT:N@Ui002:N@BJeXW?NL9JeX00`00JeY[
FP06JeX2DNX01E7YDNYAjU7ZDNT00e7Z00EAjE7ZDNYAjU7Y00=AjP05DNUAjU7ZDNYAj@03DNX01E7Y
DNYAjU7ZDNT00e7Z00EAjE7ZDNYAjU7Y00U[FP03001[FV]J00I[FP03JNaUk6W/009Yk005INaYk6W/
JNaUk003JN`01FG/JNaYk6W/IN`00fW/00EUk6W/JNaYk6G/00=Yk005INaYk6W/JNaUk003JN`00fG/
JNa[FP08JeX00`00JeY[FP06JeXWONl9JeX00`00JeY[FP07JeX00024Kg][FV]jJeY_Nf]JJgY[FVmk
JeY[NV]JKg][FV]jJeY_Na7Q5N8AhAGR4N4EhQ7Q5N8AhAGR4N4EhQ7Q5N8AhAGR4N4EhQ7Q5N8AhAGR
4N4EhQ7Q5N8AhAGR4N4EhQ7Q5N8AhAGR4N4EhQ7Q5N8AhFmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmk
JeY[NV]JKg][FRWU9N@YiBGT:NDUi2WU9N@YiBGT:NDUi2WU9N@YiBGT:NDUi2WU9N@YiBGT:NDUi2WU
9N@YiBGT:NDUi2WU9N@YiBGT:NDUi2WU9N@YiF]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmk
JeY[NSWV0cgW00DiiSgW?NLmicWV00<mi`05>NHmicgW?NLiiP03?NL01CWV?NLmicgW>NH00cgW00Di
iSgW?NLmicWV00<mi`29>NHmicgWJgY[FVmkJeY[NV]JKg][FV]j001_Nf]JJgY[FVmkJeY[NV]JENYA
jEGZDNUEjU7YENYAjEGZDNUEjU7YENYAjEGZDNUEjU7YENYAjEGZDNUEjU7YENYAjEGZDNUEjU7YENYA
jEGZDNUEjU7YENYAjEGZJeY_Nf]JJgY[FVmkJeY[NV]J001[FV]jJeY_Nf]JJgY[FVmkINaYkFG/JNeU
k6W]INaYkFG/JNeUk6W]INaYkFG/JNeUk6W]INaYkFG/JNeUk6W]INaYkFG/JNeUk6W]INaYkFG/JNeU
k6W]INaYkFG/Kg][FV]jJeY_Nf]JJgY[FVmk001[NV]JKg][FV]jJeY_Nf]JONmmkP03ONl01Gg^ONmm
kgg_ONh00gg_00EmkWg_ONmmkgg^00=mk`05ONimkgg_ONmmkP03ONl01Gg^ONmmkgg_ONh00gg_01Am
kWg_JeY[NV]JKg][FV]jJeY_Nf]J001[FVmkJeY[NV]JKg][FV]j0F]J000AJeX34N801A7Q4N8AhQ7R
4N400a7R00DAhA7R4N8AhQ7Q00<AhP054N4AhQ7R4N8Ah@034N801A7Q4N8AhQ7R4N400a7R00@AhA7R
4N8AhQ9[FP8Yi0059N@Yi2WT:N@Ui003:N@01BGT:N@Yi2WT9N@00bWT00DUi2WT:N@Yi2GT00<Yi005
9N@Yi2WT:N@Ui003:N@01BGT:N@Yi2WT9N@04V]J9cgW2F]J00<006]JJeX01V]J00EAjE7ZDNYAjU7Y
00=AjP05DNUAjU7ZDNYAj@03DNX01E7YDNYAjU7ZDNT00e7Z00EAjE7ZDNYAjU7Y00=AjP05DNUAjU7Z
DNYAj@02DNX9JeX00`00JeY[FP06JeX3JN`01FG/JNaYk6W/IN`00fW/00EUk6W/JNaYk6G/00=Yk005
INaYk6W/JNaUk003JN`01FG/JNaYk6W/IN`00fW/00AUk6W/JNaYk0U[FP03001[FV]J00I[FRMmk`U[
FP03001[FV]J00M[FP0008I[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeXEhQ7Q5N8A
hAGR4N4EhQ7Q5N8AhAGR4N4EhQ7Q5N8AhAGR4N4EhQ7Q5N8AhAGR4N4EhQ7Q5N8AhAGR4N4EhQ7Q5N8A
hAGR4N4EhQ7QJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg/Ui2WU9N@YiBGT:NDU
i2WU9N@YiBGT:NDUi2WU9N@YiBGT:NDUi2WU9N@YiBGT:NDUi2WU9N@YiBGT:NDUi2WU9N@YiBGT:NDU
i2WUJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeXmicWV0cgW00DiiSgW?NLmicWV
00<mi`05>NHmicgW?NLiiP03?NL01CWV?NLmicgW>NH00cgW00DiiSgW?NLmicWV00<mi`26>NI_Nf]J
JgY[FVmkJeY[NV]JKg/006]jJeY_Nf]JJgY[FVmkJeY[NU7YENYAjEGZDNUEjU7YENYAjEGZDNUEjU7Y
ENYAjEGZDNUEjU7YENYAjEGZDNUEjU7YENYAjEGZDNUEjU7YENYAjEGZDNUEjU7YENY[FV]jJeY_Nf]J
JgY[FVmkJeX006]JKg][FV]jJeY_Nf]JJgY[FVW]INaYkFG/JNeUk6W]INaYkFG/JNeUk6W]INaYkFG/
JNeUk6W]INaYkFG/JNeUk6W]INaYkFG/JNeUk6W]INaYkFG/JNeUk6W]INa[NV]JKg][FV]jJeY_Nf]J
JgX006mkJeY[NV]JKg][FV]jJeY_N`9mk`05ONimkgg_ONmmkP03ONl01Gg^ONmmkgg_ONh00gg_00Em
kWg_ONmmkgg^00=mk`05ONimkgg_ONmmkP03ONl05Wg^ONmmkgg_JeY_Nf]JJgY[FVmkJeY[NV]J001[
FV]jJeY_Nf]JJgY[FVmk0F]J000BJeX01A7Q4N8AhQ7R4N400a7R00DAhA7R4N8AhQ7Q00<AhP054N4A
hQ7R4N8Ah@034N801A7Q4N8AhQ7R4N400a7R00HAhA7R4N8AhQ7Q4N8CJeX3:N@01BGT:N@Yi2WT9N@0
0bWT00DUi2WT:N@Yi2GT00<Yi0059N@Yi2WT:N@Ui003:N@01BGT:N@Yi2WT9N@00bWT00<Ui2WT:N@0
4f]J9SgW2F]J00<006]JJeX01f]J00=AjU7YDNX00U7Z00EAjE7ZDNYAjU7Y00=AjP05DNUAjU7ZDNYA
j@03DNX01E7YDNYAjU7ZDNT00e7Z00EAjE7ZDNYAjU7Y00=AjP03DNU[FV]J00M[FP03001[FV]J00M[
FP05INaYk6W/JNaUk003JN`01FG/JNaYk6W/IN`00fW/00EUk6W/JNaYk6G/00=Yk005INaYk6W/JNaU
k003JN`01VG/JNaYk6W/INaYk0U[FP03001[FV]J00M[FRImk`U[FP03001[FV]J00M[FP0008E_Nf]J
JgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NQ7Q5N8AhAGR4N4EhQ7Q5N8AhAGR4N4EhQ7Q
5N8AhAGR4N4EhQ7Q5N8AhAGR4N4EhQ7Q5N8AhAGR4N4EhQ7Q5N8AhAGR4N4EhV]JKg][FV]jJeY_Nf]J
JgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FRWU9N@YiBGT:NDUi2WU9N@YiBGT:NDUi2WU9N@YiBGT
:NDUi2WU9N@YiBGT:NDUi2WU9N@YiBGT:NDUi2WU9N@YiBGT:NDUi6mkJeY[NV]JKg][FV]jJeY_Nf]J
JgY[FVmkJeY[NV]JKg][FV]jJeY_N`02?NL01CWV?NLmicgW>NH00cgW00DiiSgW?NLmicWV00<mi`05
>NHmicgW?NLiiP03?NL01CWV?NLmicgW>NH00cgW08TiiSgWJeY[NV]JKg][FV]jJeY_Nf]JJgX006mk
JeY[NV]JKg][FV]jJeY_Nf]JENYAjEGZDNUEjU7YENYAjEGZDNUEjU7YENYAjEGZDNUEjU7YENYAjEGZ
DNUEjU7YENYAjEGZDNUEjU7YENYAjEGZDNUEjU7YJgY[FVmkJeY[NV]JKg][FV]jJeX006]JJgY[FVmk
JeY[NV]JKg][FV]jINaYkFG/JNeUk6W]INaYkFG/JNeUk6W]INaYkFG/JNeUk6W]INaYkFG/JNeUk6W]
INaYkFG/JNeUk6W]INaYkFG/JNeUk6W]JeY_Nf]JJgY[FVmkJeY[NV]JKg/006]jJeY_Nf]JJgY[FVmk
JeY[NWg^00=mk`05ONimkgg_ONmmkP03ONl01Gg^ONmmkgg_ONh00gg_00EmkWg_ONmmkgg^00=mk`05
ONimkgg_ONmmkP03ONl057g^Kg][FV]jJeY_Nf]JJgY[FVmkJeX006]JKg][FV]jJeY_Nf]JJgX1JeX0
01=[FP034N8AhA7R008AhP054N4AhQ7R4N8Ah@034N801A7Q4N8AhQ7R4N400a7R00DAhA7R4N8AhQ7Q
00<AhP054N4AhQ7R4N8Ah@024N8EJeX01BGT:N@Yi2WT9N@00bWT00DUi2WT:N@Yi2GT00<Yi0059N@Y
i2WT:N@Ui003:N@01BGT:N@Yi2WT9N@00bWT00@Ui2WT:N@Yi1E[FR@mi`Y[FP03001[FV]J00Q[FP9A
jP05DNUAjU7ZDNYAj@03DNX01E7YDNYAjU7ZDNT00e7Z00EAjE7ZDNYAjU7Y00=AjP05DNUAjU7ZDNYA
j@03DNX00e7YDNY[FP09JeX00`00JeY[FP08JeX00fW/INaYk002JN`01FG/JNaYk6W/IN`00fW/00EU
k6W/JNaYk6G/00=Yk005INaYk6W/JNaUk003JN`01FG/JNaYk6W/IN`00VW/2V]J00<006]JJeX01f]J
9Gg_2V]J00<006]JJeX01f]J0000QV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmk
JeXEhQ7Q5N8AhAGR4N4EhQ7Q5N8AhAGR4N4EhQ7Q5N8AhAGR4N4EhQ7Q5N8AhAGR4N4EhQ7Q5N8AhAGR
4N4EhQ7Q5N8AhFmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgXUi2WU
9N@YiBGT:NDUi2WU9N@YiBGT:NDUi2WU9N@YiBGT:NDUi2WU9N@YiBGT:NDUi2WU9N@YiBGT:NDUi2WU
9N@YiF]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]j>NH3?NL01CWV?NLm
icgW>NH00cgW00DiiSgW?NLmicWV00<mi`05>NHmicgW?NLiiP03?NL01CWV?NLmicgW>NH00SgW08Y[
NV]JKg][FV]jJeY_Nf]JJgY[FVmk001[NV]JKg][FV]jJeY_Nf]JJgY[FUGZDNUEjU7YENYAjEGZDNUE
jU7YENYAjEGZDNUEjU7YENYAjEGZDNUEjU7YENYAjEGZDNUEjU7YENYAjEGZDNUEjU7YENY[FVmkJeY[
NV]JKg][FV]jJeY_Nf]J001[FVmkJeY[NV]JKg][FV]jJeY_NfG/JNeUk6W]INaYkFG/JNeUk6W]INaY
kFG/JNeUk6W]INaYkFG/JNeUk6W]INaYkFG/JNeUk6W]INaYkFG/JNeUk6W]INa_Nf]JJgY[FVmkJeY[
NV]JKg][FV]j001_Nf]JJgY[FVmkJeY[NV]JKg][FWg_ONh3ONl01Gg^ONmmkgg_ONh00gg_00EmkWg_
ONmmkgg^00=mk`05ONimkgg_ONmmkP03ONl06Wg^ONmmkgg_ONimkf]JJgY[FVmkJeY[NV]JKg][FV]j
JeX006]JJgY[FVmkJeY[NV]JKg/1JeX001A[FP8AhP054N4AhQ7R4N8Ah@034N801A7Q4N8AhQ7R4N40
0a7R00DAhA7R4N8AhQ7Q00<AhP054N4AhQ7R4N8Ah@034N8GJeX00bWT9N@Yi002:N@01BGT:N@Yi2WT
9N@00bWT00DUi2WT:N@Yi2GT00<Yi0059N@Yi2WT:N@Ui003:N@01BGT:N@Yi2WT9N@05V]J8cgW2f]J
00<006]JJeX026]J00EAjE7ZDNYAjU7Y00=AjP05DNUAjU7ZDNYAj@03DNX01E7YDNYAjU7ZDNT00e7Z
00EAjE7ZDNYAjU7Y00=AjP03DNUAjU7Z00][FP03001[FV]J00Q[FP=Yk005INaYk6W/JNaUk003JN`0
1FG/JNaYk6W/IN`00fW/00EUk6W/JNaYk6G/00=Yk005INaYk6W/JNaUk003JN`;JeX00`00JeY[FP08
JeXSONl;JeX00`00JeY[FP07JeX00028Kg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]J
JgY[FVmk4N4EhQ7Q5N8AhAGR4N4EhQ7Q5N8AhAGR4N4EhQ7Q5N8AhAGR4N4EhQ7Q5N8AhAGR4N4EhQ7Q
5N8AhAGR4N4EhV]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]J
:NDUi2WU9N@YiBGT:NDUi2WU9N@YiBGT:NDUi2WU9N@YiBGT:NDUi2WU9N@YiBGT:NDUi2WU9N@YiBGT
:NDUi6]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FSgW>NH3?NL0
1CWV?NLmicgW>NH00cgW00DiiSgW?NLmicWV00<mi`05>NHmicgW?NLiiP03?NL0SSWV?NLmicgWJeY_
Nf]JJgY[FVmkJeY[NV]JKg][FV]j001_Nf]JJgY[FVmkJeY[NV]JKg][FV]jDNUEjU7YENYAjEGZDNUE
jU7YENYAjEGZDNUEjU7YENYAjEGZDNUEjU7YENYAjEGZDNUEjU7YENYAjEGZDNUEjU7YKg][FV]jJeY_
Nf]JJgY[FVmkJeY[NV]J001[FV]jJeY_Nf]JJgY[FVmkJeY[NV]JJNeUk6W]INaYkFG/JNeUk6W]INaY
kFG/JNeUk6W]INaYkFG/JNeUk6W]INaYkFG/JNeUk6W]INaYkFG/JNeUk6W]JeY[NV]JKg][FV]jJeY_
Nf]JJgY[FVmk001[NV]JKg][FV]jJeY_Nf]JJgY[FVmk0Wg_00EmkWg_ONmmkgg^00=mk`05ONimkgg_
ONmmkP03ONl01Gg^ONmmkgg_ONh00gg_00EmkWg_ONmmkgg^009mk`0EJgY[FVmkJeY[NV]JKg][FV]j
JeY_Nf]J001[FVmkJeY[NV]JKg][FV]j005[FP005F]J0a7R00DAhA7R4N8AhQ7Q00<AhP054N4AhQ7R
4N8Ah@034N801A7Q4N8AhQ7R4N400a7R00@AhA7R4N8AhQY[FP8Yi0059N@Yi2WT:N@Ui003:N@01BGT
:N@Yi2WT9N@00bWT00DUi2WT:N@Yi2GT00<Yi0059N@Yi2WT:N@Ui00JJeXO?NL=JeX00`00JeY[FP0:
JeX01E7YDNYAjU7ZDNT00e7Z00EAjE7ZDNYAjU7Y00=AjP05DNUAjU7ZDNYAj@03DNX01E7YDNYAjU7Z
DNT00U7Z3F]J00<006]JJeX02V]J0fW/00EUk6W/JNaYk6G/00=Yk005INaYk6W/JNaUk003JN`01FG/
JNaYk6W/IN`00fW/00AUk6W/JNaYk0e[FP03001[FV]J00Y[FQmmk`e[FP03001[FV]J00M[FP0008Y[
NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FQGR4N4EhQ7Q5N8AhAGR4N4E
hQ7Q5N8AhAGR4N4EhQ7Q5N8AhAGR4N4EhQ7Q5N8AhAGR4N4EhQ7Q5N9[FV]jJeY_Nf]JJgY[FVmkJeY[
NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_NbGT:NDUi2WU9N@YiBGT:NDUi2WU9N@Y
iBGT:NDUi2WU9N@YiBGT:NDUi2WU9N@YiBGT:NDUi2WU9NA[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[
NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FSgW>NH3?NL01CWV?NLmicgW>NH00cgW00DiiSgW
?NLmicWV00<mi`05>NHmicgW?NLiiP03?NL0SV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg/006]j
JeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jDNUEjU7YENYAjEGZDNUEjU7YENYAjEGZDNUEjU7YENYAjEGZ
DNUEjU7YENYAjEGZDNUEjU7YENYAjFmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeX006]JKg][FV]j
JeY_Nf]JJgY[FVmkJeY[NV]JJNeUk6W]INaYkFG/JNeUk6W]INaYkFG/JNeUk6W]INaYkFG/JNeUk6W]
INaYkFG/JNeUk6W]INaYkF]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgX006mkJeY[NV]JKg][FV]j
JeY_Nf]JJgY[FVmk0Wg_00EmkWg_ONmmkgg^00=mk`05ONimkgg_ONmmkP03ONl01Gg^ONmmkgg_ONh0
0gg_01YmkWg_ONm[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]J001[FV]jJeY_Nf]JJgY[FVmk0F]J
000GJeX34N801A7Q4N8AhQ7R4N400a7R00DAhA7R4N8AhQ7Q00<AhP054N4AhQ7R4N8Ah@034N8NJeX2
:N@01BGT:N@Yi2WT9N@00bWT00DUi2WT:N@Yi2GT00<Yi0059N@Yi2WT:N@Ui003:N@00bGTJeY[FP0L
JeXK?NL?JeX00`00JeY[FP0<JeX01E7YDNYAjU7ZDNT00e7Z00EAjE7ZDNYAjU7Y00=AjP05DNUAjU7Z
DNYAj@03DNX00e7YDNYAjP0?JeX00`00JeY[FP0<JeX3JN`01FG/JNaYk6W/IN`00fW/00EUk6W/JNaY
k6G/00=Yk005INaYk6W/JNaUk003JN`?JeX00`00JeY[FP0<JeXKONl?JeX00`00JeY[FP07JeX0002<
Kg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]J5N8AhAGR4N4EhQ7Q
5N8AhAGR4N4EhQ7Q5N8AhAGR4N4EhQ7Q5N8AhAGR4N4EhQ7Q5N9[FV]jJeY_Nf]JJgY[FVmkJeY[NV]J
Kg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmk9N@YiBGT:NDUi2WU9N@YiBGT
:NDUi2WU9N@YiBGT:NDUi2WU9N@YiBGT:NDUi2WU9NA[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]J
Kg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]J?NLiiP<mi`05>NHmicgW?NLiiP03?NL0
1CWV?NLmicgW>NH00cgW09HiiSgW?NLmif]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]j001_
Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgYAjEGZDNUEjU7YENYAjEGZDNUEjU7YENYAjEGZDNUE
jU7YENYAjEGZDNUEjU7YENYAjFmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]J001[FV]jJeY_
Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeYYkFG/JNeUk6W]INaYkFG/JNeUk6W]INaYkFG/JNeUk6W]INaY
kFG/JNeUk6W]INaYkF]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmk001[NV]JKg][FV]jJeY_
Nf]JJgY[FVmkJeY[NV]JKg/2ONl01Gg^ONmmkgg_ONh00gg_00EmkWg_ONmmkgg^00=mk`05ONimkgg_
ONmmkP02ONl06F]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]J001[FVmkJeY[NV]JKg][FV]j
005[FP006F]J0a7R00DAhA7R4N8AhQ7Q00<AhP054N4AhQ7R4N8Ah@034N800a7Q4N8AhP0SJeX2:N@0
1BGT:N@Yi2WT9N@00bWT00DUi2WT:N@Yi2GT00<Yi0049N@Yi2WT:N@SJeXF?NLBJeX00`00JeY[FP0>
JeX01E7YDNYAjU7ZDNT00e7Z00EAjE7ZDNYAjU7Y00=AjP06DNUAjU7ZDNYAjE7Z4V]J00<006]JJeX0
3V]J0fW/00EUk6W/JNaYk6G/00=Yk005INaYk6W/JNaUk003JN`00fG/JNaYk00BJeX00`00JeY[FP0>
JeXFONlBJeX00`00JeY[FP07JeX0002>JgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]J
Kg][FV]jJeY_Nf]JJgY[FVmk4N4EhQ7Q5N8AhAGR4N4EhQ7Q5N8AhAGR4N4EhQ7Q5N8AhAGR4N5_Nf]J
JgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]J
Kg][FV]jJeY_Nf]J:NDUi2WU9N@YiBGT:NDUi2WU9N@YiBGT:NDUi2WU9N@YiBGT:NE[FV]jJeY_Nf]J
JgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]J
Kg][FV]j>NH3?NL01CWV?NLmicgW>NH00cgW00DiiSgW?NLmicWV008mi`2GJgY[FVmkJeY[NV]JKg][
FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg/006]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[
FUGZDNUEjU7YENYAjEGZDNUEjU7YENYAjEGZDNUEjU7YENYAjEGZJeY_Nf]JJgY[FVmkJeY[NV]JKg][
FV]jJeY_Nf]JJgY[FVmkJeX006]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_NfG/JNeU
k6W]INaYkFG/JNeUk6W]INaYkFG/JNeUk6W]INaYkFG/Kg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][
FV]jJeY_Nf]JJgX006mkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg/00Wg_00EmkWg_ONmm
kgg^00=mk`05ONimkgg_ONmmkP03ONl07Wg^ONm[FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_
Nf]JJgY[FP00JeY[NV]JKg][FV]jJeY_N`5[FP0076]J0Q7R00DAhA7R4N8AhQ7Q00<AhP064N4AhQ7R
4N8AhA7R:F]J00<Yi2GT:N@00RWT00DUi2WT:N@Yi2GT00<Yi0039N@Yi2WT02U[FQ0miaE[FP03001[
FV]J015[FP=AjP05DNUAjU7ZDNYAj@03DNX01E7YDNYAjU7ZDNT05F]J00<006]JJeX04F]J0VW/00EU
k6W/JNaYk6G/00=Yk006INaYk6W/JNaUk6W/5F]J00<006]JJeX04F]J47g_5F]J00<006]JJeX01f]J
0000U6mkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]J
Kg][FV]jJeXEhQ7Q5N8AhAGR4N4EhQ7Q5N8AhF]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]J
JgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]J
Kg/Ui2WU9N@YiBGT:NDUi2WU9N@YiF]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]J
JgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeXmicWV
0cgW0:HiiSgW?NLmicWVKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[
NP00Kg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NU7YENYAjEGZDNUE
jU7YENYAjEGZJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FP00JeY[
NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVW]INaYkFG/JNeUk6W]INaY
kFG/JgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_N`00JgY[FVmkJeY[
NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_N`9mk`05ONimkgg_ONmmkP03ONl086]J
Kg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeX006]JKg][FV]jJeY_Nf]J
JgX1JeX00;=[FP03001[FV]J03I[FP03001[FV]J03I[FP03001[FV]J03I[FP03001[FV]J00M[FP00
0?m[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]j
JeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmk
JeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]j
JeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmk
JeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]j
JeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmk
001[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]j
JeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]J001[FVmk
JeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg/006Q[FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][
FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]j001_Nf]JJgY[
FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][
FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]J001[FV]jJeY_Nf]JJgY[
FVmk0F]J002cJeX00`00JeY[FP0fJeX00`00JeY[FP0fJeX00`00JeY[FP0fJeX00`00JeY[FP07JeX0
003oKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_
Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[
NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_
Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[
NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_
Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[
NP00Kg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_
Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FP00JeY[
NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]j001XJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]j
JeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_N`00JgY[FVmk
JeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]j
JeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FP00JeY_Nf]JJgY[FVmk
JeY[NP5[FP00/f]J00<006]JJeX0=V]J00<006]JJeX0=V]J00<006]JJeX0=V]J00<006]JJeX01f]J
0000of]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]J
JgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]J
Kg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]J
JgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]J
Kg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]J
JgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]J
Kg/006]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]J
JgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeX006]J
Kg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_N`00J6]JJgY[FVmkJeY[NV]JKg][FV]jJeY_
Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgX006mkJeY[
NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_
Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeX006]JJgY[FVmkJeY[
NV]JKg/1JeX00;=[FP03001[FV]J03I[FP03001[FV]J03I[FP03001[FV]J03I[FP03001[FV]J00M[
FP000?m_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[
FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][
FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[
FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][
FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[
FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][
FV]j001_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[
FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]J001[
FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgX006Q[FVmkJeY[NV]JKg][FV]jJeY_Nf]J
JgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmk001[NV]J
Kg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]J
JgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]J001[FVmkJeY[NV]J
Kg][FV]j0F]J0008JeZ/000hJeX00`00JeY[FP0fJeX00`00JeY[FP0fJeX00`00JeY[FP07JeX0003o
JgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]J
Kg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]J
JgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]J
Kg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]J
JgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]J
Kg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]J
JgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]J
Kg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FP00JeY_Nf]J
JgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmk001XJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[
NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NP00Kg][FV]jJeY_
Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[
NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FP00JeY[NV]JKg][FV]jJeY_
N`5[FP00k6]J00<006]JJeX0=V]J00<006]JJeX0=V]J00<006]JJeX01f]J0000ofmkJeY[NV]JKg][
FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[
FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][
FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[
FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][
FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[
FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][
FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[
FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeX006]JJgY[FVmkJeY[NV]JKg][
FV]jJeY_Nf]JJgY[FVmkJeY[NP00J6]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]J
JgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg/006]jJeY_Nf]JJgY[FVmkJeY[NV]J
Kg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]J
JgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeX006]JKg][FV]jJeY_Nf]JJgX1JeX00>a[FP03
001[FV]J03I[FP03001[FV]J03I[FP03001[FV]J00M[FP000?m[NV]JKg][FV]jJeY_Nf]JJgY[FVmk
JeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]j
JeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmk
JeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]j
JeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmk
JeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]j
JeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmk
JeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]j
JeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]J001[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmk
JeY[NV]JKg/006Q[FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][
FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]j001_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[
FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][
FV]jJeY_Nf]JJgY[FVmkJeY[NV]J001[FV]jJeY_Nf]JJgY[FVmk0F]J003/JeX00`00JeY[FP0fJeX0
0`00JeY[FP0fJeX00`00JeY[FP07JeX0003oKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_
Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[
NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_
Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[
NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_
Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[
NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_
Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[
NV]JKg][FV]jJeY_Nf]JJgY[FP00JeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]j001X
JeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmk
JeY[NV]JKg][FV]jJeY_N`00JgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]j
JeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmk
JeY[NV]JKg][FP00JeY_Nf]JJgY[FVmkJeY[NP5[FP00k6]J00<006]JJeX0=V]J00<006]JJeX0=V]J
00<006]JJeX01f]J0000of]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]J
Kg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]J
JgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]J
Kg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]J
JgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]J
Kg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]J
JgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]J
Kg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]J
JgY[FVmkJeX006]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_N`00J6]JJgY[FVmkJeY[
NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_
Nf]JJgX006mkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[
NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeX0
06]JJgY[FVmkJeY[NV]JKg/1JeX001i[FP0>4X8BXa:24Z<BPQ:S4X8BXa:24Z<BPQ:S4X8BXb][FP0>
:ZHZQRZV9XHZYRZ6:ZHVQRZV:XHZYRJ6:ZHZQR][FP0>?XXnZSj9?ZXnRSjZ?XTnZSj:?ZXnRCjZ?XXn
ZR][FP0>DZeBSE:]DXeB[E:=DZeBSE:]DXeB[E:=DZeBSAE[FP03001[FV]J01=[FP0>IY5Z/FZAJ[5V
TFZaJY5Z/FJAJ[5ZTFZaIY5Z/AE[FP03001[FV]J01=[FP0>O[AnU7jdOYAn]7jDO[AnU7jdOYAn]7jD
O[AnU1E[FP03001[FV]J00M[FP000?m_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[
NV]JKg][FV]jJeY_Nf]JJgXBPQJS4X8FXa:25Z<BPQJS4X8FXa:25Z<BPQJS4X8FXa:25Z<BPV]jJeY_
Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[
NV]JKg][FV]jJeXZYRJ6:ZHVQRZV9XHZYRJ6:ZHVQRZV9XHZYRJ6:ZHVQRZV9XHZYV]JKg][FV]jJeY_
Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[
NV]JKg/nRCjZ>XTnZSj9?ZXjRCjZ?XTnZSZ9?ZXnRCjZ>XTnZSj9?ZXjRFmkJeY[NV]JKg][FV]jJeY_
Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeYF
[E:=EZiBSEJ]DXeF[U:=EZeBSEJ^DXeF[E:=EZiBSEJ]DXeF[V]JJgY[FVmkJeY[NV]JKg][FV]jJeY_
Nf]JJgY[FVmkJeY[NV]J001[FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgX006QVT6Za
IY1Z/FJ@J[5VT6ZaIY1Z/FJ@J[5VT6ZaIY1Z/FJ@J[5VT6]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]j
JeY_Nf]JJgY[FVmk001[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jOYAn]GjDO[EnU7je
OYAn]GjDO[EnU7jeOYAn]GjDO[EnU7jeOYAn]F]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]j
JeY_Nf]J001[FVmkJeY[NV]JKg][FV]j0F]J000IJeX05Q:S4X8BXa:24Z<BPQ:S4X8BXa:24Z<BPQ:S
4X8BXa:24Z<BPQ:S4X8BXa:28f]J01HZQRZV9XHZYRZ6:ZHVQRZV:XHZYRJ6:ZHZQRZV9XHZYRZ6:ZHV
QRZV:XHZYR=[FP0F?ZXnRCjZ?XXnZSj9?ZXnRSjZ?XTnZSj:?ZXnRCjZ?XXnZSj9?ZXnRSjZ?XTSJeX0
5U:=DZeBSE:]DXeB[E:=DZeBSE:]DXeB[E:=DZeBSE:]DXeB[E:=DZeBSE:]4V]J00<006]JJeX03V]J
01IZ/FZAJ[5VTFZaJY5Z/FJAJ[5ZTFZaIY5Z/FZAJ[5VTFZaJY5Z/FJAJ[5ZTA9[FP03001[FV]J00i[
FP0FOYAn]7jDO[AnU7jdOYAn]7jDO[AnU7jdOYAn]7jDO[AnU7jdOYAn]7jDO[@BJeX00`00JeY[FP07
JeX0003oJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]J5Z<BPQJS
4X8FXa:25Z<BPQJS4X8FXa:25Z<BPQJS4X8FXa:25Z<BPQJS4X8FXa:25Z=[FVmkJeY[NV]JKg][FV]j
JeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]j9XHZYRJ6:ZHVQRZV
9XHZYRJ6:ZHVQRZV9XHZYRJ6:ZHVQRZV9XHZYRJ6:ZHVQRZV9XI_Nf]JJgY[FVmkJeY[NV]JKg][FV]j
JeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]J?ZXnRCjZ>XTnZSj9?ZXjRCjZ
?XTnZSZ9?ZXnRCjZ>XTnZSj9?ZXjRCjZ?XTnZSZ9?ZY[FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]j
JeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkDXeF[E:=EZiBSEJ]DXeF[U:=EZeBSEJ^
DXeF[E:=EZiBSEJ]DXeF[U:=EZeBSEJ^DXe[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FP00
JeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJ[5VT6Za001XIY1Z/FJ@J[5VT6ZaIY1Z/FJ@J[5V
T6ZaIY1Z/FJ@J[5VT6ZaIY1Z/FJ@J[5[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NP00Kg][
FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jOYAn]GjDO[EnU7jeOYAn]GjDO[EnU7jeOYAn]GjDO[En
U7jeOYAn]GjDO[EnU7jeOYA_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FP00JeY[NV]JKg][
FV]jJeY_N`5[FP005f]J01/BXa:24Z<BPQ:S4X8BXa:24Z<BPQ:S4X8BXa:24Z<BPQ:S4X8BXa:24Z<B
PQ:S4X8BXa:24Z<07V]J01/ZQRZV9XHZYRZ6:ZHVQRZV:XHZYRJ6:ZHZQRZV9XHZYRZ6:ZHVQRZV:XHZ
YRJ6:ZHZQRZV9XH07V]J01/nZSj9?ZXnRSjZ?XTnZSj:?ZXnRCjZ?XXnZSj9?ZXnRSjZ?XTnZSj:?ZXn
RCjZ?XXnZSj9?ZX07V]J01]BSE:]DXeB[E:=DZeBSE:]DXeB[E:=DZeBSE:]DXeB[E:=DZeBSE:]DXeB
[E:=DZeBSE:]DXd03f]J00<006]JJeX036]J01]Z/FZAJ[5VTFZaJY5Z/FJAJ[5ZTFZaIY5Z/FZAJ[5V
TFZaJY5Z/FJAJ[5ZTFZaIY5Z/FZAJ[403f]J00<006]JJeX036]J01]nU7jdOYAn]7jDO[AnU7jdOYAn
]7jDO[AnU7jdOYAn]7jDO[AnU7jdOYAn]7jDO[AnU7jdOY@03f]J00<006]JJeX01f]J0000ofmkJeY[
NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]J5Z<BPQJS4X8FXa:25Z<BPQJS4X8F
Xa:25Z<BPQJS4X8FXa:25Z<BPQJS4X8FXa:25Z<BPQJS4X8FXf]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[
NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]j9XHZYRJ6:ZHVQRZV9XHZYRJ6:ZHVQRZV9XHZ
YRJ6:ZHVQRZV9XHZYRJ6:ZHVQRZV9XHZYRJ6:ZHVQVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[
NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]J?ZXnRCjZ>XTnZSj9?ZXjRCjZ?XTnZSZ9?ZXnRCjZ>XTn
ZSj9?ZXjRCjZ?XTnZSZ9?ZXnRCjZ>XTnZV]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[
NV]JKg][FV]jJeY_Nf]JJgY[FVmkDXeF[E:=EZiBSEJ]DXeF[U:=EZeBSEJ^DXeF[E:=EZiBSEJ]DXeF
[U:=EZeBSEJ^DXeF[E:=EZiBSF]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeX006]JJgY[FVmkJeY[
NV]JKg][FV]jJeY_Nf]JJ[5VT6ZaIY1Z/@00J6J@J[5VT6ZaIY1Z/FJ@J[5VT6ZaIY1Z/FJ@J[5VT6Za
IY1Z/FJ@J[5VT6ZaIY1Z/F]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg/006]jJeY_Nf]JJgY[FVmk
JeY[NV]JKg][FV]jOYAn]GjDO[EnU7jeOYAn]GjDO[EnU7jeOYAn]GjDO[EnU7jeOYAn]GjDO[EnU7je
OYAn]GjDO[EnU6mkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeX006]JKg][FV]jJeY_Nf]JJgX1JeX0
01E[FP0O4Z<BPQ:S4X8BXa:24Z<BPQ:S4X8BXa:24Z<BPQ:S4X8BXa:24Z<BPQ:S4X8BXa:24Z<BPQ:S
4X8BXa:24Z<06V]J01lZQRZV9XHZYRZ6:ZHVQRZV:XHZYRJ6:ZHZQRZV9XHZYRZ6:ZHVQRZV:XHZYRJ6
:ZHZQRZV9XHZYRZ6:ZHVQP0JJeX07cjZ?XTnZSj:?ZXnRCjZ?XXnZSj9?ZXnRSjZ?XTnZSj:?ZXnRCjZ
?XXnZSj9?ZXnRSjZ?XTnZSj:?ZXnRCjZ01Y[FP0ODXeB[E:=DZeBSE:]DXeB[E:=DZeBSE:]DXeB[E:=
DZeBSE:]DXeB[E:=DZeBSE:]DXeB[E:=DZeBSE:]DXd03F]J00<006]JJeX02V]J01mZ/FZAJ[5VTFZa
JY5Z/FJAJ[5ZTFZaIY5Z/FZAJ[5VTFZaJY5Z/FJAJ[5ZTFZaIY5Z/FZAJ[5VTFZaJY5Z/@0=JeX00`00
JeY[FP0:JeX07gjDO[AnU7jdOYAn]7jDO[AnU7jdOYAn]7jDO[AnU7jdOYAn]7jDO[AnU7jdOYAn]7jD
O[AnU7jdOYAn]7jD00e[FP03001[FV]J00M[FP000?m[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]J
Kg][FV]jJeY_Nf]JJgXBPQJS4X8FXa:25Z<BPQJS4X8FXa:25Z<BPQJS4X8FXa:25Z<BPQJS4X8FXa:2
5Z<BPQJS4X8FXa:25Z<BPQJSJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]J
Kg][FV]jJeXZYRJ6:ZHVQRZV9XHZYRJ6:ZHVQRZV9XHZYRJ6:ZHVQRZV9XHZYRJ6:ZHVQRZV9XHZYRJ6
:ZHVQRZV9XHZYRJ6Kg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]J
?ZXnRCjZ>XTnZSj9?ZXjRCjZ?XTnZSZ9?ZXnRCjZ>XTnZSj9?ZXjRCjZ?XTnZSZ9?ZXnRCjZ>XTnZSj9
?ZXjRCjZJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkDXeF[E:=
EZiBSEJ]DXeF[U:=EZeBSEJ^DXeF[E:=EZiBSEJ]DXeF[U:=EZeBSEJ^DXeF[E:=EZiBSEJ]DXeF[U:=
JgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]J001[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJ[5VT6ZaIY1Z/FJ@
J[4006QVT6ZaIY1Z/FJ@J[5VT6ZaIY1Z/FJ@J[5VT6ZaIY1Z/FJ@J[5VT6ZaIY1Z/FJ@J[5VT6ZaJeY_
Nf]JJgY[FVmkJeY[NV]JKg][FV]j001_Nf]JJgY[FVmkJeY[NV]JKg][FV]jOYAn]GjDO[EnU7jeOYAn
]GjDO[EnU7jeOYAn]GjDO[EnU7jeOYAn]GjDO[EnU7jeOYAn]GjDO[EnU7jeOYAn]GjDKg][FV]jJeY_
Nf]JJgY[FVmkJeY[NV]J001[FV]jJeY_Nf]JJgY[FVmk0F]J000DJeX08Q:24Z<BPQ:S4X8BXa:24Z<B
PQ:S4X8BXa:24Z<BPQ:S4X8BXa:24Z<BPQ:S4X8BXa:24Z<BPQ:S4X8BXa:24Z<BPQ:S5f]J028ZYRJ6
:ZHZQRZV9XHZYRZ6:ZHVQRZV:XHZYRJ6:ZHZQRZV9XHZYRZ6:ZHVQRZV:XHZYRJ6:ZHZQRZV9XHZYRZ6
:ZHVQQI[FP0S?ZXnRCjZ?XXnZSj9?ZXnRSjZ?XTnZSj:?ZXnRCjZ?XXnZSj9?ZXnRSjZ?XTnZSj:?ZXn
RCjZ?XXnZSj9?ZXnRSjZ?XTnZP0FJeX08e:=DZeBSE:]DXeB[E:=DZeBSE:]DXeB[E:=DZeBSE:]DXeB
[E:=DZeBSE:]DXeB[E:=DZeBSE:]DXeB[E:=DZeBSE:]DXd02f]J00<006]JJeX026]J02=Z/FZAJ[5V
TFZaJY5Z/FJAJ[5ZTFZaIY5Z/FZAJ[5VTFZaJY5Z/FJAJ[5ZTFZaIY5Z/FZAJ[5VTFZaJY5Z/FJAJ[5Z
TFZa00][FP03001[FV]J00Q[FP0SOYAn]7jDO[AnU7jdOYAn]7jDO[AnU7jdOYAn]7jDO[AnU7jdOYAn
]7jDO[AnU7jdOYAn]7jDO[AnU7jdOYAn]7jDO[AnU00;JeX00`00JeY[FP07JeX0003oKg][FV]jJeY_
Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FQJS4X8FXa:25Z<BPQJS4X8FXa:25Z<BPQJS4X8F
Xa:25Z<BPQJS4X8FXa:25Z<BPQJS4X8FXa:25Z<BPQJS4X8FXa:2JgY[FVmkJeY[NV]JKg][FV]jJeY_
Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_NbJ6:ZHVQRZV9XHZYRJ6:ZHVQRZV9XHZYRJ6:ZHVQRZV9XHZ
YRJ6:ZHVQRZV9XHZYRJ6:ZHVQRZV9XHZYRJ6:ZHVQRZVJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_
Nf]JJgY[FVmkJeY[NV]JKg/nRCjZ>XTnZSj9?ZXjRCjZ?XTnZSZ9?ZXnRCjZ>XTnZSj9?ZXjRCjZ?XTn
ZSZ9?ZXnRCjZ>XTnZSj9?ZXjRCjZ?XTnZSZ9Kg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_
Nf]JJgY[FVmkJeYF[E:=EZiBSEJ]DXeF[U:=EZeBSEJ^DXeF[E:=EZiBSEJ]DXeF[U:=EZeBSEJ^DXeF
[E:=EZiBSEJ]DXeF[U:=EZeBSEJ^JeY[NV]JKg][FV]jJeY_Nf]JJgY[FP00JeY[NV]JKg][FV]jJeY_
Nf]JJgYVT6ZaIY1Z/FJ@J[5VT6Za001XIY1Z/FJ@J[5VT6ZaIY1Z/FJ@J[5VT6ZaIY1Z/FJ@J[5VT6Za
IY1Z/FJ@J[5VT6ZaIY1Z/FJ@JgY[FVmkJeY[NV]JKg][FV]jJeY_N`00JgY[FVmkJeY[NV]JKg][FV]j
JeYn]GjDO[EnU7jeOYAn]GjDO[EnU7jeOYAn]GjDO[EnU7jeOYAn]GjDO[EnU7jeOYAn]GjDO[EnU7je
OYAn]GjDO[EnU7jeJeY_Nf]JJgY[FVmkJeY[NV]JKg][FP00JeY_Nf]JJgY[FVmkJeY[NP5[FP004f]J
02@BXa:24Z<BPQ:S4X8BXa:24Z<BPQ:S4X8BXa:24Z<BPQ:S4X8BXa:24Z<BPQ:S4X8BXa:24Z<BPQ:S
4X8BXa:24Z<BPQ:S4X8EJeX092J6:ZHZQRZV9XHZYRZ6:ZHVQRZV:XHZYRJ6:ZHZQRZV9XHZYRZ6:ZHV
QRZV:XHZYRJ6:ZHZQRZV9XHZYRZ6:ZHVQRZV:XHZYQE[FP0T?ZXnRSjZ?XTnZSj:?ZXnRCjZ?XXnZSj9
?ZXnRSjZ?XTnZSj:?ZXnRCjZ?XXnZSj9?ZXnRSjZ?XTnZSj:?ZXnRCjZ?XXnZSj95F]J02ABSE:]DXeB
[E:=DZeBSE:]DXeB[E:=DZeBSE:]DXeB[E:=DZeBSE:]DXeB[E:=DZeBSE:]DXeB[E:=DZeBSE:]DXeB
[E:=DZd:JeX00`00JeY[FP08JeX096ZaIY5Z/FZAJ[5VTFZaJY5Z/FJAJ[5ZTFZaIY5Z/FZAJ[5VTFZa
JY5Z/FJAJ[5ZTFZaIY5Z/FZAJ[5VTFZaJY5Z/FJAJ[5ZT@Y[FP03001[FV]J00M[FP0UO[AnU7jdOYAn
]7jDO[AnU7jdOYAn]7jDO[AnU7jdOYAn]7jDO[AnU7jdOYAn]7jDO[AnU7jdOYAn]7jDO[AnU7jdOYAn
]7jDO[@02V]J00<006]JJeX01f]J0000of]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[
FVmk4X8FXa:25Z<BPQJS4X8FXa:25Z<BPQJS4X8FXa:25Z<BPQJS4X8FXa:25Z<BPQJS4X8FXa:25Z<B
PQJS4X8FXa:25Z<BPQJSJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]J:ZHV
QRZV9XHZYRJ6:ZHVQRZV9XHZYRJ6:ZHVQRZV9XHZYRJ6:ZHVQRZV9XHZYRJ6:ZHVQRZV9XHZYRJ6:ZHV
QRZV9XHZYRJ6JgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]j>XTnZSj9?ZXj
RCjZ?XTnZSZ9?ZXnRCjZ>XTnZSj9?ZXjRCjZ?XTnZSZ9?ZXnRCjZ>XTnZSj9?ZXjRCjZ?XTnZSZ9?ZXn
RCjZJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JEZiBSEJ]DXeF[U:=EZeB
SEJ^DXeF[E:=EZiBSEJ]DXeF[U:=EZeBSEJ^DXeF[E:=EZiBSEJ]DXeF[U:=EZeBSEJ^DXeF[E:=Kg][
FV]jJeY_Nf]JJgY[FVmkJeX006]JKg][FV]jJeY_Nf]JJgY[FVmkIY1Z/FJ@J[5VT6ZaIY1Z/@00J6J@
J[5VT6ZaIY1Z/FJ@J[5VT6ZaIY1Z/FJ@J[5VT6ZaIY1Z/FJ@J[5VT6ZaIY1Z/FJ@J[5VT6ZaJeY[NV]J
Kg][FV]jJeY_Nf]JJgX006mkJeY[NV]JKg][FV]jJeY_NgjDO[EnU7jeOYAn]GjDO[EnU7jeOYAn]GjD
O[EnU7jeOYAn]GjDO[EnU7jeOYAn]GjDO[EnU7jeOYAn]GjDO[EnU7jeOYAn]GjDJgY[FVmkJeY[NV]J
Kg][FV]jJeX006]JJgY[FVmkJeY[NV]JKg/1JeX0019[FP0V4X8BXa:24Z<BPQ:S4X8BXa:24Z<BPQ:S
4X8BXa:24Z<BPQ:S4X8BXa:24Z<BPQ:S4X8BXa:24Z<BPQ:S4X8BXa:24Z<BPQ:S4X8BXa=[FP0V:ZHZ
QRZV9XHZYRZ6:ZHVQRZV:XHZYRJ6:ZHZQRZV9XHZYRZ6:ZHVQRZV:XHZYRJ6:ZHZQRZV9XHZYRZ6:ZHV
QRZV:XHZYRJ6:ZHZQQ=[FP0V?XXnZSj9?ZXnRSjZ?XTnZSj:?ZXnRCjZ?XXnZSj9?ZXnRSjZ?XTnZSj:
?ZXnRCjZ?XXnZSj9?ZXnRSjZ?XTnZSj:?ZXnRCjZ?XXnZQ=[FP0VDZeBSE:]DXeB[E:=DZeBSE:]DXeB
[E:=DZeBSE:]DXeB[E:=DZeBSE:]DXeB[E:=DZeBSE:]DXeB[E:=DZeBSE:]DXeB[E:=DZeBS@U[FP03
001[FV]J00M[FP0VIY5Z/FZAJ[5VTFZaJY5Z/FJAJ[5ZTFZaIY5Z/FZAJ[5VTFZaJY5Z/FJAJ[5ZTFZa
IY5Z/FZAJ[5VTFZaJY5Z/FJAJ[5ZTFZaIY5Z/@U[FP03001[FV]J00M[FP0VO[AnU7jdOYAn]7jDO[An
U7jdOYAn]7jDO[AnU7jdOYAn]7jDO[AnU7jdOYAn]7jDO[AnU7jdOYAn]7jDO[AnU7jdOYAn]7jDO[An
U0U[FP03001[FV]J00M[FP000?m_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeXFXa:2
5Z<BPQJS4X8FXa:25Z<BPQJS4X8FXa:25Z<BPQJS4X8FXa:25Z<BPQJS4X8FXa:25Z<BPQJS4X8FXa:2
5Z<BPQJS4X8FXa:2Kg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgXVQRZV9XHZYRJ6
:ZHVQRZV9XHZYRJ6:ZHVQRZV9XHZYRJ6:ZHVQRZV9XHZYRJ6:ZHVQRZV9XHZYRJ6:ZHVQRZV9XHZYRJ6
:ZHVQRZVJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeXnZSj9?ZXjRCjZ?XTnZSZ9
?ZXnRCjZ>XTnZSj9?ZXjRCjZ?XTnZSZ9?ZXnRCjZ>XTnZSj9?ZXjRCjZ?XTnZSZ9?ZXnRCjZ>XTnZSj9
JgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg]BSEJ]DXeF[U:=EZeBSEJ^DXeF[E:=
EZiBSEJ]DXeF[U:=EZeBSEJ^DXeF[E:=EZiBSEJ]DXeF[U:=EZeBSEJ^DXeF[E:=EZiBSEJ]JeY_Nf]J
JgY[FVmkJeY[NV]J001[FV]jJeY_Nf]JJgY[FVmkJeYZ/FJ@J[5VT6ZaIY1Z/FJ@J[4006QVT6ZaIY1Z
/FJ@J[5VT6ZaIY1Z/FJ@J[5VT6ZaIY1Z/FJ@J[5VT6ZaIY1Z/FJ@J[5VT6ZaIY1Z/FJ@Kg][FV]jJeY_
Nf]JJgY[FVmk001[NV]JKg][FV]jJeY_Nf]JJgYnU7jeOYAn]GjDO[EnU7jeOYAn]GjDO[EnU7jeOYAn
]GjDO[EnU7jeOYAn]GjDO[EnU7jeOYAn]GjDO[EnU7jeOYAn]GjDO[EnU7jeJeY[NV]JKg][FV]jJeY_
Nf]J001[FVmkJeY[NV]JKg][FV]j0F]J000AJeX09a:S4X8BXa:24Z<BPQ:S4X8BXa:24Z<BPQ:S4X8B
Xa:24Z<BPQ:S4X8BXa:24Z<BPQ:S4X8BXa:24Z<BPQ:S4X8BXa:24Z<BPQ:S4X8BX`0BJeX09bZ6:ZHV
QRZV:XHZYRJ6:ZHZQRZV9XHZYRZ6:ZHVQRZV:XHZYRJ6:ZHZQRZV9XHZYRZ6:ZHVQRZV:XHZYRJ6:ZHZ
QRZV9XHZYRZ6:ZHVQP0BJeX09cjZ?XTnZSj:?ZXnRCjZ?XXnZSj9?ZXnRSjZ?XTnZSj:?ZXnRCjZ?XXn
ZSj9?ZXnRSjZ?XTnZSj:?ZXnRCjZ?XXnZSj9?ZXnRSjZ?XTnZP0BJeX09e:=DZeBSE:]DXeB[E:=DZeB
SE:]DXeB[E:=DZeBSE:]DXeB[E:=DZeBSE:]DXeB[E:=DZeBSE:]DXeB[E:=DZeBSE:]DXeB[E:=DZeB
S@09JeX00`00JeY[FP06JeX09fZaJY5Z/FJAJ[5ZTFZaIY5Z/FZAJ[5VTFZaJY5Z/FJAJ[5ZTFZaIY5Z
/FZAJ[5VTFZaJY5Z/FJAJ[5ZTFZaIY5Z/FZAJ[5VTFZaJY5Z/@09JeX00`00JeY[FP06JeX09gjDO[An
U7jdOYAn]7jDO[AnU7jdOYAn]7jDO[AnU7jdOYAn]7jDO[AnU7jdOYAn]7jDO[AnU7jdOYAn]7jDO[An
U7jdOYAn]7jDO[AnU009JeX00`00JeY[FP07JeX0003oJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[
FVmkJeY[NQ:25Z<BPQJS4X8FXa:25Z<BPQJS4X8FXa:25Z<BPQJS4X8FXa:25Z<BPQJS4X8FXa:25Z<B
PQJS4X8FXa:25Z<BPQJS4X8FXa:25Z<BPV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[
FRZV9XHZYRJ6:ZHVQRZV9XHZYRJ6:ZHVQRZV9XHZYRJ6:ZHVQRZV9XHZYRJ6:ZHVQRZV9XHZYRJ6:ZHV
QRZV9XHZYRJ6:ZHVQRZV9XHZYV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Ncj9?ZXj
RCjZ?XTnZSZ9?ZXnRCjZ>XTnZSj9?ZXjRCjZ?XTnZSZ9?ZXnRCjZ>XTnZSj9?ZXjRCjZ?XTnZSZ9?ZXn
RCjZ>XTnZSj9?ZXjRFmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FUJ]DXeF[U:=EZeB
SEJ^DXeF[E:=EZiBSEJ]DXeF[U:=EZeBSEJ^DXeF[E:=EZiBSEJ]DXeF[U:=EZeBSEJ^DXeF[E:=EZiB
SEJ]DXeF[V]JJgY[FVmkJeY[NV]JKg][FP00JeY_Nf]JJgY[FVmkJeY[NVJ@J[5VT6ZaIY1Z/FJ@J[5V
T6Za001XIY1Z/FJ@J[5VT6ZaIY1Z/FJ@J[5VT6ZaIY1Z/FJ@J[5VT6ZaIY1Z/FJ@J[5VT6ZaIY1Z/FJ@
J[5VT6]jJeY_Nf]JJgY[FVmkJeY[NP00Kg][FV]jJeY_Nf]JJgY[FWjeOYAn]GjDO[EnU7jeOYAn]GjD
O[EnU7jeOYAn]GjDO[EnU7jeOYAn]GjDO[EnU7jeOYAn]GjDO[EnU7jeOYAn]GjDO[EnU7jeOYAn]F]J
Kg][FV]jJeY_Nf]JJgY[FP00JeY[NV]JKg][FV]jJeY_N`5[FP004F]J02LBXa:24Z<BPQ:S4X8BXa:2
4Z<BPQ:S4X8BXa:24Z<BPQ:S4X8BXa:24Z<BPQ:S4X8BXa:24Z<BPQ:S4X8BXa:24Z<BPQ:S4X8BXa:2
4Z<04V]J02LVQRZV:XHZYRJ6:ZHZQRZV9XHZYRZ6:ZHVQRZV:XHZYRJ6:ZHZQRZV9XHZYRZ6:ZHVQRZV
:XHZYRJ6:ZHZQRZV9XHZYRZ6:ZHVQRZV:XH04V]J02LnZSj:?ZXnRCjZ?XXnZSj9?ZXnRSjZ?XTnZSj:
?ZXnRCjZ?XXnZSj9?ZXnRSjZ?XTnZSj:?ZXnRCjZ?XXnZSj9?ZXnRSjZ?XTnZSj:?ZX04V]J02MBSE:]
DXeB[E:=DZeBSE:]DXeB[E:=DZeBSE:]DXeB[E:=DZeBSE:]DXeB[E:=DZeBSE:]DXeB[E:=DZeBSE:]
DXeB[E:=DZeBSE:]DXd02F]J00<006]JJeX01V]J02MZ/FJAJ[5ZTFZaIY5Z/FZAJ[5VTFZaJY5Z/FJA
J[5ZTFZaIY5Z/FZAJ[5VTFZaJY5Z/FJAJ[5ZTFZaIY5Z/FZAJ[5VTFZaJY5Z/FJAJ[402F]J00<006]J
JeX01V]J02MnU7jdOYAn]7jDO[AnU7jdOYAn]7jDO[AnU7jdOYAn]7jDO[AnU7jdOYAn]7jDO[AnU7jd
OYAn]7jDO[AnU7jdOYAn]7jDO[AnU7jdOY@02F]J00<006]JJeX01f]J0000ofmkJeY[NV]JKg][FV]j
JeY_Nf]JJgY[FVmkJeY[NV]JKg/BPQJS4X8FXa:25Z<BPQJS4X8FXa:25Z<BPQJS4X8FXa:25Z<BPQJS
4X8FXa:25Z<BPQJS4X8FXa:25Z<BPQJS4X8FXa:25Z<BPQJS4X9_Nf]JJgY[FVmkJeY[NV]JKg][FV]j
JeY_Nf]JJgY[FVmkJeXZYRJ6:ZHVQRZV9XHZYRJ6:ZHVQRZV9XHZYRJ6:ZHVQRZV9XHZYRJ6:ZHVQRZV
9XHZYRJ6:ZHVQRZV9XHZYRJ6:ZHVQRZV9XHZYRJ6:ZI[FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]j
JeY_Nf]JJgXjRCjZ?XTnZSZ9?ZXnRCjZ>XTnZSj9?ZXjRCjZ?XTnZSZ9?ZXnRCjZ>XTnZSj9?ZXjRCjZ
?XTnZSZ9?ZXnRCjZ>XTnZSj9?ZXjRCjZ?XU[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]j
JeYF[U:=EZeBSEJ^DXeF[E:=EZiBSEJ]DXeF[U:=EZeBSEJ^DXeF[E:=EZiBSEJ]DXeF[U:=EZeBSEJ^
DXeF[E:=EZiBSEJ]DXeF[U:=EZe[FVmkJeY[NV]JKg][FV]jJeX006]JJgY[FVmkJeY[NV]JKg]VT6Za
IY1Z/FJ@J[5VT6ZaIY1Z/@00J6J@J[5VT6ZaIY1Z/FJ@J[5VT6ZaIY1Z/FJ@J[5VT6ZaIY1Z/FJ@J[5V
T6ZaIY1Z/FJ@J[5VT6ZaIY1_Nf]JJgY[FVmkJeY[NV]JKg/006]jJeY_Nf]JJgY[FVmkJeYn]GjDO[En
U7jeOYAn]GjDO[EnU7jeOYAn]GjDO[EnU7jeOYAn]GjDO[EnU7jeOYAn]GjDO[EnU7jeOYAn]GjDO[En
U7jeOYAn]GjDO[E[FV]jJeY_Nf]JJgY[FVmkJeX006]JKg][FV]jJeY_Nf]JJgX1JeX0015[FP0W4Z<B
PQ:S4X8BXa:24Z<BPQ:S4X8BXa:24Z<BPQ:S4X8BXa:24Z<BPQ:S4X8BXa:24Z<BPQ:S4X8BXa:24Z<B
PQ:S4X8BXa:24Z<BPQ:S019[FP0W:XHZYRJ6:ZHZQRZV9XHZYRZ6:ZHVQRZV:XHZYRJ6:ZHZQRZV9XHZ
YRZ6:ZHVQRZV:XHZYRJ6:ZHZQRZV9XHZYRZ6:ZHVQRZV:XHZYRJ6019[FP0W?ZXnRCjZ?XXnZSj9?ZXn
RSjZ?XTnZSj:?ZXnRCjZ?XXnZSj9?ZXnRSjZ?XTnZSj:?ZXnRCjZ?XXnZSj9?ZXnRSjZ?XTnZSj:?ZXn
RCjZ019[FP0WDXeB[E:=DZeBSE:]DXeB[E:=DZeBSE:]DXeB[E:=DZeBSE:]DXeB[E:=DZeBSE:]DXeB
[E:=DZeBSE:]DXeB[E:=DZeBSE:]DXeB[E:=00U[FP03001[FV]J00I[FP0WJ[5ZTFZaIY5Z/FZAJ[5V
TFZaJY5Z/FJAJ[5ZTFZaIY5Z/FZAJ[5VTFZaJY5Z/FJAJ[5ZTFZaIY5Z/FZAJ[5VTFZaJY5Z/FJAJ[5Z
TFZa00U[FP03001[FV]J00I[FP0WOYAn]7jDO[AnU7jdOYAn]7jDO[AnU7jdOYAn]7jDO[AnU7jdOYAn
]7jDO[AnU7jdOYAn]7jDO[AnU7jdOYAn]7jDO[AnU7jdOYAn]7jD00U[FP03001[FV]J00M[FP000?m[
NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]j4X8FXa:25Z<BPQJS4X8FXa:25Z<BPQJS4X8F
Xa:25Z<BPQJS4X8FXa:25Z<BPQJS4X8FXa:25Z<BPQJS4X8FXa:25Z<BPQJS4X8FXa:2JgY[FVmkJeY[
NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]J:ZHVQRZV9XHZYRJ6:ZHVQRZV9XHZYRJ6:ZHVQRZV9XHZ
YRJ6:ZHVQRZV9XHZYRJ6:ZHVQRZV9XHZYRJ6:ZHVQRZV9XHZYRJ6:ZHVQRZVJeY_Nf]JJgY[FVmkJeY[
NV]JKg][FV]jJeY_Nf]JJgY[FVmk?XTnZSZ9?ZXnRCjZ>XTnZSj9?ZXjRCjZ?XTnZSZ9?ZXnRCjZ>XTn
ZSj9?ZXjRCjZ?XTnZSZ9?ZXnRCjZ>XTnZSj9?ZXjRCjZ?XTnZSZ9Kg][FV]jJeY_Nf]JJgY[FVmkJeY[
NV]JKg][FV]jJeY_Nf]JEZeBSEJ^DXeF[E:=EZiBSEJ]DXeF[U:=EZeBSEJ^DXeF[E:=EZiBSEJ]DXeF
[U:=EZeBSEJ^DXeF[E:=EZiBSEJ]DXeF[U:=EZeBSEJ^JeY[NV]JKg][FV]jJeY_Nf]J001[FVmkJeY[
NV]JKg][FV]jIY1Z/FJ@J[5VT6ZaIY1Z/FJ@J[4006QVT6ZaIY1Z/FJ@J[5VT6ZaIY1Z/FJ@J[5VT6Za
IY1Z/FJ@J[5VT6ZaIY1Z/FJ@J[5VT6ZaIY1Z/FJ@JgY[FVmkJeY[NV]JKg][FV]j001_Nf]JJgY[FVmk
JeY[NV]JO[EnU7jeOYAn]GjDO[EnU7jeOYAn]GjDO[EnU7jeOYAn]GjDO[EnU7jeOYAn]GjDO[EnU7je
OYAn]GjDO[EnU7jeOYAn]GjDO[EnU7jeJeY_Nf]JJgY[FVmkJeY[NV]J001[FV]jJeY_Nf]JJgY[FVmk
0F]J000AJeX09a:S4X8BXa:24Z<BPQ:S4X8BXa:24Z<BPQ:S4X8BXa:24Z<BPQ:S4X8BXa:24Z<BPQ:S
4X8BXa:24Z<BPQ:S4X8BXa:24Z<BPQ:S4X8BX`0BJeX09bJ6:ZHZQRZV9XHZYRZ6:ZHVQRZV:XHZYRJ6
:ZHZQRZV9XHZYRZ6:ZHVQRZV:XHZYRJ6:ZHZQRZV9XHZYRZ6:ZHVQRZV:XHZYRJ6:ZHZQP0BJeX09cjZ
?XXnZSj9?ZXnRSjZ?XTnZSj:?ZXnRCjZ?XXnZSj9?ZXnRSjZ?XTnZSj:?ZXnRCjZ?XXnZSj9?ZXnRSjZ
?XTnZSj:?ZXnRCjZ?XXnZP0BJeX09e:=DZeBSE:]DXeB[E:=DZeBSE:]DXeB[E:=DZeBSE:]DXeB[E:=
DZeBSE:]DXeB[E:=DZeBSE:]DXeB[E:=DZeBSE:]DXeB[E:=DZeBS@09JeX00`00JeY[FP06JeX09fZa
IY5Z/FZAJ[5VTFZaJY5Z/FJAJ[5ZTFZaIY5Z/FZAJ[5VTFZaJY5Z/FJAJ[5ZTFZaIY5Z/FZAJ[5VTFZa
JY5Z/FJAJ[5ZTFZaIY5Z/@09JeX00`00JeY[FP06JeX09gjDO[AnU7jdOYAn]7jDO[AnU7jdOYAn]7jD
O[AnU7jdOYAn]7jDO[AnU7jdOYAn]7jDO[AnU7jdOYAn]7jDO[AnU7jdOYAn]7jDO[AnU009JeX00`00
JeY[FP07JeX0003oKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Na:25Z<BPQJS4X8FXa:2
5Z<BPQJS4X8FXa:25Z<BPQJS4X8FXa:25Z<BPQJS4X8FXa:25Z<BPQJS4X8FXa:25Z<BPQJS4X8FXa:2
5Z<BPVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FRZV9XHZYRJ6:ZHVQRZV9XHZYRJ6
:ZHVQRZV9XHZYRJ6:ZHVQRZV9XHZYRJ6:ZHVQRZV9XHZYRJ6:ZHVQRZV9XHZYRJ6:ZHVQRZV9XHZYV]J
JgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NSZ9?ZXnRCjZ>XTnZSj9?ZXjRCjZ?XTnZSZ9
?ZXnRCjZ>XTnZSj9?ZXjRCjZ?XTnZSZ9?ZXnRCjZ>XTnZSj9?ZXjRCjZ?XTnZSZ9?ZXnRF]jJeY_Nf]J
JgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FUJ^DXeF[E:=EZiBSEJ]DXeF[U:=EZeBSEJ^DXeF[E:=
EZiBSEJ]DXeF[U:=EZeBSEJ^DXeF[E:=EZiBSEJ]DXeF[U:=EZeBSEJ^DXeF[F]JKg][FV]jJeY_Nf]J
JgY[FP00JeY[NV]JKg][FV]jJeY_NfJ@J[5VT6ZaIY1Z/FJ@J[5VT6Za001XIY1Z/FJ@J[5VT6ZaIY1Z
/FJ@J[5VT6ZaIY1Z/FJ@J[5VT6ZaIY1Z/FJ@J[5VT6ZaIY1Z/FJ@J[5VT6mkJeY[NV]JKg][FV]jJeY_
N`00JgY[FVmkJeY[NV]JKg][FWjeOYAn]GjDO[EnU7jeOYAn]GjDO[EnU7jeOYAn]GjDO[EnU7jeOYAn
]GjDO[EnU7jeOYAn]GjDO[EnU7jeOYAn]GjDO[EnU7jeOYAn]F]JJgY[FVmkJeY[NV]JKg][FP00JeY_
Nf]JJgY[FVmkJeY[NP5[FP004F]J02LBXa:24Z<BPQ:S4X8BXa:24Z<BPQ:S4X8BXa:24Z<BPQ:S4X8B
Xa:24Z<BPQ:S4X8BXa:24Z<BPQ:S4X8BXa:24Z<BPQ:S4X8BXa:24Z<04V]J02LZQRZV9XHZYRZ6:ZHV
QRZV:XHZYRJ6:ZHZQRZV9XHZYRZ6:ZHVQRZV:XHZYRJ6:ZHZQRZV9XHZYRZ6:ZHVQRZV:XHZYRJ6:ZHZ
QRZV9XH04V]J02LnZSj9?ZXnRSjZ?XTnZSj:?ZXnRCjZ?XXnZSj9?ZXnRSjZ?XTnZSj:?ZXnRCjZ?XXn
ZSj9?ZXnRSjZ?XTnZSj:?ZXnRCjZ?XXnZSj9?ZX04V]J02MBSE:]DXeB[E:=DZeBSE:]DXeB[E:=DZeB
SE:]DXeB[E:=DZeBSE:]DXeB[E:=DZeBSE:]DXeB[E:=DZeBSE:]DXeB[E:=DZeBSE:]DXd02F]J00<0
06]JJeX01V]J02MZ/FZAJ[5VTFZaJY5Z/FJAJ[5ZTFZaIY5Z/FZAJ[5VTFZaJY5Z/FJAJ[5ZTFZaIY5Z
/FZAJ[5VTFZaJY5Z/FJAJ[5ZTFZaIY5Z/FZAJ[402F]J00<006]JJeX01V]J02MnU7jdOYAn]7jDO[An
U7jdOYAn]7jDO[AnU7jdOYAn]7jDO[AnU7jdOYAn]7jDO[AnU7jdOYAn]7jDO[AnU7jdOYAn]7jDO[An
U7jdOY@02F]J00<006]JJeX01f]J0000of]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgXB
PQJS4X8FXa:25Z<BPQJS4X8FXa:25Z<BPQJS4X8FXa:25Z<BPQJS4X8FXa:25Z<BPQJS4X8FXa:25Z<B
PQJS4X8FXa:25Z<BPQJS4X9[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeXZYRJ6:ZHV
QRZV9XHZYRJ6:ZHVQRZV9XHZYRJ6:ZHVQRZV9XHZYRJ6:ZHVQRZV9XHZYRJ6:ZHVQRZV9XHZYRJ6:ZHV
QRZV9XHZYRJ6:ZI[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg/nRCjZ>XTnZSj9?ZXj
RCjZ?XTnZSZ9?ZXnRCjZ>XTnZSj9?ZXjRCjZ?XTnZSZ9?ZXnRCjZ>XTnZSj9?ZXjRCjZ?XTnZSZ9?ZXn
RCjZ>XU_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeYF[E:=EZiBSEJ]DXeF[U:=EZeB
SEJ^DXeF[E:=EZiBSEJ]DXeF[U:=EZeBSEJ^DXeF[E:=EZiBSEJ]DXeF[U:=EZeBSEJ^DXeF[E:=EZi[
FV]jJeY_Nf]JJgY[FVmkJeX006]JKg][FV]jJeY_Nf]JJgYVT6ZaIY1Z/FJ@J[5VT6ZaIY1Z/@00J6J@
J[5VT6ZaIY1Z/FJ@J[5VT6ZaIY1Z/FJ@J[5VT6ZaIY1Z/FJ@J[5VT6ZaIY1Z/FJ@J[5VT6ZaIY1[NV]J
Kg][FV]jJeY_Nf]JJgX006mkJeY[NV]JKg][FV]jJeYn]GjDO[EnU7jeOYAn]GjDO[EnU7jeOYAn]GjD
O[EnU7jeOYAn]GjDO[EnU7jeOYAn]GjDO[EnU7jeOYAn]GjDO[EnU7jeOYAn]GjDO[E[FVmkJeY[NV]J
Kg][FV]jJeX006]JJgY[FVmkJeY[NV]JKg/1JeX0019[FP0V4X8BXa:24Z<BPQ:S4X8BXa:24Z<BPQ:S
4X8BXa:24Z<BPQ:S4X8BXa:24Z<BPQ:S4X8BXa:24Z<BPQ:S4X8BXa:24Z<BPQ:S4X8BXa=[FP0V:ZHZ
QRZV9XHZYRZ6:ZHVQRZV:XHZYRJ6:ZHZQRZV9XHZYRZ6:ZHVQRZV:XHZYRJ6:ZHZQRZV9XHZYRZ6:ZHV
QRZV:XHZYRJ6:ZHZQQ=[FP0V?XXnZSj9?ZXnRSjZ?XTnZSj:?ZXnRCjZ?XXnZSj9?ZXnRSjZ?XTnZSj:
?ZXnRCjZ?XXnZSj9?ZXnRSjZ?XTnZSj:?ZXnRCjZ?XXnZQ=[FP0VDZeBSE:]DXeB[E:=DZeBSE:]DXeB
[E:=DZeBSE:]DXeB[E:=DZeBSE:]DXeB[E:=DZeBSE:]DXeB[E:=DZeBSE:]DXeB[E:=DZeBS@U[FP03
001[FV]J00M[FP0VIY5Z/FZAJ[5VTFZaJY5Z/FJAJ[5ZTFZaIY5Z/FZAJ[5VTFZaJY5Z/FJAJ[5ZTFZa
IY5Z/FZAJ[5VTFZaJY5Z/FJAJ[5ZTFZaIY5Z/@U[FP03001[FV]J00M[FP0VO[AnU7jdOYAn]7jDO[An
U7jdOYAn]7jDO[AnU7jdOYAn]7jDO[AnU7jdOYAn]7jDO[AnU7jdOYAn]7jDO[AnU7jdOYAn]7jDO[An
U0U[FP03001[FV]J00M[FP000?m_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeXFXa:2
5Z<BPQJS4X8FXa:25Z<BPQJS4X8FXa:25Z<BPQJS4X8FXa:25Z<BPQJS4X8FXa:25Z<BPQJS4X8FXa:2
5Z<BPQJS4X8FXa:2Kg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgXVQRZV9XHZYRJ6
:ZHVQRZV9XHZYRJ6:ZHVQRZV9XHZYRJ6:ZHVQRZV9XHZYRJ6:ZHVQRZV9XHZYRJ6:ZHVQRZV9XHZYRJ6
:ZHVQRZVJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeXnZSj9?ZXjRCjZ?XTnZSZ9
?ZXnRCjZ>XTnZSj9?ZXjRCjZ?XTnZSZ9?ZXnRCjZ>XTnZSj9?ZXjRCjZ?XTnZSZ9?ZXnRCjZ>XTnZSj9
JgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg]BSEJ]DXeF[U:=EZeBSEJ^DXeF[E:=
EZiBSEJ]DXeF[U:=EZeBSEJ^DXeF[E:=EZiBSEJ]DXeF[U:=EZeBSEJ^DXeF[E:=EZiBSEJ]JeY_Nf]J
JgY[FVmkJeY[NV]J001[FV]jJeY_Nf]JJgY[FVmkJeYZ/FJ@J[5VT6ZaIY1Z/FJ@J[4006QVT6ZaIY1Z
/FJ@J[5VT6ZaIY1Z/FJ@J[5VT6ZaIY1Z/FJ@J[5VT6ZaIY1Z/FJ@J[5VT6ZaIY1Z/FJ@Kg][FV]jJeY_
Nf]JJgY[FVmk001[NV]JKg][FV]jJeY_Nf]JJgYnU7jeOYAn]GjDO[EnU7jeOYAn]GjDO[EnU7jeOYAn
]GjDO[EnU7jeOYAn]GjDO[EnU7jeOYAn]GjDO[EnU7jeOYAn]GjDO[EnU7jeJeY[NV]JKg][FV]jJeY_
Nf]J001[FVmkJeY[NV]JKg][FV]j0F]J000CJeX091:S4X8BXa:24Z<BPQ:S4X8BXa:24Z<BPQ:S4X8B
Xa:24Z<BPQ:S4X8BXa:24Z<BPQ:S4X8BXa:24Z<BPQ:S4X8BXa:24Z<BPQE[FP0T9XHZYRZ6:ZHVQRZV
:XHZYRJ6:ZHZQRZV9XHZYRZ6:ZHVQRZV:XHZYRJ6:ZHZQRZV9XHZYRZ6:ZHVQRZV:XHZYRJ6:ZHZQRZV
5F]J02@nZSj:?ZXnRCjZ?XXnZSj9?ZXnRSjZ?XTnZSj:?ZXnRCjZ?XXnZSj9?ZXnRSjZ?XTnZSj:?ZXn
RCjZ?XXnZSj9?ZXnRSjZ?XTEJeX095:=DZeBSE:]DXeB[E:=DZeBSE:]DXeB[E:=DZeBSE:]DXeB[E:=
DZeBSE:]DXeB[E:=DZeBSE:]DXeB[E:=DZeBSE:]DXeB[@Y[FP03001[FV]J00Q[FP0TJ[5VTFZaJY5Z
/FJAJ[5ZTFZaIY5Z/FZAJ[5VTFZaJY5Z/FJAJ[5ZTFZaIY5Z/FZAJ[5VTFZaJY5Z/FJAJ[5ZTFZaIY5Z
/FZA2V]J00<006]JJeX01f]J02En]7jDO[AnU7jdOYAn]7jDO[AnU7jdOYAn]7jDO[AnU7jdOYAn]7jD
O[AnU7jdOYAn]7jDO[AnU7jdOYAn]7jDO[AnU7jdOYAn]00:JeX00`00JeY[FP07JeX0003oJgY[FVmk
JeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg/BPQJS4X8FXa:25Z<BPQJS4X8FXa:25Z<BPQJS
4X8FXa:25Z<BPQJS4X8FXa:25Z<BPQJS4X8FXa:25Z<BPQJS4X8FXa:25Z=[FV]jJeY_Nf]JJgY[FVmk
JeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeXZYRJ6:ZHVQRZV9XHZYRJ6:ZHVQRZV9XHZYRJ6:ZHVQRZV
9XHZYRJ6:ZHVQRZV9XHZYRJ6:ZHVQRZV9XHZYRJ6:ZHVQRZV9XI[NV]JKg][FV]jJeY_Nf]JJgY[FVmk
JeY[NV]JKg][FV]jJeY_Nf]JJgXjRCjZ?XTnZSZ9?ZXnRCjZ>XTnZSj9?ZXjRCjZ?XTnZSZ9?ZXnRCjZ
>XTnZSj9?ZXjRCjZ?XTnZSZ9?ZXnRCjZ>XTnZSj9?ZY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmk
JeY[NV]JKg][FV]jJeYF[U:=EZeBSEJ^DXeF[E:=EZiBSEJ]DXeF[U:=EZeBSEJ^DXeF[E:=EZiBSEJ]
DXeF[U:=EZeBSEJ^DXeF[E:=EZiBSEJ]DXe_Nf]JJgY[FVmkJeY[NV]JKg][FP00JeY_Nf]JJgY[FVmk
JeY[NV]JKg]VT6ZaIY1Z/FJ@J[5VT6Za001XIY1Z/FJ@J[5VT6ZaIY1Z/FJ@J[5VT6ZaIY1Z/FJ@J[5V
T6ZaIY1Z/FJ@J[5VT6ZaIY1Z/FJ@J[5[FV]jJeY_Nf]JJgY[FVmkJeY[NP00Kg][FV]jJeY_Nf]JJgY[
FVmkOYAn]GjDO[EnU7jeOYAn]GjDO[EnU7jeOYAn]GjDO[EnU7jeOYAn]GjDO[EnU7jeOYAn]GjDO[En
U7jeOYAn]GjDO[EnU7jeOYA[NV]JKg][FV]jJeY_Nf]JJgY[FP00JeY[NV]JKg][FV]jJeY_N`5[FP00
56]J028BPQ:S4X8BXa:24Z<BPQ:S4X8BXa:24Z<BPQ:S4X8BXa:24Z<BPQ:S4X8BXa:24Z<BPQ:S4X8B
Xa:24Z<BPQ:S4X8BXaM[FP0R:ZHVQRZV:XHZYRJ6:ZHZQRZV9XHZYRZ6:ZHVQRZV:XHZYRJ6:ZHZQRZV
9XHZYRZ6:ZHVQRZV:XHZYRJ6:ZHZQRZV9XHFJeX08cjZ?XTnZSj:?ZXnRCjZ?XXnZSj9?ZXnRSjZ?XTn
ZSj:?ZXnRCjZ?XXnZSj9?ZXnRSjZ?XTnZSj:?ZXnRCjZ?XXnZSj9?ZX05V]J02=BSE:]DXeB[E:=DZeB
SE:]DXeB[E:=DZeBSE:]DXeB[E:=DZeBSE:]DXeB[E:=DZeBSE:]DXeB[E:=DZeBSE:]DXeB[E:=00][
FP03001[FV]J00Q[FP0SJ[5ZTFZaIY5Z/FZAJ[5VTFZaJY5Z/FJAJ[5ZTFZaIY5Z/FZAJ[5VTFZaJY5Z
/FJAJ[5ZTFZaIY5Z/FZAJ[5VTFZaJY5Z/@0;JeX00`00JeY[FP08JeX08gjDO[AnU7jdOYAn]7jDO[An
U7jdOYAn]7jDO[AnU7jdOYAn]7jDO[AnU7jdOYAn]7jDO[AnU7jdOYAn]7jDO[AnU7jdOY@02f]J00<0
06]JJeX01f]J0000ofmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeXFXa:25Z<B
PQJS4X8FXa:25Z<BPQJS4X8FXa:25Z<BPQJS4X8FXa:25Z<BPQJS4X8FXa:25Z<BPQJS4X8FXa:25Z<B
PV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg/VQRZV9XHZYRJ6:ZHV
QRZV9XHZYRJ6:ZHVQRZV9XHZYRJ6:ZHVQRZV9XHZYRJ6:ZHVQRZV9XHZYRJ6:ZHVQRZV9XHZYV]JKg][
FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmk?XTnZSZ9?ZXnRCjZ>XTnZSj9?ZXj
RCjZ?XTnZSZ9?ZXnRCjZ>XTnZSj9?ZXjRCjZ?XTnZSZ9?ZXnRCjZ>XTnZSj9?ZXjRFmkJeY[NV]JKg][
FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JEZeBSEJ^DXeF[E:=EZiBSEJ]DXeF[U:=EZeB
SEJ^DXeF[E:=EZiBSEJ]DXeF[U:=EZeBSEJ^DXeF[E:=EZiBSEJ]DXeF[V]JJgY[FVmkJeY[NV]JKg][
FV]jJeX006]JJgY[FVmkJeY[NV]JKg][FV]jIY1Z/FJ@J[5VT6ZaIY1Z/@00J6J@J[5VT6ZaIY1Z/FJ@
J[5VT6ZaIY1Z/FJ@J[5VT6ZaIY1Z/FJ@J[5VT6ZaIY1Z/FJ@J[5VT6]jJeY_Nf]JJgY[FVmkJeY[NV]J
Kg/006]jJeY_Nf]JJgY[FVmkJeY[NV]JO[EnU7jeOYAn]GjDO[EnU7jeOYAn]GjDO[EnU7jeOYAn]GjD
O[EnU7jeOYAn]GjDO[EnU7jeOYAn]GjDO[EnU7jeOYAn]F]JKg][FV]jJeY_Nf]JJgY[FVmkJeX006]J
Kg][FV]jJeY_Nf]JJgX1JeX001E[FP0P4Z<BPQ:S4X8BXa:24Z<BPQ:S4X8BXa:24Z<BPQ:S4X8BXa:2
4Z<BPQ:S4X8BXa:24Z<BPQ:S4X8BXa:24Z<BPQU[FP0P:XHZYRJ6:ZHZQRZV9XHZYRZ6:ZHVQRZV:XHZ
YRJ6:ZHZQRZV9XHZYRZ6:ZHVQRZV:XHZYRJ6:ZHZQRZV9XHZYQQ[FP0Q?XXnZSj9?ZXnRSjZ?XTnZSj:
?ZXnRCjZ?XXnZSj9?ZXnRSjZ?XTnZSj:?ZXnRCjZ?XXnZSj9?ZXnRSjZ?XTnZSj:01Q[FP0QDZeBSE:]
DXeB[E:=DZeBSE:]DXeB[E:=DZeBSE:]DXeB[E:=DZeBSE:]DXeB[E:=DZeBSE:]DXeB[E:=DZeBSE:]
00a[FP03001[FV]J00U[FP0QIY5Z/FZAJ[5VTFZaJY5Z/FJAJ[5ZTFZaIY5Z/FZAJ[5VTFZaJY5Z/FJA
J[5ZTFZaIY5Z/FZAJ[5VTFZaJY5Z/FJA00a[FP03001[FV]J00U[FP0QO[AnU7jdOYAn]7jDO[AnU7jd
OYAn]7jDO[AnU7jdOYAn]7jDO[AnU7jdOYAn]7jDO[AnU7jdOYAn]7jDO[AnU7jd00a[FP03001[FV]J
00M[FP000?m[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgXBPQJS4X8FXa:2
5Z<BPQJS4X8FXa:25Z<BPQJS4X8FXa:25Z<BPQJS4X8FXa:25Z<BPQJS4X8FXa:25Z<BPV]jJeY_Nf]J
JgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeXZYRJ6:ZHVQRZV9XHZYRJ6
:ZHVQRZV9XHZYRJ6:ZHVQRZV9XHZYRJ6:ZHVQRZV9XHZYRJ6:ZHVQRZV9XHZYV]JKg][FV]jJeY_Nf]J
JgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg/nRCjZ>XTnZSj9?ZXjRCjZ?XTnZSZ9
?ZXnRCjZ>XTnZSj9?ZXjRCjZ?XTnZSZ9?ZXnRCjZ>XTnZSj9?ZXjRFmkJeY[NV]JKg][FV]jJeY_Nf]J
JgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeYF[E:=EZiBSEJ]DXeF[U:=EZeBSEJ^DXeF[E:=
EZiBSEJ]DXeF[U:=EZeBSEJ^DXeF[E:=EZiBSEJ]DXeF[V]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]J
001[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgYVT6ZaIY1Z/FJ@J[4006QVT6ZaIY1Z/FJ@J[5VT6ZaIY1Z
/FJ@J[5VT6ZaIY1Z/FJ@J[5VT6ZaIY1Z/FJ@J[5VT6]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]j001_
Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeYn]GjDO[EnU7jeOYAn]GjDO[EnU7jeOYAn]GjDO[EnU7jeOYAn
]GjDO[EnU7jeOYAn]GjDO[EnU7jeOYAn]F]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]J001[FV]jJeY_
Nf]JJgY[FVmk0F]J000FJeX07A:24Z<BPQ:S4X8BXa:24Z<BPQ:S4X8BXa:24Z<BPQ:S4X8BXa:24Z<B
PQ:S4X8BXa:24Z<BPQ:S4X8076]J01dZYRZ6:ZHVQRZV:XHZYRJ6:ZHZQRZV9XHZYRZ6:ZHVQRZV:XHZ
YRJ6:ZHZQRZV9XHZYRZ6:ZHVQRZV01a[FP0M?XXnZSj9?ZXnRSjZ?XTnZSj:?ZXnRCjZ?XXnZSj9?ZXn
RSjZ?XTnZSj:?ZXnRCjZ?XXnZSj9?ZXnRP0LJeX07E:]DXeB[E:=DZeBSE:]DXeB[E:=DZeBSE:]DXeB
[E:=DZeBSE:]DXeB[E:=DZeBSE:]DXeB[E:=DZd03V]J00<006]JJeX02f]J01eVTFZaJY5Z/FJAJ[5Z
TFZaIY5Z/FZAJ[5VTFZaJY5Z/FJAJ[5ZTFZaIY5Z/FZAJ[5VTFZaJY5Z/FJA00i[FP03001[FV]J00][
FP0MO[AnU7jdOYAn]7jDO[AnU7jdOYAn]7jDO[AnU7jdOYAn]7jDO[AnU7jdOYAn]7jDO[AnU7jdOYAn
]00>JeX00`00JeY[FP07JeX0003oKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[
FVmkJeY[NQ:25Z<BPQJS4X8FXa:25Z<BPQJS4X8FXa:25Z<BPQJS4X8FXa:25Z<BPQJS4X8FXa:25Z<B
PV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[
FRZV9XHZYRJ6:ZHVQRZV9XHZYRJ6:ZHVQRZV9XHZYRJ6:ZHVQRZV9XHZYRJ6:ZHVQRZV9XHZYV]JKg][
FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Ncj9?ZXj
RCjZ?XTnZSZ9?ZXnRCjZ>XTnZSj9?ZXjRCjZ?XTnZSZ9?ZXnRCjZ>XTnZSj9?ZXjRFmkJeY[NV]JKg][
FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FUJ]DXeF[U:=EZeB
SEJ^DXeF[E:=EZiBSEJ]DXeF[U:=EZeBSEJ^DXeF[E:=EZiBSEJ]DXeF[V]JJgY[FVmkJeY[NV]JKg][
FV]jJeY_Nf]JJgY[FP00JeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NVJ@J[5VT6Za001XIY1Z/FJ@
J[5VT6ZaIY1Z/FJ@J[5VT6ZaIY1Z/FJ@J[5VT6ZaIY1Z/FJ@J[5VT6]jJeY_Nf]JJgY[FVmkJeY[NV]J
Kg][FV]jJeY_N`00JgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FWjeOYAn]GjDO[EnU7jeOYAn]GjD
O[EnU7jeOYAn]GjDO[EnU7jeOYAn]GjDO[EnU7jeOYAn]F]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]J
Kg][FP00JeY_Nf]JJgY[FVmkJeY[NP5[FP0066]J01TBPQ:S4X8BXa:24Z<BPQ:S4X8BXa:24Z<BPQ:S
4X8BXa:24Z<BPQ:S4X8BXa:24Z<BPP0PJeX06BZV:XHZYRJ6:ZHZQRZV9XHZYRZ6:ZHVQRZV:XHZYRJ6
:ZHZQRZV9XHZYRZ6:ZHVQRZV021[FP0I?XXnZSj9?ZXnRSjZ?XTnZSj:?ZXnRCjZ?XXnZSj9?ZXnRSjZ
?XTnZSj:?ZXnRCjZ?XX086]J01UB[E:=DZeBSE:]DXeB[E:=DZeBSE:]DXeB[E:=DZeBSE:]DXeB[E:=
DZeBSE:]DXeB[@0@JeX00`00JeY[FP0=JeX06FJAJ[5ZTFZaIY5Z/FZAJ[5VTFZaJY5Z/FJAJ[5ZTFZa
IY5Z/FZAJ[5VTFZaJY5Z/FJA011[FP03001[FV]J00e[FP0IO[AnU7jdOYAn]7jDO[AnU7jdOYAn]7jD
O[AnU7jdOYAn]7jDO[AnU7jdOYAn]7jDO[@046]J00<006]JJeX01f]J0000of]jJeY_Nf]JJgY[FVmk
JeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]j4X8FXa:25Z<BPQJS4X8FXa:25Z<BPQJS
4X8FXa:25Z<BPQJS4X8FXa:25Z=[FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmk
JeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]J:ZHVQRZV9XHZYRJ6:ZHVQRZV9XHZYRJ6:ZHVQRZV
9XHZYRJ6:ZHVQRZV9XI[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmk
JeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmk?XTnZSZ9?ZXnRCjZ>XTnZSj9?ZXjRCjZ?XTnZSZ9?ZXnRCjZ
>XTnZSj9?ZY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmk
JeY[NV]JKg][FV]jJeY_Nf]JEZeBSEJ^DXeF[E:=EZiBSEJ]DXeF[U:=EZeBSEJ^DXeF[E:=EZiBSEJ]
DXe_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeX006]JKg][FV]jJeY_Nf]JJgY[FVmk
JeY[NV]JKg][FV]jIY1Z/@00J6J@J[5VT6ZaIY1Z/FJ@J[5VT6ZaIY1Z/FJ@J[5VT6ZaIY1Z/FJ@J[5[
FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgX006mkJeY[NV]JKg][FV]jJeY_Nf]JJgY[
FVmkJeY[NV]JO[EnU7jeOYAn]GjDO[EnU7jeOYAn]GjDO[EnU7jeOYAn]GjDO[EnU7jeOYA[NV]JKg][
FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeX006]JJgY[FVmkJeY[NV]JKg/1JeX001][FP0C4Z<B
PQ:S4X8BXa:24Z<BPQ:S4X8BXa:24Z<BPQ:S4X8BXa:24Z<09V]J01<ZQRZV9XHZYRZ6:ZHVQRZV:XHZ
YRJ6:ZHZQRZV9XHZYRZ6:ZHVQP0VJeX04cjZ?XTnZSj:?ZXnRCjZ?XXnZSj9?ZXnRSjZ?XTnZSj:?ZXn
RCjZ02I[FP0CDXeB[E:=DZeBSE:]DXeB[E:=DZeBSE:]DXeB[E:=DZeBSE:]DXd04f]J00<006]JJeX0
46]J01=Z/FZAJ[5VTFZaJY5Z/FJAJ[5ZTFZaIY5Z/FZAJ[5VTFZaJY5Z/@0CJeX00`00JeY[FP0?JeX0
57jdOYAn]7jDO[AnU7jdOYAn]7jDO[AnU7jdOYAn]7jDO[AnU7jdOY@CJeX00`00JeY[FP07JeX0003o
Kg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeXFXa:2
5Z<BPQJS4X8FXa:25Z<BPQJS4X8FXa:25Z<BPVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]J
Kg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg/VQRZV9XHZYRJ6
:ZHVQRZV9XHZYRJ6:ZHVQRZV9XHZYV]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]J
Kg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeXnZSZ9?ZXnRCjZ>XTnZSj9
?ZXjRCjZ?XTnZSZ9?ZXnRF]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]J
Kg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgYBSEJ^DXeF[E:=EZiBSEJ]DXeF[U:=
EZeBSEJ^DXeF[F]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FP00JeY[NV]J
Kg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]j001XJeYZ/FJ@J[5VT6ZaIY1Z/FJ@J[5VT6ZaIY1Z
/FJ@J[5VT6mkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_N`00JgY[FVmkJeY[
NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg]nU7jeOYAn]GjDO[EnU7jeOYAn]GjDO[EnU7jeOYAn
]F]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FP00JeY_Nf]JJgY[FVmkJeY[
NP5[FP0086]J00XBPQ:S4X8BXa:24Z<BPQ:S4X8BXbm[FP0::ZHZQRZV9XHZYRZ6:ZHVQRZV:XH_JeX0
2Sj:?ZXnRCjZ?XXnZSj9?ZXnRSjZ;f]J00YB[E:=DZeBSE:]DXeB[E:=DZeBSAM[FP03001[FV]J01E[
FP0:IY5Z/FZAJ[5VTFZaJY5Z/FJAJ[4GJeX00`00JeY[FP0EJeX02WjdOYAn]7jDO[AnU7jdOYAn]7jD
5f]J00<006]JJeX01f]J0000of]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[
NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_
Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[
NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_
Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[
NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_
Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[
NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_
Nf]JJgY[FVmkJeX006]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_N`00J6]JJgY[FVmk
JeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]j
JeY_Nf]JJgX006mkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmk
JeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]j
JeX006]JJgY[FVmkJeY[NV]JKg/1JeX00>a[FP03001[FV]J03I[FP03001[FV]J03I[FP03001[FV]J
00M[FP000?m_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]J
JgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]J
Kg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]J
JgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]J
Kg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]J
JgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]J
Kg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]J
JgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]J
001[FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgX006Q[FVmkJeY[NV]JKg][FV]jJeY_
Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmk001[
NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_
Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]J001[FVmkJeY[
NV]JKg][FV]j0F]J003/JeX00`00JeY[FP0fJeX00`00JeY[FP0fJeX00`00JeY[FP07JeX0003oJgY[
FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][
FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[
FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][
FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[
FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][
FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[
FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][
FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FP00JeY_Nf]JJgY[
FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmk001XJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]J
Kg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NP00Kg][FV]jJeY_Nf]J
JgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]J
Kg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FP00JeY[NV]JKg][FV]jJeY_N`5[
FP00k6]J00<006]JJeX0=V]J00<006]JJeX0=V]J00<006]JJeX01f]J0000ofmkJeY[NV]JKg][FV]j
JeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmk
JeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]j
JeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmk
JeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]j
JeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmk
JeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]j
JeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmk
JeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeX006]JJgY[FVmkJeY[NV]JKg][FV]j
JeY_Nf]JJgY[FVmkJeY[NP00J6]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[
FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg/006]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][
FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[
FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeX006]JKg][FV]jJeY_Nf]JJgX1JeX00>a[FP03001[
FV]J03I[FP03001[FV]J03I[FP03001[FV]J00M[FP0000Q[NV]JKg][FV]jJeY_Nf]Ji@0007Y[FVmk
JeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]j
JeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]j001_Nf]JJgY[FVmk
JeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]j
JeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]J001[FV]jJeY_Nf]JJgY[FVmk
0F]J003oJeXVJeX00`00JeY[FP0fJeX00`00JeY[FP07JeX0003oKg][FV]jJeY_Nf]JJgY[FVmkJeY[
NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_
Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[
NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_
Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[
NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_
Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[
NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_
Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[
NV]JKg][FV]j001XJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]j
JeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_N`00JgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmk
JeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]j
JeY_Nf]JJgY[FVmkJeY[NV]JKg][FP00JeY_Nf]JJgY[FVmkJeY[NP5[FP00of]J9V]J00<006]JJeX0
=V]J00<006]JJeX01f]J0000of]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[
NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_
Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[
NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_
Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[
NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_
Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[
NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_
Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_N`00J6]JJgY[FVmk
JeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]j
JeY_Nf]JJgX006mkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmk
JeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]j
JeX006]JJgY[FVmkJeY[NV]JKg/1JeX00?m[FRI[FP03001[FV]J03I[FP03001[FV]J00M[FP000?m_
Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[
NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_
Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[
NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_
Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[
NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_
Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[
NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_
Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgX006Q[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmk
JeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmk001[NV]JKg][FV]j
JeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmk
JeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]J001[FVmkJeY[NV]JKg][FV]j
0F]J003oJeXVJeX00`00JeY[FP0fJeX00`00JeY[FP07JeX0003oJgY[FVmkJeY[NV]JKg][FV]jJeY_
Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[
NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_
Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[
NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_
Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[
NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_
Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[
NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_
Nf]JJgY[FVmk001XJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmk
JeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NP00Kg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]j
JeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmk
JeY[NV]JKg][FV]jJeY_Nf]JJgY[FP00JeY[NV]JKg][FV]jJeY_N`5[FP00of]J9V]J00<006]JJeX0
=V]J00<006]JJeX01f]J0000ofmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_
Nf]JJgY[FVmkJeY[NV]JKg][FQM44d<GA1=35d@C@aM44d<GA1=35d@C@aM44d=_Nf]JJgY[FVmkJeY[
NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_
Nf]JJgY[FVmkJeY[NRM7:dPWB2]89dL[B2M8:dPWAb]89dP[B2M7:dQ[FV]jJeY_Nf]JJgY[FVmkJeY[
NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_
Nf]JJgY[FSm=?d`oCC]<?ddoC3m=>d`oCCm<?ddkC3m=?da[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[
NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_
Ne=@Ee5CD5MADe1GDE=@Ee5CD5MADe1GDE=@Ee5[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[
NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NP00J6]JKg][FV]E
IeE[EVMEJeEWEF]FIeE[EFMEJeIWEF]EIeE_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmk
JeY[NV]JKg/006]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NWmIOeYoFGmJ
OeUoFWmIOeYoFGmJOeUoFWmIOeY[FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmk
JeX006]JKg][FV]jJeY_Nf]JJgX1JeX001][FP054d@C@a=34d<CA0034d<01A=44d<C@a=34d@00a=3
00<CA1=34d<09V]J00DWB2]8:dP[B2M800<[B0059dP[B2]8:dPWB003:dP00bM8:dP[B00VJeXC?d`V
JeXCDe4VJeX00f]EIeE[E@02JeD01FMEJeE[EF]EIeD00f]E00IWEF]EJeE[EFMEJeDCJeX00`00JeY[
FP0?JeX00gmJOeUoFP02OeX01GmIOeYoFWmJOeT00gmJ00EoFGmJOeYoFWmI009oFQ=[FP03001[FV]J
00M[FP000?m[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NQ=3
5d@C@aM44d<GA1=35d@C@aM44d<GA1=35d@C@aM44d<GA1=35d@C@aM4JeY[NV]JKg][FV]jJeY_Nf]J
JgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FR]89dP[B2M7
:dPWB2]89dL[B2M8:dPWAb]89dP[B2M7:dPWB2]89dL[B2M8JgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]J
JgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Ncm<?ddkC3m=?d`oCC]<
?ddoC3m=>d`oCCm<?ddkC3m=?d`oCC]<?ddoC3m=JeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]J
JgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FUMADe1GDE=@Ee5CD5MADe1GDE=@
Ee5CD5MADe1GDE=@Ee5CD5MADe1GDE=@Kg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]J
JgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NVMEJeH006QWEF]EIeE[EVMEJeEWEF]FIeE[
EFMEJeIWEF]EIeE[EVMEJeEWEF]FJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]j001_
Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FWmJOeUoFWmIOeYoFGmJOeUoFWmIOeYoFGmJOeUo
FWmIOeYoFGmJOeUoFWmIJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]J001[FV]jJeY_
Nf]JJgY[FVmk0F]J000HJeX00a=34d@C@`024d<01A=44d<C@a=34d@00a=300DCA1=34d<C@a=400<C
@`044d@C@a=34d<PJeX00b]89dP[B002:dP01BM8:dP[B2]89dP00b]800DWB2]8:dP[B2M800<[B004
9dP[B2]8:dPPJeXI?d`PJeXIDe4PJeX2JeD01FMEJeE[EF]EIeD00f]E00EWEF]EJeE[EFME00=[E@05
IeE[EF]EJeEWE@02JeD@JeX00`00JeY[FP0=JeX00gmJOeUoFP02OeX01GmIOeYoFWmJOeT00gmJ00Eo
FGmJOeYoFWmI00=oFP04OeUoFWmJOeX@JeX00`00JeY[FP07JeX0003oKg][FV]jJeY_Nf]JJgY[FVmk
JeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NQ=35d@C@aM44d<GA1=35d@C@aM44d<GA1=35d@C@aM4
4d<GA1=35d@C@aM44d<GA1=35d@C@f]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmk
JeY[NV]JKg][FV]jJeY_Nf]JJgY[FR]89dP[B2M7:dPWB2]89dL[B2M8:dPWAb]89dP[B2M7:dPWB2]8
9dL[B2M8:dPWAb]89dP[B6]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmk
JeY[NV]JKg][FV]jJeY_Ncm<?ddkC3m=?d`oCC]<?ddoC3m=>d`oCCm<?ddkC3m=?d`oCC]<?ddoC3m=
>d`oCCm<?ddkC6mkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmk
JeY[NV]JKg][FUMADe1GDE=@Ee5CD5MADe1GDE=@Ee5CD5MADe1GDE=@Ee5CD5MADe1GDE=@Ee5CD5MA
De1GDF]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmk
JeY[NVMEJeIWEF]E001XIeE[EVMEJeEWEF]FIeE[EFMEJeIWEF]EIeE[EVMEJeEWEF]FIeE[EFMEJeIW
EF]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_N`00JgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[
FWmJOeUoFWmIOeYoFGmJOeUoFWmIOeYoFGmJOeUoFWmIOeYoFGmJOeUoFWmIOeYoFGmJOeUoFV]JKg][
FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FP00JeY_Nf]JJgY[FVmkJeY[NP5[FP005V]J00<C@a=44d<0
0Q=300DCA1=34d<C@a=400<C@`054d@C@a=34d<CA0034d<01A=44d<C@a=34d@00a=376]J00<[B2M8
:dP00R]800DWB2]8:dP[B2M800<[B0059dP[B2]8:dPWB003:dP01BM8:dP[B2]89dP00b]876]J7Cm<
76]J7E=A76]J0V]E00EWEF]EJeE[EFME00=[E@05IeE[EF]EJeEWE@03JeD01FMEJeE[EF]EIeD00f]E
00=WEF]EJeD03V]J00<006]JJeX02f]J00=oFWmIOeX00WmJ00EoFGmJOeYoFWmI00=oFP05OeUoFWmJ
OeYoF@03OeX01GmIOeYoFWmJOeT00gmJ3V]J00<006]JJeX01f]J0000of]jJeY_Nf]JJgY[FVmkJeY[
NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NQ=35d@C@aM44d<GA1=35d@C@aM44d<GA1=35d@C@aM44d<G
A1=35d@C@aM44d<GA1=35d@C@aM44d<GA1=3JgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[
NV]JKg][FV]jJeY_Nf]JJgY[FR]89dP[B2M7:dPWB2]89dL[B2M8:dPWAb]89dP[B2M7:dPWB2]89dL[
B2M8:dPWAb]89dP[B2M7:dPWB2]8JeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[
NV]JKg][FV]jJeY_Ncm<?ddkC3m=?d`oCC]<?ddoC3m=>d`oCCm<?ddkC3m=?d`oCC]<?ddoC3m=>d`o
CCm<?ddkC3m=?d`oCC]<Kg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[
NV]JKg][FUMADe1GDE=@Ee5CD5MADe1GDE=@Ee5CD5MADe1GDE=@Ee5CD5MADe1GDE=@Ee5CD5MADe1G
DE=@Ee5CD5MAJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[
NVMEJeIWEF]EIeE[EP00J6MEJeEWEF]FIeE[EFMEJeIWEF]EIeE[EVMEJeEWEF]FIeE[EFMEJeIWEF]E
IeE[EVMEJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgX006mkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FWmJ
OeUoFWmIOeYoFGmJOeUoFWmIOeYoFGmJOeUoFWmIOeYoFGmJOeUoFWmIOeYoFGmJOeUoFWmIOeYoFGmJ
JeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeX006]JJgY[FVmkJeY[NV]JKg/1JeX001E[FP054d@C@a=3
4d<CA0034d<01A=44d<C@a=34d@00a=300DCA1=34d<C@a=400<C@`054d@C@a=34d<CA0034d<IJeX0
1BM8:dP[B2]89dP00b]800DWB2]8:dP[B2M800<[B0059dP[B2]8:dPWB003:dP01BM8:dP[B2]89dP0
0b]866]J8Cm<66]J8E=A66]J0V]E00EWEF]EJeE[EFME00=[E@05IeE[EF]EJeEWE@03JeD01FMEJeE[
EF]EIeD00f]E00EWEF]EJeE[EFME009[E@a[FP03001[FV]J00U[FP03OeYoFGmJ009oFP05OeUoFWmJ
OeYoF@03OeX01GmIOeYoFWmJOeT00gmJ00EoFGmJOeYoFWmI00=oFP04OeUoFWmJOeX<JeX00`00JeY[
FP07JeX0003oKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FQM44d<GA1=35d@C
@aM44d<GA1=35d@C@aM44d<GA1=35d@C@aM44d<GA1=35d@C@aM44d<GA1=35d@C@aM44d<GA1=3JgY[
FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_NbM8:dPWAb]89dP[B2M7:dPW
B2]89dL[B2M8:dPWAb]89dP[B2M7:dPWB2]89dL[B2M8:dPWAb]89dP[B2M7:dPWB2]8JeY_Nf]JJgY[
FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg/oC3m=>d`oCCm<?ddkC3m=?d`oCC]<?ddo
C3m=>d`oCCm<?ddkC3m=?d`oCC]<?ddoC3m=>d`oCCm<?ddkC3m=?d`oCC]<Kg][FV]jJeY_Nf]JJgY[
FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeYGDE=@Ee5CD5MADe1GDE=@Ee5CD5MADe1GDE=@Ee5C
D5MADe1GDE=@Ee5CD5MADe1GDE=@Ee5CD5MADe1GDE=@Ee5CD5MAJeY[NV]JKg][FV]jJeY_Nf]JJgY[
FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgYWEF]FIeE[EFMEJeIWEF]E001XIeE[EVMEJeEWEF]FIeE[EFME
JeIWEF]EIeE[EVMEJeEWEF]FIeE[EFMEJeIWEF]EIeE[EVMEJgY[FVmkJeY[NV]JKg][FV]jJeY_N`00
JgY[FVmkJeY[NV]JKg][FV]jJeYoFWmIOeYoFGmJOeUoFWmIOeYoFGmJOeUoFWmIOeYoFGmJOeUoFWmI
OeYoFGmJOeUoFWmIOeYoFGmJOeUoFWmIOeYoFGmJJeY_Nf]JJgY[FVmkJeY[NV]JKg][FP00JeY_Nf]J
JgY[FVmkJeY[NP5[FP0056]J0a=300DCA1=34d<C@a=400<C@`054d@C@a=34d<CA0034d<01A=44d<C
@a=34d@00a=300DCA1=34d<C@a=4008C@aM[FP<[B0059dP[B2]8:dPWB003:dP01BM8:dP[B2]89dP0
0b]800DWB2]8:dP[B2M800<[B0059dP[B2]8:dPWB002:dPFJeXS?d`FJeXSDe4FJeX00f]EIeE[E@02
JeD01FMEJeE[EF]EIeD00f]E00EWEF]EJeE[EFME00=[E@05IeE[EF]EJeEWE@03JeD01VMEJeE[EF]E
IeE[E@][FP03001[FV]J00Q[FP05OeUoFWmJOeYoF@03OeX01GmIOeYoFWmJOeT00gmJ00EoFGmJOeYo
FWmI00=oFP05OeUoFWmJOeYoF@03OeX00gmIOeYoFP0;JeX00`00JeY[FP07JeX0003oJgY[FVmkJeY[
NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg/C@aM44d<GA1=35d@C@aM44d<GA1=35d@C@aM44d<G
A1=35d@C@aM44d<GA1=35d@C@aM44d<GA1=35d@C@aM44d<GA1=35dA[FV]jJeY_Nf]JJgY[FVmkJeY[
NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeX[B2M7:dPWB2]89dL[B2M8:dPWAb]89dP[B2M7:dPWB2]89dL[
B2M8:dPWAb]89dP[B2M7:dPWB2]89dL[B2M8:dPWAb]89dQ[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[
NV]JKg][FV]jJeY_Nf]JJgXkC3m=?d`oCC]<?ddoC3m=>d`oCCm<?ddkC3m=?d`oCC]<?ddoC3m=>d`o
CCm<?ddkC3m=?d`oCC]<?ddoC3m=>d`oCCm<?de[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[
NV]JKg][FV]jJeYGDE=@Ee5CD5MADe1GDE=@Ee5CD5MADe1GDE=@Ee5CD5MADe1GDE=@Ee5CD5MADe1G
DE=@Ee5CD5MADe1GDE=@Ee5CD5MADe1_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[
NV]JKg]WEF]EIeE[EVMEJeEWEF]F001XIeE[EFMEJeIWEF]EIeE[EVMEJeEWEF]FIeE[EFMEJeIWEF]E
IeE[EVMEJeEWEF]FIeE[EFMEJeI[FV]jJeY_Nf]JJgY[FVmkJeY[NP00Kg][FV]jJeY_Nf]JJgY[FVmk
OeUoFWmIOeYoFGmJOeUoFWmIOeYoFGmJOeUoFWmIOeYoFGmJOeUoFWmIOeYoFGmJOeUoFWmIOeYoFGmJ
OeUoFWmIOeYoFGmJOeU[NV]JKg][FV]jJeY_Nf]JJgY[FP00JeY[NV]JKg][FV]jJeY_N`5[FP004f]J
0Q=300DCA1=34d<C@a=400<C@`054d@C@a=34d<CA0034d<01A=44d<C@a=34d@00a=300DCA1=34d<C
@a=400<C@`034d@C@f]J01A[FP8[B0059dP[B2]8:dPWB003:dP01BM8:dP[B2]89dP00b]800DWB2]8
:dP[B2M800<[B0059dP[B2]8:dPWB003:dP00bM8:dQ[FP0DJeXT?d`EJeXTDe4EJeX3JeD01FMEJeE[
EF]EIeD00f]E00EWEF]EJeE[EFME00=[E@05IeE[EF]EJeEWE@03JeD01FMEJeE[EF]EIeD00f]E00=W
EF]JJeX026]J00<006]JJeX01f]J0gmJ00EoFGmJOeYoFWmI00=oFP05OeUoFWmJOeYoF@03OeX01GmI
OeYoFWmJOeT00gmJ00EoFGmJOeYoFWmI00=oFP03OeUoFV]J00U[FP03001[FV]J00M[FP000?m_Nf]J
JgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeXGA1=35d@C@aM44d<GA1=35d@C@aM44d<GA1=3
5d@C@aM44d<GA1=35d@C@aM44d<GA1=35d@C@aM44d<GA1=35d@C@aM44d<GA1=3Kg][FV]jJeY_Nf]J
JgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgXWAb]89dP[B2M7:dPWB2]89dL[B2M8:dPWAb]89dP[B2M7
:dPWB2]89dL[B2M8:dPWAb]89dP[B2M7:dPWB2]89dL[B2M8:dPWAb]8JeY[NV]JKg][FV]jJeY_Nf]J
JgY[FVmkJeY[NV]JKg][FV]jJeXoCCm<?ddkC3m=?d`oCC]<?ddoC3m=>d`oCCm<?ddkC3m=?d`oCC]<
?ddoC3m=>d`oCCm<?ddkC3m=?d`oCC]<?ddoC3m=>d`oCCm<JgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]J
JgY[FVmkJeY[NV]JKg]CD5MADe1GDE=@Ee5CD5MADe1GDE=@Ee5CD5MADe1GDE=@Ee5CD5MADe1GDE=@
Ee5CD5MADe1GDE=@Ee5CD5MADe1GDE=@Ee5CD5MAJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]J
JgY[FVmkJeY[EFMEJeIWEF]EIeE[EVMEJeD006QWEF]FIeE[EFMEJeIWEF]EIeE[EVMEJeEWEF]FIeE[
EFMEJeIWEF]EIeE[EVMEJeEWEF]FIeE[EFMEKg][FV]jJeY_Nf]JJgY[FVmk001[NV]JKg][FV]jJeY_
Nf]JJgYoFGmJOeUoFWmIOeYoFGmJOeUoFWmIOeYoFGmJOeUoFWmIOeYoFGmJOeUoFWmIOeYoFGmJOeUo
FWmIOeYoFGmJOeUoFWmIOeYoFGmJJeY[NV]JKg][FV]jJeY_Nf]J001[FVmkJeY[NV]JKg][FV]j0F]J
000BJeX00a=34d@C@`024d<01A=44d<C@a=34d@00a=300DCA1=34d<C@a=400<C@`054d@C@a=34d<C
A0034d<01A=44d<C@a=34d@00a=300<CA6]JJeX04F]J00<[B2M8:dP00R]800DWB2]8:dP[B2M800<[
B0059dP[B2]8:dPWB003:dP01BM8:dP[B2]89dP00b]800DWB2]8:dP[B2M800<[B0039dQ[FV]J015[
FRHoC1=[FRICDA=[FP9[E@05IeE[EF]EJeEWE@03JeD01FMEJeE[EF]EIeD00f]E00EWEF]EJeE[EFME
00=[E@05IeE[EF]EJeEWE@03JeD016MEJeE[EF]E2F]J00<006]JJeX01f]J00=oFWmIOeX00WmJ00Eo
FGmJOeYoFWmI00=oFP05OeUoFWmJOeYoF@03OeX01GmIOeYoFWmJOeT00gmJ00EoFGmJOeYoFWmI00=o
FP03OeU[FV]J00M[FP03001[FV]J00M[FP000?m[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][
FV]j4d<GA1=35d@C@aM44d<GA1=35d@C@aM44d<GA1=35d@C@aM44d<GA1=35d@C@aM44d<GA1=35d@C
@aM44d<GA1=35d@C@aM44d<GA1=3JgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]J:dPW
B2]89dL[B2M8:dPWAb]89dP[B2M7:dPWB2]89dL[B2M8:dPWAb]89dP[B2M7:dPWB2]89dL[B2M8:dPW
Ab]89dP[B2M7:dPWB2]8JeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmk?d`oCC]<?ddo
C3m=>d`oCCm<?ddkC3m=?d`oCC]<?ddoC3m=>d`oCCm<?ddkC3m=?d`oCC]<?ddoC3m=>d`oCCm<?ddk
C3m=?d`oCC]<Kg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JEe5CD5MADe1GDE=@Ee5C
D5MADe1GDE=@Ee5CD5MADe1GDE=@Ee5CD5MADe1GDE=@Ee5CD5MADe1GDE=@Ee5CD5MADe1GDE=@Ee5C
D5MAJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jIeE[EVMEJeEWEF]FIeE[EFMEJeH0
06QWEF]EIeE[EVMEJeEWEF]FIeE[EFMEJeIWEF]EIeE[EVMEJeEWEF]FIeE[EFMEJeIWEF]EIeE[EVME
JgY[FVmkJeY[NV]JKg][FV]j001_Nf]JJgY[FVmkJeY[NV]JOeYoFGmJOeUoFWmIOeYoFGmJOeUoFWmI
OeYoFGmJOeUoFWmIOeYoFGmJOeUoFWmIOeYoFGmJOeUoFWmIOeYoFGmJOeUoFWmIOeYoFGmJJeY_Nf]J
JgY[FVmkJeY[NV]J001[FV]jJeY_Nf]JJgY[FVmk0F]J000AJeX01A=44d<C@a=34d@00a=300DCA1=3
4d<C@a=400<C@`054d@C@a=34d<CA0034d<01A=44d<C@a=34d@00a=300DCA1=34d<C@a=4008C@a9[
FP059dP[B2]8:dPWB003:dP01BM8:dP[B2]89dP00b]800DWB2]8:dP[B2M800<[B0059dP[B2]8:dPW
B003:dP01BM8:dP[B2]89dP00R]84V]J9cm<4V]J9e=A4V]J00=[EFMEJeD00V]E00EWEF]EJeE[EFME
00=[E@05IeE[EF]EJeEWE@03JeD01FMEJeE[EF]EIeD00f]E00EWEF]EJeE[EFME00=[E@03IeE[EF]J
00Q[FP03001[FV]J00I[FP05OeUoFWmJOeYoF@03OeX01GmIOeYoFWmJOeT00gmJ00EoFGmJOeYoFWmI
00=oFP05OeUoFWmJOeYoF@03OeX01GmIOeYoFWmJOeT00WmJ2F]J00<006]JJeX01f]J0000ofmkJeY[
NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg/C@aM44d<GA1=35d@C@aM44d<GA1=35d@C@aM44d<G
A1=35d@C@aM44d<GA1=35d@C@aM44d<GA1=35d@C@aM44d<GA1=35d@C@aM44d=_Nf]JJgY[FVmkJeY[
NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeX[B2M7:dPWB2]89dL[B2M8:dPWAb]89dP[B2M7:dPWB2]89dL[
B2M8:dPWAb]89dP[B2M7:dPWB2]89dL[B2M8:dPWAb]89dP[B2M7:dQ[FV]jJeY_Nf]JJgY[FVmkJeY[
NV]JKg][FV]jJeY_Nf]JJgXkC3m=?d`oCC]<?ddoC3m=>d`oCCm<?ddkC3m=?d`oCC]<?ddoC3m=>d`o
CCm<?ddkC3m=?d`oCC]<?ddoC3m=>d`oCCm<?ddkC3m=?da[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[
NV]JKg][FV]jJeYGDE=@Ee5CD5MADe1GDE=@Ee5CD5MADe1GDE=@Ee5CD5MADe1GDE=@Ee5CD5MADe1G
DE=@Ee5CD5MADe1GDE=@Ee5CD5MADe1GDE=@Ee5[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[
NV]JKg]WEF]EIeE[EVMEJeEWEF]FIeE[E@00J6MEJeIWEF]EIeE[EVMEJeEWEF]FIeE[EFMEJeIWEF]E
IeE[EVMEJeEWEF]FIeE[EFMEJeIWEF]EIeE_Nf]JJgY[FVmkJeY[NV]JKg/006]jJeY_Nf]JJgY[FVmk
JeYoFWmIOeYoFGmJOeUoFWmIOeYoFGmJOeUoFWmIOeYoFGmJOeUoFWmIOeYoFGmJOeUoFWmIOeYoFGmJ
OeUoFWmIOeYoFGmJOeUoFWmIOeY[FV]jJeY_Nf]JJgY[FVmkJeX006]JKg][FV]jJeY_Nf]JJgX1JeX0
015[FP8C@`054d@C@a=34d<CA0034d<01A=44d<C@a=34d@00a=300DCA1=34d<C@a=400<C@`054d@C
@a=34d<CA0034d<01A=44d<C@a=34d@04V]J0R]800DWB2]8:dP[B2M800<[B0059dP[B2]8:dPWB003
:dP01BM8:dP[B2]89dP00b]800DWB2]8:dP[B2M800<[B0059dP[B2]8:dPWB00BJeXW?d`BJeXWDe4B
JeX3JeD01FMEJeE[EF]EIeD00f]E00EWEF]EJeE[EFME00=[E@05IeE[EF]EJeEWE@03JeD01FMEJeE[
EF]EIeD00f]E00AWEF]EJeE[E@U[FP03001[FV]J00I[FP9oFP05OeUoFWmJOeYoF@03OeX01GmIOeYo
FWmJOeT00gmJ00EoFGmJOeYoFWmI00=oFP05OeUoFWmJOeYoF@03OeX01GmIOeYoFWmJOeT02F]J00<0
06]JJeX01f]J0000of]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgXC@aM44d<GA1=35d@C
@aM44d<GA1=35d@C@aM44d<GA1=35d@C@aM44d<GA1=35d@C@aM44d<GA1=35d@C@aM44d<GA1=35d@C
@aM44d=[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeX[B2M8:dPWAb]89dP[B2M7:dPW
B2]89dL[B2M8:dPWAb]89dP[B2M7:dPWB2]89dL[B2M8:dPWAb]89dP[B2M7:dPWB2]89dL[B2M8:dQ[
FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg/oC3m=>d`oCCm<?ddkC3m=?d`oCC]<?ddo
C3m=>d`oCCm<?ddkC3m=?d`oCC]<?ddoC3m=>d`oCCm<?ddkC3m=?d`oCC]<?ddoC3m=>da_Nf]JJgY[
FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeYGDE=@Ee5CD5MADe1GDE=@Ee5CD5MADe1GDE=@Ee5C
D5MADe1GDE=@Ee5CD5MADe1GDE=@Ee5CD5MADe1GDE=@Ee5CD5MADe1GDE=@Ee5[FV]jJeY_Nf]JJgY[
FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgYWEF]FIeE[EFMEJeIWEF]EIeE[EP00J6MEJeEWEF]FIeE[EFME
JeIWEF]EIeE[EVMEJeEWEF]FIeE[EFMEJeIWEF]EIeE[EVMEJeEWEF]FIeE[NV]JKg][FV]jJeY_Nf]J
JgX006mkJeY[NV]JKg][FV]jJeYoFWmIOeYoFGmJOeUoFWmIOeYoFGmJOeUoFWmIOeYoFGmJOeUoFWmI
OeYoFGmJOeUoFWmIOeYoFGmJOeUoFWmIOeYoFGmJOeUoFWmIOeY[FVmkJeY[NV]JKg][FV]jJeX006]J
JgY[FVmkJeY[NV]JKg/1JeX0015[FP054d@C@a=34d<CA0034d<01A=44d<C@a=34d@00a=300DCA1=3
4d<C@a=400<C@`054d@C@a=34d<CA0034d<01A=44d<C@a=34d@00Q=34V]J00DWB2]8:dP[B2M800<[
B0059dP[B2]8:dPWB003:dP01BM8:dP[B2]89dP00b]800DWB2]8:dP[B2M800<[B0059dP[B2]8:dPW
B002:dPBJeXW?d`BJeXWDe4BJeX00f]EIeE[E@02JeD01FMEJeE[EF]EIeD00f]E00EWEF]EJeE[EFME
00=[E@05IeE[EF]EJeEWE@03JeD01FMEJeE[EF]EIeD00f]E00=WEF]EJeX026]J00<006]JJeX01V]J
00EoFGmJOeYoFWmI00=oFP05OeUoFWmJOeYoF@03OeX01GmIOeYoFWmJOeT00gmJ00EoFGmJOeYoFWmI
00=oFP05OeUoFWmJOeYoF@02OeX9JeX00`00JeY[FP07JeX0003oKg][FV]jJeY_Nf]JJgY[FVmkJeY[
NV]JKg][FV]jJeY_Na=35d@C@aM44d<GA1=35d@C@aM44d<GA1=35d@C@aM44d<GA1=35d@C@aM44d<G
A1=35d@C@aM44d<GA1=35d@C@aM44d<GA1=35d@C@fmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[
NV]JKg][FR]89dL[B2M8:dPWAb]89dP[B2M7:dPWB2]89dL[B2M8:dPWAb]89dP[B2M7:dPWB2]89dL[
B2M8:dPWAb]89dP[B2M7:dPWB2]89dL[B6]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[
NS]<?ddoC3m=>d`oCCm<?ddkC3m=?d`oCC]<?ddoC3m=>d`oCCm<?ddkC3m=?d`oCC]<?ddoC3m=>d`o
CCm<?ddkC3m=?d`oCC]<?ddoC6]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FUMADe1G
DE=@Ee5CD5MADe1GDE=@Ee5CD5MADe1GDE=@Ee5CD5MADe1GDE=@Ee5CD5MADe1GDE=@Ee5CD5MADe1G
DE=@Ee5CD5MADe1GDF]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_NfMEJeEWEF]FIeE[
EFMEJeIWEF]E001XIeE[EVMEJeEWEF]FIeE[EFMEJeIWEF]EIeE[EVMEJeEWEF]FIeE[EFMEJeIWEF]E
IeE[EVMEJeEWEFmkJeY[NV]JKg][FV]jJeY_N`00JgY[FVmkJeY[NV]JKg][FWmJOeUoFWmIOeYoFGmJ
OeUoFWmIOeYoFGmJOeUoFWmIOeYoFGmJOeUoFWmIOeYoFGmJOeUoFWmIOeYoFGmJOeUoFWmIOeYoFGmJ
OeUoFV]JJgY[FVmkJeY[NV]JKg][FP00JeY_Nf]JJgY[FVmkJeY[NP5[FP004F]J0Q=300DCA1=34d<C
@a=400<C@`054d@C@a=34d<CA0034d<01A=44d<C@a=34d@00a=300DCA1=34d<C@a=400<C@`054d@C
@a=34d<CA00BJeX2:dP01BM8:dP[B2]89dP00b]800DWB2]8:dP[B2M800<[B0059dP[B2]8:dPWB003
:dP01BM8:dP[B2]89dP00b]800DWB2]8:dP[B2M8019[FRLoC19[FRMCDA9[FP=[E@05IeE[EF]EJeEW
E@03JeD01FMEJeE[EF]EIeD00f]E00EWEF]EJeE[EFME00=[E@05IeE[EF]EJeEWE@03JeD016MEJeE[
EF]E2F]J00<006]JJeX01V]J0WmJ00EoFGmJOeYoFWmI00=oFP05OeUoFWmJOeYoF@03OeX01GmIOeYo
FWmJOeT00gmJ00EoFGmJOeYoFWmI00=oFP05OeUoFWmJOeYoF@09JeX00`00JeY[FP07JeX0003oJgY[
FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NQ=35d@C@aM44d<GA1=35d@C@aM44d<GA1=35d@C
@aM44d<GA1=35d@C@aM44d<GA1=35d@C@aM44d<GA1=35d@C@aM44d<GA1=35d@C@f]jJeY_Nf]JJgY[
FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FR]89dP[B2M7:dPWB2]89dL[B2M8:dPWAb]89dP[B2M7:dPW
B2]89dL[B2M8:dPWAb]89dP[B2M7:dPWB2]89dL[B2M8:dPWAb]89dP[B6]JKg][FV]jJeY_Nf]JJgY[
FVmkJeY[NV]JKg][FV]jJeY_Ncm<?ddkC3m=?d`oCC]<?ddoC3m=>d`oCCm<?ddkC3m=?d`oCC]<?ddo
C3m=>d`oCCm<?ddkC3m=?d`oCC]<?ddoC3m=>d`oCCm<?ddkC6mkJeY[NV]JKg][FV]jJeY_Nf]JJgY[
FVmkJeY[NV]JKg][FUMADe1GDE=@Ee5CD5MADe1GDE=@Ee5CD5MADe1GDE=@Ee5CD5MADe1GDE=@Ee5C
D5MADe1GDE=@Ee5CD5MADe1GDE=@Ee5CD5MADe1GDF]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[
FVmkJeY[NVMEJeIWEF]EIeE[EVMEJeEWEF]F001XIeE[EFMEJeIWEF]EIeE[EVMEJeEWEF]FIeE[EFME
JeIWEF]EIeE[EVMEJeEWEF]FIeE[EFMEJeIWEF]jJeY_Nf]JJgY[FVmkJeY[NP00Kg][FV]jJeY_Nf]J
JgY[FWmJOeUoFWmIOeYoFGmJOeUoFWmIOeYoFGmJOeUoFWmIOeYoFGmJOeUoFWmIOeYoFGmJOeUoFWmI
OeYoFGmJOeUoFWmIOeYoFGmJOeUoFV]JKg][FV]jJeY_Nf]JJgY[FP00JeY[NV]JKg][FV]jJeY_N`5[
FP004F]J00DCA1=34d<C@a=400<C@`054d@C@a=34d<CA0034d<01A=44d<C@a=34d@00a=300DCA1=3
4d<C@a=400<C@`054d@C@a=34d<CA0024d<BJeX01BM8:dP[B2]89dP00b]800DWB2]8:dP[B2M800<[
B0059dP[B2]8:dPWB003:dP01BM8:dP[B2]89dP00b]800DWB2]8:dP[B2M8008[B19[FRLoC19[FRMC
DA9[FP03JeEWEF]E009[E@05IeE[EF]EJeEWE@03JeD01FMEJeE[EF]EIeD00f]E00EWEF]EJeE[EFME
00=[E@05IeE[EF]EJeEWE@03JeD00fMEJeE[FP08JeX00`00JeY[FP06JeX01GmIOeYoFWmJOeT00gmJ
00EoFGmJOeYoFWmI00=oFP05OeUoFWmJOeYoF@03OeX01GmIOeYoFWmJOeT00gmJ00EoFGmJOeYoFWmI
009oFPU[FP03001[FV]J00M[FP000?m_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeXG
A1=35d@C@aM44d<GA1=35d@C@aM44d<GA1=35d@C@aM44d<GA1=35d@C@aM44d<GA1=35d@C@aM44d<G
A1=35d@C@aM44d<GA1=3Kg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgXWAb]89dP[
B2M7:dPWB2]89dL[B2M8:dPWAb]89dP[B2M7:dPWB2]89dL[B2M8:dPWAb]89dP[B2M7:dPWB2]89dL[
B2M8:dPWAb]8JeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeXoCCm<?ddkC3m=?d`o
CC]<?ddoC3m=>d`oCCm<?ddkC3m=?d`oCC]<?ddoC3m=>d`oCCm<?ddkC3m=?d`oCC]<?ddoC3m=>d`o
CCm<JgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg]CD5MADe1GDE=@Ee5CD5MADe1G
DE=@Ee5CD5MADe1GDE=@Ee5CD5MADe1GDE=@Ee5CD5MADe1GDE=@Ee5CD5MADe1GDE=@Ee5CD5MAJeY_
Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[EFMEJeIWEF]EIeE[EVMEJeD006QWEF]F
IeE[EFMEJeIWEF]EIeE[EVMEJeEWEF]FIeE[EFMEJeIWEF]EIeE[EVMEJeEWEF]FIeE[EFMEKg][FV]j
JeY_Nf]JJgY[FVmk001[NV]JKg][FV]jJeY_Nf]JJgYoFGmJOeUoFWmIOeYoFGmJOeUoFWmIOeYoFGmJ
OeUoFWmIOeYoFGmJOeUoFWmIOeYoFGmJOeUoFWmIOeYoFGmJOeUoFWmIOeYoFGmJJeY[NV]JKg][FV]j
JeY_Nf]J001[FVmkJeY[NV]JKg][FV]j0F]J000BJeX00a=34d@C@`024d<01A=44d<C@a=34d@00a=3
00DCA1=34d<C@a=400<C@`054d@C@a=34d<CA0034d<01A=44d<C@a=34d@00a=300<CA6]JJeX04F]J
00<[B2M8:dP00R]800DWB2]8:dP[B2M800<[B0059dP[B2]8:dPWB003:dP01BM8:dP[B2]89dP00b]8
00DWB2]8:dP[B2M800<[B0039dQ[FV]J015[FRHoC1=[FRICDA=[FP9[E@05IeE[EF]EJeEWE@03JeD0
1FMEJeE[EF]EIeD00f]E00EWEF]EJeE[EFME00=[E@05IeE[EF]EJeEWE@03JeD016MEJeE[EF]E2F]J
00<006]JJeX01f]J00=oFWmIOeX00WmJ00EoFGmJOeYoFWmI00=oFP05OeUoFWmJOeYoF@03OeX01GmI
OeYoFWmJOeT00gmJ00EoFGmJOeYoFWmI00=oFP03OeU[FV]J00M[FP03001[FV]J00M[FP000?m[NV]J
Kg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Na=35d@C@aM44d<GA1=35d@C@aM44d<GA1=3
5d@C@aM44d<GA1=35d@C@aM44d<GA1=35d@C@aM44d<GA1=35d@C@aM44d<GA6]JJgY[FVmkJeY[NV]J
Kg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FR]89dL[B2M8:dPWAb]89dP[B2M7:dPWB2]89dL[B2M8
:dPWAb]89dP[B2M7:dPWB2]89dL[B2M8:dPWAb]89dP[B2M7:dPWB6]jJeY_Nf]JJgY[FVmkJeY[NV]J
Kg][FV]jJeY_Nf]JJgY[FVmkJeY[NS]<?ddoC3m=>d`oCCm<?ddkC3m=?d`oCC]<?ddoC3m=>d`oCCm<
?ddkC3m=?d`oCC]<?ddoC3m=>d`oCCm<?ddkC3m=?d`oCF]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]J
Kg][FV]jJeY_Nf]JJgY[FUMADe1GDE=@Ee5CD5MADe1GDE=@Ee5CD5MADe1GDE=@Ee5CD5MADe1GDE=@
Ee5CD5MADe1GDE=@Ee5CD5MADe1GDE=@Ee5CD6mkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]J
Kg][FV]jJeY_NfMEJeEWEF]FIeE[EFMEJeH006QWEF]EIeE[EVMEJeEWEF]FIeE[EFMEJeIWEF]EIeE[
EVMEJeEWEF]FIeE[EFMEJeIWEF]EIeE[EV]JJgY[FVmkJeY[NV]JKg][FV]j001_Nf]JJgY[FVmkJeY[
NV]JKg]oFGmJOeUoFWmIOeYoFGmJOeUoFWmIOeYoFGmJOeUoFWmIOeYoFGmJOeUoFWmIOeYoFGmJOeUo
FWmIOeYoFGmJOeUoFWmIOeYoFF]jJeY_Nf]JJgY[FVmkJeY[NV]J001[FV]jJeY_Nf]JJgY[FVmk0F]J
000CJeX24d<01A=44d<C@a=34d@00a=300DCA1=34d<C@a=400<C@`054d@C@a=34d<CA0034d<01A=4
4d<C@a=34d@00a=300<CA1=3JeX056]J0R]800DWB2]8:dP[B2M800<[B0059dP[B2]8:dPWB003:dP0
1BM8:dP[B2]89dP00b]800DWB2]8:dP[B2M800<[B0039dP[B6]J01A[FR@oC1E[FRACDAE[FP=[E@05
IeE[EF]EJeEWE@03JeD01FMEJeE[EF]EIeD00f]E00EWEF]EJeE[EFME00=[E@05IeE[EF]EJeEWE@03
JeD00fMEJeY[FP08JeX00`00JeY[FP07JeX3OeX01GmIOeYoFWmJOeT00gmJ00EoFGmJOeYoFWmI00=o
FP05OeUoFWmJOeYoF@03OeX01GmIOeYoFWmJOeT00gmJ00=oFGmJJeX02F]J00<006]JJeX01f]J0000
ofmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeXGA1=35d@C@aM44d<GA1=35d@C
@aM44d<GA1=35d@C@aM44d<GA1=35d@C@aM44d<GA1=35d@C@aM44d<GA1=35d@C@f]jJeY_Nf]JJgY[
FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg/WB2]89dL[B2M8:dPWAb]89dP[B2M7:dPW
B2]89dL[B2M8:dPWAb]89dP[B2M7:dPWB2]89dL[B2M8:dPWAb]89dP[B6]JKg][FV]jJeY_Nf]JJgY[
FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmk?d`oCC]<?ddoC3m=>d`oCCm<?ddkC3m=?d`oCC]<?ddo
C3m=>d`oCCm<?ddkC3m=?d`oCC]<?ddoC3m=>d`oCCm<?ddkC6mkJeY[NV]JKg][FV]jJeY_Nf]JJgY[
FVmkJeY[NV]JKg][FV]jJeY_Nf]JEe5CD5MADe1GDE=@Ee5CD5MADe1GDE=@Ee5CD5MADe1GDE=@Ee5C
D5MADe1GDE=@Ee5CD5MADe1GDE=@Ee5CD5MADe1GDF]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[
FVmkJeY[NV]JKg][FV]jIeE[EVMEJeEWEF]FIeE[E@00J6MEJeIWEF]EIeE[EVMEJeEWEF]FIeE[EFME
JeIWEF]EIeE[EVMEJeEWEF]FIeE[EFMEJeIWEF]jJeY_Nf]JJgY[FVmkJeY[NV]JKg/006]jJeY_Nf]J
JgY[FVmkJeY[NV]JOeYoFGmJOeUoFWmIOeYoFGmJOeUoFWmIOeYoFGmJOeUoFWmIOeYoFGmJOeUoFWmI
OeYoFGmJOeUoFWmIOeYoFGmJOeUoFV]JKg][FV]jJeY_Nf]JJgY[FVmkJeX006]JKg][FV]jJeY_Nf]J
JgX1JeX001A[FP<C@`054d@C@a=34d<CA0034d<01A=44d<C@a=34d@00a=300DCA1=34d<C@a=400<C
@`054d@C@a=34d<CA0024d<GJeX3:dP01BM8:dP[B2]89dP00b]800DWB2]8:dP[B2M800<[B0059dP[
B2]8:dPWB003:dP01BM8:dP[B2]89dP00R]85V]J8cm<5V]J8e=A5V]J00=[EFMEJeD00V]E00EWEF]E
JeE[EFME00=[E@05IeE[EF]EJeEWE@03JeD01FMEJeE[EF]EIeD00f]E00IWEF]EJeE[EFMEJeD;JeX0
0`00JeY[FP08JeX01GmIOeYoFWmJOeT00gmJ00EoFGmJOeYoFWmI00=oFP05OeUoFWmJOeYoF@03OeX0
1GmIOeYoFWmJOeT00gmJ00=oFGmJOeX02f]J00<006]JJeX01f]J0000of]jJeY_Nf]JJgY[FVmkJeY[
NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NQ=35d@C@aM44d<GA1=35d@C@aM44d<GA1=35d@C@aM44d<G
A1=35d@C@aM44d<GA1=35d@C@aM44d<GA1=35dA[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[
NV]JKg][FV]jJeY_Nf]JJgY[FR]89dP[B2M7:dPWB2]89dL[B2M8:dPWAb]89dP[B2M7:dPWB2]89dL[
B2M8:dPWAb]89dP[B2M7:dPWB2]89dM_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[
NV]JKg][FV]jJeXoCCm<?ddkC3m=?d`oCC]<?ddoC3m=>d`oCCm<?ddkC3m=?d`oCC]<?ddoC3m=>d`o
CCm<?ddkC3m=?d`oCC]<?de[FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[
NV]JKg]CD5MADe1GDE=@Ee5CD5MADe1GDE=@Ee5CD5MADe1GDE=@Ee5CD5MADe1GDE=@Ee5CD5MADe1G
DE=@Ee5CD5MADe1[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[
EFMEJeIWEF]EIeE[EP00J6MEJeEWEF]FIeE[EFMEJeIWEF]EIeE[EVMEJeEWEF]FIeE[EFMEJeIWEF]E
IeE[EVMEJeE[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgX006mkJeY[NV]JKg][FV]jJeY_Nf]JJgYoFGmJ
OeUoFWmIOeYoFGmJOeUoFWmIOeYoFGmJOeUoFWmIOeYoFGmJOeUoFWmIOeYoFGmJOeUoFWmIOeYoFGmJ
OeU_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeX006]JJgY[FVmkJeY[NV]JKg/1JeX001E[FP054d@C@a=3
4d<CA0034d<01A=44d<C@a=34d@00a=300DCA1=34d<C@a=400<C@`054d@C@a=34d<CA0024d<JJeX0
1BM8:dP[B2]89dP00b]800DWB2]8:dP[B2M800<[B0059dP[B2]8:dPWB003:dP01BM8:dP[B2]89dP0
0R]86V]J7cm<6V]J7e=A6V]J00=[EFMEJeD00V]E00EWEF]EJeE[EFME00=[E@05IeE[EF]EJeEWE@03
JeD01FMEJeE[EF]EIeD00f]E00=WEF]EJeX036]J00<006]JJeX02V]J00EoFGmJOeYoFWmI00=oFP05
OeUoFWmJOeYoF@03OeX01GmIOeYoFWmJOeT00gmJ00EoFGmJOeYoFWmI009oFPe[FP03001[FV]J00M[
FP000?m_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FQM44d<GA1=35d@C
@aM44d<GA1=35d@C@aM44d<GA1=35d@C@aM44d<GA1=35d@C@aM44d<GA1=35dA[FVmkJeY[NV]JKg][
FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NRM7:dPWB2]89dL[B2M8:dPW
Ab]89dP[B2M7:dPWB2]89dL[B2M8:dPWAb]89dP[B2M7:dPWB2]89dM_Nf]JJgY[FVmkJeY[NV]JKg][
FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FSm=?d`oCC]<?ddoC3m=>d`oCCm<?ddk
C3m=?d`oCC]<?ddoC3m=>d`oCCm<?ddkC3m=?d`oCC]<?de[FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][
FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Ne=@Ee5CD5MADe1GDE=@Ee5CD5MADe1GDE=@Ee5C
D5MADe1GDE=@Ee5CD5MADe1GDE=@Ee5CD5MADe1[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][
FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]EIeE[EVMEJeD006QWEF]FIeE[EFMEJeIWEF]EIeE[EVME
JeEWEF]FIeE[EFMEJeIWEF]EIeE[EVMEJeE[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmk001[NV]J
Kg][FV]jJeY_Nf]JJgY[FVmkJeY[NWmIOeYoFGmJOeUoFWmIOeYoFGmJOeUoFWmIOeYoFGmJOeUoFWmI
OeYoFGmJOeUoFWmIOeYoFGmJOeU_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]J001[FVmkJeY[NV]J
Kg][FV]j0F]J000GJeX01A=44d<C@a=34d@00a=300DCA1=34d<C@a=400<C@`054d@C@a=34d<CA003
4d<00a=44d<C@`0NJeX01BM8:dP[B2]89dP00b]800DWB2]8:dP[B2M800<[B0059dP[B2]8:dPWB003
:dP00bM8:dP[B00NJeXK?d`NJeXKDe4NJeX00f]EIeE[E@02JeD01FMEJeE[EF]EIeD00f]E00EWEF]E
JeE[EFME00=[E@06IeE[EF]EJeEWEF]E3f]J00<006]JJeX036]J00EoFGmJOeYoFWmI00=oFP05OeUo
FWmJOeYoF@03OeX01GmIOeYoFWmJOeT00gmJ00=oFGmJOeX03f]J00<006]JJeX01f]J0000of]jJeY_
Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FQM44d<GA1=35d@C@aM44d<G
A1=35d@C@aM44d<GA1=35d@C@aM44d<GA1=35d@C@aM4JeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_
Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NRM7:dPWB2]89dL[B2M8:dPWAb]89dP[
B2M7:dPWB2]89dL[B2M8:dPWAb]89dP[B2M7Kg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_
Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FSm=?d`oCC]<?ddoC3m=>d`oCCm<?ddkC3m=?d`o
CC]<?ddoC3m=>d`oCCm<?ddkC3m=JeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_
Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Ne=@Ee5CD5MADe1GDE=@Ee5CD5MADe1GDE=@Ee5CD5MADe1G
DE=@Ee5CD5MADe1GDE=@JgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_
Nf]JJgY[FVmkJeY[NV]JKg][FV]EIeE[EP00J6MEJeEWEF]FIeE[EFMEJeIWEF]EIeE[EVMEJeEWEF]F
IeE[EFMEJeIWEF]EJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgX006mkJeY[NV]JKg][FV]j
JeY_Nf]JJgY[FVmkJeY[NWmIOeYoFGmJOeUoFWmIOeYoFGmJOeUoFWmIOeYoFGmJOeUoFWmIOeYoFGmJ
OeUoFWmIKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeX006]JJgY[FVmkJeY[NV]JKg/1JeX0
01U[FP054d@C@a=34d<CA0034d<01A=44d<C@a=34d@00a=300HCA1=34d<C@a=44d<SJeX01BM8:dP[
B2]89dP00b]800DWB2]8:dP[B2M800<[B0069dP[B2]8:dPWB2]88f]J5Sm<8f]J5U=A8f]J00=[EFME
JeD00V]E00EWEF]EJeE[EFME00=[E@05IeE[EF]EJeEWE@03JeD00fMEJeY[FP0@JeX00`00JeY[FP0>
JeX01GmIOeYoFWmJOeT00gmJ00EoFGmJOeYoFWmI00=oFP06OeUoFWmJOeYoFGmJ4V]J00<006]JJeX0
1f]J0000ofmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[
NQ=35d@C@aM44d<GA1=35d@C@aM44d<GA1=35d@C@aM44d<GA1=3JgY[FVmkJeY[NV]JKg][FV]jJeY_
Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FR]89dP[
B2M7:dPWB2]89dL[B2M8:dPWAb]89dP[B2M7:dPWB2]8JeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_
Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Ncm<?ddkC3m=?d`o
CC]<?ddoC3m=>d`oCCm<?ddkC3m=?d`oCC]<Kg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_
Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FUMADe1GDE=@Ee5CD5MADe1G
DE=@Ee5CD5MADe1GDE=@Ee5CD5MAJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_
Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NP00J6MEJeIWEF]EIeE[EVMEJeEWEF]F
IeE[EFMEJeIWEF]EIeE[EVMEJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg/006]j
JeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgYoFGmJOeUoFWmIOeYoFGmJOeUoFWmIOeYoFGmJ
OeUoFWmIOeYoFGmJJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeX006]JKg][FV]j
JeY_Nf]JJgX1JeX001a[FP<C@`054d@C@a=34d<CA0034d<01A=44d<C@a=34d@0:F]J0b]800DWB2]8
:dP[B2M800<[B0059dP[B2]8:dPWB00YJeX@?d`YJeX@De4YJeX01FMEJeE[EF]EIeD00f]E00EWEF]E
JeE[EFME00=[EAE[FP03001[FV]J015[FP=oFP05OeUoFWmJOeYoF@03OeX01GmIOeYoFWmJOeT05F]J
00<006]JJeX01f]J0000of]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]J
Kg][FV]jJeY_Nf]JJgY[FVmkJeXGA1=35d@C@aM44d<GA1=35d@C@fmkJeY[NV]JKg][FV]jJeY_Nf]J
JgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]J
Kg][FV]jJeY_Nf]JJgXWAb]89dP[B2M7:dPWB2]89dL[B6]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]J
JgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]J
Kg][FV]jJeXoCCm<?ddkC3m=?d`oCC]<?ddoC6]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]J
JgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]J
Kg]CD5MADe1GDE=@Ee5CD5MADe1GDF]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]J
JgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_N`00J6]JJgY[FVmkJeY[
EFMEJeIWEF]EIeE[EVMEJeEWEFmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_
Nf]JJgX006mkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgYoFGmJOeUo
FWmIOeYoFGmJOeUoFV]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeX0
06]JJgY[FVmkJeY[NV]JKg/1JeX00?m[FRI[FP03001[FV]J03I[FP03001[FV]J00M[FP000?m_Nf]J
JgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]J
Kg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]J
JgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]J
Kg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]J
JgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]J
Kg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]J
JgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]J
Kg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]J
JgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgX006Q[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[
NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmk001[NV]JKg][FV]jJeY_
Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[
NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]J001[FVmkJeY[NV]JKg][FV]j0F]J
003oJeXVJeX00`00JeY[FP0fJeX00`00JeY[FP07JeX0003oJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]J
JgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]J
Kg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]J
JgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]J
Kg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]J
JgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]J
Kg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]J
JgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]J
Kg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]J
JgY[FVmk001XJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[
NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NP00Kg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_
Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[
NV]JKg][FV]jJeY_Nf]JJgY[FP00JeY[NV]JKg][FV]jJeY_N`5[FP00of]J9V]J00<006]JJeX0=V]J
00<006]JJeX01f]J0000ofmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]J
JgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]J
Kg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]J
JgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]J
Kg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]J
JgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]J
Kg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]J
JgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]J
Kg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NP00J6]JKg][FV]jJeY_
Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[
NV]JKg/006]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_
Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeX0
06]JKg][FV]jJeY_Nf]JJgX1JeX00?m[FRI[FP03001[FV]J03I[FP03001[FV]J00M[FP000?m[NV]J
Kg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]J
JgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]J
Kg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]J
JgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]J
Kg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]J
JgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]J
Kg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]J
JgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]J
Kg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg/006Q[FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_
Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]j001_Nf]JJgY[FVmkJeY[
NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_
Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]J001[FV]jJeY_Nf]JJgY[FVmk0F]J
0008Je[o000O000hJeX00`00JeY[FP07JeX0003oKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]j
JeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmk
JeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]j
JeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmk
JeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]j
JeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmk
JeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]j
JeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmk
JeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]j
001XJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[
FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][
FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[
FVmkJeY[NV]JKg][FP00JeY_Nf]JJgY[FVmkJeY[NP5[FP00of]JGf]J00<006]JJeX01f]J0000of]j
JeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmk
JeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]j
JeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmk
JeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]j
JeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmk
JeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]j
JeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmk
JeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]j
JeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_N`00J6]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[
FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][
FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[
FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeX006]JJgY[FVmkJeY[NV]JKg/1
JeX00?m[FUm[FP03001[FV]J00M[FP000?m_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmk
JeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]j
JeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmk
JeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]j
JeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmk
JeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]j
JeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmk
JeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]j
JeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgX006Q[
FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][
FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[
FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][
FV]jJeY_Nf]J001[FVmkJeY[NV]JKg][FV]j0F]J003oJeYOJeX00`00JeY[FP07JeX0003oJgY[FVmk
JeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]j
JeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmk
JeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]j
JeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmk
JeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]j
JeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmk
JeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]j
JeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmk
JeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmk001XJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][
FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[
FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][
FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FP00JeY[NV]JKg][FV]jJeY_N`5[FP00
of]JGf]J00<006]JJeX01f]J0000ofmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]j
JeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmk
JeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]j
JeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmk
JeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]j
JeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmk
JeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]j
JeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmk
JeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NP00J6]JKg][
FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[
FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][
FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[
FVmkJeX006]JKg][FV]jJeY_Nf]JJgX1JeX001i[FPhCi2][FP03:nXWjB_Z008[jP059nT[jR_Z:nXW
j@03:nX00bOYJeY[FP0YJeX>?nl[JeX>Do@[JeX2JoX01FOiJoY[nV_jIoT00f_j00AWnF_jJoY[nR][
FPiooaE[FP03001[FV]J00M[FP0008i[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_
Nf]JJgY[FVmkJeY[NV]JKg/Ci1OU4n@GiA?T5nDCi1OU4n@GiA?T5nDCi1OU4n@GiA?T5nDCi6mkJeY[
NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_
Nf]JJgY[FVmkJeX[jROY:nXWjB_Z9nT[jROY:nXWjB_Z9nT[jROY:nXWjB_Z9nT[jV]JJgY[FVmkJeY[
NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_
Nf]JJgXkkP<ok`05>nhokco_?nlkkP03?nl01C_^?nlokco_>nh00So_09M[NV]JKg][FV]jJeY_Nf]J
JgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]J
EoECm5OeDoAGmE?dEoECm5OeDoAGmE?dEoECm5OeDoAGmE?dEoE[FVmkJeY[NV]JKg][FV]jJeY_Nf]J
JgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkIoU[nVOi
JoYWnF_jIoU[nVOiJoYWnF_jIoU[nVOiJoYWnF_jIoU_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]J
JgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_N`0DOol076]JJgY[FVmk
JeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]J001[FV]jJeY_Nf]JJgY[FVmk0F]J000IJeXF4n@S
JeX01BOY:nX[jR_Z9nT00b_Z00DWjB_Z:nX[jROY00<[jP069nT[jR_Z:nXWjB_Z8f]J5So_8f]J5U?d
8f]J00=[nVOiJoX00V_j00EWnF_jJoY[nVOi00=[nP05IoU[nV_jJoYWn@03JoX00fOiJeY[FP0QJeXF
OolBJeX00`00JeY[FP07JeX0002<Kg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[
FVmkJeY[NV]J5nDCi1OU4n@GiA?T5nDCi1OU4n@GiA?T5nDCi1OU4n@GiA?T5nDCi1OU4n@GiA?T5nE[
FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[
FVmk9nT[jROY:nXWjB_Z9nT[jROY:nXWjB_Z9nT[jROY:nXWjB_Z9nT[jROY:nXWjB_Z9nU[NV]JKg][
FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]J?nlk
kP<ok`05>nhokco_?nlkkP03?nl01C_^?nlokco_>nh00co_09HkkSo_?nlokf]JKg][FV]jJeY_Nf]J
JgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgYCm5OeDoAGmE?d
EoECm5OeDoAGmE?dEoECm5OeDoAGmE?dEoECm5OeDoAGmE?dEoECm6mkJeY[NV]JKg][FV]jJeY_Nf]J
JgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY[nVOiJoYWnF_jIoU[nVOi
JoYWnF_jIoU[nVOiJoYWnF_jIoU[nVOiJoYWnF_jIoU[nV]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]J
JgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg/IOol06F]jJeY_Nf]JJgY[FVmkJeY[
NV]JKg][FV]jJeY_Nf]J001[FVmkJeY[NV]JKg][FV]j005[FP005f]J6a?T7V]J00DWjB_Z:nX[jROY
00<[jP059nT[jR_Z:nXWj@03:nX01BOY:nX[jR_Z9nT00b_Z00<WjB_Z:nX07V]J6co_7V]J6e?d7V]J
00=[nVOiJoX00V_j00EWnF_jJoY[nVOi00=[nP05IoU[nV_jJoYWn@03JoX01VOiJoY[nV_jIoU[nQi[
FQ]oo`m[FP03001[FV]J00M[FP0008Y[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_
Nf]JJgY[FQOU4n@GiA?T5nDCi1OU4n@GiA?T5nDCi1OU4n@GiA?T5nDCi1OU4n@GiA?T5nDCi1OU4n@G
iA?T5nE[FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_
NbOY:nXWjB_Z9nT[jROY:nXWjB_Z9nT[jROY:nXWjB_Z9nT[jROY:nXWjB_Z9nT[jROY:nXWjB_Z9nU[
NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FSo_>nh3
?nl01C_^?nlokco_>nh00co_00DkkSo_?nlokc_^00<ok`05>nhokco_?nlkkP03?nl0SV]JKg][FV]j
JeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jDoAGmE?dEoECm5Oe
DoAGmE?dEoECm5OeDoAGmE?dEoECm5OeDoAGmE?dEoECm5OeDoAGmE?dEoECm6mkJeY[NV]JKg][FV]j
JeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JJoYWnF_jIoU[nVOiJoYWnF_j
IoU[nVOiJoYWnF_jIoU[nVOiJoYWnF_jIoU[nVOiJoYWnF_jIoU[nV]JJgY[FVmkJeY[NV]JKg][FV]j
JeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmk7Goo01M[NV]JKg][FV]jJeY_Nf]JJgY[
FVmkJeY[NV]J001[FV]jJeY_Nf]JJgY[FVmk005[FP005F]J7a?T6V]J00DWjB_Z:nX[jROY00<[jP05
9nT[jR_Z:nXWj@03:nX01BOY:nX[jR_Z9nT00b_Z00DWjB_Z:nX[jROY008[jQY[FQlokaY[FQmCm1Y[
FP03JoYWnF_j009[nP05IoU[nV_jJoYWn@03JoX01FOiJoY[nV_jIoT00f_j00EWnF_jJoY[nVOi00=[
nP03IoU[nV]J01U[FQmoo`e[FP03001[FV]J00M[FP0008Q_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_
Nf]JJgY[FVmkJeY[NV]JKg/Ci1OU4n@GiA?T5nDCi1OU4n@GiA?T5nDCi1OU4n@GiA?T5nDCi1OU4n@G
iA?T5nDCi1OU4n@GiA?T5nDCi1OUJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_
Nf]JJgY[FVmkJeX[jROY:nXWjB_Z9nT[jROY:nXWjB_Z9nT[jROY:nXWjB_Z9nT[jROY:nXWjB_Z9nT[
jROY:nXWjB_Z9nT[jROYJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_
Nf]J?nlkkP<ok`05>nhokco_?nlkkP03?nl01C_^?nlokco_>nh00co_00DkkSo_?nlokc_^00<ok`2>
>nhokco_?nm[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgYCm5Oe
DoAGmE?dEoECm5OeDoAGmE?dEoECm5OeDoAGmE?dEoECm5OeDoAGmE?dEoECm5OeDoAGmE?dEoECm5Oe
DoA_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY[nVOiJoYWnF_j
IoU[nVOiJoYWnF_jIoU[nVOiJoYWnF_jIoU[nVOiJoYWnF_jIoU[nVOiJoYWnF_jIoU[nVOiJoY[FV]j
JeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg/QOol05F]jJeY_Nf]JJgY[
FVmkJeY[NV]JKg][FP00JeY_Nf]JJgY[FVmkJeY[NP01JeX001A[FR8Ci1M[FP<[jP059nT[jR_Z:nXW
j@03:nX01BOY:nX[jR_Z9nT00b_Z00DWjB_Z:nX[jROY00<[jP059nT[jR_Z:nXWj@02:nXFJeXS?nlF
JeXSDo@FJeX00f_jIoU[nP02JoX01FOiJoY[nV_jIoT00f_j00EWnF_jJoY[nVOi00=[nP05IoU[nV_j
JoYWn@03JoX01VOiJoY[nV_jIoU[nQI[FR=oo`][FP03001[FV]J00M[FP0008I[NV]JKg][FV]jJeY_
Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]J5nDCi1OU4n@GiA?T5nDCi1OU4n@GiA?T5nDCi1OU4n@G
iA?T5nDCi1OU4n@GiA?T5nDCi1OU4n@GiA?T5nDCi1OU4nA_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_
Nf]JJgY[FVmkJeY[NV]JKg][FV]j9nT[jROY:nXWjB_Z9nT[jROY:nXWjB_Z9nT[jROY:nXWjB_Z9nT[
jROY:nXWjB_Z9nT[jROY:nXWjB_Z9nT[jROY:nY[FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_
Nf]JJgY[FVmkJeY[NS_^0co_00DkkSo_?nlokc_^00<ok`05>nhokco_?nlkkP03?nl01C_^?nlokco_
>nh00co_00DkkSo_?nlokc_^008ok`28JgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]J
Kg][FV]jJeYGmE?dEoECm5OeDoAGmE?dEoECm5OeDoAGmE?dEoECm5OeDoAGmE?dEoECm5OeDoAGmE?d
EoECm5OeDoAGmE?dEoECm5OeJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]J
Kg]WnF_jIoU[nVOiJoYWnF_jIoU[nVOiJoYWnF_jIoU[nVOiJoYWnF_jIoU[nVOiJoYWnF_jIoU[nVOi
JoYWnF_jIoU[nVOiKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeXSOol0
56]JJgY[FVmkJeY[NV]JKg][FV]jJeX006]JJgY[FVmkJeY[NV]JKg/1JeX001=[FR@Ci1E[FP8[jP05
9nT[jR_Z:nXWj@03:nX01BOY:nX[jR_Z9nT00b_Z00DWjB_Z:nX[jROY00<[jP059nT[jR_Z:nXWj@03
:nX00bOY:nY[FP0DJeXT?nlEJeXTDo@EJeX3JoX01FOiJoY[nV_jIoT00f_j00EWnF_jJoY[nVOi00=[
nP05IoU[nV_jJoYWn@03JoX01FOiJoY[nV_jIoT00f_j00=WnF]JJeX04V]J9Goo2V]J00<006]JJeX0
1f]J0000QFmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]j4n@GiA?T5nDCi1OU4n@G
iA?T5nDCi1OU4n@GiA?T5nDCi1OU4n@GiA?T5nDCi1OU4n@GiA?T5nDCi1OU4n@GiA?T5nDCi1OUJeY_
Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]J:nXWjB_Z9nT[jROY:nXWjB_Z9nT[
jROY:nXWjB_Z9nT[jROY:nXWjB_Z9nT[jROY:nXWjB_Z9nT[jROY:nXWjB_Z9nT[jROYKg][FV]jJeY_
Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmk008ok`05>nhokco_?nlkkP03?nl01C_^?nlo
kco_>nh00co_00DkkSo_?nlokc_^00<ok`05>nhokco_?nlkkP03?nl0R3_^?nm[FV]jJeY_Nf]JJgY[
FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeYGmE?dEoECm5OeDoAGmE?dEoECm5OeDoAGmE?dEoEC
m5OeDoAGmE?dEoECm5OeDoAGmE?dEoECm5OeDoAGmE?dEoECm5OeDoA[NV]JKg][FV]jJeY_Nf]JJgY[
FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgYWnF_jIoU[nVOiJoYWnF_jIoU[nVOiJoYWnF_jIoU[nVOiJoYW
nF_jIoU[nVOiJoYWnF_jIoU[nVOiJoYWnF_jIoU[nVOiJoY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[
FVmkJeY[NV]JKg][FV]j9Goo01=_Nf]JJgY[FVmkJeY[NV]JKg][FP00JeY_Nf]JJgY[FVmkJeY[NP01
JeX0019[FRHCi1=[FP03:nXWjB_Z008[jP059nT[jR_Z:nXWj@03:nX01BOY:nX[jR_Z9nT00b_Z00DW
jB_Z:nX[jROY00<[jP059nT[jR_Z:nXWj@03:nX00bOYJeY[FP0AJeXV?nlCJeXVDo@CJeX2JoX01FOi
JoY[nV_jIoT00f_j00EWnF_jJoY[nVOi00=[nP05IoU[nV_jJoYWn@03JoX01FOiJoY[nV_jIoT00f_j
00AWnF_jJoY[nQ=[FRIoo`U[FP03001[FV]J00M[FP0008I[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[
NV]JKg][FV]jJeXGiA?T5nDCi1OU4n@GiA?T5nDCi1OU4n@GiA?T5nDCi1OU4n@GiA?T5nDCi1OU4n@G
iA?T5nDCi1OU4n@GiA?T5nDCi1OU4n@GiA?TJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[
NV]JKg/WjB_Z9nT[jROY:nXWjB_Z9nT[jROY:nXWjB_Z9nT[jROY:nXWjB_Z9nT[jROY:nXWjB_Z9nT[
jROY:nXWjB_Z9nT[jROY:nXWjB_ZJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeXo
kc_^0co_00DkkSo_?nlokc_^00<ok`05>nhokco_?nlkkP03?nl01C_^?nlokco_>nh00co_00DkkSo_
?nlokc_^00<ok`26>ni_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NU?dEoECm5Oe
DoAGmE?dEoECm5OeDoAGmE?dEoECm5OeDoAGmE?dEoECm5OeDoAGmE?dEoECm5OeDoAGmE?dEoECm5Oe
DoAGmE?dEoE[FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FV_jIoU[nVOiJoYWnF_j
IoU[nVOiJoYWnF_jIoU[nVOiJoYWnF_jIoU[nVOiJoYWnF_jIoU[nVOiJoYWnF_jIoU[nVOiJoYWnF_j
IoU[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_NbIoo`0BJeY_Nf]JJgY[FVmkJeY[
NV]J001[FV]jJeY_Nf]JJgY[FVmk0F]J000AJeXW4n@BJeX01BOY:nX[jR_Z9nT00b_Z00DWjB_Z:nX[
jROY00<[jP059nT[jR_Z:nXWj@03:nX01BOY:nX[jR_Z9nT00b_Z00DWjB_Z:nX[jROY008[jQ9[FRLo
ka9[FRMCm19[FP03JoYWnF_j009[nP05IoU[nV_jJoYWn@03JoX01FOiJoY[nV_jIoT00f_j00EWnF_j
JoY[nVOi00=[nP05IoU[nV_jJoYWn@03JoX00fOiJoY[FP0AJeXWOol9JeX00`00JeY[FP07JeX00024
Kg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Na?T5nDCi1OU4n@GiA?T5nDCi1OU4n@GiA?T
5nDCi1OU4n@GiA?T5nDCi1OU4n@GiA?T5nDCi1OU4n@GiA?T5nDCi1OU4n@GiA?T5nDCi6mkJeY[NV]J
Kg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FR_Z9nT[jROY:nXWjB_Z9nT[jROY:nXWjB_Z9nT[jROY
:nXWjB_Z9nT[jROY:nXWjB_Z9nT[jROY:nXWjB_Z9nT[jROY:nXWjB_Z9nT[jV]JJgY[FVmkJeY[NV]J
Kg][FV]jJeY_Nf]JJgY[FVmkJeY[NS_^0co_00DkkSo_?nlokc_^00<ok`05>nhokco_?nlkkP03?nl0
1C_^?nlokco_>nh00co_00DkkSo_?nlokc_^00<ok`27>nhokco_JgY[FVmkJeY[NV]JKg][FV]jJeY_
Nf]JJgY[FVmkJeY[NV]JEoECm5OeDoAGmE?dEoECm5OeDoAGmE?dEoECm5OeDoAGmE?dEoECm5OeDoAG
mE?dEoECm5OeDoAGmE?dEoECm5OeDoAGmE?dEoECm5OeJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_
Nf]JJgY[FVmkIoU[nVOiJoYWnF_jIoU[nVOiJoYWnF_jIoU[nVOiJoYWnF_jIoU[nVOiJoYWnF_jIoU[
nVOiJoYWnF_jIoU[nVOiJoYWnF_jIoU[nVOiKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_
Nf]J02Moo`0BJeY[NV]JKg][FV]jJeY_Nf]J001[FVmkJeY[NV]JKg][FV]j0F]J000AJeXW4n@BJeX2
:nX01BOY:nX[jR_Z9nT00b_Z00DWjB_Z:nX[jROY00<[jP059nT[jR_Z:nXWj@03:nX01BOY:nX[jR_Z
9nT00b_Z00DWjB_Z:nX[jROY019[FRLoka9[FRMCm19[FP=[nP05IoU[nV_jJoYWn@03JoX01FOiJoY[
nV_jIoT00f_j00EWnF_jJoY[nVOi00=[nP05IoU[nV_jJoYWn@03JoX016OiJoY[nV_j4V]J9goo2F]J
00<006]JJeX01f]J0000Pf]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgXCi1OU4n@GiA?T
5nDCi1OU4n@GiA?T5nDCi1OU4n@GiA?T5nDCi1OU4n@GiA?T5nDCi1OU4n@GiA?T5nDCi1OU4n@GiA?T
5nDCi1OU4nA[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeX[jROY:nXWjB_Z9nT[jROY
:nXWjB_Z9nT[jROY:nXWjB_Z9nT[jROY:nXWjB_Z9nT[jROY:nXWjB_Z9nT[jROY:nXWjB_Z9nT[jROY
:nY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg/00So_00DkkSo_?nlokc_^00<ok`05
>nhokco_?nlkkP03?nl01C_^?nlokco_>nh00co_00DkkSo_?nlokc_^00<ok`29>nhokco_?nlkkVmk
JeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FUOeDoAGmE?dEoECm5OeDoAGmE?dEoECm5Oe
DoAGmE?dEoECm5OeDoAGmE?dEoECm5OeDoAGmE?dEoECm5OeDoAGmE?dEoECm5OeDoAGmF]JJgY[FVmk
JeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NVOiJoYWnF_jIoU[nVOiJoYWnF_jIoU[nVOiJoYWnF_j
IoU[nVOiJoYWnF_jIoU[nVOiJoYWnF_jIoU[nVOiJoYWnF_jIoU[nVOiJoYWnF]jJeY_Nf]JJgY[FVmk
JeY[NV]JKg][FV]jJeY_Nf]JJgY[FP0WOol04V]JKg][FV]jJeY_Nf]JJgY[FP00JeY[NV]JKg][FV]j
JeY_N`5[FP004F]J9a?T4V]J00DWjB_Z:nX[jROY00<[jP059nT[jR_Z:nXWj@03:nX01BOY:nX[jR_Z
9nT00b_Z00DWjB_Z:nX[jROY00<[jP059nT[jR_Z:nXWj@02:nXBJeXW?nlBJeXWDo@BJeX00f_jIoU[
nP02JoX01FOiJoY[nV_jIoT00f_j00EWnF_jJoY[nVOi00=[nP05IoU[nV_jJoYWn@03JoX01FOiJoY[
nV_jIoT00f_j00=WnF_jJeX04F]J9goo2F]J00<006]JJeX01f]J0000Q6mkJeY[NV]JKg][FV]jJeY_
Nf]JJgY[FVmkJeY[NV]JKg/Ci1OU4n@GiA?T5nDCi1OU4n@GiA?T5nDCi1OU4n@GiA?T5nDCi1OU4n@G
iA?T5nDCi1OU4n@GiA?T5nDCi1OU4n@GiA?T5nDCi1OU4nA_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_
Nf]JJgY[FVmkJeX[jROY:nXWjB_Z9nT[jROY:nXWjB_Z9nT[jROY:nXWjB_Z9nT[jROY:nXWjB_Z9nT[
jROY:nXWjB_Z9nT[jROY:nXWjB_Z9nT[jROY:nY[FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_
Nf]JJgXkkP<ok`05>nhokco_?nlkkP03?nl01C_^?nlokco_>nh00co_00DkkSo_?nlokc_^00<ok`05
>nhokco_?nlkkP03?nl0Qc_^?nlokf]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FUOe
DoAGmE?dEoECm5OeDoAGmE?dEoECm5OeDoAGmE?dEoECm5OeDoAGmE?dEoECm5OeDoAGmE?dEoECm5Oe
DoAGmE?dEoECm5OeDoAGmF]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_NfOiJoYWnF_j
IoU[nVOiJoYWnF_jIoU[nVOiJoYWnF_jIoU[nVOiJoYWnF_jIoU[nVOiJoYWnF_jIoU[nVOiJoYWnF_j
IoU[nVOiJoYWnFmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FP0WOol04V]JJgY[FVmk
JeY[NV]JKg][FP00JeY_Nf]JJgY[FVmkJeY[NP5[FP004F]J9a?T4V]J0R_Z00DWjB_Z:nX[jROY00<[
jP059nT[jR_Z:nXWj@03:nX01BOY:nX[jR_Z9nT00b_Z00DWjB_Z:nX[jROY00<[jP059nT[jR_Z:nXW
j@0BJeXW?nlBJeXWDo@BJeX3JoX01FOiJoY[nV_jIoT00f_j00EWnF_jJoY[nVOi00=[nP05IoU[nV_j
JoYWn@03JoX01FOiJoY[nV_jIoT00f_j00AWnF_jJoY[nQ9[FRMoo`U[FP03001[FV]J00M[FP0008=[
NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]j4n@GiA?T5nDCi1OU4n@GiA?T5nDCi1OU4n@G
iA?T5nDCi1OU4n@GiA?T5nDCi1OU4n@GiA?T5nDCi1OU4n@GiA?T5nDCi1OU4n@GiA?TJgY[FVmkJeY[
NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]J:nXWjB_Z9nT[jROY:nXWjB_Z9nT[jROY:nXWjB_Z9nT[
jROY:nXWjB_Z9nT[jROY:nXWjB_Z9nT[jROY:nXWjB_Z9nT[jROY:nXWjB_ZJeY_Nf]JJgY[FVmkJeY[
NV]JKg][FV]jJeY_Nf]JJgY[FVmk008ok`05>nhokco_?nlkkP03?nl01C_^?nlokco_>nh00co_00Dk
kSo_?nlokc_^00<ok`05>nhokco_?nlkkP03?nl0RC_^?nlokco_>ni_Nf]JJgY[FVmkJeY[NV]JKg][
FV]jJeY_Nf]JJgY[FVmkJeYGmE?dEoECm5OeDoAGmE?dEoECm5OeDoAGmE?dEoECm5OeDoAGmE?dEoEC
m5OeDoAGmE?dEoECm5OeDoAGmE?dEoECm5OeDoAGmE?dEoE[FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][
FV]jJeY_Nf]JJgYWnF_jIoU[nVOiJoYWnF_jIoU[nVOiJoYWnF_jIoU[nVOiJoYWnF_jIoU[nVOiJoYW
nF_jIoU[nVOiJoYWnF_jIoU[nVOiJoYWnF_jIoU[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][
FV]jJeX09goo019[FVmkJeY[NV]JKg][FV]jJeX006]JJgY[FVmkJeY[NV]JKg/1JeX0015[FRLCi19[
FP059nT[jR_Z:nXWj@03:nX01BOY:nX[jR_Z9nT00b_Z00DWjB_Z:nX[jROY00<[jP059nT[jR_Z:nXW
j@03:nX01BOY:nX[jR_Z9nT00R_Z4V]J9co_4V]J9e?d4V]J00=[nVOiJoX00V_j00EWnF_jJoY[nVOi
00=[nP05IoU[nV_jJoYWn@03JoX01FOiJoY[nV_jIoT00f_j00EWnF_jJoY[nVOi00=[nP03IoU[nV]J
015[FRMoo`U[FP03001[FV]J00M[FP0008A_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmk
4n@GiA?T5nDCi1OU4n@GiA?T5nDCi1OU4n@GiA?T5nDCi1OU4n@GiA?T5nDCi1OU4n@GiA?T5nDCi1OU
4n@GiA?T5nDCi1OU4n@GiA?TKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]J:nXWjB_Z
9nT[jROY:nXWjB_Z9nT[jROY:nXWjB_Z9nT[jROY:nXWjB_Z9nT[jROY:nXWjB_Z9nT[jROY:nXWjB_Z
9nT[jROY:nXWjB_ZJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]j>nh3?nl01C_^?nlo
kco_>nh00co_00DkkSo_?nlokc_^00<ok`05>nhokco_?nlkkP03?nl01C_^?nlokco_>nh00co_08Lk
kSo_?nm[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeYGmE?dEoECm5OeDoAGmE?dEoEC
m5OeDoAGmE?dEoECm5OeDoAGmE?dEoECm5OeDoAGmE?dEoECm5OeDoAGmE?dEoECm5OeDoAGmE?dEoE[
FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg]WnF_jIoU[nVOiJoYWnF_jIoU[nVOiJoYW
nF_jIoU[nVOiJoYWnF_jIoU[nVOiJoYWnF_jIoU[nVOiJoYWnF_jIoU[nVOiJoYWnF_jIoU_Nf]JJgY[
FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeX09goo019[FV]jJeY_Nf]JJgY[FVmkJeX006]JKg][
FV]jJeY_Nf]JJgX1JeX0019[FRHCi1=[FP03:nXWjB_Z008[jP059nT[jR_Z:nXWj@03:nX01BOY:nX[
jR_Z9nT00b_Z00DWjB_Z:nX[jROY00<[jP059nT[jR_Z:nXWj@03:nX00bOYJeY[FP0AJeXV?nlCJeXV
Do@CJeX2JoX01FOiJoY[nV_jIoT00f_j00EWnF_jJoY[nVOi00=[nP05IoU[nV_jJoYWn@03JoX01FOi
JoY[nV_jIoT00f_j00AWnF_jJoY[nQ=[FRIoo`U[FP03001[FV]J00M[FP0008I[NV]JKg][FV]jJeY_
Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeXGiA?T5nDCi1OU4n@GiA?T5nDCi1OU4n@GiA?T5nDCi1OU4n@G
iA?T5nDCi1OU4n@GiA?T5nDCi1OU4n@GiA?T5nDCi1OU4n@GiA?TJgY[FVmkJeY[NV]JKg][FV]jJeY_
Nf]JJgY[FVmkJeY[NV]JKg/WjB_Z9nT[jROY:nXWjB_Z9nT[jROY:nXWjB_Z9nT[jROY:nXWjB_Z9nT[
jROY:nXWjB_Z9nT[jROY:nXWjB_Z9nT[jROY:nXWjB_ZJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_
Nf]JJgY[FVmkJeXokc_^0co_00DkkSo_?nlokc_^00<ok`05>nhokco_?nlkkP03?nl01C_^?nlokco_
>nh00co_00DkkSo_?nlokc_^00<ok`26>ni_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmk
JeY[NU?dEoECm5OeDoAGmE?dEoECm5OeDoAGmE?dEoECm5OeDoAGmE?dEoECm5OeDoAGmE?dEoECm5Oe
DoAGmE?dEoECm5OeDoAGmE?dEoE[FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FV_j
IoU[nVOiJoYWnF_jIoU[nVOiJoYWnF_jIoU[nVOiJoYWnF_jIoU[nVOiJoYWnF_jIoU[nVOiJoYWnF_j
IoU[nVOiJoYWnF_jIoU[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_NbIoo`0BJeY_
Nf]JJgY[FVmkJeY[NV]J001[FV]jJeY_Nf]JJgY[FVmk0F]J000CJeXT4n@EJeX2:nX01BOY:nX[jR_Z
9nT00b_Z00DWjB_Z:nX[jROY00<[jP059nT[jR_Z:nXWj@03:nX01BOY:nX[jR_Z9nT00b_Z00<WjB_Z
JeX056]J93o_5F]J95?d5F]J0f_j00EWnF_jJoY[nVOi00=[nP05IoU[nV_jJoYWn@03JoX01FOiJoY[
nV_jIoT00f_j00EWnF_jJoY[nVOi00=[nP03IoU[FV]J019[FREoo`Y[FP03001[FV]J00M[FP0008E_
Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NQ?T5nDCi1OU4n@GiA?T5nDCi1OU4n@G
iA?T5nDCi1OU4n@GiA?T5nDCi1OU4n@GiA?T5nDCi1OU4n@GiA?T5nDCi1OU4n@GiF]JKg][FV]jJeY_
Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FR_Z9nT[jROY:nXWjB_Z9nT[jROY:nXWjB_Z9nT[
jROY:nXWjB_Z9nT[jROY:nXWjB_Z9nT[jROY:nXWjB_Z9nT[jROY:nXWjFmkJeY[NV]JKg][FV]jJeY_
Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_N`02?nl01C_^?nlokco_>nh00co_00DkkSo_?nlokc_^00<o
k`05>nhokco_?nlkkP03?nl01C_^?nlokco_>nh00co_08PkkSo_JeY[NV]JKg][FV]jJeY_Nf]JJgY[
FVmkJeY[NV]JKg][FV]jJeY_Nf]JEoECm5OeDoAGmE?dEoECm5OeDoAGmE?dEoECm5OeDoAGmE?dEoEC
m5OeDoAGmE?dEoECm5OeDoAGmE?dEoECm5OeDoAGmE?dJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[
FVmkJeY[NV]JKg][FV]jIoU[nVOiJoYWnF_jIoU[nVOiJoYWnF_jIoU[nVOiJoYWnF_jIoU[nVOiJoYW
nF_jIoU[nVOiJoYWnF_jIoU[nVOiJoYWnF_jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[
FVmkJeY[NREoo`0CKg][FV]jJeY_Nf]JJgY[FVmkJeX006]JKg][FV]jJeY_Nf]JJgX00F]J000DJeXR
4n@GJeX3:nX01BOY:nX[jR_Z9nT00b_Z00DWjB_Z:nX[jROY00<[jP059nT[jR_Z:nXWj@03:nX01BOY
:nX[jR_Z9nT00R_Z5V]J8co_5V]J8e?d5V]J00=[nVOiJoX00V_j00EWnF_jJoY[nVOi00=[nP05IoU[
nV_jJoYWn@03JoX01FOiJoY[nV_jIoT00f_j00IWnF_jJoY[nVOiJoXFJeXSOol;JeX00`00JeY[FP07
JeX00026JgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FQOU4n@GiA?T5nDCi1OU
4n@GiA?T5nDCi1OU4n@GiA?T5nDCi1OU4n@GiA?T5nDCi1OU4n@GiA?T5nDCi1OU4n@GiA?TKg][FV]j
JeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NROY:nXWjB_Z9nT[jROY:nXWjB_Z
9nT[jROY:nXWjB_Z9nT[jROY:nXWjB_Z9nT[jROY:nXWjB_Z9nT[jROY:nXWjB_ZJeY[NV]JKg][FV]j
JeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgXkkP<ok`05>nhokco_?nlkkP03?nl01C_^?nlo
kco_>nh00co_00DkkSo_?nlokc_^00<ok`05>nhokco_?nlkkP02?nl0R6]jJeY_Nf]JJgY[FVmkJeY[
NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JEoECm5OeDoAGmE?dEoECm5OeDoAGmE?dEoECm5OeDoAG
mE?dEoECm5OeDoAGmE?dEoECm5OeDoAGmE?dEoECm5OeDoAGmF]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[
NV]JKg][FV]jJeY_Nf]JJgY[FVmkIoU[nVOiJoYWnF_jIoU[nVOiJoYWnF_jIoU[nVOiJoYWnF_jIoU[
nVOiJoYWnF_jIoU[nVOiJoYWnF_jIoU[nVOiJoYWnFmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[
NV]JKg][FV]jJeY_Nf]J8goo01A[FV]jJeY_Nf]JJgY[FVmkJeY[NV]J001[FV]jJeY_Nf]JJgY[FVmk
0F]J000EJeXP4n@IJeX01BOY:nX[jR_Z9nT00b_Z00DWjB_Z:nX[jROY00<[jP059nT[jR_Z:nXWj@03
:nX01BOY:nX[jR_Z9nT00b_Z66]J8Co_66]J8E?d66]J0V_j00EWnF_jJoY[nVOi00=[nP05IoU[nV_j
JoYWn@03JoX01FOiJoY[nV_jIoT00f_j00EWnF_jJoY[nVOi009[nQQ[FR5oo`a[FP03001[FV]J00M[
FP0008Q_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg/Ci1OU4n@GiA?T5nDC
i1OU4n@GiA?T5nDCi1OU4n@GiA?T5nDCi1OU4n@GiA?T5nDCi1OU4n@GiA?T5nDCi6mkJeY[NV]JKg][
FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeX[jROY:nXWjB_Z9nT[jROY:nXW
jB_Z9nT[jROY:nXWjB_Z9nT[jROY:nXWjB_Z9nT[jROY:nXWjB_Z9nT[jV]JJgY[FVmkJeY[NV]JKg][
FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgXkkP<ok`05>nhokco_?nlkkP03?nl01C_^
?nlokco_>nh00co_00DkkSo_?nlokc_^00<ok`2?>nhokco_JgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]J
JgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FUOeDoAGmE?dEoECm5OeDoAGmE?dEoECm5OeDoAGmE?d
EoECm5OeDoAGmE?dEoECm5OeDoAGmE?dEoECm5OeJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]J
JgY[FVmkJeY[NV]JKg][FV]jJeY_NfOiJoYWnF_jIoU[nVOiJoYWnF_jIoU[nVOiJoYWnF_jIoU[nVOi
JoYWnF_jIoU[nVOiJoYWnF_jIoU[nVOiKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]J
JgY[FVmkJeY[NV]JKg][FP0OOol05V]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]J001[FVmkJeY[NV]J
Kg][FV]j0F]J000FJeXM4n@LJeX00b_Z9nT[jP02:nX01BOY:nX[jR_Z9nT00b_Z00DWjB_Z:nX[jROY
00<[jP059nT[jR_Z:nXWj@03:nXLJeXM?nlLJeXMDo@LJeX2JoX01FOiJoY[nV_jIoT00f_j00EWnF_j
JoY[nVOi00=[nP05IoU[nV_jJoYWn@03JoX00fOiJoY[nP0LJeXMOol>JeX00`00JeY[FP07JeX0002:
JgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Na?T5nDCi1OU4n@GiA?T
5nDCi1OU4n@GiA?T5nDCi1OU4n@GiA?T5nDCi1OU4n@GiA?T5nDCi6mkJeY[NV]JKg][FV]jJeY_Nf]J
JgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FR_Z9nT[jROY:nXWjB_Z9nT[jROY
:nXWjB_Z9nT[jROY:nXWjB_Z9nT[jROY:nXWjB_Z9nT[jV]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]J
JgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NS_^0co_00DkkSo_?nlokc_^00<ok`05>nho
kco_?nlkkP03?nl01C_^?nlokco_>nh00So_091[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][
FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeYGmE?dEoECm5OeDoAGmE?dEoECm5OeDoAGmE?dEoEC
m5OeDoAGmE?dEoECm5OeDoAGmE?dEoE[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][
FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg]WnF_jIoU[nVOiJoYWnF_jIoU[nVOiJoYWnF_jIoU[nVOiJoYW
nF_jIoU[nVOiJoYWnF_jIoU_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][
FV]jJeY_Nf]JJgY[FVmkJeXKOol066]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FP00JeY[NV]J
Kg][FV]jJeY_N`5[FP0066]J6A?T86]J00<[jROY:nX00R_Z00DWjB_Z:nX[jROY00<[jP059nT[jR_Z
:nXWj@03:nX012OY:nX[jR_Z86]J6Co_86]J6E?d86]J0V_j00EWnF_jJoY[nVOi00=[nP05IoU[nV_j
JoYWn@03JoX01FOiJoY[nV_jIoT00V_j86]J6Goo46]J00<006]JJeX01f]J0000S6mkJeY[NV]JKg][
FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmk4n@GiA?T5nDCi1OU4n@GiA?T5nDC
i1OU4n@GiA?T5nDCi1OU4n@GiA?T5nE[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][
FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]J:nXWjB_Z9nT[jROY:nXWjB_Z9nT[jROY:nXW
jB_Z9nT[jROY:nXWjB_Z9nU_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][
FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]j>nh3?nl01C_^?nlokco_>nh00co_00DkkSo_?nlokc_^
00<ok`2G>nhokf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]J
JgY[FVmkJeY[NV]JKg][FV]jJeYGmE?dEoECm5OeDoAGmE?dEoECm5OeDoAGmE?dEoECm5OeDoAGmE?d
EoECm6]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]J
JgY[FVmkJeY[NV]JKg]WnF_jIoU[nVOiJoYWnF_jIoU[nVOiJoYWnF_jIoU[nVOiJoYWnF_jIoU[nV]J
Kg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]J
JgY[FVmkJeX05Woo01]_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeX006]JKg][FV]j
JeY_Nf]JJgX00F]J000KJeXC4n@VJeX01BOY:nX[jR_Z9nT00b_Z00DWjB_Z:nX[jROY00<[jP039nT[
jR_Z02I[FQ<okbI[FQ=Cm2I[FP03JoYWnF_j009[nP05IoU[nV_jJoYWn@03JoX01VOiJoY[nV_jIoU[
nRE[FQAooa=[FP03001[FV]J00M[FP0008i[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]j
JeY_Nf]JJgY[FVmkJeY[NV]JKg][FQOU4n@GiA?T5nDCi1OU4n@GiA?T5nDCi1OU4n@GiA?TJgY[FVmk
JeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]j
JeY_Nf]JJgY[FVmkJeY[NROY:nXWjB_Z9nT[jROY:nXWjB_Z9nT[jROY:nXWjB_ZJeY_Nf]JJgY[FVmk
JeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]j
JeY_Nf]JJgY[FP<ok`05>nhokco_?nlkkP03?nl0X3_^?nlokco_>ni_Nf]JJgY[FVmkJeY[NV]JKg][
FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[
FVmkDoAGmE?dEoECm5OeDoAGmE?dEoECm5OeDoAGmE?dEoE[FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][
FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJoYW
nF_jIoU[nVOiJoYWnF_jIoU[nVOiJoYWnF_jIoU[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][
FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]j47oo01i[FVmk
JeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeX006]JJgY[FVmkJeY[NV]JKg/1JeX0
021[FPXCi2m[FP03:nXWjB_Z008[jP059nT[jR_Z:nXWj@0_JeX:?nl_JeX:Do@_JeX2JoX01FOiJoY[
nV_jIoT00f_j;f]J2Woo5f]J00<006]JJeX01f]J0000ofmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmk
JeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]j
JeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmk
JeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]j
JeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmk
JeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]j
JeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmk
JeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]j
JeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmk
JeY[NP00J6]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][
FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[
FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][
FV]jJeY_Nf]JJgY[FVmkJeX006]JKg][FV]jJeY_Nf]JJgX1JeX00?m[FUm[FP03001[FV]J00M[FP00
0?m[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]j
JeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmk
JeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]j
JeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmk
JeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]j
JeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmk
JeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]j
JeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmk
JeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg/006Q[FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][
FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[
FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][
FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]J001[FV]jJeY_Nf]JJgY[
FVmk0F]J003oJeYOJeX00`00JeY[FP07JeX0003oKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]j
JeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmk
JeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]j
JeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmk
JeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]j
JeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmk
JeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]j
JeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmk
JeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]j
001XJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[
FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][
FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[
FVmkJeY[NV]JKg][FP00JeY_Nf]JJgY[FVmkJeY[NP5[FP00of]JGf]J00<006]JJeX01f]J0000of]j
JeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmk
JeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]j
JeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmk
JeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]j
JeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmk
JeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]j
JeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmk
JeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]j
JeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_N`00J6]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[
FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][
FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[
FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeX006]JJgY[FVmkJeY[NV]JKg/1
JeX00?m[FUm[FP03001[FV]J00M[FP0000Q_Nf]JJgY[FVmkJeY[NV]Jo`00F00000Q[FVmkJeY[NV]J
Kg][FV]j0F]J003oJeYYJeX0003oJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][
FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[
FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][
FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[
FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][
FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[
FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][
FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[
FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmk001XJeY[NV]J
Kg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]J
JgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]J
Kg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]J
JgY[FVmkJeY[NV]JKg][FV]jJeY_N`5[FP00of]JJF]J0000ofmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[
FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][
FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[
FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][
FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[
FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][
FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[
FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][
FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[
FVmkJeY[NP00J6]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]J
Kg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]J
JgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]J
Kg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgX1JeX00?m[FVU[FP000?m[NV]JKg][
FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[
FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][
FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[
FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][
FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[
FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][
FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[
FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][
FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg/006Q[FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]J
JgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]J
Kg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]J
JgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmk0F]J003o
JeYYJeX0003oKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][
FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[
FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][
FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[
FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][
FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[
FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][
FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[
FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]j001XJeY_Nf]JJgY[FVmkJeY[NV]J
Kg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]J
JgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]J
Kg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]J
JgY[FVmkJeY[NP5[FP00\
\>"],
  ImageRangeCache->{{{148.063, 435.063}, {619.375, 332.375}} -> {-3.40022, \
7.14609, 0.0219515, 0.0219515}}]
}, Open  ]],

Cell[TextData[{
  "The purpose of this notebook is to outline some of the number-theoretical \
ideas and their implementations surrounding the concept of partitions and \
sums of integer powers in general. The author has used this material to \
introduce students to a variety of concepts in number theory, combinatorics \
and algorithm-design throughout interactive sessions of ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  ". Because the nature of the subject offers the teacher ample margin to \
exercise his/her  particular teaching style and personal taste in enhancing \
or omitting particular sections of this material; for instance, the author \
always includes a few proofs, discussion sessions, individual problem-solving \
sessions, collective problem-solving session (these sessions being held \
simultaneously to cater for continuity), a written assignment, homework and \
an exam to adequately cover a theme such as this one. Thus, no attempt has \
been made to include abundant comments in order to provide a suitable \
framework on which to base a lecture. The proof of the results mentioned \
throughout the work will be omitted as they all can be found in the \
references."
}], "Text"]
}, Open  ]],

Cell[CellGroupData[{

Cell["Partitions ", "Section"],

Cell[CellGroupData[{

Cell["INTRODUCTION", "Subsection"],

Cell["\<\
First, we design an auxiliary function to display lists of numbers as sums of \
powers\
\>", "Text"],

Cell[BoxData[{
    \(asSum[x_] := asSum[x, 1]\[IndentingNewLine]\), "\[IndentingNewLine]", 
    \(asSum[{a_}, 1] := ToString[a]\), "\[IndentingNewLine]", 
    \(asSum[{a_}, p_Integer?Positive] := ToString[a]\^p\), "\n", 
    \(asSum[{a_, b__}, p_] := 
      DisplayForm[
        RowBox[{asSum[{a}, p], "\<+\>", asSum[{b}, p]}]]\)}], "Input",
  InitializationCell->True],

Cell[CellGroupData[{

Cell[BoxData[
    \(asSum[Range[5], 2]\)], "Input"],

Cell[BoxData[
    TagBox[
      RowBox[{\("1"\^2\), "+", 
        TagBox[
          RowBox[{\("2"\^2\), "+", 
            TagBox[
              RowBox[{\("3"\^2\), "+", 
                TagBox[\("4"\^2 + "5"\^2\),
                  DisplayForm]}],
              DisplayForm]}],
          DisplayForm]}],
      DisplayForm]], "Output"]
}, Open  ]],

Cell["Ferrers graphs are standard representations for partitions", "Text"],

Cell[BoxData[
    \(Ferrers[s_] := 
      Module[{i, j, f = Reverse[s]}, \[IndentingNewLine]t = 
          Table[Table[
              If[i \[LessEqual] f\[LeftDoubleBracket]j\[RightDoubleBracket], 
                Disk[{i, j}, 0.3], {}], {i, Max[f]}], {j, 
              Length[f]}]; \[IndentingNewLine]Graphics[{RGBColor[1, 0.1, 
              0.2], t, RGBColor[0, 0, 0], t\  /. \ Disk \[Rule] Circle}, 
          PlotRange \[Rule] \ {{0, 1 + Length[s]}, {0, 1 + Length[s]}}, 
          AspectRatio \[Rule] Automatic, 
          DisplayFunction \[Rule] Identity]]\)], "Input"],

Cell[CellGroupData[{

Cell[BoxData[
    \(\(Show[Ferrers\ [{1, 2, 3, 4}], 
        DisplayFunction \[Rule] $DisplayFunction];\)\)], "Input"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 0.2 0 0.2 [
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
1 .1 .2 r
.2 .2 m
.2 .2 .06 0 365.73 arc
F
.4 .2 m
.4 .2 .06 0 365.73 arc
F
.6 .2 m
.6 .2 .06 0 365.73 arc
F
.8 .2 m
.8 .2 .06 0 365.73 arc
F
.2 .4 m
.2 .4 .06 0 365.73 arc
F
.4 .4 m
.4 .4 .06 0 365.73 arc
F
.6 .4 m
.6 .4 .06 0 365.73 arc
F
.2 .6 m
.2 .6 .06 0 365.73 arc
F
.4 .6 m
.4 .6 .06 0 365.73 arc
F
.2 .8 m
.2 .8 .06 0 365.73 arc
F
0 0 0 r
.5 Mabswid
[ ] 0 setdash
newpath
.2 .2 .06 0 365.73 arc
s
newpath
.4 .2 .06 0 365.73 arc
s
newpath
.6 .2 .06 0 365.73 arc
s
newpath
.8 .2 .06 0 365.73 arc
s
newpath
.2 .4 .06 0 365.73 arc
s
newpath
.4 .4 .06 0 365.73 arc
s
newpath
.6 .4 .06 0 365.73 arc
s
newpath
.2 .6 .06 0 365.73 arc
s
newpath
.4 .6 .06 0 365.73 arc
s
newpath
.2 .8 .06 0 365.73 arc
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 288},
  ImageMargins->{{35, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0001J1000`40O003h00Oof]JJF]J0000of]j
JeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmk
JeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]j
JeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmk
JeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]j
JeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmk
JeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]j
JeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmk
JeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]j
JeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_N`00J6]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[
FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][
FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[
FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg/1
JeX00?m[FVU[FP000?m_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]j
JeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmk
JeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]j
JeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmk
JeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]j
JeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmk
JeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]j
JeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmk
JeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgX006Q[FVmkJeY[NV]JKg][
FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[
FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][
FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[
FVmkJeY[NV]JKg][FV]j0F]J003oJeYYJeX0003oJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmk
JeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]j
JeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmk
JeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]j
JeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmk
JeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]j
JeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmk
JeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]j
JeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmk
001XJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][
FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[
FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][
FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_N`5[FP00of]JJF]J0000ofmkJeY[NV]JKg][FV]j
JeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmk
JeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]j
JeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmk
JeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]j
JeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmk
JeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]j
JeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmk
JeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]j
JeY_Nf]JJgY[FVmkJeY[NP00J6]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[
FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][
FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[
FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgX1JeX00?m[FVU[FP00
0?m[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]j
JeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmk
JeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]j
JeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmk
JeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]j
JeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmk
JeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]j
JeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmk
JeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg/006Q[FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][
FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[
FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][
FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[
FVmk0F]J003oJeYYJeX0003oKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmk
JeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]j
JeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmk
JeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]j
JeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmk
JeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]j
JeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmk
JeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]j
JeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]j001XJeY_Nf]JJgY[
FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][
FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[
FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][
FV]jJeY_Nf]JJgY[FVmkJeY[NP5[FP00of]JJF]J0000of]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]j
JeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmk
JeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]j
JeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmk
JeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]j
JeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmk
JeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]j
JeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmk
JeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]j
JeY_N`00J6]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[
FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][
FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[
FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg/1JeX00?m[FVU[FP000?m_Nf]JJgY[FVmk
JeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]j
JeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmk
JeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]j
JeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmk
JeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]j
JeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmk
JeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]j
JeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmk
JeY[NV]JKg][FV]jJeY_Nf]JJgX006Q[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][
FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[
FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][
FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]j0F]J003oJeYY
JeX0003oJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmk
JeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]j
JeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmk
JeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]j
JeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmk
JeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]j
JeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmk
JeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]j
JeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmk001XJeY[NV]JKg][FV]jJeY_Nf]JJgY[
FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][
FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[
FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][
FV]jJeY_N`5[FP00of]JJF]J0000ofmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]j
JeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmk
JeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]j
JeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmk
JeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]j
JeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmk
JeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]j
JeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmk
JeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NP00J6]JKg][
FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[
FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][
FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[
FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgX1JeX00?m[FVU[FP000?m[NV]JKg][FV]jJeY_Nf]JJgY[FVmk
JeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]j
JeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmk
JeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]j
JeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmk
JeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]j
JeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmk
JeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]j
JeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmk
JeY[NV]JKg/006Q[FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][
FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[
FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][
FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmk0F]J003oJeYYJeX0003oKg][FV]j
JeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmk
JeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]j
JeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmk
JeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]j
JeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmk
JeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]j
JeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmk
JeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]j
JeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]j001XJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[
FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][
FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[
FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NP5[FP00
of]JJF]J0000of]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]j
JeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmk
JeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]j
JeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmk
JeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]j
JeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmk
JeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]j
JeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmk
JeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_N`00J6]JJgY[FVmkJeY[NV]JKg][
FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[
FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][
FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[
FVmkJeY[NV]JKg/1JeX00?m[FVU[FP000?m_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmk
JeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]j
JeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmk
JeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]j
JeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmk
JeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]j
JeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmk
JeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]j
JeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgX006Q[
FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][
FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[
FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][
FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]j0F]J003oJeYYJeX0003oJgY[FVmkJeY[NV]JKg][FV]j
JeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmk
JeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]j
JeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmk
JeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]j
JeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmk
JeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]j
JeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmk
JeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]j
JeY_Nf]JJgY[FVmk001XJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[
FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][
FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[
FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_N`5[FP00of]JJF]J0000ofmk
JeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]j
JeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmk
JeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]j
JeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmk
JeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]j
JeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmk
JeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]j
JeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmk
JeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NP00J6]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][
FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[
FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][
FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgX1
JeX00?m[FVU[FP000?m[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmk
JeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]j
JeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmk
JeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]j
JeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmk
JeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]j
JeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmk
JeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]j
JeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg/006Q[FV]jJeY_Nf]JJgY[
FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][
FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[
FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][
FV]jJeY_Nf]JJgY[FVmk0F]J003oJeYYJeX0003oKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]j
JeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmk
JeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]j
JeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmk
JeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]j
JeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmk
JeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]j
JeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmk
JeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]j
001XJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[
FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][
FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[
FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NP5[FP00of]JJF]J0000of]jJeY_Nf]JJgY[FVmk
JeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]j
JeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmk
JeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]j
JeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmk
JeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]j
JeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmk
JeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]j
JeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmk
JeY[NV]JKg][FV]jJeY_N`00J6]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][
FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[
FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][
FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg/1JeX00?m[FVU[FP00
0?m_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmk
JeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]j
JeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmk
JeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]j
JeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmk
JeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]j
JeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmk
JeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]j
JeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgX006Q[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[
FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][
FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[
FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][
FV]j0F]J003oJeYYJeX0003oJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]j
JeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmk
JeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]j
JeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmk
JeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]j
JeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmk
JeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]j
JeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmk
JeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmk001XJeY[NV]JKg][
FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[
FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][
FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[
FVmkJeY[NV]JKg][FV]jJeY_N`5[FP00of]JJF]J0000ofmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmk
JeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]j
JeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmk
JeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]j
JeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmk
JeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]j
JeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmk
JeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]j
JeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmk
JeY[NP00J6]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][
FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[
FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][
FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgX1JeX00?m[FVU[FP000?m[NV]JKg][FV]j
JeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmk
JeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]j
JeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmk
JeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]j
JeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmk
JeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]j
JeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmk
JeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]j
JeY_Nf]JJgY[FVmkJeY[NV]JKg/006Q[FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[
FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][
FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[
FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmk0F]J003oJeYY
JeX0003oKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]j
JeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmk
JeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]j
JeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmk
JeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]j
JeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmk
JeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]j
JeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmk
JeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]j001XJeY_Nf]JJgY[FVmkJeY[NV]JKg][
FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[
FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][
FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[
FVmkJeY[NP5[FP00of]JJF]J0000of]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmk
JeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]j
JeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmk
JeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]j
JeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmk
JeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]j
JeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmk
JeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]j
JeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_N`00J6]JJgY[
FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][
FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[
FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][
FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg/1JeX00?m[FVU[FP00049_Nf]JJgY[FVmkJeY[NV]JKg][FV]j
JeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmk
JeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeX:0000?FmkJeY[
NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_
Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmk00/0
000mKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_
Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[
NV]JKg/02`0003e_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_
Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[
NV]JKg][FV]jJeY_N`0;0000@fmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_
Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[
NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]j005[FP00?f]J0`0000=lAGa6O4D00Wa500El
AWa5O4ElAGa600@003M[FP80009lA@05O4IlAGa5O4ElAP03O4D00ga600000002000gJeX20002O4D0
1Ga6O4ElAGa5O4H00ga500=lAP0000000P00=f]J0P000Wa500ElAWa5O4ElAGa600=lA@03O4H00000
0080041[FP00051[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[
NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_
Nf]JJgY[FVmkJeY[NV]J001lAGaVO4ElIWa5O6IlAGaVO4ElIWa5O6IlAGaVO4ElIWa50P0003=_Nf]J
JgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]J
Kg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgX00P00015lAGaVO4ElIWa5O6IlAGaV
O4ElIWa5O6IlAGaVO4ElIWa50080000cKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]J
JgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]J
Kg][FV]j0080000AO4ElIWa5O6IlAGaVO4ElIWa5O6IlAGaVO4ElIWa5O6IlA@020000<fmkJeY[NV]J
Kg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]J
JgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NP0200004Ga5O6IlAGaVO4ElIWa5O6IlAGaV
O4ElIWa5O6IlAGaVO4D00P0003e_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]J
Kg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]J
JgY[FVmkJeY[NV]JKg][FV]jJeY_N`01JeX003a[FP8000=lA@05O4IlAGa5O4ElAP03O4D01Ga6O4El
AGa5O4H00ga500=lAP000000<6]J00<007a6O4D00Wa500ElAWa5O4ElAGa600=lA@05O4IlAGa5O4El
AP03O4D00ga60000000_JeX200001Ga6O4ElAGa5O4H00ga500ElAWa5O4ElAGa600=lA@05O4IlAGa5
O4ElAP02000_JeX200001Ga6O4ElAGa5O4H00ga500ElAWa5O4ElAGa600=lA@06O4IlAGa5O4ElAP00
?F]J0000>VmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[
NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_
Nf]J0P0001QlIWa5O6IlAGaVO4ElIWa5O6IlAGaVO4ElIWa5O6IlAGaVO4ElIWa5O6IlAGaVO4D20000
;6]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[
FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeX2000067aVO4ElIWa5O6IlAGaVO4ElIWa5O6IlAGaV
O4ElIWa5O6IlAGaVO4ElIWa5O6IlA@80001cJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[
NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FP00O4El
IWa5O6IlAGaVO4ElIWa5O6IlAGaVO4ElIWa5O6IlAGaVO4ElIWa5O6IlAGaVO4D006]JJgY[FVmkJeY[
NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_
Nf]JJgY[FVmkJeY[NV]JKg/00P0001QlAGaVO4ElIWa5O6IlAGaVO4ElIWa5O6IlAGaVO4ElIWa5O6Il
AGaVO4ElIWa5O6H20000>V]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]j
JeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmk
JeY[NV]JKg][FV]j0F]J000iJeX00`00O4ElAP03O4D01Ga6O4ElAGa5O4H00ga500ElAWa5O4ElAGa6
00=lA@05O4IlAGa5O4ElAP02O4D00`00JeY[FP0XJeX00`00O4ElAP03O4D01Ga6O4ElAGa5O4H00ga5
00ElAWa5O4ElAGa600=lA@05O4IlAGa5O4ElAP02O4D00`00JeY[FP0XJeX00`00O4ElAP03O4D01Ga6
O4ElAGa5O4H00ga500ElAWa5O4ElAGa600=lA@07O4IlAGa5O4ElAWa50000:V]J00@007a5O4ElAP=l
A@05O4IlAGa5O4ElAP03O4D01Ga6O4ElAGa5O4H00ga500MlAWa5O4ElAGa6O4D0000jJeX0003oJgY[
FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][
FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]j001lIWa5O6Il
AGaVO4ElIWa5O6IlAGaVO4ElIWa5O6IlAGaVO4ElIWa5O6IlAGaVO4ElIWa5O6IlA@00JeY[NV]JKg][
FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[
FVmkJeY[NV]JKg][FP00O4ElIWa5O6IlAGaVO4ElIWa5O6IlAGaVO4ElIWa5O6IlAGaVO4ElIWa5O6Il
AGaVO4ElIWa5O6IlA@00JeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[
FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FP00O4ElIWa5O6IlAGaVO4ElIWa5O6Il
AGaVO4ElIWa5O6IlAGaVO4ElIWa5O6IlAGaVO4ElIWa5O6IlA@00JeY[NV]JKg][FV]jJeY_Nf]JJgY[
FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmk001XJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]J
Kg][FP00O4ElIWa5O6IlAGaVO4ElIWa5O6IlAGaVO4ElIWa5O6IlAGaVO4ElIWa5O6IlAGaVO4ElIWa5
O6IlA@00JeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]J
Kg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_N`5[
FP00=f]J0P0000ElAWa5O4ElAGa600=lA@05O4IlAGa5O4ElAP03O4D01Ga6O4ElAGa5O4H00ga500Il
AWa5O4ElAGa6O4D2000VJeX00`00O4ElAP03O4D01Ga6O4ElAGa5O4H00ga500ElAWa5O4ElAGa600=l
A@05O4IlAGa5O4ElAP03O4D017a6O4D000009V]J00<007a5O4H00ga500ElAWa5O4ElAGa600=lA@05
O4IlAGa5O4ElAP03O4D01Ga6O4ElAGa5O4H00ga500=lAWa500009f]J00<007a5O4H00ga500ElAWa5
O4ElAGa600=lA@05O4IlAGa5O4ElAP03O4D01Ga6O4ElAGa5O4H00ga500=lAWa50000>6]J0000ofmk
JeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]j
JeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FP00O4ElIWa5O6IlAGaV
O4ElIWa5O6IlAGaVO4ElIWa5O6IlAGaVO4ElIWa5O6IlAGaVO4ElIWa5O6IlAGaVO4ElIWa5O6H006]j
JeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmk
JeY[NV]JKg][FP00O4ElIWa5O6IlAGaVO4ElIWa5O6IlAGaVO4ElIWa5O6IlAGaVO4ElIWa5O6IlAGaV
O4ElIWa5O6IlAGaVO4ElIWa5O6H006]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmk
JeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FP00O4ElIWa5O6IlAGaVO4ElIWa5O6IlAGaV
O4ElIWa5O6IlAGaVO4ElIWa5O6IlAGaVO4ElIWa5O6IlAGaVO4ElIWa5001[FV]jJeY_Nf]JJgY[FVmk
JeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NP00J6]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][
FP00O4ElIWa5O6IlAGaVO4ElIWa5O6IlAGaVO4ElIWa5O6IlAGaVO4ElIWa5O6IlAGaVO4ElIWa5O6Il
AGaVO4ElIWa5001[FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][
FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgX1
JeX003I[FP03001lAWa5009lA@05O4IlAGa5O4ElAP03O4D01Ga6O4ElAGa5O4H00ga500ElAWa5O4El
AGa600=lA@07O4IlAGa5O4ElAWa5000096]J00<007a6O4D00Wa500ElAWa5O4ElAGa600=lA@05O4Il
AGa5O4ElAP03O4D01Ga6O4ElAGa5O4H00ga500MlAWa5O4ElAGa6O4D0000TJeX00`00O4IlA@02O4D0
1Ga6O4ElAGa5O4H00ga500ElAWa5O4ElAGa600=lA@05O4IlAGa5O4ElAP03O4D01ga6O4ElAGa5O4Il
A@0002=[FP03001lAGa600=lA@05O4IlAGa5O4ElAP03O4D01Ga6O4ElAGa5O4H00ga500ElAWa5O4El
AGa600=lA@07O4IlAGa5O4ElAWa50000=V]J0000of]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_
Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[
NV]JKg][FV]jJeY_Nf]JJgX007aVO4ElIWa5O6IlAGaVO4ElIWa5O6IlAGaVO4ElIWa5O6IlAGaVO4El
IWa5O6IlAGaVO4ElIWa5O6IlAGaVO4ElIWa5O6IlA@00JeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[
NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgX007aVO4ElIWa5O6IlAGaVO4El
IWa5O6IlAGaVO4ElIWa5O6IlAGaVO4ElIWa5O6IlAGaVO4ElIWa5O6IlAGaVO4ElIWa5O6IlA@00JeY[
NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_
Nf]JJgX007aVO4ElIWa5O6IlAGaVO4ElIWa5O6IlAGaVO4ElIWa5O6IlAGaVO4ElIWa5O6IlAGaVO4El
IWa5O6IlAGaVO4ElIWa5O6IlA@00JeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_
N`00J6]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]J001lAGaVO4ElIWa5O6IlAGaVO4ElIWa5O6IlAGaV
O4ElIWa5O6IlAGaVO4ElIWa5O6IlAGaVO4ElIWa5O6IlAGaVO4ElIWa5O6IlA@00JeY[NV]JKg][FV]j
JeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmk
JeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg/1JeX003E[FP05001lAGa5O4ElAP03O4D01Ga6
O4ElAGa5O4H00ga500ElAWa5O4ElAGa600=lA@05O4IlAGa5O4ElAP03O4D01Wa6O4ElAGa5O4H0029[
FP05001lAGa5O4ElAP03O4D01Ga6O4ElAGa5O4H00ga500ElAWa5O4ElAGa600=lA@05O4IlAGa5O4El
AP03O4D01Wa6O4ElAGa5O4H0025[FP03001lAWa5009lA@05O4IlAGa5O4ElAP03O4D01Ga6O4ElAGa5
O4H00ga500ElAWa5O4ElAGa600=lA@05O4IlAGa5O4ElAP03O4D00ga6001[FP0PJeX00`00O4IlA@02
O4D01Ga6O4ElAGa5O4H00ga500ElAWa5O4ElAGa600=lA@05O4IlAGa5O4ElAP03O4D01Ga6O4ElAGa5
O4H00ga500=lAP00JeX0=6]J0000ofmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]j
JeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmk
JeY[NV]J001lAGaVO4ElIWa5O6IlAGaVO4ElIWa5O6IlAGaVO4ElIWa5O6IlAGaVO4ElIWa5O6IlAGaV
O4ElIWa5O6IlAGaVO4ElIWa5O6IlAGaV001_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmk
JeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]J001lAGaVO4ElIWa5O6IlAGaVO4ElIWa5O6IlAGaV
O4ElIWa5O6IlAGaVO4ElIWa5O6IlAGaVO4ElIWa5O6IlAGaVO4ElIWa5O6IlAGaV001_Nf]JJgY[FVmk
JeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NP00O6IlAGaV
O4ElIWa5O6IlAGaVO4ElIWa5O6IlAGaVO4ElIWa5O6IlAGaVO4ElIWa5O6IlAGaVO4ElIWa5O6IlAGaV
O4ElIWa5O6IlAGaV001_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NP00J6]JKg][
FV]jJeY_Nf]JJgY[FVmkJeY[NP00O6IlAGaVO4ElIWa5O6IlAGaVO4ElIWa5O6IlAGaVO4ElIWa5O6Il
AGaVO4ElIWa5O6IlAGaVO4ElIWa5O6IlAGaVO4ElIWa5O6IlAGaV001_Nf]JJgY[FVmkJeY[NV]JKg][
FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[
FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgX1JeX003A[FP04001lAGa5O4H3O4D01Ga6O4ElAGa5O4H00ga5
00ElAWa5O4ElAGa600=lA@05O4IlAGa5O4ElAP03O4D01Ga6O4ElAGa5O4H00ga500<006]JJeX07V]J
00@007a5O4ElAP=lA@05O4IlAGa5O4ElAP03O4D01Ga6O4ElAGa5O4H00ga500ElAWa5O4ElAGa600=l
A@05O4IlAGa5O4ElAP03O4D00`00JeY[FP0MJeX01@00O4ElAGa5O4H00ga500ElAWa5O4ElAGa600=l
A@05O4IlAGa5O4ElAP03O4D01Ga6O4ElAGa5O4H00ga500ElAWa5O4ElAGa600=lA@03001[FV]J01e[
FP05001lAGa5O4ElAP03O4D01Ga6O4ElAGa5O4H00ga500ElAWa5O4ElAGa600=lA@05O4IlAGa5O4El
AP03O4D01Ga6O4ElAGa5O4H00ga500<006]JJeX0<V]J0000of]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][
FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[
FVmkJeY[NV]JKg][FV]jJeY_N`00O6IlAGaVO4ElIWa5O6IlAGaVO4ElIWa5O6IlAGaVO4ElIWa5O6Il
AGaVO4ElIWa5O6IlAGaVO4ElIWa5O6IlAGaVO4ElIWa5O6IlAGaVO4D006]JKg][FV]jJeY_Nf]JJgY[
FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_N`00O6IlAGaVO4ElIWa5O6Il
AGaVO4ElIWa5O6IlAGaVO4ElIWa5O6IlAGaVO4ElIWa5O6IlAGaVO4ElIWa5O6IlAGaVO4ElIWa5O6Il
AGaVO4D006]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][
FV]jJeY_N`00O6IlAGaVO4ElIWa5O6IlAGaVO4ElIWa5O6IlAGaVO4ElIWa5O6IlAGaVO4ElIWa5O6Il
AGaVO4ElIWa5O6IlAGaVO4ElIWa5O6IlAGaV001[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][
FV]jJeY_N`00J6]JJgY[FVmkJeY[NV]JKg][FV]jJeX007a5O6IlAGaVO4ElIWa5O6IlAGaVO4ElIWa5
O6IlAGaVO4ElIWa5O6IlAGaVO4ElIWa5O6IlAGaVO4ElIWa5O6IlAGaVO4ElIWa5O6IlAGaV001[NV]J
Kg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]J
JgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg/1JeX003=[FP03001lAGa600=lA@05
O4IlAGa5O4ElAP03O4D01Ga6O4ElAGa5O4H00ga500ElAWa5O4ElAGa600=lA@05O4IlAGa5O4ElAP03
O4D017a6O4ElA@007V]J00<007a5O4H00ga500ElAWa5O4ElAGa600=lA@05O4IlAGa5O4ElAP03O4D0
1Ga6O4ElAGa5O4H00ga500ElAWa5O4ElAGa600=lA@04O4IlAGa5000NJeX00`00O4ElAP03O4D01Ga6
O4ElAGa5O4H00ga500ElAWa5O4ElAGa600=lA@05O4IlAGa5O4ElAP03O4D01Ga6O4ElAGa5O4H00ga5
00=lAWa500007V]J00@007a5O4ElAP=lA@05O4IlAGa5O4ElAP03O4D01Ga6O4ElAGa5O4H00ga500El
AWa5O4ElAGa600=lA@05O4IlAGa5O4ElAP03O4D00ga6O4D0000dJeX0003oKg][FV]jJeY_Nf]JJgY[
FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][
FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FP00O4ElIWa5O6IlAGaVO4ElIWa5O6IlAGaVO4ElIWa5O6Il
AGaVO4ElIWa5O6IlAGaVO4ElIWa5O6IlAGaVO4ElIWa5O6IlAGaVO4ElIWa5O6IlA@00JeY[NV]JKg][
FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FP00O4ElIWa5O6Il
AGaVO4ElIWa5O6IlAGaVO4ElIWa5O6IlAGaVO4ElIWa5O6IlAGaVO4ElIWa5O6IlAGaVO4ElIWa5O6Il
AGaVO4ElIWa5O6IlA@00JeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[
FVmkJeY[NV]JKg][FP00O4ElIWa5O6IlAGaVO4ElIWa5O6IlAGaVO4ElIWa5O6IlAGaVO4ElIWa5O6Il
AGaVO4ElIWa5O6IlAGaVO4ElIWa5O6IlAGaVO4ElIWa5O6IlA@00JeY[NV]JKg][FV]jJeY_Nf]JJgY[
FVmkJeY[NV]JKg][FV]j001XJeY_Nf]JJgY[FVmkJeY[NV]JKg][FP00O4ElIWa5O6IlAGaVO4ElIWa5
O6IlAGaVO4ElIWa5O6IlAGaVO4ElIWa5O6IlAGaVO4ElIWa5O6IlAGaVO4ElIWa5O6IlAGaVO4ElIWa5
O6IlA@00JeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]J
Kg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NP5[FP00<V]J00<007a6
O4D00Wa500ElAWa5O4ElAGa600=lA@05O4IlAGa5O4ElAP03O4D01Ga6O4ElAGa5O4H00ga500ElAWa5
O4ElAGa600=lA@06O4IlAGa5O4ElAP007F]J00<007a6O4D00Wa500ElAWa5O4ElAGa600=lA@05O4Il
AGa5O4ElAP03O4D01Ga6O4ElAGa5O4H00ga500ElAWa5O4ElAGa600=lA@06O4IlAGa5O4ElAP007F]J
00<007a6O4D00Wa500ElAWa5O4ElAGa600=lA@05O4IlAGa5O4ElAP03O4D01Ga6O4ElAGa5O4H00ga5
00ElAWa5O4ElAGa600=lA@06O4IlAGa5O4ElAP007F]J00<007a6O4D00Wa500ElAWa5O4ElAGa600=l
A@05O4IlAGa5O4ElAP03O4D01Ga6O4ElAGa5O4H00ga500ElAWa5O4ElAGa600=lA@06O4IlAGa5O4El
AP00<f]J0000of]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]j
JeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeX007a5O6IlAGaV
O4ElIWa5O6IlAGaVO4ElIWa5O6IlAGaVO4ElIWa5O6IlAGaVO4ElIWa5O6IlAGaVO4ElIWa5O6IlAGaV
O4ElIWa5O6IlAGaVO4ElIP00Kg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmk
JeY[NV]JKg][FV]jJeX007a5O6IlAGaVO4ElIWa5O6IlAGaVO4ElIWa5O6IlAGaVO4ElIWa5O6IlAGaV
O4ElIWa5O6IlAGaVO4ElIWa5O6IlAGaVO4ElIWa5O6IlAGaVO4ElIP00Kg][FV]jJeY_Nf]JJgY[FVmk
JeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeX007a5O6IlAGaVO4ElIWa5O6IlAGaV
O4ElIWa5O6IlAGaVO4ElIWa5O6IlAGaVO4ElIWa5O6IlAGaVO4ElIWa5O6IlAGaVO4ElIWa5O6IlAGaV
O4D006]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_N`00J6]JJgY[FVmkJeY[NV]JKg][
FV]j001lIWa5O6IlAGaVO4ElIWa5O6IlAGaVO4ElIWa5O6IlAGaVO4ElIWa5O6IlAGaVO4ElIWa5O6Il
AGaVO4ElIWa5O6IlAGaVO4ElIWa5O6IlAGaVO4D006]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][
FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[
FVmkJeY[NV]JKg/1JeX0039[FP04001lAGa5O4H3O4D01Ga6O4ElAGa5O4H00ga500ElAWa5O4ElAGa6
00=lA@05O4IlAGa5O4ElAP03O4D01Ga6O4ElAGa5O4H00ga500ElAWa5O4ElA@0001a[FP04001lAGa5
O4H3O4D01Ga6O4ElAGa5O4H00ga500ElAWa5O4ElAGa600=lA@05O4IlAGa5O4ElAP03O4D01Ga6O4El
AGa5O4H00ga500ElAWa5O4ElA@0001a[FP04001lAGa5O4H3O4D01Ga6O4ElAGa5O4H00ga500ElAWa5
O4ElAGa600=lA@05O4IlAGa5O4ElAP03O4D01Ga6O4ElAGa5O4H00ga500AlAWa5O4D001a[FP05001l
AGa5O4ElAP03O4D01Ga6O4ElAGa5O4H00ga500ElAWa5O4ElAGa600=lA@05O4IlAGa5O4ElAP03O4D0
1Ga6O4ElAGa5O4H00ga500AlAWa5O4D003=[FP000?m_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]J
JgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]J
Kg][FV]jJeY_Nf]J001lAGaVO4ElIWa5O6IlAGaVO4ElIWa5O6IlAGaVO4ElIWa5O6IlAGaVO4ElIWa5
O6IlAGaVO4ElIWa5O6IlAGaVO4ElIWa5O6IlAGaVO4ElIWa5O6H006]jJeY_Nf]JJgY[FVmkJeY[NV]J
Kg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]J001lAGaVO4ElIWa5O6IlAGaVO4ElIWa5
O6IlAGaVO4ElIWa5O6IlAGaVO4ElIWa5O6IlAGaVO4ElIWa5O6IlAGaVO4ElIWa5O6IlAGaVO4ElIWa5
O6H006]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_N`00
O6IlAGaVO4ElIWa5O6IlAGaVO4ElIWa5O6IlAGaVO4ElIWa5O6IlAGaVO4ElIWa5O6IlAGaVO4ElIWa5
O6IlAGaVO4ElIWa5O6IlAGaVO4ElIWa5001[FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]J
JgX006Q[FVmkJeY[NV]JKg][FV]jJeY_N`00O6IlAGaVO4ElIWa5O6IlAGaVO4ElIWa5O6IlAGaVO4El
IWa5O6IlAGaVO4ElIWa5O6IlAGaVO4ElIWa5O6IlAGaVO4ElIWa5O6IlAGaVO4ElIWa5001[FV]jJeY_
Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[
NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]j0F]J000bJeX00`00O4IlA@02O4D01Ga6O4El
AGa5O4H00ga500ElAWa5O4ElAGa600=lA@05O4IlAGa5O4ElAP03O4D01Ga6O4ElAGa5O4H00ga500Ml
AWa5O4ElAGa6O4D0000LJeX00`00O4IlA@02O4D01Ga6O4ElAGa5O4H00ga500ElAWa5O4ElAGa600=l
A@05O4IlAGa5O4ElAP03O4D01Ga6O4ElAGa5O4H00ga500MlAWa5O4ElAGa6O4D0000KJeX00`00O4El
AP03O4D01Ga6O4ElAGa5O4H00ga500ElAWa5O4ElAGa600=lA@05O4IlAGa5O4ElAP03O4D01Ga6O4El
AGa5O4H00ga500IlAWa5O4ElAGa6000LJeX00`00O4ElAP03O4D01Ga6O4ElAGa5O4H00ga500ElAWa5
O4ElAGa600=lA@05O4IlAGa5O4ElAP03O4D01Ga6O4ElAGa5O4H00ga500IlAWa5O4ElAGa6000cJeX0
003oJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[
NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FP00O4ElIWa5O6IlAGaVO4El
IWa5O6IlAGaVO4ElIWa5O6IlAGaVO4ElIWa5O6IlAGaVO4ElIWa5O6IlAGaVO4ElIWa5O6IlAGaVO4El
IWa5O6IlAGaV001_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_
Nf]JJgY[FP00O4ElIWa5O6IlAGaVO4ElIWa5O6IlAGaVO4ElIWa5O6IlAGaVO4ElIWa5O6IlAGaVO4El
IWa5O6IlAGaVO4ElIWa5O6IlAGaVO4ElIWa5O6IlAGaV001_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_
Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgX007aVO4ElIWa5O6IlAGaVO4ElIWa5O6IlAGaVO4El
IWa5O6IlAGaVO4ElIWa5O6IlAGaVO4ElIWa5O6IlAGaVO4ElIWa5O6IlAGaVO4ElIWa5O6IlA@00JeY_
Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmk001XJeY[NV]JKg][FV]jJeY_Nf]JJgX007aV
O4ElIWa5O6IlAGaVO4ElIWa5O6IlAGaVO4ElIWa5O6IlAGaVO4ElIWa5O6IlAGaVO4ElIWa5O6IlAGaV
O4ElIWa5O6IlAGaVO4ElIWa5O6IlA@00JeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmk
JeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]j
JeY_N`5[FP00<V]J00@007a5O4ElAP=lA@05O4IlAGa5O4ElAP03O4D01Ga6O4ElAGa5O4H00ga500El
AWa5O4ElAGa600=lA@05O4IlAGa5O4ElAP03O4D01Ga6O4ElAGa5000076]J00@007a5O4ElAP=lA@05
O4IlAGa5O4ElAP03O4D01Ga6O4ElAGa5O4H00ga500ElAWa5O4ElAGa600=lA@05O4IlAGa5O4ElAP03
O4D01Ga6O4ElAGa500006f]J00D007a5O4ElAGa600=lA@05O4IlAGa5O4ElAP03O4D01Ga6O4ElAGa5
O4H00ga500ElAWa5O4ElAGa600=lA@05O4IlAGa5O4ElAP03O4D017a6O4ElA@0076]J00D007a5O4El
AGa600=lA@05O4IlAGa5O4ElAP03O4D01Ga6O4ElAGa5O4H00ga500ElAWa5O4ElAGa600=lA@05O4Il
AGa5O4ElAP03O4D017a6O4ElA@00<f]J0000ofmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]J
Kg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]J
JgY[FVmkJeX007a5O6IlAGaVO4ElIWa5O6IlAGaVO4ElIWa5O6IlAGaVO4ElIWa5O6IlAGaVO4ElIWa5
O6IlAGaVO4ElIWa5O6IlAGaVO4ElIWa5O6IlAGaVO4ElIP00JgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]J
JgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeX007a5O6IlAGaVO4ElIWa5O6IlAGaVO4ElIWa5
O6IlAGaVO4ElIWa5O6IlAGaVO4ElIWa5O6IlAGaVO4ElIWa5O6IlAGaVO4ElIWa5O6IlAGaVO4ElIP00
JgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeX007a5
O6IlAGaVO4ElIWa5O6IlAGaVO4ElIWa5O6IlAGaVO4ElIWa5O6IlAGaVO4ElIWa5O6IlAGaVO4ElIWa5
O6IlAGaVO4ElIWa5O6IlAGaVO4D006]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NP00
J6]JKg][FV]jJeY_Nf]JJgY[FVmk001lIWa5O6IlAGaVO4ElIWa5O6IlAGaVO4ElIWa5O6IlAGaVO4El
IWa5O6IlAGaVO4ElIWa5O6IlAGaVO4ElIWa5O6IlAGaVO4ElIWa5O6IlAGaVO4D006]JJgY[FVmkJeY[
NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_
Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgX1JeX0039[FP03001lAWa5009lA@05O4IlAGa5O4El
AP03O4D01Ga6O4ElAGa5O4H00ga500ElAWa5O4ElAGa600=lA@05O4IlAGa5O4ElAP03O4D01Wa6O4El
AGa5O4H001e[FP03001lAWa5009lA@05O4IlAGa5O4ElAP03O4D01Ga6O4ElAGa5O4H00ga500ElAWa5
O4ElAGa600=lA@05O4IlAGa5O4ElAP03O4D01Wa6O4ElAGa5O4H001e[FP03001lAWa5009lA@05O4Il
AGa5O4ElAP03O4D01Ga6O4ElAGa5O4H00ga500ElAWa5O4ElAGa600=lA@05O4IlAGa5O4ElAP03O4D0
1Wa6O4ElAGa5O4H001a[FP03001lAGa600=lA@05O4IlAGa5O4ElAP03O4D01Ga6O4ElAGa5O4H00ga5
00ElAWa5O4ElAGa600=lA@05O4IlAGa5O4ElAP03O4D01Wa6O4ElAGa5O4H003=[FP000?m[NV]JKg][
FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[
FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]J001lAGaVO4ElIWa5O6IlAGaVO4ElIWa5O6Il
AGaVO4ElIWa5O6IlAGaVO4ElIWa5O6IlAGaVO4ElIWa5O6IlAGaVO4ElIWa5O6IlAGaVO4ElIWa5001[
FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]J001l
AGaVO4ElIWa5O6IlAGaVO4ElIWa5O6IlAGaVO4ElIWa5O6IlAGaVO4ElIWa5O6IlAGaVO4ElIWa5O6Il
AGaVO4ElIWa5O6IlAGaVO4ElIWa5001[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][
FV]jJeY_Nf]JJgY[FVmkJeY[NV]J001lAGaVO4ElIWa5O6IlAGaVO4ElIWa5O6IlAGaVO4ElIWa5O6Il
AGaVO4ElIWa5O6IlAGaVO4ElIWa5O6IlAGaVO4ElIWa5O6IlAGaVO4ElIWa5001[FVmkJeY[NV]JKg][
FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg/006Q[FV]jJeY_Nf]JJgY[FVmkJeY[NP00O6IlAGaVO4ElIWa5
O6IlAGaVO4ElIWa5O6IlAGaVO4ElIWa5O6IlAGaVO4ElIWa5O6IlAGaVO4ElIWa5O6IlAGaVO4ElIWa5
O6IlAGaVO4ElIWa5001[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]J
JgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmk0F]J000b
JeX01000O4ElAGa60ga500ElAWa5O4ElAGa600=lA@05O4IlAGa5O4ElAP03O4D01Ga6O4ElAGa5O4H0
0ga500ElAWa5O4ElAGa600=lA@04O4IlAGa5000MJeX01000O4ElAGa60ga500ElAWa5O4ElAGa600=l
A@05O4IlAGa5O4ElAP03O4D01Ga6O4ElAGa5O4H00ga500ElAWa5O4ElAGa600=lA@04O4IlAGa5000M
JeX01000O4ElAGa60ga500ElAWa5O4ElAGa600=lA@05O4IlAGa5O4ElAP03O4D01Ga6O4ElAGa5O4H0
0ga500ElAWa5O4ElAGa600=lA@03O4IlA@0001i[FP04001lAGa5O4H3O4D01Ga6O4ElAGa5O4H00ga5
00ElAWa5O4ElAGa600=lA@05O4IlAGa5O4ElAP03O4D01Ga6O4ElAGa5O4H00ga500=lAWa50000=6]J
0000ofmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]J
Kg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeX007a5O6IlAGaVO4ElIWa5
O6IlAGaVO4ElIWa5O6IlAGaVO4ElIWa5O6IlAGaVO4ElIWa5O6IlAGaVO4ElIWa5O6IlAGaVO4ElIWa5
O6IlAGaVO4D006]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]J
JgY[FVmkJeX007a5O6IlAGaVO4ElIWa5O6IlAGaVO4ElIWa5O6IlAGaVO4ElIWa5O6IlAGaVO4ElIWa5
O6IlAGaVO4ElIWa5O6IlAGaVO4ElIWa5O6IlAGaVO4D006]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]J
JgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeX007a5O6IlAGaVO4ElIWa5O6IlAGaVO4ElIWa5
O6IlAGaVO4ElIWa5O6IlAGaVO4ElIWa5O6IlAGaVO4ElIWa5O6IlAGaVO4ElIWa5O6IlAGaV001_Nf]J
JgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NP00J6]JKg][FV]jJeY_Nf]JJgY[FVmkJeX0
07a5O6IlAGaVO4ElIWa5O6IlAGaVO4ElIWa5O6IlAGaVO4ElIWa5O6IlAGaVO4ElIWa5O6IlAGaVO4El
IWa5O6IlAGaVO4ElIWa5O6IlAGaV001_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[
NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_
Nf]JJgX1JeX003=[FP05001lAGa5O4ElAP03O4D01Ga6O4ElAGa5O4H00ga500ElAWa5O4ElAGa600=l
A@05O4IlAGa5O4ElAP03O4D01Ga6O4ElAGa5O4H00ga500<006]JJeX07F]J00D007a5O4ElAGa600=l
A@05O4IlAGa5O4ElAP03O4D01Ga6O4ElAGa5O4H00ga500ElAWa5O4ElAGa600=lA@05O4IlAGa5O4El
AP03O4D00`00JeY[FP0MJeX01@00O4ElAGa5O4H00ga500ElAWa5O4ElAGa600=lA@05O4IlAGa5O4El
AP03O4D01Ga6O4ElAGa5O4H00ga500ElAWa5O4ElAGa600=lA@03001[FV]J01a[FP03001lAWa5009l
A@05O4IlAGa5O4ElAP03O4D01Ga6O4ElAGa5O4H00ga500ElAWa5O4ElAGa600=lA@05O4IlAGa5O4El
AP03O4D01Ga6O4ElAGa50000=6]J0000of]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[
FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][
FV]jJeY_N`00O6IlAGaVO4ElIWa5O6IlAGaVO4ElIWa5O6IlAGaVO4ElIWa5O6IlAGaVO4ElIWa5O6Il
AGaVO4ElIWa5O6IlAGaVO4ElIWa5O6IlAGaV001[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][
FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_N`00O6IlAGaVO4ElIWa5O6IlAGaVO4ElIWa5O6Il
AGaVO4ElIWa5O6IlAGaVO4ElIWa5O6IlAGaVO4ElIWa5O6IlAGaVO4ElIWa5O6IlAGaV001[NV]JKg][
FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_N`00O6Il
AGaVO4ElIWa5O6IlAGaVO4ElIWa5O6IlAGaVO4ElIWa5O6IlAGaVO4ElIWa5O6IlAGaVO4ElIWa5O6Il
AGaVO4ElIWa5O6IlAGaV001[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_N`00J6]J
JgY[FVmkJeY[NV]JKg][FV]jJeX007a5O6IlAGaVO4ElIWa5O6IlAGaVO4ElIWa5O6IlAGaVO4ElIWa5
O6IlAGaVO4ElIWa5O6IlAGaVO4ElIWa5O6IlAGaVO4ElIWa5O6IlAGaV001[NV]JKg][FV]jJeY_Nf]J
JgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]J
Kg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg/1JeX003A[FP03001lAWa5009lA@05O4IlAGa5O4ElAP03
O4D01Ga6O4ElAGa5O4H00ga500ElAWa5O4ElAGa600=lA@05O4IlAGa5O4ElAP03O4D00ga6001[FP0P
JeX00`00O4IlA@02O4D01Ga6O4ElAGa5O4H00ga500ElAWa5O4ElAGa600=lA@05O4IlAGa5O4ElAP03
O4D01Ga6O4ElAGa5O4H00ga500=lAP00JeX07f]J00<007a5O4H00ga500ElAWa5O4ElAGa600=lA@05
O4IlAGa5O4ElAP03O4D01Ga6O4ElAGa5O4H00ga500ElAWa5O4ElAGa600=lA@03O4H006]J01m[FP03
001lAGa600=lA@05O4IlAGa5O4ElAP03O4D01Ga6O4ElAGa5O4H00ga500ElAWa5O4ElAGa600=lA@05
O4IlAGa5O4ElAP03O4D00ga6001[FP0dJeX0003oKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]j
JeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmk
JeY[NV]JKg][FV]jJeX007a5O6IlAGaVO4ElIWa5O6IlAGaVO4ElIWa5O6IlAGaVO4ElIWa5O6IlAGaV
O4ElIWa5O6IlAGaVO4ElIWa5O6IlAGaVO4ElIWa5001[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmk
JeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeX007a5O6IlAGaVO4ElIWa5O6IlAGaV
O4ElIWa5O6IlAGaVO4ElIWa5O6IlAGaVO4ElIWa5O6IlAGaVO4ElIWa5O6IlAGaVO4ElIWa5001[FVmk
JeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]j
JeX007a5O6IlAGaVO4ElIWa5O6IlAGaVO4ElIWa5O6IlAGaVO4ElIWa5O6IlAGaVO4ElIWa5O6IlAGaV
O4ElIWa5O6IlAGaVO4ElIWa5001[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]j
001XJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]j001lIWa5O6IlAGaVO4ElIWa5O6IlAGaVO4ElIWa5O6Il
AGaVO4ElIWa5O6IlAGaVO4ElIWa5O6IlAGaVO4ElIWa5O6IlAGaVO4ElIWa5001[FVmkJeY[NV]JKg][
FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[
FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NP5[FP00=F]J00<007a5O4H00ga500ElAWa5O4El
AGa600=lA@05O4IlAGa5O4ElAP03O4D01Ga6O4ElAGa5O4H00ga500MlAWa5O4ElAGa6O4D0000SJeX0
0`00O4ElAP03O4D01Ga6O4ElAGa5O4H00ga500ElAWa5O4ElAGa600=lA@05O4IlAGa5O4ElAP03O4D0
1ga6O4ElAGa5O4IlA@0002=[FP03001lAGa600=lA@05O4IlAGa5O4ElAP03O4D01Ga6O4ElAGa5O4H0
0ga500ElAWa5O4ElAGa600=lA@07O4IlAGa5O4ElAWa500008V]J0P0000=lAGa6O4D00Wa500ElAWa5
O4ElAGa600=lA@05O4IlAGa5O4ElAP03O4D01Ga6O4ElAGa5O4H00ga500ElAWa5O4ElAGa6008003I[
FP000?m[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][
FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeX007a5O6Il
AGaVO4ElIWa5O6IlAGaVO4ElIWa5O6IlAGaVO4ElIWa5O6IlAGaVO4ElIWa5O6IlAGaVO4ElIWa5O6Il
A@00JeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[
FVmkJeY[NV]JKg][FV]jJeX007a5O6IlAGaVO4ElIWa5O6IlAGaVO4ElIWa5O6IlAGaVO4ElIWa5O6Il
AGaVO4ElIWa5O6IlAGaVO4ElIWa5O6IlA@00JeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[
FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeX007a5O6IlAGaVO4ElIWa5O6Il
AGaVO4ElIWa5O6IlAGaVO4ElIWa5O6IlAGaVO4ElIWa5O6IlAGaVO4ElIWa5O6IlA@00JeY_Nf]JJgY[
FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg/006Q[FV]jJeY_Nf]JJgY[FVmkJeY[NV]J
Kg][FV]jJeX007a5O6IlAGaVO4ElIWa5O6IlAGaVO4ElIWa5O6IlAGaVO4ElIWa5O6IlAGaVO4ElIWa5
O6IlAGaVO4ElIWa5O6H006]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]J
Kg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]J
JgY[FVmk0F]J000gJeX00`00O4ElAP03O4D01Ga6O4ElAGa5O4H00ga500ElAWa5O4ElAGa600=lA@05
O4IlAGa5O4ElAP03O4D017a6O4ElA@009F]J00@007a5O4ElAP=lA@05O4IlAGa5O4ElAP03O4D01Ga6
O4ElAGa5O4H00ga500ElAWa5O4ElAGa600=lA@04O4IlAGa5000UJeX01000O4ElAGa60ga500ElAWa5
O4ElAGa600=lA@05O4IlAGa5O4ElAP03O4D01Ga6O4ElAGa5O4H00ga500=lAWa500009V]J00@007a5
O4ElAP=lA@05O4IlAGa5O4ElAP03O4D01Ga6O4ElAGa5O4H00ga500ElAWa5O4ElAGa600=lA@03O4Il
A@0003Q[FP0007m_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_
Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[
NV]J001lAGaVO4ElIWa5O6IlAGaVO4ElIWa5O6IlAGaVO4ElIWa5O6IlAGaVO4ElIWa5O6IlAGaVO4El
IWa5O6H006mkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[
NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NP020000AWa5O6IlAGaVO4ElIWa5O6IlAGaVO4ElIWa5O6Il
AGaVO4ElIWa5O6IlAGaVO4ElIWa5O6IlAGaVO4ElIP00Kg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][
FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]j0P0009ilAGaV
O4ElIWa5O6IlAGaVO4ElIWa5O6IlAGaVO4ElIWa5O6IlAGaVO4ElIWa5O6IlAGaVO4ElIWa5001[FVmk
JeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]j
JeY_Nf]JJgY[FVmkJeY[NP00O6IlAGaVO4ElIWa5O6IlAGaVO4ElIWa5O6IlAGaVO4ElIWa5O6IlAGaV
O4ElIWa5O6IlAGaVO4ElIWa5001[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]j
JeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmk
JeY[NV]JKg][FV]j0F]J000iJeX00`00O4ElAP03O4D01Ga6O4ElAGa5O4H00ga500ElAWa5O4ElAGa6
00=lA@05O4IlAGa5O4ElAP02O4D00`00JeY[FP0XJeX00`00O4ElAP03O4D01Ga6O4ElAGa5O4H00ga5
00ElAWa5O4ElAGa600=lA@05O4IlAGa5O4ElAP02O4D00`00JeY[FP0XJeX00`00O4ElAP03O4D01Ga6
O4ElAGa5O4H00ga500ElAWa5O4ElAGa600=lA@05O4IlAGa5O4ElAP02O4D00`00JeY[FP0WJeX01000
O4ElAGa60ga500ElAWa5O4ElAGa600=lA@05O4IlAGa5O4ElAP03O4D01Ga6O4ElAGa5O4H00Wa500<0
06]JJeX0=f]J0000i6]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][
FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[
FVmkJeY[NV]J001lAGaVO4ElIWa5O6IlAGaVO4ElIWa5O6IlAGaVO4ElIWa5O6IlAGaVO4ElIWa5O6Il
AGaV001_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[
FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]J001lAGaVO4ElIWa5O6IlAGaVO4ElIWa5O6Il
AGaVO4ElIWa5O6IlAGaVO4ElIWa5O6IlAGaV001_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[
FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NP00O6Il
AGaVO4ElIWa5O6IlAGaVO4ElIWa5O6IlAGaVO4ElIWa5O6IlAGaVO4ElIWa5O6IlA@800016Kg][FV]j
JeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmk
JeY[NV]JKg][FV]jJeY_Nf]JJgX007aVO4ElIWa5O6IlAGaVO4ElIWa5O6IlAGaVO4ElIWa5O6IlAGaV
O4ElIWa5O6IlAGaVO4D20000>FmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_
Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[
NV]JKg][FV]jJeY_N`01JeX003][FP800005O4IlAGa5O4ElAP03O4D01Ga6O4ElAGa5O4H00ga500Il
AWa5O4ElAGa6O4D2000^JeX00`00O4ElAP03O4D01Ga6O4ElAGa5O4H00ga500ElAWa5O4ElAGa600=l
A@04O4IlA@00000]JeX200000ga5O4IlA@02O4D01Ga6O4ElAGa5O4H00ga500ElAWa5O4ElAGa600=l
A@03O4IlA@0002i[FP800003O4ElAWa5009lA@05O4IlAGa5O4ElAP03O4D01Ga6O4ElAGa5O4H00ga5
00=lAP000000?6]J0000DFmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]J
JgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]J
Kg][FV]jJeY_Nf]JJgY[FVmk001lIWa5O6IlAGaVO4ElIWa5O6IlAGaVO4ElIWa5O6IlAGaVO4ElIP02
0000<F]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]j
JeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]J0080000CO6IlAGaVO4ElIWa5
O6IlAGaVO4ElIWa5O6IlAGaVO4ElIWa5O6H00P00035[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmk
JeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]j
JeY_Nf]JJgY[FP0200004gaVO4ElIWa5O6IlAGaVO4ElIWa5O6IlAGaVO4ElIWa5O6IlAGaV0080000a
JeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmk
JeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeX00P00055lIWa5O6IlAGaVO4ElIWa5
O6IlAGaVO4ElIWa5O6IlAGaVO4ElIP00JgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]J
Kg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]J
JgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgX00F]J000nJeX20003O4D01Ga6O4ElAGa5O4H00ga500Al
AWa5O4ElA@8003E[FP8000=lA@05O4IlAGa5O4ElAP03O4D017a6O4ElAGa50P00=F]J0P000ga500El
AWa5O4ElAGa600=lA@04O4IlAGa5O4D2000eJeX20003O4D01Ga6O4ElAGa5O4H00ga500AlAWa5O4El
A@8003m[FP00041[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[
NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_
Nf]JJgY[FVmkJeY[NV]JKg][FPD00008O4ElIWa5O6IlAGaVO4ElIP80000iJeY[NV]JKg][FV]jJeY_
Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[
NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]J00@00009O6IlAGaVO4ElIWa5O6Il
AGaV0080000iJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[
NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_
Nf]J00@00009O6IlAGaVO4ElIWa5O6IlAGaV0080000iJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[
NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_
Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]J00@00008O6IlAGaVO4ElIWa5O6IlA@<00010JeY[NV]J
Kg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]J
JgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]J
Kg/1JeX004E[FPP003m[FPT003m[FPT003m[FPP004A[FP000?m_Nf]JJgY[FVmkJeY[NV]JKg][FV]j
JeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmk
JeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]j
JeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmk
JeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]j
JeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmk
JeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]j
JeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmk
JeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]j
JeY_Nf]JJgX006Q[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[
FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][
FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[
FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]j0F]J003oJeYYJeX0003oJgY[FVmk
JeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]j
JeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmk
JeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]j
JeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmk
JeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]j
JeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmk
JeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]j
JeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmk
JeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmk001XJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][
FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[
FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][
FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_N`5[FP00
of]JJF]J0000ofmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmk
JeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]j
JeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmk
JeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]j
JeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmk
JeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]j
JeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmk
JeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]j
JeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NP00J6]JKg][FV]jJeY_Nf]JJgY[
FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][
FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[
FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][
FV]jJeY_Nf]JJgX1JeX00?m[FVU[FP000?m[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]j
JeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmk
JeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]j
JeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmk
JeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]j
JeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmk
JeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]j
JeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmk
JeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg/006Q[
FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[
FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][
FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[
FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmk0F]J003oJeYYJeX0003oKg][FV]jJeY_Nf]JJgY[FVmk
JeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]j
JeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmk
JeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]j
JeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmk
JeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]j
JeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmk
JeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]j
JeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmk
JeY[NV]JKg][FV]j001XJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][
FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[
FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][
FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NP5[FP00of]JJF]J0000of]j
JeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmk
JeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]j
JeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmk
JeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]j
JeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmk
JeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]j
JeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmk
JeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]j
JeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_N`00J6]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[
FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][
FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[
FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg/1
JeX00?m[FVU[FP000?m_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]j
JeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmk
JeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]j
JeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmk
JeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]j
JeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmk
JeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]j
JeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmk
JeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgX006Q[FVmkJeY[NV]JKg][
FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[
FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][
FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[
FVmkJeY[NV]JKg][FV]j0F]J003oJeYYJeX0003oJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmk
JeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]j
JeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmk
JeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]j
JeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmk
JeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]j
JeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmk
JeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]j
JeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmk
001XJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][
FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[
FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][
FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_N`5[FP00of]JJF]J0000ofmkJeY[NV]JKg][FV]j
JeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmk
JeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]j
JeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmk
JeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]j
JeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmk
JeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]j
JeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmk
JeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]j
JeY_Nf]JJgY[FVmkJeY[NP00J6]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[
FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][
FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[
FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgX1JeX00?m[FVU[FP00
0?m[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]j
JeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmk
JeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]j
JeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmk
JeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]j
JeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmk
JeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]j
JeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmk
JeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg/006Q[FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][
FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[
FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][
FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[
FVmk0F]J003oJeYYJeX0003oKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmk
JeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]j
JeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmk
JeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]j
JeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmk
JeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]j
JeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmk
JeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]j
JeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]j001XJeY_Nf]JJgY[
FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][
FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[
FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][
FV]jJeY_Nf]JJgY[FVmkJeY[NP5[FP00of]JJF]J0000of]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]j
JeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmk
JeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]j
JeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmk
JeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]j
JeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmk
JeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]j
JeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmk
JeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]j
JeY_N`00J6]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[
FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][
FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[
FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg/1JeX00?m[FVU[FP000?m_Nf]JJgY[FVmk
JeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]j
JeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmk
JeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]j
JeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmk
JeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]j
JeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmk
JeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]j
JeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmk
JeY[NV]JKg][FV]jJeY_Nf]JJgX006Q[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][
FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[
FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][
FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]j0F]J003oJeYY
JeX0003oJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmk
JeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]j
JeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmk
JeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]j
JeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmk
JeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]j
JeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmk
JeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]j
JeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmk001XJeY[NV]JKg][FV]jJeY_Nf]JJgY[
FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][
FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[
FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][
FV]jJeY_N`5[FP00of]JJF]J0000@VmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]j
JeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmk
JeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FP`0000kJgY[FVmkJeY[NV]JKg][FV]jJeY_
Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[
NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_N`0=0000>f]jJeY_Nf]JJgY[FVmkJeY[
NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_
Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg/03@0008U[NV]JKg][FV]jJeY_
Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[
NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_
Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[
NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_
Nf]JJgY[FVmkJeY[NV]JKg][FV]j005[FP00?V]J100000=lAGa6O4D00Wa500ElAWa5O4ElAGa6009l
A@8003E[FP@0009lA@05O4IlAGa5O4ElAP03O4D00ga6O4ElA@02000eJeX40002O4D01Ga6O4ElAGa5
O4H00ga500=lAWa5O4D00P00R6]J0000D6]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[
FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][
FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]j001lIWa5O6IlAGaVO4ElIWa5O6IlAGaVO4ElIWa5O6Il
AGaVO4D20000AVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmk
JeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeX007a5O6IlAGaV
O4ElIWa5O6IlAGaVO4ElIWa5O6IlAGaVO4ElIWa50P0004I_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_
Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[
NV]JKg][FV]jJeY_Nf]J001lAGaVO4ElIWa5O6IlAGaVO4ElIWa5O6IlAGaVO4ElIWa5O6IlA@800025
Kg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]J
JgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]J
Kg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]J
JgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]J
Kg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg/00F]J000lJeX00`00O4IlA@02O4D01Ga6O4ElAGa5O4H0
0ga500ElAWa5O4ElAGa600=lA@03O4H00000031[FP03001lAWa5009lA@05O4IlAGa5O4ElAP03O4D0
1Ga6O4ElAGa5O4H00ga500=lAP000000;f]J00<007a5O4H00ga500ElAWa5O4ElAGa600=lA@05O4Il
AGa5O4ElAP03O4D00ga600000024JeX0000jKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_
Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[
NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeX2000067aVO4ElIWa5O6IlAGaVO4ElIWa5O6IlAGaVO4ElIWa5
O6IlAGaVO4ElIWa5O6IlA@80000/JgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][
FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FP80000HO6IlAGaV
O4ElIWa5O6IlAGaVO4ElIWa5O6IlAGaVO4ElIWa5O6IlAGaVO4ElIWa50P000<U[NV]JKg][FV]jJeY_
Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[
NV]JKg][FV]jJeY_Nf]J001lAGaVO4ElIWa5O6IlAGaVO4ElIWa5O6IlAGaVO4ElIWa5O6IlAGaVO4El
IWa5O6IlA@00JeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[
NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_
Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[
NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_
Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgX00F]J000iJeX00`00O4ElAP03O4D01Ga6O4ElAGa5
O4H00ga500ElAWa5O4ElAGa600=lA@05O4IlAGa5O4ElAP02O4D00`00JeY[FP0WJeX200000ga5O4Il
A@02O4D01Ga6O4ElAGa5O4H00ga500ElAWa5O4ElAGa600=lA@05O4IlAGa5O4ElAP02O4D00`00JeY[
FP0WJeX200000ga5O4IlA@02O4D01Ga6O4ElAGa5O4H00ga500ElAWa5O4ElAGa600=lA@07O4IlAGa5
O4ElAWa50000PV]J0000of]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]J
Kg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]J
JgY[FVmkJeX007a5O6IlAGaVO4ElIWa5O6IlAGaVO4ElIWa5O6IlAGaVO4ElIWa5O6IlAGaVO4ElIWa5
O6IlAGaVO4D006]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]J
JgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmk001lIWa5O6IlAGaVO4ElIWa5O6IlAGaVO4ElIWa5
O6IlAGaVO4ElIWa5O6IlAGaVO4ElIWa5O6IlAGaVO4D006]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]J
JgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmk001lIWa5
O6IlAGaVO4ElIWa5O6IlAGaVO4ElIWa5O6IlAGaVO4ElIWa5O6IlAGaVO4ElIWa5O6IlAGaVO4D006]J
JgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_N`00J6]JJgY[FVmkJeY[
NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_
Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[
NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_
Nf]JJgY[FVmkJeY[NV]JKg/1JeX003M[FP03001lAGa600=lA@05O4IlAGa5O4ElAP03O4D01Ga6O4El
AGa5O4H00ga500ElAWa5O4ElAGa600=lA@04O4IlA@00000VJeX00`00O4ElAP03O4D01Ga6O4ElAGa5
O4H00ga500ElAWa5O4ElAGa600=lA@05O4IlAGa5O4ElAP03O4D017a6O4D000009V]J00<007a5O4H0
0ga500ElAWa5O4ElAGa600=lA@05O4IlAGa5O4ElAP03O4D01Ga6O4ElAGa5O4H00ga500=lAWa50000
P6]J0000ofmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[
NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FP00O4El
IWa5O6IlAGaVO4ElIWa5O6IlAGaVO4ElIWa5O6IlAGaVO4ElIWa5O6IlAGaVO4ElIWa5O6IlAGaVO4El
IWa5O6H006]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_
Nf]JJgY[FVmkJeY[NV]JKg][FP00O4ElIWa5O6IlAGaVO4ElIWa5O6IlAGaVO4ElIWa5O6IlAGaVO4El
IWa5O6IlAGaVO4ElIWa5O6IlAGaVO4ElIWa5O6H006]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_
Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FP00O4ElIWa5O6IlAGaVO4El
IWa5O6IlAGaVO4ElIWa5O6IlAGaVO4ElIWa5O6IlAGaVO4ElIWa5O6IlAGaVO4ElIWa5001[FV]jJeY_
Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NP00J6]JKg][FV]jJeY_Nf]JJgY[FVmk
JeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]j
JeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmk
JeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]j
JeY_Nf]JJgX1JeX003I[FP03001lAWa5009lA@05O4IlAGa5O4ElAP03O4D01Ga6O4ElAGa5O4H00ga5
00ElAWa5O4ElAGa600=lA@07O4IlAGa5O4ElAWa5000096]J00<007a6O4D00Wa500ElAWa5O4ElAGa6
00=lA@05O4IlAGa5O4ElAP03O4D01Ga6O4ElAGa5O4H00ga500MlAWa5O4ElAGa6O4D0000TJeX00`00
O4IlA@02O4D01Ga6O4ElAGa5O4H00ga500ElAWa5O4ElAGa600=lA@05O4IlAGa5O4ElAP03O4D01ga6
O4ElAGa5O4IlA@0007i[FP000?m[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]J
JgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]J
Kg][FV]j001lIWa5O6IlAGaVO4ElIWa5O6IlAGaVO4ElIWa5O6IlAGaVO4ElIWa5O6IlAGaVO4ElIWa5
O6IlAGaVO4ElIWa5O6IlAGaVO4D006]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]J
Kg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]j001lIWa5O6IlAGaVO4ElIWa5O6IlAGaVO4ElIWa5
O6IlAGaVO4ElIWa5O6IlAGaVO4ElIWa5O6IlAGaVO4ElIWa5O6IlAGaVO4D006]JJgY[FVmkJeY[NV]J
Kg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]j001lIWa5
O6IlAGaVO4ElIWa5O6IlAGaVO4ElIWa5O6IlAGaVO4ElIWa5O6IlAGaVO4ElIWa5O6IlAGaVO4ElIWa5
O6IlAGaVO4D006]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg/006Q[FV]jJeY_
Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[
NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_
Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[
NV]JKg][FV]jJeY_Nf]JJgY[FVmk0F]J000eJeX01@00O4ElAGa5O4H00ga500ElAWa5O4ElAGa600=l
A@05O4IlAGa5O4ElAP03O4D01Ga6O4ElAGa5O4H00ga500IlAWa5O4ElAGa6000RJeX01@00O4ElAGa5
O4H00ga500ElAWa5O4ElAGa600=lA@05O4IlAGa5O4ElAP03O4D01Ga6O4ElAGa5O4H00ga500IlAWa5
O4ElAGa6000QJeX00`00O4IlA@02O4D01Ga6O4ElAGa5O4H00ga500ElAWa5O4ElAGa600=lA@05O4Il
AGa5O4ElAP03O4D01Ga6O4ElAGa5O4H00ga500=lAP00JeX0O6]J0000ofmkJeY[NV]JKg][FV]jJeY_
Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[
NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]J001lAGaVO4ElIWa5O6IlAGaVO4ElIWa5O6IlAGaVO4El
IWa5O6IlAGaVO4ElIWa5O6IlAGaVO4ElIWa5O6IlAGaVO4ElIWa5O6IlAGaV001_Nf]JJgY[FVmkJeY[
NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]J001lAGaVO4El
IWa5O6IlAGaVO4ElIWa5O6IlAGaVO4ElIWa5O6IlAGaVO4ElIWa5O6IlAGaVO4ElIWa5O6IlAGaVO4El
IWa5O6IlAGaV001_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_
Nf]JJgY[FVmkJeY[NP00O6IlAGaVO4ElIWa5O6IlAGaVO4ElIWa5O6IlAGaVO4ElIWa5O6IlAGaVO4El
IWa5O6IlAGaVO4ElIWa5O6IlAGaVO4ElIWa5O6IlAGaV001_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_
Nf]JJgY[FVmkJeY[NP00J6]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmk
JeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]j
JeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmk
JeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgX1JeX003A[FP04001lAGa5
O4H3O4D01Ga6O4ElAGa5O4H00ga500ElAWa5O4ElAGa600=lA@05O4IlAGa5O4ElAP03O4D01Ga6O4El
AGa5O4H00ga500<006]JJeX07V]J00@007a5O4ElAP=lA@05O4IlAGa5O4ElAP03O4D01Ga6O4ElAGa5
O4H00ga500ElAWa5O4ElAGa600=lA@05O4IlAGa5O4ElAP03O4D00`00JeY[FP0MJeX01@00O4ElAGa5
O4H00ga500ElAWa5O4ElAGa600=lA@05O4IlAGa5O4ElAP03O4D01Ga6O4ElAGa5O4H00ga500ElAWa5
O4ElAGa600=lA@03001[FV]J07Y[FP000?m[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]j
JeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmk
JeY[NV]JKg/007aVO4ElIWa5O6IlAGaVO4ElIWa5O6IlAGaVO4ElIWa5O6IlAGaVO4ElIWa5O6IlAGaV
O4ElIWa5O6IlAGaVO4ElIWa5O6IlAGaVO4ElIWa5001[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmk
JeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg/007aVO4ElIWa5O6IlAGaVO4ElIWa5O6IlAGaV
O4ElIWa5O6IlAGaVO4ElIWa5O6IlAGaVO4ElIWa5O6IlAGaVO4ElIWa5O6IlAGaVO4ElIWa5001[FVmk
JeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg/007aV
O4ElIWa5O6IlAGaVO4ElIWa5O6IlAGaVO4ElIWa5O6IlAGaVO4ElIWa5O6IlAGaVO4ElIWa5O6IlAGaV
O4ElIWa5O6IlAGaVO4ElIP00JgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg/006Q[
FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[
FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][
FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[
FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmk0F]J000cJeX00`00O4ElAP03O4D01Ga6O4ElAGa5O4H0
0ga500ElAWa5O4ElAGa600=lA@05O4IlAGa5O4ElAP03O4D01Ga6O4ElAGa5O4H00ga500AlAWa5O4D0
01i[FP03001lAGa600=lA@05O4IlAGa5O4ElAP03O4D01Ga6O4ElAGa5O4H00ga500ElAWa5O4ElAGa6
00=lA@05O4IlAGa5O4ElAP03O4D017a6O4ElA@007V]J00<007a5O4H00ga500ElAWa5O4ElAGa600=l
A@05O4IlAGa5O4ElAP03O4D01Ga6O4ElAGa5O4H00ga500ElAWa5O4ElAGa600=lA@03O4IlA@0007a[
FP000?m_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[
FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]J001lAGaVO4ElIWa5O6Il
AGaVO4ElIWa5O6IlAGaVO4ElIWa5O6IlAGaVO4ElIWa5O6IlAGaVO4ElIWa5O6IlAGaVO4ElIWa5O6Il
AGaVO4ElIWa5001[FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][
FV]jJeY_Nf]J001lAGaVO4ElIWa5O6IlAGaVO4ElIWa5O6IlAGaVO4ElIWa5O6IlAGaVO4ElIWa5O6Il
AGaVO4ElIWa5O6IlAGaVO4ElIWa5O6IlAGaVO4ElIWa5001[FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][
FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]J001lAGaVO4ElIWa5O6IlAGaVO4ElIWa5O6Il
AGaVO4ElIWa5O6IlAGaVO4ElIWa5O6IlAGaVO4ElIWa5O6IlAGaVO4ElIWa5O6IlAGaVO4ElIWa5001[
FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgX006Q[FVmkJeY[NV]JKg][FV]jJeY_Nf]J
JgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]J
Kg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]J
JgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]J
Kg][FV]j0F]J000bJeX00`00O4IlA@02O4D01Ga6O4ElAGa5O4H00ga500ElAWa5O4ElAGa600=lA@05
O4IlAGa5O4ElAP03O4D01Ga6O4ElAGa5O4H00ga500IlAWa5O4ElAGa6000MJeX00`00O4IlA@02O4D0
1Ga6O4ElAGa5O4H00ga500ElAWa5O4ElAGa600=lA@05O4IlAGa5O4ElAP03O4D01Ga6O4ElAGa5O4H0
0ga500IlAWa5O4ElAGa6000MJeX00`00O4IlA@02O4D01Ga6O4ElAGa5O4H00ga500ElAWa5O4ElAGa6
00=lA@05O4IlAGa5O4ElAP03O4D01Ga6O4ElAGa5O4H00ga500IlAWa5O4ElAGa6001kJeX0003oJgY[
FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][
FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FP00O4ElIWa5O6IlAGaVO4ElIWa5O6Il
AGaVO4ElIWa5O6IlAGaVO4ElIWa5O6IlAGaVO4ElIWa5O6IlAGaVO4ElIWa5O6IlAGaVO4ElIWa5O6Il
AGaV001_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[
FP00O4ElIWa5O6IlAGaVO4ElIWa5O6IlAGaVO4ElIWa5O6IlAGaVO4ElIWa5O6IlAGaVO4ElIWa5O6Il
AGaVO4ElIWa5O6IlAGaVO4ElIWa5O6IlAGaV001_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[
FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FP00O4ElIWa5O6IlAGaVO4ElIWa5O6IlAGaVO4ElIWa5O6Il
AGaVO4ElIWa5O6IlAGaVO4ElIWa5O6IlAGaVO4ElIWa5O6IlAGaVO4ElIWa5O6IlA@00JeY_Nf]JJgY[
FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmk001XJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]J
Kg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]J
JgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]J
Kg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_N`5[
FP00<V]J00@007a5O4ElAP=lA@05O4IlAGa5O4ElAP03O4D01Ga6O4ElAGa5O4H00ga500ElAWa5O4El
AGa600=lA@05O4IlAGa5O4ElAP03O4D01Ga6O4ElAGa5000076]J00@007a5O4ElAP=lA@05O4IlAGa5
O4ElAP03O4D01Ga6O4ElAGa5O4H00ga500ElAWa5O4ElAGa600=lA@05O4IlAGa5O4ElAP03O4D01Ga6
O4ElAGa5000076]J00@007a5O4ElAP=lA@05O4IlAGa5O4ElAP03O4D01Ga6O4ElAGa5O4H00ga500El
AWa5O4ElAGa600=lA@05O4IlAGa5O4ElAP03O4D017a6O4ElA@00Nf]J0000ofmkJeY[NV]JKg][FV]j
JeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmk
JeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeX007a5O6IlAGaVO4ElIWa5O6IlAGaVO4ElIWa5O6IlAGaV
O4ElIWa5O6IlAGaVO4ElIWa5O6IlAGaVO4ElIWa5O6IlAGaVO4ElIWa5O6IlAGaVO4ElIP00JgY[FVmk
JeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeX007a5O6IlAGaV
O4ElIWa5O6IlAGaVO4ElIWa5O6IlAGaVO4ElIWa5O6IlAGaVO4ElIWa5O6IlAGaVO4ElIWa5O6IlAGaV
O4ElIWa5O6IlAGaVO4ElIP00JgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]j
JeY_Nf]JJgY[FVmk001lIWa5O6IlAGaVO4ElIWa5O6IlAGaVO4ElIWa5O6IlAGaVO4ElIWa5O6IlAGaV
O4ElIWa5O6IlAGaVO4ElIWa5O6IlAGaVO4ElIWa5O6IlAGaVO4D006]JJgY[FVmkJeY[NV]JKg][FV]j
JeY_Nf]JJgY[FVmkJeY[NP00J6]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[
FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][
FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[
FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgX1JeX0039[FP03001l
AWa5009lA@05O4IlAGa5O4ElAP03O4D01Ga6O4ElAGa5O4H00ga500ElAWa5O4ElAGa600=lA@05O4Il
AGa5O4ElAP03O4D01ga6O4ElAGa5O4IlA@0001a[FP03001lAWa5009lA@05O4IlAGa5O4ElAP03O4D0
1Ga6O4ElAGa5O4H00ga500ElAWa5O4ElAGa600=lA@05O4IlAGa5O4ElAP03O4D01ga6O4ElAGa5O4Il
A@0001][FP03001lAGa600=lA@05O4IlAGa5O4ElAP03O4D01Ga6O4ElAGa5O4H00ga500ElAWa5O4El
AGa600=lA@05O4IlAGa5O4ElAP03O4D01Wa6O4ElAGa5O4H007][FP000?m[NV]JKg][FV]jJeY_Nf]J
JgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]J
Kg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]J001lAGaVO4ElIWa5O6IlAGaVO4ElIWa5O6IlAGaVO4ElIWa5
O6IlAGaVO4ElIWa5O6IlAGaVO4ElIWa5O6IlAGaVO4ElIWa5O6IlAGaVO4ElIWa5O6H006mkJeY[NV]J
Kg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]J001lAGaVO4ElIWa5
O6IlAGaVO4ElIWa5O6IlAGaVO4ElIWa5O6IlAGaVO4ElIWa5O6IlAGaVO4ElIWa5O6IlAGaVO4ElIWa5
O6IlAGaVO4ElIWa5O6H006mkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]J
JgY[FVmkJeY[NP00O6IlAGaVO4ElIWa5O6IlAGaVO4ElIWa5O6IlAGaVO4ElIWa5O6IlAGaVO4ElIWa5
O6IlAGaVO4ElIWa5O6IlAGaVO4ElIWa5O6IlAGaVO4ElIWa5001[FVmkJeY[NV]JKg][FV]jJeY_Nf]J
JgY[FVmkJeY[NV]JKg/006Q[FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[
NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_
Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[
NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmk0F]J000bJeX01000O4El
AGa60ga500ElAWa5O4ElAGa600=lA@05O4IlAGa5O4ElAP03O4D01Ga6O4ElAGa5O4H00ga500ElAWa5
O4ElAGa600=lA@05O4IlAGa5O4D0000LJeX01000O4ElAGa60ga500ElAWa5O4ElAGa600=lA@05O4Il
AGa5O4ElAP03O4D01Ga6O4ElAGa5O4H00ga500ElAWa5O4ElAGa600=lA@05O4IlAGa5O4D0000KJeX0
1@00O4ElAGa5O4H00ga500ElAWa5O4ElAGa600=lA@05O4IlAGa5O4ElAP03O4D01Ga6O4ElAGa5O4H0
0ga500ElAWa5O4ElAGa600=lA@04O4IlAGa5001kJeX0003oKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]J
Kg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]J
JgY[FVmkJeY[NV]JKg][FP00O4ElIWa5O6IlAGaVO4ElIWa5O6IlAGaVO4ElIWa5O6IlAGaVO4ElIWa5
O6IlAGaVO4ElIWa5O6IlAGaVO4ElIWa5O6IlAGaVO4ElIWa5O6IlA@00JeY[NV]JKg][FV]jJeY_Nf]J
JgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FP00O4ElIWa5O6IlAGaVO4ElIWa5
O6IlAGaVO4ElIWa5O6IlAGaVO4ElIWa5O6IlAGaVO4ElIWa5O6IlAGaVO4ElIWa5O6IlAGaVO4ElIWa5
O6IlA@00JeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]J
Kg][FP00O4ElIWa5O6IlAGaVO4ElIWa5O6IlAGaVO4ElIWa5O6IlAGaVO4ElIWa5O6IlAGaVO4ElIWa5
O6IlAGaVO4ElIWa5O6IlAGaVO4ElIWa5O6IlA@00JeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]J
Kg][FV]j001XJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_
Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[
NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_
Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NP5[FP00<V]J00<007a6O4D00Wa500El
AWa5O4ElAGa600=lA@05O4IlAGa5O4ElAP03O4D01Ga6O4ElAGa5O4H00ga500ElAWa5O4ElAGa600=l
A@06O4IlAGa5O4ElAP007F]J00<007a6O4D00Wa500ElAWa5O4ElAGa600=lA@05O4IlAGa5O4ElAP03
O4D01Ga6O4ElAGa5O4H00ga500ElAWa5O4ElAGa600=lA@06O4IlAGa5O4ElAP007F]J00<007a6O4D0
0Wa500ElAWa5O4ElAGa600=lA@05O4IlAGa5O4ElAP03O4D01Ga6O4ElAGa5O4H00ga500ElAWa5O4El
AGa600=lA@06O4IlAGa5O4ElAP00Nf]J0000of]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]J
JgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]J
Kg][FV]jJeX007a5O6IlAGaVO4ElIWa5O6IlAGaVO4ElIWa5O6IlAGaVO4ElIWa5O6IlAGaVO4ElIWa5
O6IlAGaVO4ElIWa5O6IlAGaVO4ElIWa5O6IlAGaVO4D006]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]J
Kg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeX007a5O6IlAGaVO4ElIWa5O6IlAGaVO4ElIWa5
O6IlAGaVO4ElIWa5O6IlAGaVO4ElIWa5O6IlAGaVO4ElIWa5O6IlAGaVO4ElIWa5O6IlAGaVO4D006]J
Kg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeX007a5
O6IlAGaVO4ElIWa5O6IlAGaVO4ElIWa5O6IlAGaVO4ElIWa5O6IlAGaVO4ElIWa5O6IlAGaVO4ElIWa5
O6IlAGaVO4ElIWa5O6IlAGaV001[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_N`00
J6]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[
NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_
Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[
NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg/1JeX0039[FP04001lAGa5O4H3O4D01Ga6O4ElAGa5
O4H00ga500ElAWa5O4ElAGa600=lA@05O4IlAGa5O4ElAP03O4D01Ga6O4ElAGa5O4H00ga500AlAWa5
O4D001e[FP04001lAGa5O4H3O4D01Ga6O4ElAGa5O4H00ga500ElAWa5O4ElAGa600=lA@05O4IlAGa5
O4ElAP03O4D01Ga6O4ElAGa5O4H00ga500AlAWa5O4D001e[FP04001lAGa5O4H3O4D01Ga6O4ElAGa5
O4H00ga500ElAWa5O4ElAGa600=lA@05O4IlAGa5O4ElAP03O4D01Ga6O4ElAGa5O4H00ga500=lAWa5
0000O6]J0000ofmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmk
JeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NP00O6IlAGaV
O4ElIWa5O6IlAGaVO4ElIWa5O6IlAGaVO4ElIWa5O6IlAGaVO4ElIWa5O6IlAGaVO4ElIWa5O6IlAGaV
O4ElIWa5O6IlAGaV001_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]j
JeY_Nf]JJgY[FVmkJeY[NP00O6IlAGaVO4ElIWa5O6IlAGaVO4ElIWa5O6IlAGaVO4ElIWa5O6IlAGaV
O4ElIWa5O6IlAGaVO4ElIWa5O6IlAGaVO4ElIWa5O6IlAGaV001_Nf]JJgY[FVmkJeY[NV]JKg][FV]j
JeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NP00O6IlAGaVO4ElIWa5O6IlAGaV
O4ElIWa5O6IlAGaVO4ElIWa5O6IlAGaVO4ElIWa5O6IlAGaVO4ElIWa5O6IlAGaVO4ElIWa5O6IlAGaV
001_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NP00J6]JKg][FV]jJeY_Nf]JJgY[
FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][
FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[
FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][
FV]jJeY_Nf]JJgX1JeX003=[FP05001lAGa5O4ElAP03O4D01Ga6O4ElAGa5O4H00ga500ElAWa5O4El
AGa600=lA@05O4IlAGa5O4ElAP03O4D01Ga6O4ElAGa5O4H00ga500<006]JJeX07F]J00D007a5O4El
AGa600=lA@05O4IlAGa5O4ElAP03O4D01Ga6O4ElAGa5O4H00ga500ElAWa5O4ElAGa600=lA@05O4Il
AGa5O4ElAP03O4D00`00JeY[FP0MJeX01@00O4ElAGa5O4H00ga500ElAWa5O4ElAGa600=lA@05O4Il
AGa5O4ElAP03O4D01Ga6O4ElAGa5O4H00ga500ElAWa5O4ElAGa600=lA@03001[FV]J07Y[FP000?m[
NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_
Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FP00O4ElIWa5O6IlAGaVO4El
IWa5O6IlAGaVO4ElIWa5O6IlAGaVO4ElIWa5O6IlAGaVO4ElIWa5O6IlAGaVO4ElIWa5O6IlAGaVO4D0
06]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[
NV]JKg][FP00O4ElIWa5O6IlAGaVO4ElIWa5O6IlAGaVO4ElIWa5O6IlAGaVO4ElIWa5O6IlAGaVO4El
IWa5O6IlAGaVO4ElIWa5O6IlAGaVO4D006]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[
NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg/007aVO4ElIWa5O6IlAGaVO4ElIWa5O6IlAGaVO4El
IWa5O6IlAGaVO4ElIWa5O6IlAGaVO4ElIWa5O6IlAGaVO4ElIWa5O6IlAGaVO4D006]JJgY[FVmkJeY[
NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg/006Q[FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]j
JeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmk
JeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]j
JeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmk
0F]J000dJeX00`00O4IlA@02O4D01Ga6O4ElAGa5O4H00ga500ElAWa5O4ElAGa600=lA@05O4IlAGa5
O4ElAP03O4D01Ga6O4ElAGa5O4H00ga500=lAP00JeX086]J00<007a6O4D00Wa500ElAWa5O4ElAGa6
00=lA@05O4IlAGa5O4ElAP03O4D01Ga6O4ElAGa5O4H00ga500ElAWa5O4ElAGa600=lA@03O4H006]J
021[FP03001lAWa5009lA@05O4IlAGa5O4ElAP03O4D01Ga6O4ElAGa5O4H00ga500ElAWa5O4ElAGa6
00=lA@05O4IlAGa5O4ElAP03O4D00ga6001[FP1lJeX0003oKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]J
Kg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]J
JgY[FVmkJeY[NV]JKg][FV]jJeY_N`00O6IlAGaVO4ElIWa5O6IlAGaVO4ElIWa5O6IlAGaVO4ElIWa5
O6IlAGaVO4ElIWa5O6IlAGaVO4ElIWa5O6IlAGaVO4ElIP00JgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]J
JgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_N`00O6IlAGaVO4ElIWa5
O6IlAGaVO4ElIWa5O6IlAGaVO4ElIWa5O6IlAGaVO4ElIWa5O6IlAGaVO4ElIWa5O6IlAGaVO4ElIP00
JgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]J
Kg][FV]jJeY_N`00O6IlAGaVO4ElIWa5O6IlAGaVO4ElIWa5O6IlAGaVO4ElIWa5O6IlAGaVO4ElIWa5
O6IlAGaVO4ElIWa5O6IlAGaVO4ElIP00JgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]J
Kg][FV]j001XJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_
Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[
NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_
Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NP5[FP00=F]J00<007a5O4H00ga500El
AWa5O4ElAGa600=lA@05O4IlAGa5O4ElAP03O4D01Ga6O4ElAGa5O4H00ga500MlAWa5O4ElAGa6O4D0
000SJeX00`00O4ElAP03O4D01Ga6O4ElAGa5O4H00ga500ElAWa5O4ElAGa600=lA@05O4IlAGa5O4El
AP03O4D01ga6O4ElAGa5O4IlA@0002=[FP03001lAGa600=lA@05O4IlAGa5O4ElAP03O4D01Ga6O4El
AGa5O4H00ga500ElAWa5O4ElAGa600=lA@07O4IlAGa5O4ElAWa50000OV]J0000of]jJeY_Nf]JJgY[
FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][
FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FP00O4ElIWa5O6IlAGaVO4ElIWa5O6Il
AGaVO4ElIWa5O6IlAGaVO4ElIWa5O6IlAGaVO4ElIWa5O6IlAGaVO4ElIWa5001[FVmkJeY[NV]JKg][
FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[
FP00O4ElIWa5O6IlAGaVO4ElIWa5O6IlAGaVO4ElIWa5O6IlAGaVO4ElIWa5O6IlAGaVO4ElIWa5O6Il
AGaVO4ElIWa5001[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[
FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FP00O4ElIWa5O6IlAGaVO4ElIWa5O6IlAGaVO4ElIWa5O6Il
AGaVO4ElIWa5O6IlAGaVO4ElIWa5O6IlAGaVO4ElIWa5001[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[
FVmkJeY[NV]JKg][FV]jJeY_N`00J6]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]J
Kg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]J
JgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]J
Kg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg/1JeX003M[FP03
001lAGa600=lA@05O4IlAGa5O4ElAP03O4D01Ga6O4ElAGa5O4H00ga500ElAWa5O4ElAGa600=lA@04
O4IlAGa5000UJeX01000O4ElAGa60ga500ElAWa5O4ElAGa600=lA@05O4IlAGa5O4ElAP03O4D01Ga6
O4ElAGa5O4H00ga500AlAWa5O4D002E[FP04001lAGa5O4H3O4D01Ga6O4ElAGa5O4H00ga500ElAWa5
O4ElAGa600=lA@05O4IlAGa5O4ElAP03O4D00ga6O4D00020JeX0001oKg][FV]jJeY_Nf]JJgY[FVmk
JeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]j
JeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FP00O4ElIWa5O6IlAGaVO4ElIWa5O6IlAGaV
O4ElIWa5O6IlAGaVO4ElIWa5O6IlAGaVO4ElIWa5O6IlAGaV001_Nf]JJgY[FVmkJeY[NV]JKg][FV]j
JeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgX00P00
04IlAGaVO4ElIWa5O6IlAGaVO4ElIWa5O6IlAGaVO4ElIWa5O6IlAGaVO4ElIWa5O6IlAGaVO4ElIWa5
O6H006mkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]J
Kg][FV]jJeY_Nf]JJgY[FVmkJeY[NP80002NO4ElIWa5O6IlAGaVO4ElIWa5O6IlAGaVO4ElIWa5O6Il
AGaVO4ElIWa5O6IlAGaVO4ElIWa5O6IlA@00JeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[
FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][
FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[
FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][
FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NP5[FP00>F]J00<007a5O4H0
0ga500ElAWa5O4ElAGa600=lA@05O4IlAGa5O4ElAP03O4D01Ga6O4ElAGa5O4H00Wa500<006]JJeX0
:6]J00<007a5O4H00ga500ElAWa5O4ElAGa600=lA@05O4IlAGa5O4ElAP03O4D01Ga6O4ElAGa5O4H0
0Wa500<006]JJeX0:6]J00<007a5O4H00ga500ElAWa5O4ElAGa600=lA@05O4IlAGa5O4ElAP03O4D0
1Ga6O4ElAGa5O4H00Wa500<006]JJeX0Of]J0000i6]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_
Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[
NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]J001lAGaVO4ElIWa5O6IlAGaVO4ElIWa5O6IlAGaVO4El
IWa5O6IlAGaVO4ElIWa5O6IlAGaV001_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[
NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]J001lAGaVO4El
IWa5O6IlAGaVO4ElIWa5O6IlAGaVO4ElIWa5O6IlAGaVO4ElIWa5O6IlAGaV001_Nf]JJgY[FVmkJeY[
NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_
Nf]JJgY[FVmkJeY[NP00O6IlAGaVO4ElIWa5O6IlAGaVO4ElIWa5O6IlAGaVO4ElIWa5O6IlAGaVO4El
IWa5O6IlA@800021Kg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]J
Kg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]J
JgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]J
Kg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]J
JgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmk005[FP00>f]J0P0000ElAWa5O4ElAGa600=lA@05
O4IlAGa5O4ElAP03O4D01Wa6O4ElAGa5O4IlA@8002i[FP03001lAGa600=lA@05O4IlAGa5O4ElAP03
O4D01Ga6O4ElAGa5O4H00ga500AlAWa5000002e[FP800003O4ElAWa5009lA@05O4IlAGa5O4ElAP03
O4D01Ga6O4ElAGa5O4H00ga500=lAWa50000Q6]J0000DFmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmk
JeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]j
JeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmk001lIWa5O6IlAGaVO4ElIWa5O6IlAGaV
O4ElIWa5O6IlAGaVO4ElIP020000<F]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]J
JgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]J
0080000CO6IlAGaVO4ElIWa5O6IlAGaVO4ElIWa5O6IlAGaVO4ElIWa5O6H00P00035[FVmkJeY[NV]J
Kg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]J
JgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FP0200004gaVO4ElIWa5O6IlAGaVO4ElIWa5O6IlAGaV
O4ElIWa5O6IlAGaV00800024JeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]J
Kg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]J
JgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]J
Kg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]J
JgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]j0F]J000nJeX20003O4D01Ga6
O4ElAGa5O4H00ga500AlAWa5O4ElA@8003E[FP8000=lA@05O4IlAGa5O4ElAP03O4D017a6O4ElAGa5
0P00=F]J0P000ga500ElAWa5O4ElAGa600=lA@04O4IlAGa5O4D20027JeX00010JgY[FVmkJeY[NV]J
Kg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]J
JgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeX70000
17a5O6IlAGaV100003U[FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]J
Kg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]J
JgY[FVmkJeX01P0000ElIWa5O6IlAGaV00@0000iJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]J
Kg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]J
JgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]J00H00005O6IlAGaVO4ElIP040000R6]JJgY[FVmkJeY[NV]J
Kg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]J
JgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]J
Kg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]J
JgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]J
Kg][FV]jJeY_Nf]JJgY[FVmk0F]J0017JeX40013JeX50013JeX5002=JeX0003oKg][FV]jJeY_Nf]J
JgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]J
Kg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]J
JgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]J
Kg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]J
JgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]J
Kg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]J
JgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]J
Kg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]J
JgY[FVmkJeY[NV]JKg][FV]j001XJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[
NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_
Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[
NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NP5[FP00of]JJF]J
0000of]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]J
JgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]J
Kg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]J
JgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]J
Kg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]J
JgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]J
Kg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]J
JgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]J
Kg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_N`00J6]JJgY[FVmkJeY[NV]JKg][FV]jJeY_
Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[
NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_
Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[
NV]JKg/1JeX00?m[FVU[FP000?m_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]J
Kg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]J
JgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]J
Kg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]J
JgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]J
Kg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]J
JgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]J
Kg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]J
JgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgX006Q[FVmkJeY[
NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_
Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[
NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_
Nf]JJgY[FVmkJeY[NV]JKg][FV]j0F]J003oJeYYJeX0003oJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]J
JgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]J
Kg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]J
JgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]J
Kg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]J
JgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]J
Kg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]J
JgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]J
Kg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]J
JgY[FVmk001XJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[
NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_
Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[
NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_N`5[FP00of]JJF]J0000ofmkJeY[NV]J
Kg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]J
JgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]J
Kg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]J
JgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]J
Kg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]J
JgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]J
Kg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]J
JgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]J
Kg][FV]jJeY_Nf]JJgY[FVmkJeY[NP00J6]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_
Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[
NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_
Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgX1JeX00?m[
FVU[FP000?m[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]J
Kg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]J
JgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]J
Kg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]J
JgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]J
Kg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]J
JgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]J
Kg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]J
JgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg/006Q[FV]jJeY_Nf]JJgY[FVmkJeY[
NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_
Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[
NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_
Nf]JJgY[FVmk0F]J003oJeYYJeX0003oKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]J
JgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]J
Kg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]J
JgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]J
Kg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]J
JgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]J
Kg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]J
JgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]J
Kg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]j001XJeY_
Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[
NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_
Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[
NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NP5[FP00of]JJF]J0000of]jJeY_Nf]JJgY[FVmkJeY[NV]J
Kg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]J
JgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]J
Kg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]J
JgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]J
Kg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]J
JgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]J
Kg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]J
JgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]J
Kg][FV]jJeY_N`00J6]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_
Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[
NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_
Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg/1JeX00?m[FVU[FP000?m_Nf]J
JgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]J
Kg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]J
JgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]J
Kg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]J
JgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]J
Kg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]J
JgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]J
Kg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]J
JgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgX006Q[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[
NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_
Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[
NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]j0F]J
003oJeYYJeX0003oJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]J
JgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]J
Kg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]J
JgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]J
Kg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]J
JgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]J
Kg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]J
JgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]J
Kg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmk001XJeY[NV]JKg][FV]jJeY_
Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[
NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_
Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[
NV]JKg][FV]jJeY_N`5[FP00of]JJF]J0000ofmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]J
Kg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]J
JgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]J
Kg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]J
JgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]J
Kg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]J
JgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]J
Kg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]J
JgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NP00
J6]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_
Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[
NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_
Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgX1JeX00?m[FVU[FP000?m[NV]JKg][FV]jJeY_Nf]J
JgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]J
Kg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]J
JgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]J
Kg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]J
JgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]J
Kg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]J
JgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]J
Kg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]J
JgY[FVmkJeY[NV]JKg/006Q[FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[
NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_
Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[
NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmk0F]J003oJeYYJeX0003o
Kg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]J
JgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]J
Kg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]J
JgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]J
Kg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]J
JgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]J
Kg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]J
JgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]J
Kg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]j001XJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_
Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[
NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_
Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[
NP5[FP00of]JJF]J0000of]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]J
Kg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]J
JgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]J
Kg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]J
JgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]J
Kg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]J
JgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]J
Kg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]J
JgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_N`00J6]JJgY[FVmkJeY[
NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_
Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[
NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_
Nf]JJgY[FVmkJeY[NV]JKg/1JeX004I[FP@004A[FP@00=I[FP0003m_Nf]JJgY[FVmkJeY[NV]JKg][
FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[
FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgX01`0000AlIWa5O6Il
A@@0000iJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmk
JeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]j
00L00004O6IlAGaVO4D40000dF]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[
NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_
Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[
NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_
Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[
NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_
Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[
NV]JKg][FV]jJeY_Nf]JJgX00F]J000nJeX00`00O4IlA@02O4D01Ga6O4ElAGa5O4H00ga500=lAWa5
O4D00P00=F]J0P0000ElAWa5O4ElAGa600=lA@05O4IlAGa5O4ElAP02O4D2003@JeX0000lJgY[FVmk
JeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]j
JeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]J0P00019l
IWa5O6IlAGaVO4ElIWa5O6IlAGaVO4ElIWa5O6IlAGaVO4D20000AVmkJeY[NV]JKg][FV]jJeY_Nf]J
JgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]J
Kg][FV]jJeY_Nf]JJgY[FVmkJeX007a5O6IlAGaVO4ElIWa5O6IlAGaVO4ElIWa5O6IlAGaVO4ElIWa5
0P000<e_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[
FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][
FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[
FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][
FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[
FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][
FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_N`01JeX0
03][FP03001lAGa600=lA@05O4IlAGa5O4ElAP03O4D01Ga6O4ElAGa5O4H00ga500=lAP000000;f]J
00<007a5O4H00ga500ElAWa5O4ElAGa600=lA@05O4IlAGa5O4ElAP03O4D00ga60000003<JeX0001D
Kg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]J
JgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeX007a5
O6IlAGaVO4ElIWa5O6IlAGaVO4ElIWa5O6IlAGaVO4ElIWa5O6IlAGaVO4ElIWa50P0004I[NV]JKg][
FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[
FVmkJeY[NV]JKg][FV]jJeY_Nf]J001lAGaVO4ElIWa5O6IlAGaVO4ElIWa5O6IlAGaVO4ElIWa5O6Il
AGaVO4ElIWa5O6IlA@800039JgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]j
JeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmk
JeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]j
JeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmk
JeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]j
JeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmk
JeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]j
005[FP00>F]J00<007a5O4H00ga500ElAWa5O4ElAGa600=lA@05O4IlAGa5O4ElAP03O4D01Ga6O4El
AGa5O4H00Wa500<006]JJeX09f]J0P0000=lAGa6O4D00Wa500ElAWa5O4ElAGa600=lA@05O4IlAGa5
O4ElAP03O4D01Ga6O4ElAGa5O4H00Wa500<006]JJeX0af]J0000of]jJeY_Nf]JJgY[FVmkJeY[NV]J
Kg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]J
JgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeX007a5O6IlAGaVO4ElIWa5O6IlAGaVO4ElIWa5
O6IlAGaVO4ElIWa5O6IlAGaVO4ElIWa5O6IlAGaVO4ElIP00JgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]J
JgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmk001lIWa5
O6IlAGaVO4ElIWa5O6IlAGaVO4ElIWa5O6IlAGaVO4ElIWa5O6IlAGaVO4ElIWa5O6IlAGaVO4ElIP00
JgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]J
Kg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]J
JgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]J
Kg][FV]jJeY_N`00J6]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_
Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[
NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_
Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg/1JeX003M[FP03001lAGa600=l
A@05O4IlAGa5O4ElAP03O4D01Ga6O4ElAGa5O4H00ga500ElAWa5O4ElAGa600=lA@04O4IlAGa5000V
JeX00`00O4ElAP03O4D01Ga6O4ElAGa5O4H00ga500ElAWa5O4ElAGa600=lA@05O4IlAGa5O4ElAP03
O4D017a6O4ElA@00af]J0000ofmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_
Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[
NV]JKg][FP00O4ElIWa5O6IlAGaVO4ElIWa5O6IlAGaVO4ElIWa5O6IlAGaVO4ElIWa5O6IlAGaVO4El
IWa5O6IlAGaVO4ElIWa5O6H006]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[
NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FP00O4ElIWa5O6IlAGaVO4ElIWa5O6IlAGaVO4El
IWa5O6IlAGaVO4ElIWa5O6IlAGaVO4ElIWa5O6IlAGaVO4ElIWa5O6H006]jJeY_Nf]JJgY[FVmkJeY[
NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_
Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[
NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NP00J6]JKg][FV]j
JeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmk
JeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]j
JeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmk
JeY[NV]JKg][FV]jJeY_Nf]JJgX1JeX003I[FP03001lAWa5009lA@05O4IlAGa5O4ElAP03O4D01Ga6
O4ElAGa5O4H00ga500ElAWa5O4ElAGa600=lA@07O4IlAGa5O4ElAWa5000096]J00<007a6O4D00Wa5
00ElAWa5O4ElAGa600=lA@05O4IlAGa5O4ElAP03O4D01Ga6O4ElAGa5O4H00ga500MlAWa5O4ElAGa6
O4D00036JeX0003oJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]J
JgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NP00
O6IlAGaVO4ElIWa5O6IlAGaVO4ElIWa5O6IlAGaVO4ElIWa5O6IlAGaVO4ElIWa5O6IlAGaVO4ElIWa5
O6IlAGaVO4ElIWa5001[FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]J
Kg][FV]jJeY_Nf]JJgY[FVmkJeY[NP00O6IlAGaVO4ElIWa5O6IlAGaVO4ElIWa5O6IlAGaVO4ElIWa5
O6IlAGaVO4ElIWa5O6IlAGaVO4ElIWa5O6IlAGaVO4ElIWa5001[FV]jJeY_Nf]JJgY[FVmkJeY[NV]J
Kg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]J
JgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]J
Kg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmk001XJeY[NV]JKg][FV]jJeY_
Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[
NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_
Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[
NV]JKg][FV]jJeY_N`5[FP00=F]J00D007a5O4ElAGa600=lA@05O4IlAGa5O4ElAP03O4D01Ga6O4El
AGa5O4H00ga500ElAWa5O4ElAGa600=lA@06O4IlAGa5O4ElAP008V]J00D007a5O4ElAGa600=lA@05
O4IlAGa5O4ElAP03O4D01Ga6O4ElAGa5O4H00ga500ElAWa5O4ElAGa600=lA@06O4IlAGa5O4ElAP00
aF]J0000ofmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[
NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]J001lAGaVO4El
IWa5O6IlAGaVO4ElIWa5O6IlAGaVO4ElIWa5O6IlAGaVO4ElIWa5O6IlAGaVO4ElIWa5O6IlAGaVO4El
IWa5O6IlAGaV001_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_
Nf]JJgY[FVmkJeY[NV]J001lAGaVO4ElIWa5O6IlAGaVO4ElIWa5O6IlAGaVO4ElIWa5O6IlAGaVO4El
IWa5O6IlAGaVO4ElIWa5O6IlAGaVO4ElIWa5O6IlAGaV001_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_
Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[
NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_
Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NP00J6]JKg][FV]jJeY_Nf]JJgY[FVmk
JeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]j
JeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmk
JeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]j
JeY_Nf]JJgX1JeX003A[FP04001lAGa5O4H3O4D01Ga6O4ElAGa5O4H00ga500ElAWa5O4ElAGa600=l
A@05O4IlAGa5O4ElAP03O4D01Ga6O4ElAGa5O4H00ga500<006]JJeX07V]J00@007a5O4ElAP=lA@05
O4IlAGa5O4ElAP03O4D01Ga6O4ElAGa5O4H00ga500ElAWa5O4ElAGa600=lA@05O4IlAGa5O4ElAP03
O4D00`00JeY[FP32JeX0003oJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]j
JeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmk
001lIWa5O6IlAGaVO4ElIWa5O6IlAGaVO4ElIWa5O6IlAGaVO4ElIWa5O6IlAGaVO4ElIWa5O6IlAGaV
O4ElIWa5O6IlAGaVO4ElIWa5O6IlA@00JeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmk
JeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmk001lIWa5O6IlAGaVO4ElIWa5O6IlAGaVO4ElIWa5O6IlAGaV
O4ElIWa5O6IlAGaVO4ElIWa5O6IlAGaVO4ElIWa5O6IlAGaVO4ElIWa5O6IlA@00JeY_Nf]JJgY[FVmk
JeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]j
JeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmk
JeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmk001XJeY[NV]JKg][
FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[
FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][
FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[
FVmkJeY[NV]JKg][FV]jJeY_N`5[FP00<f]J00<007a5O4H00ga500ElAWa5O4ElAGa600=lA@05O4Il
AGa5O4ElAP03O4D01Ga6O4ElAGa5O4H00ga500ElAWa5O4ElAGa600=lA@04O4IlAGa5000NJeX00`00
O4ElAP03O4D01Ga6O4ElAGa5O4H00ga500ElAWa5O4ElAGa600=lA@05O4IlAGa5O4ElAP03O4D01Ga6
O4ElAGa5O4H00ga500AlAWa5O4D00<=[FP000?m_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[
FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][
FV]jJeY_Nf]J001lAGaVO4ElIWa5O6IlAGaVO4ElIWa5O6IlAGaVO4ElIWa5O6IlAGaVO4ElIWa5O6Il
AGaVO4ElIWa5O6IlAGaVO4ElIWa5O6IlAGaVO4ElIWa5001[FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][
FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]J001lAGaVO4ElIWa5O6IlAGaVO4ElIWa5O6Il
AGaVO4ElIWa5O6IlAGaVO4ElIWa5O6IlAGaVO4ElIWa5O6IlAGaVO4ElIWa5O6IlAGaVO4ElIWa5001[
FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[
FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][
FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgX0
06Q[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]J
Kg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]J
JgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]J
Kg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]j0F]J000bJeX00`00O4IlA@02O4D01Ga6O4ElAGa5
O4H00ga500ElAWa5O4ElAGa600=lA@05O4IlAGa5O4ElAP03O4D01Ga6O4ElAGa5O4H00ga500IlAWa5
O4ElAGa6000MJeX00`00O4IlA@02O4D01Ga6O4ElAGa5O4H00ga500ElAWa5O4ElAGa600=lA@05O4Il
AGa5O4ElAP03O4D01Ga6O4ElAGa5O4H00ga500IlAWa5O4ElAGa60033JeX0003oJgY[FVmkJeY[NV]J
Kg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]J
JgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FP00O4ElIWa5O6IlAGaVO4ElIWa5O6IlAGaVO4ElIWa5
O6IlAGaVO4ElIWa5O6IlAGaVO4ElIWa5O6IlAGaVO4ElIWa5O6IlAGaVO4ElIWa5O6IlAGaV001_Nf]J
JgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FP00O4ElIWa5
O6IlAGaVO4ElIWa5O6IlAGaVO4ElIWa5O6IlAGaVO4ElIWa5O6IlAGaVO4ElIWa5O6IlAGaVO4ElIWa5
O6IlAGaVO4ElIWa5O6IlAGaV001_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]J
Kg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]J
JgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]J
Kg][FV]jJeY_Nf]JJgY[FVmk001XJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_
Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[
NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_
Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_N`5[FP00<V]J00@0
07a5O4ElAP=lA@05O4IlAGa5O4ElAP03O4D01Ga6O4ElAGa5O4H00ga500ElAWa5O4ElAGa600=lA@05
O4IlAGa5O4ElAP03O4D01Ga6O4ElAGa5000076]J00@007a5O4ElAP=lA@05O4IlAGa5O4ElAP03O4D0
1Ga6O4ElAGa5O4H00ga500ElAWa5O4ElAGa600=lA@05O4IlAGa5O4ElAP03O4D01Ga6O4ElAGa50000
`V]J0000ofmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[
NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeX007a5O6IlAGaVO4El
IWa5O6IlAGaVO4ElIWa5O6IlAGaVO4ElIWa5O6IlAGaVO4ElIWa5O6IlAGaVO4ElIWa5O6IlAGaVO4El
IWa5O6IlAGaVO4ElIP00JgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_
Nf]JJgY[FVmkJeX007a5O6IlAGaVO4ElIWa5O6IlAGaVO4ElIWa5O6IlAGaVO4ElIWa5O6IlAGaVO4El
IWa5O6IlAGaVO4ElIWa5O6IlAGaVO4ElIWa5O6IlAGaVO4ElIP00JgY[FVmkJeY[NV]JKg][FV]jJeY_
Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[
NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_
Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NP00J6]JKg][FV]jJeY_Nf]JJgY[FVmk
JeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]j
JeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmk
JeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]j
JeY_Nf]JJgX1JeX0039[FP03001lAWa5009lA@05O4IlAGa5O4ElAP03O4D01Ga6O4ElAGa5O4H00ga5
00ElAWa5O4ElAGa600=lA@05O4IlAGa5O4ElAP03O4D01ga6O4ElAGa5O4IlA@0001a[FP03001lAWa5
009lA@05O4IlAGa5O4ElAP03O4D01Ga6O4ElAGa5O4H00ga500ElAWa5O4ElAGa600=lA@05O4IlAGa5
O4ElAP03O4D01ga6O4ElAGa5O4IlA@000<9[FP000?m[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]J
Kg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]J
JgY[FVmkJeY[NV]J001lAGaVO4ElIWa5O6IlAGaVO4ElIWa5O6IlAGaVO4ElIWa5O6IlAGaVO4ElIWa5
O6IlAGaVO4ElIWa5O6IlAGaVO4ElIWa5O6IlAGaVO4ElIWa5O6H006mkJeY[NV]JKg][FV]jJeY_Nf]J
JgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]J001lAGaVO4ElIWa5O6IlAGaVO4ElIWa5
O6IlAGaVO4ElIWa5O6IlAGaVO4ElIWa5O6IlAGaVO4ElIWa5O6IlAGaVO4ElIWa5O6IlAGaVO4ElIWa5
O6H006mkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]J
Kg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]J
JgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]J
Kg/006Q[FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_
Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[
NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_
Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmk0F]J000bJeX01000O4ElAGa60ga500ElAWa5
O4ElAGa600=lA@05O4IlAGa5O4ElAP03O4D01Ga6O4ElAGa5O4H00ga500ElAWa5O4ElAGa600=lA@05
O4IlAGa5O4D0000LJeX01000O4ElAGa60ga500ElAWa5O4ElAGa600=lA@05O4IlAGa5O4ElAP03O4D0
1Ga6O4ElAGa5O4H00ga500ElAWa5O4ElAGa600=lA@05O4IlAGa5O4D00032JeX0003oKg][FV]jJeY_
Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[
NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FP00O4ElIWa5O6IlAGaVO4ElIWa5O6IlAGaVO4El
IWa5O6IlAGaVO4ElIWa5O6IlAGaVO4ElIWa5O6IlAGaVO4ElIWa5O6IlAGaVO4ElIWa5O6IlA@00JeY[
NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FP00O4El
IWa5O6IlAGaVO4ElIWa5O6IlAGaVO4ElIWa5O6IlAGaVO4ElIWa5O6IlAGaVO4ElIWa5O6IlAGaVO4El
IWa5O6IlAGaVO4ElIWa5O6IlA@00JeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_
Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[
NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_
Nf]JJgY[FVmkJeY[NV]JKg][FV]j001XJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmk
JeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]j
JeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmk
JeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NP5[FP00<V]J
00<007a6O4D00Wa500ElAWa5O4ElAGa600=lA@05O4IlAGa5O4ElAP03O4D01Ga6O4ElAGa5O4H00ga5
00ElAWa5O4ElAGa600=lA@06O4IlAGa5O4ElAP007F]J00<007a6O4D00Wa500ElAWa5O4ElAGa600=l
A@05O4IlAGa5O4ElAP03O4D01Ga6O4ElAGa5O4H00ga500ElAWa5O4ElAGa600=lA@06O4IlAGa5O4El
AP00`f]J0000of]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]j
JeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeX007a5O6IlAGaV
O4ElIWa5O6IlAGaVO4ElIWa5O6IlAGaVO4ElIWa5O6IlAGaVO4ElIWa5O6IlAGaVO4ElIWa5O6IlAGaV
O4ElIWa5O6IlAGaVO4D006]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmk
JeY[NV]JKg][FV]jJeX007a5O6IlAGaVO4ElIWa5O6IlAGaVO4ElIWa5O6IlAGaVO4ElIWa5O6IlAGaV
O4ElIWa5O6IlAGaVO4ElIWa5O6IlAGaVO4ElIWa5O6IlAGaVO4D006]JKg][FV]jJeY_Nf]JJgY[FVmk
JeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]j
JeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmk
JeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_N`00J6]JJgY[FVmkJeY[NV]JKg][
FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[
FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][
FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[
FVmkJeY[NV]JKg/1JeX0039[FP04001lAGa5O4H3O4D01Ga6O4ElAGa5O4H00ga500ElAWa5O4ElAGa6
00=lA@05O4IlAGa5O4ElAP03O4D01Ga6O4ElAGa5O4H00ga500AlAWa5O4D001e[FP04001lAGa5O4H3
O4D01Ga6O4ElAGa5O4H00ga500ElAWa5O4ElAGa600=lA@05O4IlAGa5O4ElAP03O4D01Ga6O4ElAGa5
O4H00ga500AlAWa5O4D00<=[FP000?m_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[
NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_
Nf]JJgX007aVO4ElIWa5O6IlAGaVO4ElIWa5O6IlAGaVO4ElIWa5O6IlAGaVO4ElIWa5O6IlAGaVO4El
IWa5O6IlAGaVO4ElIWa5O6IlAGaVO4ElIP00Kg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_
Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgX007aVO4ElIWa5O6IlAGaVO4ElIWa5O6IlAGaVO4El
IWa5O6IlAGaVO4ElIWa5O6IlAGaVO4ElIWa5O6IlAGaVO4ElIWa5O6IlAGaVO4ElIP00Kg][FV]jJeY_
Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[
NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_
Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgX006Q[FVmk
JeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]j
JeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmk
JeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]j
JeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]j0F]J000cJeX01@00O4ElAGa5O4H00ga500ElAWa5O4ElAGa6
00=lA@05O4IlAGa5O4ElAP03O4D01Ga6O4ElAGa5O4H00ga500ElAWa5O4ElAGa600=lA@03001[FV]J
01e[FP05001lAGa5O4ElAP03O4D01Ga6O4ElAGa5O4H00ga500ElAWa5O4ElAGa600=lA@05O4IlAGa5
O4ElAP03O4D01Ga6O4ElAGa5O4H00ga500<006]JJeX0`V]J0000of]jJeY_Nf]JJgY[FVmkJeY[NV]J
Kg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]J
JgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]J001lAGaVO4ElIWa5O6IlAGaVO4ElIWa5O6IlAGaVO4ElIWa5
O6IlAGaVO4ElIWa5O6IlAGaVO4ElIWa5O6IlAGaVO4ElIWa5O6IlA@00JeY[NV]JKg][FV]jJeY_Nf]J
JgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]J001lAGaVO4ElIWa5
O6IlAGaVO4ElIWa5O6IlAGaVO4ElIWa5O6IlAGaVO4ElIWa5O6IlAGaVO4ElIWa5O6IlAGaVO4ElIWa5
O6IlA@00JeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]J
Kg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]J
JgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]J
Kg][FV]jJeY_N`00J6]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_
Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[
NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_
Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg/1JeX003A[FP03001lAWa5009l
A@05O4IlAGa5O4ElAP03O4D01Ga6O4ElAGa5O4H00ga500ElAWa5O4ElAGa600=lA@05O4IlAGa5O4El
AP03O4D00ga6001[FP0PJeX00`00O4IlA@02O4D01Ga6O4ElAGa5O4H00ga500ElAWa5O4ElAGa600=l
A@05O4IlAGa5O4ElAP03O4D01Ga6O4ElAGa5O4H00ga500=lAP00JeX0a6]J0000ofmkJeY[NV]JKg][
FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[
FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg/007aVO4ElIWa5O6IlAGaVO4ElIWa5O6Il
AGaVO4ElIWa5O6IlAGaVO4ElIWa5O6IlAGaVO4ElIWa5O6IlAGaVO4ElIWa5O6H006]jJeY_Nf]JJgY[
FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg/0
07aVO4ElIWa5O6IlAGaVO4ElIWa5O6IlAGaVO4ElIWa5O6IlAGaVO4ElIWa5O6IlAGaVO4ElIWa5O6Il
AGaVO4ElIWa5O6H006]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][
FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[
FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][
FV]jJeY_Nf]JJgY[FVmkJeY[NP00J6]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]J
JgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]J
Kg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]J
JgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgX1JeX003E[FP03
001lAGa600=lA@05O4IlAGa5O4ElAP03O4D01Ga6O4ElAGa5O4H00ga500ElAWa5O4ElAGa600=lA@07
O4IlAGa5O4ElAWa500008f]J00<007a5O4H00ga500ElAWa5O4ElAGa600=lA@05O4IlAGa5O4ElAP03
O4D01Ga6O4ElAGa5O4H00ga500MlAWa5O4ElAGa6O4D00036JeX0003oJgY[FVmkJeY[NV]JKg][FV]j
JeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmk
JeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]J001lAGaVO4ElIWa5O6IlAGaVO4ElIWa5O6IlAGaV
O4ElIWa5O6IlAGaVO4ElIWa5O6IlAGaVO4ElIWa5O6IlAGaVO4D006]JKg][FV]jJeY_Nf]JJgY[FVmk
JeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]J001lAGaV
O4ElIWa5O6IlAGaVO4ElIWa5O6IlAGaVO4ElIWa5O6IlAGaVO4ElIWa5O6IlAGaVO4ElIWa5O6IlAGaV
O4D006]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]j
JeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmk
JeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]j
JeY_Nf]JJgY[FVmk001XJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[
FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][
FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[
FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_N`5[FP00=f]J00<007a5O4H0
0ga500ElAWa5O4ElAGa600=lA@05O4IlAGa5O4ElAP03O4D01Ga6O4ElAGa5O4H00ga500AlAWa5O4D0
02E[FP04001lAGa5O4H3O4D01Ga6O4ElAGa5O4H00ga500ElAWa5O4ElAGa600=lA@05O4IlAGa5O4El
AP03O4D017a6O4ElA@00af]J0000EVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]j
JeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmk
JeY[NV]JKg][FV]jJeX007a5O6IlAGaVO4ElIWa5O6IlAGaVO4ElIWa5O6IlAGaVO4ElIWa5O6IlAGaV
O4ElIWa5O6IlAGaVO4D200009fmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_
Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NP0200007Ga5O6IlAGaVO4ElIWa5O6Il
AGaVO4ElIWa5O6IlAGaVO4ElIWa5O6IlAGaVO4ElIWa5O6IlAGaVO4D00P000<M_Nf]JJgY[FVmkJeY[
NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_
Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[
NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_
Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[
NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_
Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[
NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NP01JeX003U[FP800005O4IlAGa5O4ElAP03O4D01Ga6O4El
AGa5O4H00ga500ElAWa5O4ElAGa600=lA@03O4IlA@0002][FP800005O4IlAGa5O4ElAP03O4D01Ga6
O4ElAGa5O4H00ga500ElAWa5O4ElAGa600=lA@03O4IlA@000<Y[FP000?m[NV]JKg][FV]jJeY_Nf]J
JgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]J
Kg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmk001lIWa5O6IlAGaVO4ElIWa5
O6IlAGaVO4ElIWa5O6IlAGaVO4ElIWa5O6IlAGaVO4ElIP00Kg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]J
Kg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]J
JgY[FVmk001lIWa5O6IlAGaVO4ElIWa5O6IlAGaVO4ElIWa5O6IlAGaVO4ElIWa5O6IlAGaVO4ElIP00
Kg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]J
JgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]J
Kg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]J
JgY[FVmkJeY[NV]JKg/006Q[FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[
NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_
Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[
NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmk0F]J000lJeX00`00O4Il
A@02O4D01Ga6O4ElAGa5O4H00ga500ElAWa5O4ElAGa600=lA@04O4IlA@00000^JeX00`00O4ElAP03
O4D01Ga6O4ElAGa5O4H00ga500ElAWa5O4ElAGa600=lA@04O4IlA@00003;JeX0001AKg][FV]jJeY_
Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[
NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg/007aVO4El
IWa5O6IlAGaVO4ElIWa5O6IlAGaVO4ElIWa5O6IlAGaV0080000aJeY_Nf]JJgY[FVmkJeY[NV]JKg][
FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[
FVmkJeY[NV]JKg][FV]jJeX00P0001=lIWa5O6IlAGaVO4ElIWa5O6IlAGaVO4ElIWa5O6IlAGaVO4El
IP020000c6]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][
FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[
FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][
FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[
FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][
FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[
FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NP5[FP00
?V]J100000=lAGa6O4D00Wa500ElAWa5O4ElAGa600=lA@8003E[FP@00003O4ElAWa5009lA@05O4Il
AGa5O4ElAP03O4D2003?JeX00012JgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][
FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[
FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]J3@0003][FV]jJeY_Nf]JJgY[FVmkJeY[NV]J
Kg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]J
JgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]J00d0003@JeY[NV]JKg][FV]jJeY_Nf]J
JgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]J
Kg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]J
JgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]J
Kg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]J
JgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]J
Kg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]J
JgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg/1JeX00?m[FVU[FP000?m_Nf]JJgY[
FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][
FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[
FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][
FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[
FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][
FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[
FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][
FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[
FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgX006Q[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]J
Kg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]J
JgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]J
Kg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]j0F]J003o
JeYYJeX0003oJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[
FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][
FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[
FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][
FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[
FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][
FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[
FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][
FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmk001XJeY[NV]JKg][FV]jJeY_Nf]J
JgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]J
Kg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]J
JgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]J
Kg][FV]jJeY_N`5[FP00of]JJF]J0000ofmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][
FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[
FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][
FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[
FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][
FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[
FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][
FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[
FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NP00J6]J
Kg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]J
JgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]J
Kg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]J
JgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgX1JeX00?m[FVU[FP000?m[NV]JKg][FV]jJeY_Nf]JJgY[
FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][
FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[
FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][
FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[
FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][
FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[
FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][
FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[
FVmkJeY[NV]JKg/006Q[FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]J
Kg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]J
JgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]J
Kg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmk0F]J003oJeYYJeX0003oKg][
FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[
FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][
FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[
FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][
FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[
FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][
FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[
FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][
FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]j001XJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]J
JgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]J
Kg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]J
JgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NP5[
FP00of]JJF]J0000of]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][
FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[
FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][
FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[
FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][
FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[
FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][
FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[
FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_N`00J6]JJgY[FVmkJeY[NV]J
Kg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]J
JgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]J
Kg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]J
JgY[FVmkJeY[NV]JKg/1JeX00?m[FVU[FP000?m_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[
FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][
FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[
FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][
FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[
FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][
FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[
FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][
FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgX0
06Q[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]J
Kg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]J
JgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]J
Kg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]j0F]J003oJeYYJeX0003oJgY[FVmkJeY[NV]JKg][
FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[
FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][
FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[
FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][
FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[
FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][
FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[
FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][
FV]jJeY_Nf]JJgY[FVmk001XJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]J
JgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]J
Kg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]J
JgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_N`5[FP00of]JJF]J0000
ofmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][
FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[
FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][
FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[
FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][
FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[
FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][
FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[
FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NP00J6]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]J
Kg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]J
JgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]J
Kg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]J
JgX1JeX00?m[FVU[FP000?m[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[
FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][
FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[
FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][
FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[
FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][
FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[
FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][
FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg/006Q[FV]jJeY_Nf]J
JgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]J
Kg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]J
JgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]J
Kg][FV]jJeY_Nf]JJgY[FVmk0F]J003oJeYYJeX0003oKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][
FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[
FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][
FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[
FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][
FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[
FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][
FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[
FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][
FV]j001XJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]J
JgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]J
Kg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]J
JgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NP5[FP00of]JJF]J0000of]jJeY_Nf]JJgY[
FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][
FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[
FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][
FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[
FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][
FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[
FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][
FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[
FVmkJeY[NV]JKg][FV]jJeY_N`00J6]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]J
Kg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]J
JgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]J
Kg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg/1JeX00?m[FVU[
FP000?m_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[
FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][
FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[
FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][
FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[
FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][
FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[
FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][
FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgX006Q[FVmkJeY[NV]JKg][FV]jJeY_Nf]J
JgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]J
Kg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]J
JgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]J
Kg][FV]j0F]J003oJeYYJeX0003oJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][
FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[
FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][
FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[
FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][
FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[
FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][
FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[
FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmk001XJeY[NV]J
Kg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]J
JgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]J
Kg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]J
JgY[FVmkJeY[NV]JKg][FV]jJeY_N`5[FP00A6]J2000of]J7F]J0000?fmkJeY[NV]JKg][FV]jJeY_
Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[
NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NP05000027aVO4El
IWa5O6IlAGaVO4D20000of]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]J
Kg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]J
JgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]J
Kg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]J
JgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]J
Kg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]J
JgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]J
Kg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]J
JgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_N`006V]JJgY[FVmkJeY[
NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgX1JeX003i[FP03001lAWa5009l
A@05O4IlAGa5O4ElAP03O4D00ga6O4ElA@02003oJeXIJeX0000lJgY[FVmkJeY[NV]JKg][FV]jJeY_
Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[
NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]J0P00019lIWa5O6IlAGaVO4ElIWa5
O6IlAGaVO4ElIWa5O6IlAGaVO4D20000ofmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][
FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[
FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][
FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[
FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][
FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[
FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][
FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[
FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NP005V]J
Kg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmk0F]J000kJeX00`00O4ElAP03
O4D01Ga6O4ElAGa5O4H00ga500ElAWa5O4ElAGa600=lA@03O4H000000?m[FQE[FP0005A_Nf]JJgY[
FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][
FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FP00O4ElIWa5O6Il
AGaVO4ElIWa5O6IlAGaVO4ElIWa5O6IlAGaVO4ElIWa5O6IlAGaVO4D20000of]jJeY_Nf]JJgY[FVmk
JeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]j
JeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmk
JeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]j
JeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmk
JeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]j
JeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmk
JeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]j
JeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmk
JeY[NV]JKg][FV]jJeY_N`004V]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NP5[FP00
>F]J00<007a5O4H00ga500ElAWa5O4ElAGa600=lA@05O4IlAGa5O4ElAP03O4D01Ga6O4ElAGa5O4H0
0Wa500<006]JJeX0of]J46]J0000of]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmk
JeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]j
JeY_Nf]JJgY[FVmkJeX007a5O6IlAGaVO4ElIWa5O6IlAGaVO4ElIWa5O6IlAGaVO4ElIWa5O6IlAGaV
O4ElIWa5O6IlAGaVO4ElIP00JgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]j
JeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmk
JeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]j
JeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmk
JeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]j
JeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_N`00J6]JJgY[
FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][
FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[
FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][
FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg/1JeX003M[FP03001lAGa600=lA@05O4IlAGa5O4ElAP03O4D0
1Ga6O4ElAGa5O4H00ga500ElAWa5O4ElAGa600=lA@04O4IlAGa5003oJeX@JeX0003oKg][FV]jJeY_
Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[
NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]J001lAGaVO4ElIWa5O6IlAGaVO4El
IWa5O6IlAGaVO4ElIWa5O6IlAGaVO4ElIWa5O6IlAGaVO4ElIWa5O6IlAGaVO4ElIP00JgY[FVmkJeY[
NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_
Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[
NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_
Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[
NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_
Nf]JJgY[FVmkJeY[NV]JKg][FV]j001XJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmk
JeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]j
JeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmk
JeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NP5[FP00=F]J
00<007a5O4H00ga500ElAWa5O4ElAGa600=lA@05O4IlAGa5O4ElAP03O4D01Ga6O4ElAGa5O4H00ga5
00MlAWa5O4ElAGa6O4D0003oJeX?JeX0003oJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[
NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_
Nf]JJgY[FVmkJeY[NP00O6IlAGaVO4ElIWa5O6IlAGaVO4ElIWa5O6IlAGaVO4ElIWa5O6IlAGaVO4El
IWa5O6IlAGaVO4ElIWa5O6IlAGaVO4ElIWa5001[FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_
Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[
NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_
Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[
NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_
Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmk001X
JeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]j
JeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmk
JeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]j
JeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_N`5[FP00=6]J00<007a6O4D00Wa500ElAWa5O4ElAGa6
00=lA@05O4IlAGa5O4ElAP03O4D01Ga6O4ElAGa5O4H00ga500ElAWa5O4ElAGa600=lA@03O4IlA@00
0?m[FPe[FP000?m_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_
Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FP00O4El
IWa5O6IlAGaVO4ElIWa5O6IlAGaVO4ElIWa5O6IlAGaVO4ElIWa5O6IlAGaVO4ElIWa5O6IlAGaVO4El
IWa5O6IlAGaVO4ElIP00Kg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[
NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_
Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[
NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_
Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[
NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgX006Q[FVmkJeY[NV]JKg][FV]j
JeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmk
JeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]j
JeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmk
JeY[NV]JKg][FV]j0F]J000cJeX01@00O4ElAGa5O4H00ga500ElAWa5O4ElAGa600=lA@05O4IlAGa5
O4ElAP03O4D01Ga6O4ElAGa5O4H00ga500ElAWa5O4ElAGa600=lA@03O4H006]J0?m[FP][FP000?m[
NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_
Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg/007aVO4ElIWa5O6IlAGaVO4El
IWa5O6IlAGaVO4ElIWa5O6IlAGaVO4ElIWa5O6IlAGaVO4ElIWa5O6IlAGaVO4ElIWa5O6IlAGaVO4El
IWa5001[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[
NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_
Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[
NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_
Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[
NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg/006Q[FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]j
JeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmk
JeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]j
JeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmk
0F]J000bJeX01000O4ElAGa60ga500ElAWa5O4ElAGa600=lA@05O4IlAGa5O4ElAP03O4D01Ga6O4El
AGa5O4H00ga500ElAWa5O4ElAGa600=lA@04O4IlAGa5003oJeX<JeX0003oKg][FV]jJeY_Nf]JJgY[
FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][
FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FP00O4ElIWa5O6IlAGaVO4ElIWa5O6IlAGaVO4ElIWa5O6Il
AGaVO4ElIWa5O6IlAGaVO4ElIWa5O6IlAGaVO4ElIWa5O6IlAGaVO4ElIWa5O6IlA@00JeY[NV]JKg][
FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[
FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][
FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[
FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][
FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[
FVmkJeY[NV]JKg][FV]j001XJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]J
Kg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]J
JgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]J
Kg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NP5[FP00<V]J00<007a6
O4D00Wa500ElAWa5O4ElAGa600=lA@05O4IlAGa5O4ElAP03O4D01Ga6O4ElAGa5O4H00ga500ElAWa5
O4ElAGa600=lA@06O4IlAGa5O4ElAP00of]J36]J0000of]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]j
JeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmk
JeY[NV]JKg][FV]jJeX007a5O6IlAGaVO4ElIWa5O6IlAGaVO4ElIWa5O6IlAGaVO4ElIWa5O6IlAGaV
O4ElIWa5O6IlAGaVO4ElIWa5O6IlAGaVO4ElIWa5O6IlAGaVO4ElIP00Kg][FV]jJeY_Nf]JJgY[FVmk
JeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]j
JeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmk
JeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]j
JeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmk
JeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]j
JeY_N`00J6]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[
FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][
FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[
FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg/1JeX0039[FP04001lAGa5O4H3O4D01Ga6
O4ElAGa5O4H00ga500ElAWa5O4ElAGa600=lA@05O4IlAGa5O4ElAP03O4D01Ga6O4ElAGa5O4H00ga5
00ElAWa5O4ElA@000?m[FP][FP000?m_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[
NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_
Nf]J001lAGaVO4ElIWa5O6IlAGaVO4ElIWa5O6IlAGaVO4ElIWa5O6IlAGaVO4ElIWa5O6IlAGaVO4El
IWa5O6IlAGaVO4ElIWa5O6IlAGaVO4ElIWa5O6H006]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_
Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[
NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_
Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[
NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_
Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgX006Q[FVmk
JeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]j
JeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmk
JeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]j
JeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]j0F]J000bJeX00`00O4IlA@02O4D01Ga6O4ElAGa5O4H00ga5
00ElAWa5O4ElAGa600=lA@05O4IlAGa5O4ElAP03O4D01Ga6O4ElAGa5O4H00ga500MlAWa5O4ElAGa6
O4D0003oJeX;JeX0003oJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_
Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FP00O4El
IWa5O6IlAGaVO4ElIWa5O6IlAGaVO4ElIWa5O6IlAGaVO4ElIWa5O6IlAGaVO4ElIWa5O6IlAGaVO4El
IWa5O6IlAGaVO4ElIWa5O6IlAGaV001_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[
NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_
Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[
NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_
Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[
NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmk001XJeY[NV]JKg][FV]j
JeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmk
JeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]j
JeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmk
JeY[NV]JKg][FV]jJeY_N`5[FP00<V]J00@007a5O4ElAP=lA@05O4IlAGa5O4ElAP03O4D01Ga6O4El
AGa5O4H00ga500ElAWa5O4ElAGa600=lA@05O4IlAGa5O4ElAP03O4D01Ga6O4ElAGa50000of]J2f]J
0000ofmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]J
Kg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeX007a5O6IlAGaVO4ElIWa5
O6IlAGaVO4ElIWa5O6IlAGaVO4ElIWa5O6IlAGaVO4ElIWa5O6IlAGaVO4ElIWa5O6IlAGaVO4ElIWa5
O6IlAGaVO4D006]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]J
JgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]J
Kg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]J
JgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]J
Kg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]J
JgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NP00J6]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[
NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_
Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[
NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_
Nf]JJgX1JeX0039[FP03001lAWa5009lA@05O4IlAGa5O4ElAP03O4D01Ga6O4ElAGa5O4H00ga500El
AWa5O4ElAGa600=lA@05O4IlAGa5O4ElAP03O4D01Wa6O4ElAGa5O4H00?m[FPa[FP000?m[NV]JKg][
FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[
FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]J001lAGaVO4ElIWa5O6IlAGaVO4ElIWa5O6Il
AGaVO4ElIWa5O6IlAGaVO4ElIWa5O6IlAGaVO4ElIWa5O6IlAGaVO4ElIWa5O6IlAGaVO4ElIWa5001[
FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][
FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[
FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][
FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[
FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][
FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg/006Q[FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]J
JgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]J
Kg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]J
JgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmk0F]J000b
JeX01000O4ElAGa60ga500ElAWa5O4ElAGa600=lA@05O4IlAGa5O4ElAP03O4D01Ga6O4ElAGa5O4H0
0ga500ElAWa5O4ElAGa600=lA@04O4IlAGa5003oJeX<JeX0003oKg][FV]jJeY_Nf]JJgY[FVmkJeY[
NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_
Nf]JJgY[FVmkJeY[NV]JKg][FV]j001lIWa5O6IlAGaVO4ElIWa5O6IlAGaVO4ElIWa5O6IlAGaVO4El
IWa5O6IlAGaVO4ElIWa5O6IlAGaVO4ElIWa5O6IlAGaVO4ElIWa5O6H006mkJeY[NV]JKg][FV]jJeY_
Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[
NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_
Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[
NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_
Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[
NV]JKg][FV]j001XJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]j
JeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmk
JeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]j
JeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NP5[FP00<f]J00D007a5O4ElAGa6
00=lA@05O4IlAGa5O4ElAP03O4D01Ga6O4ElAGa5O4H00ga500ElAWa5O4ElAGa600=lA@05O4IlAGa5
O4ElAP03O4D00`00JeY[FP3oJeX;JeX0003oJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[
NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_
Nf]JJgY[FVmkJeX007a5O6IlAGaVO4ElIWa5O6IlAGaVO4ElIWa5O6IlAGaVO4ElIWa5O6IlAGaVO4El
IWa5O6IlAGaVO4ElIWa5O6IlAGaVO4ElIWa5001[FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_
Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[
NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_
Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[
NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_
Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmk001X
JeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]j
JeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmk
JeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]j
JeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_N`5[FP00=6]J00<007a6O4D00Wa500ElAWa5O4ElAGa6
00=lA@05O4IlAGa5O4ElAP03O4D01Ga6O4ElAGa5O4H00ga500ElAWa5O4ElAGa600=lA@03O4H006]J
0?m[FPe[FP000?m_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_
Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmk001l
IWa5O6IlAGaVO4ElIWa5O6IlAGaVO4ElIWa5O6IlAGaVO4ElIWa5O6IlAGaVO4ElIWa5O6IlAGaVO4El
IWa5O6IlAGaV001[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[
NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_
Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[
NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_
Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[
NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgX006Q[FVmkJeY[NV]JKg][FV]j
JeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmk
JeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]j
JeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmk
JeY[NV]JKg][FV]j0F]J000eJeX00`00O4ElAP03O4D01Ga6O4ElAGa5O4H00ga500ElAWa5O4ElAGa6
00=lA@05O4IlAGa5O4ElAP03O4D01ga6O4ElAGa5O4IlA@000?m[FPm[FP0003I[NV]JKg][FV]jJeY_
Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[
NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeX20000ogaVO4ElIWa5O6IlAGaVO4ElIWa5
O6IlAGaVO4ElIWa5O6IlAGaVO4ElIWa5O6IlAGaVO4ElIWa5O6IlAGaVO4D006]JKg][FV]jJeY_Nf]J
JgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]J
Kg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]J
JgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]J
Kg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]J
JgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]J
Kg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]J
JgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]J
Kg][FV]jJeY_N`00<6]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_
Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_N`5[FP00>6]J00<0
07a6O4D00Wa500ElAWa5O4ElAGa600=lA@05O4IlAGa5O4ElAP03O4D01Ga6O4ElAGa5O4H00ga500Al
AWa5O4D00?m[FQ1[FP0005I_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][
FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[
FVmkJeY[NV]J001lAGaVO4ElIWa5O6IlAGaVO4ElIWa5O6IlAGaVO4ElIWa5O6IlAGaVO4ElIWa5O6Il
AGaVO4ElIWa50P000?m_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]j
JeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmk
JeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]j
JeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmk
JeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]j
JeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmk
JeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]j
JeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmk
JeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgX0011[FVmkJeY[NV]JKg][
FV]jJeY_Nf]JJgY[FVmkJeY[NP5[FP00>F]J0P0000ElAWa5O4ElAGa600=lA@05O4IlAGa5O4ElAP03
O4D01Ga6O4ElAGa5O4H00ga500=lAWa50000of]J4f]J0000>f]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][
FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[
FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg/00P000?mlAGaVO4ElIWa5O6IlAGaVO4El
IWa5O6IlAGaVO4ElIWa5O6IlAGaVO4ElIWa5O6H006mkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[
NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_
Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[
NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_
Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[
NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_
Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[
NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_
Nf]JJgY[FVmkJeX002][NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmk
JeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_N`01JeX003e[FP05001lAGa5O4El
AP03O4D01Ga6O4ElAGa5O4H00ga500IlAWa5O4ElAGa6O4D2003oJeXDJeX0000nKg][FV]jJeY_Nf]J
JgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]J
Kg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FP80000AO6Il
AGaVO4ElIWa5O6IlAGaVO4ElIWa5O6IlAGaVO4ElIP020000of]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[
NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_
Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[
NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_
Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[
NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_
Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[
NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_
Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[
NV]JKg][FP005F]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NP01JeX0041[
FP800003O4ElAWa5009lA@06O4IlAGa5O4ElAWa51000of]J66]J0000@V]jJeY_Nf]JJgY[FVmkJeY[
NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_
Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FP/0003o
JeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmk
JeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]j
JeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmk
JeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]j
JeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmk
JeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]j
JeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmk
JeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]j
JeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]J000KJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[
FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmk005[FP00of]JJF]J0000ofmkJeY[NV]JKg][FV]jJeY_
Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[
NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_
Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[
NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_
Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[
NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_
Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[
NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_
Nf]JJgY[FVmkJeY[NP00J6]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmk
JeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]j
JeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmk
JeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgX1JeX00?m[FVU[FP000?m[
NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_
Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[
NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_
Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[
NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_
Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[
NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_
Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[
NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg/006Q[FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]j
JeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmk
JeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]j
JeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmk
0F]J003oJeYYJeX0003oKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[
NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_
Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[
NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_
Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[
NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_
Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[
NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_
Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]j001XJeY_Nf]JJgY[FVmk
JeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]j
JeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmk
JeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]j
JeY_Nf]JJgY[FVmkJeY[NP5[FP00of]JJF]J0000of]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_
Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[
NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_
Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[
NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_
Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[
NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_
Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[
NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_
N`00J6]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmk
JeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]j
JeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmk
JeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg/1JeX00?m[FVU[FP000?m_Nf]JJgY[FVmkJeY[
NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_
Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[
NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_
Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[
NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_
Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[
NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_
Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[
NV]JKg][FV]jJeY_Nf]JJgX006Q[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]j
JeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmk
JeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]j
JeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]j0F]J003oJeYYJeX0
003oJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[
NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_
Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[
NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_
Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[
NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_
Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[
NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_
Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmk001XJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmk
JeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]j
JeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmk
JeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]j
JeY_N`5[FP00of]JJF]J0000ofmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_
Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[
NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_
Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[
NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_
Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[
NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_
Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[
NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NP00J6]JKg][FV]j
JeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmk
JeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]j
JeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmk
JeY[NV]JKg][FV]jJeY_Nf]JJgX1JeX00?m[FVU[FP000?m[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[
NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_
Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[
NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_
Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[
NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_
Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[
NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_
Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[
NV]JKg/006Q[FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]j
JeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmk
JeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]j
JeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmk0F]J003oJeYYJeX0003oKg][FV]jJeY_
Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[
NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_
Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[
NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_
Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[
NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_
Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[
NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_
Nf]JJgY[FVmkJeY[NV]JKg][FV]j001XJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmk
JeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]j
JeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmk
JeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NP5[FP00of]J
JF]J0000of]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_
Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[
NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_
Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[
NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_
Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[
NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_
Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[
NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_N`00J6]JJgY[FVmkJeY[NV]JKg][FV]j
JeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmk
JeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]j
JeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmk
JeY[NV]JKg/1JeX00?m[FVU[FP000?m_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[
NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_
Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[
NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_
Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[
NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_
Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[
NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_
Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgX006Q[FVmk
JeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]j
JeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmk
JeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]j
JeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]j0F]J003oJeYYJeX0003oJgY[FVmkJeY[NV]JKg][FV]jJeY_
Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[
NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_
Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[
NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_
Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[
NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_
Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[
NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_
Nf]JJgY[FVmk001XJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmk
JeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]j
JeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmk
JeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_N`5[FP00of]JJF]J0000ofmkJeY[
NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_
Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[
NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_
Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[
NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_
Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[
NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_
Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[
NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NP00J6]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]j
JeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmk
JeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]j
JeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgX1JeX0
0?m[FVU[FP000?m[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[
NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_
Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[
NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_
Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[
NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_
Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[
NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_
Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg/006Q[FV]jJeY_Nf]JJgY[FVmk
JeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]j
JeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmk
JeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]j
JeY_Nf]JJgY[FVmk0F]J003oJeYYJeX0003oKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_
Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[
NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_
Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[
NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_
Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[
NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_
Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[
NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]j001X
JeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmk
JeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]j
JeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmk
JeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NP5[FP00of]JJF]J0000of]jJeY_Nf]JJgY[FVmkJeY[
NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_
Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[
NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_
Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[
NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_
Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[
NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_
Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[
NV]JKg][FV]jJeY_N`00J6]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]j
JeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmk
JeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]j
JeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg/1JeX00?m[FVU[FP000?m_
Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[
NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_
Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[
NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_
Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[
NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_
Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[
NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_
Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgX006Q[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmk
JeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]j
JeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmk
JeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]j
0F]J003oJeYYJeX0003oJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_
Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[
NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_
Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[
NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_
Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[
NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_
Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[
NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmk001XJeY[NV]JKg][FV]j
JeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmk
JeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]j
JeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmk
JeY[NV]JKg][FV]jJeY_N`5[FP00of]JJF]J0000ofmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[
NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_
Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[
NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_
Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[
NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_
Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[
NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_
Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[
NP00J6]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]j
JeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmk
JeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]j
JeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgX1JeX00?m[FVU[FP000?m[NV]JKg][FV]jJeY_
Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[
NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_
Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[
NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_
Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[
NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_
Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[
NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_
Nf]JJgY[FVmkJeY[NV]JKg/006Q[FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmk
JeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]j
JeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmk
JeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmk0F]J003oJeYYJeX0
003oKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_
Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[
NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_
Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[
NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_
Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[
NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_
Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[
NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]j001XJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]j
JeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmk
JeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]j
JeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmk
JeY[NP5[FP00of]JJF]J0000of]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[
NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_
Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[
NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_
Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[
NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_
Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[
NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_
Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_N`00J6]JJgY[FVmk
JeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]j
JeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmk
JeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]j
JeY_Nf]JJgY[FVmkJeY[NV]JKg/1JeX00?m[FVU[FP000?m_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_
Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[
NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_
Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[
NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_
Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[
NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_
Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[
NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_
Nf]JJgX006Q[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmk
JeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]j
JeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmk
JeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]j0F]J003oJeYYJeX0003oJgY[FVmkJeY[
NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_
Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[
NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_
Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[
NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_
Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[
NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_
Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[
NV]JKg][FV]jJeY_Nf]JJgY[FVmk001XJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]j
JeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmk
JeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]j
JeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_N`5[FP00of]J
JF]J0000ofmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[
NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_
Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[
NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_
Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[
NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_
Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[
NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_
Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NP00J6]JKg][FV]jJeY_Nf]JJgY[FVmk
JeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]j
JeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmk
JeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]j
JeY_Nf]JJgX1JeX00001\
\>"],
  ImageRangeCache->{{{140.063, 427.063}, {394.063, 107.063}} -> {-2.44016, \
1.86519, 0.0174218, 0.0174218}}]
}, Open  ]],

Cell["\<\
More generally, let H be a set of positive integers. The set of partitions of \
n into parts taken from a set H is computed as follows.\
\>", "Text"],

Cell[BoxData[{
    \(partH[_, 0] := {{}}\), "\[IndentingNewLine]", 
    \(partH[H_, n_] := {}\  /; \ \(\(First[H]\)\(>\)\(n\)\(\n\)\)\), "\n", 
    \(partH[H_, n_] := 
      Module[{h, p, ans}, \[IndentingNewLine]ans = 
          Map[\((h = #; \[IndentingNewLine]p = 
                  partH[Select[H, # \[GreaterEqual] h &], 
                    n - h]; \[IndentingNewLine]Map[Join[{h}, #] &, p])\) &, 
            H]; \[IndentingNewLine]Flatten[ans, 
          1]\ ]\[IndentingNewLine]\), "\[IndentingNewLine]", 
    \(partitions[n_] := partH[Range[n], n]\), "\[IndentingNewLine]", 
    \(partitionsOdd[n_] := 
      partH[Range[1, n, 2], n]\), "\[IndentingNewLine]", 
    \(partitionsDif[n_] := 
      DeleteCases[partitions[n], {___, x_, x_, ___}]\)}], "Input",
  InitializationCell->True],

Cell[CellGroupData[{

Cell[BoxData[
    \(asSum\  /@ \ partitions[5]\  // \ TableForm\)], "Input"],

Cell[BoxData[
    InterpretationBox[GridBox[{
          {
            TagBox[
              RowBox[{"1", "+", 
                TagBox[
                  RowBox[{"1", "+", 
                    TagBox[
                      RowBox[{"1", "+", 
                        TagBox[\(1 + 1\),
                          DisplayForm]}],
                      DisplayForm]}],
                  DisplayForm]}],
              DisplayForm]},
          {
            TagBox[
              RowBox[{"1", "+", 
                TagBox[
                  RowBox[{"1", "+", 
                    TagBox[\(1 + 2\),
                      DisplayForm]}],
                  DisplayForm]}],
              DisplayForm]},
          {
            TagBox[
              RowBox[{"1", "+", 
                TagBox[\(1 + 3\),
                  DisplayForm]}],
              DisplayForm]},
          {
            TagBox[
              RowBox[{"1", "+", 
                TagBox[\(2 + 2\),
                  DisplayForm]}],
              DisplayForm]},
          {
            TagBox[\(1 + 4\),
              DisplayForm]},
          {
            TagBox[\(2 + 3\),
              DisplayForm]},
          {"\<\"5\"\>"}
          },
        RowSpacings->1,
        ColumnSpacings->3,
        RowAlignments->Baseline,
        ColumnAlignments->{Left}],
      TableForm[ {
        DisplayForm[ 
          RowBox[ {"1", "+", 
            DisplayForm[ 
              RowBox[ {"1", "+", 
                DisplayForm[ 
                  RowBox[ {"1", "+", 
                    DisplayForm[ 
                      RowBox[ {"1", "+", "1"}]]}]]}]]}]], 
        DisplayForm[ 
          RowBox[ {"1", "+", 
            DisplayForm[ 
              RowBox[ {"1", "+", 
                DisplayForm[ 
                  RowBox[ {"1", "+", "2"}]]}]]}]], 
        DisplayForm[ 
          RowBox[ {"1", "+", 
            DisplayForm[ 
              RowBox[ {"1", "+", "3"}]]}]], 
        DisplayForm[ 
          RowBox[ {"1", "+", 
            DisplayForm[ 
              RowBox[ {"2", "+", "2"}]]}]], 
        DisplayForm[ 
          RowBox[ {"1", "+", "4"}]], 
        DisplayForm[ 
          RowBox[ {"2", "+", "3"}]], "5"}]]], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(Table[Length[partitions[n]], {n, 10}]\)], "Input"],

Cell[BoxData[
    \({1, 2, 3, 5, 7, 11, 15, 22, 30, 42}\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(\(Show[GraphicsArray[Ferrers\  /@ \ partitions[5]], 
        DisplayFunction \[Rule] $DisplayFunction, 
        GraphicsSpacing \[Rule] {1, 0}];\)\)], "Input"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .07692 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.136054 0.0018315 0.136054 [
[ 0 0 0 0 ]
[ 1 .07692 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .07692 L
0 .07692 L
closepath
clip
newpath
% Start of sub-graphic
p
0.0238095 0.0018315 0.0970696 0.0750916 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 0.166667 0 0.166667 [
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
1 .1 .2 r
.16667 .16667 m
.16667 .16667 .05 0 365.73 arc
F
.16667 .33333 m
.16667 .33333 .05 0 365.73 arc
F
.16667 .5 m
.16667 .5 .05 0 365.73 arc
F
.16667 .66667 m
.16667 .66667 .05 0 365.73 arc
F
.16667 .83333 m
.16667 .83333 .05 0 365.73 arc
F
0 0 0 r
.5 Mabswid
[ ] 0 setdash
newpath
.16667 .16667 .05 0 365.73 arc
s
newpath
.16667 .33333 .05 0 365.73 arc
s
newpath
.16667 .5 .05 0 365.73 arc
s
newpath
.16667 .66667 .05 0 365.73 arc
s
newpath
.16667 .83333 .05 0 365.73 arc
s
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.17033 0.0018315 0.24359 0.0750916 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 0.2 0 0.2 [
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
1 .1 .2 r
.2 .2 m
.2 .2 .06 0 365.73 arc
F
.4 .2 m
.4 .2 .06 0 365.73 arc
F
.2 .4 m
.2 .4 .06 0 365.73 arc
F
.2 .6 m
.2 .6 .06 0 365.73 arc
F
.2 .8 m
.2 .8 .06 0 365.73 arc
F
0 0 0 r
.5 Mabswid
[ ] 0 setdash
newpath
.2 .2 .06 0 365.73 arc
s
newpath
.4 .2 .06 0 365.73 arc
s
newpath
.2 .4 .06 0 365.73 arc
s
newpath
.2 .6 .06 0 365.73 arc
s
newpath
.2 .8 .06 0 365.73 arc
s
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.31685 0.0018315 0.39011 0.0750916 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 0.25 0 0.25 [
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
1 .1 .2 r
.25 .25 m
.25 .25 .075 0 365.73 arc
F
.5 .25 m
.5 .25 .075 0 365.73 arc
F
.75 .25 m
.75 .25 .075 0 365.73 arc
F
.25 .5 m
.25 .5 .075 0 365.73 arc
F
.25 .75 m
.25 .75 .075 0 365.73 arc
F
0 0 0 r
.5 Mabswid
[ ] 0 setdash
newpath
.25 .25 .075 0 365.73 arc
s
newpath
.5 .25 .075 0 365.73 arc
s
newpath
.75 .25 .075 0 365.73 arc
s
newpath
.25 .5 .075 0 365.73 arc
s
newpath
.25 .75 .075 0 365.73 arc
s
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.46337 0.0018315 0.53663 0.0750916 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 0.25 0 0.25 [
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
1 .1 .2 r
.25 .25 m
.25 .25 .075 0 365.73 arc
F
.5 .25 m
.5 .25 .075 0 365.73 arc
F
.25 .5 m
.25 .5 .075 0 365.73 arc
F
.5 .5 m
.5 .5 .075 0 365.73 arc
F
.25 .75 m
.25 .75 .075 0 365.73 arc
F
0 0 0 r
.5 Mabswid
[ ] 0 setdash
newpath
.25 .25 .075 0 365.73 arc
s
newpath
.5 .25 .075 0 365.73 arc
s
newpath
.25 .5 .075 0 365.73 arc
s
newpath
.5 .5 .075 0 365.73 arc
s
newpath
.25 .75 .075 0 365.73 arc
s
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.60989 0.0018315 0.68315 0.0750916 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 0.333333 0 0.333333 [
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
1 .1 .2 r
.33333 .33333 m
.33333 .33333 .1 0 365.73 arc
F
.66667 .33333 m
.66667 .33333 .1 0 365.73 arc
F
1 .33333 m
1 .33333 .1 0 365.73 arc
F
1.33333 .33333 m
1.33333 .33333 .1 0 365.73 arc
F
.33333 .66667 m
.33333 .66667 .1 0 365.73 arc
F
0 0 0 r
.5 Mabswid
[ ] 0 setdash
newpath
.33333 .33333 .1 0 365.73 arc
s
newpath
.66667 .33333 .1 0 365.73 arc
s
newpath
1 .33333 .1 0 365.73 arc
s
newpath
1.33333 .33333 .1 0 365.73 arc
s
newpath
.33333 .66667 .1 0 365.73 arc
s
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.75641 0.0018315 0.82967 0.0750916 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 0.333333 0 0.333333 [
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
1 .1 .2 r
.33333 .33333 m
.33333 .33333 .1 0 365.73 arc
F
.66667 .33333 m
.66667 .33333 .1 0 365.73 arc
F
1 .33333 m
1 .33333 .1 0 365.73 arc
F
.33333 .66667 m
.33333 .66667 .1 0 365.73 arc
F
.66667 .66667 m
.66667 .66667 .1 0 365.73 arc
F
0 0 0 r
.5 Mabswid
[ ] 0 setdash
newpath
.33333 .33333 .1 0 365.73 arc
s
newpath
.66667 .33333 .1 0 365.73 arc
s
newpath
1 .33333 .1 0 365.73 arc
s
newpath
.33333 .66667 .1 0 365.73 arc
s
newpath
.66667 .66667 .1 0 365.73 arc
s
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.90293 0.0018315 0.97619 0.0750916 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 0.5 0 0.5 [
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
1 .1 .2 r
.5 .5 m
.5 .5 .15 0 365.73 arc
F
1 .5 m
1 .5 .15 0 365.73 arc
F
1.5 .5 m
1.5 .5 .15 0 365.73 arc
F
2 .5 m
2 .5 .15 0 365.73 arc
F
2.5 .5 m
2.5 .5 .15 0 365.73 arc
F
0 0 0 r
.5 Mabswid
[ ] 0 setdash
newpath
.5 .5 .15 0 365.73 arc
s
newpath
1 .5 .15 0 365.73 arc
s
newpath
1.5 .5 .15 0 365.73 arc
s
newpath
2 .5 .15 0 365.73 arc
s
newpath
2.5 .5 .15 0 365.73 arc
s
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 22.125},
  ImageMargins->{{35, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X00006a000`40O003h00O0?m[NV]JKg][FV]j
JeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmk
JeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]j
JeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmk
JeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]j
JeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmk
JeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]j
JeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmk
JeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]j
JeY_Nf]JJgY[FVmkJeY[NV]JKg/006Q[FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[
FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][
FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[
FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmk0F]J003oJeYY
JeX0003oKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]j
JeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmk
JeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]j
JeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmk
JeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]j
JeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmk
JeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]j
JeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmk
JeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]j001XJeY_Nf]JJgY[FVmkJeY[NV]JKg][
FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[
FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][
FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[
FVmkJeY[NP5[FP00of]JJF]J00004V]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FP80
000aJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[
NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgX00P0000=[FV]jJeX00P000?m[
NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_
Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[
NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_
Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[
NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_
Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[
NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_
Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[
NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg/001a[FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]j
JeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_N`5[FP004F]J00@007a5O4D0031[FP03001lA@00009[
FP03001lA@0002a[FP8000A[FP8000A[FP<002=[FP<000A[FP800;A[FP00015_Nf]JJgY[FVmkJeY[
NV]JKg][FV]jJeY_Nf]JJgY[FVmk00<0001]Kg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_
Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[
NV]J001lAGaV001_N`00O6IlAGaV001[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_
Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_N`00O6H006mkJeY[
NP00O6H00P0005i[FVmk001lIWa5001[FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[
FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NP00O6IlA@00JeY_Nf]J001lA@00JeY[NV]JKg][
FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[
FVmkJeY[NV]JKg][FV]jJeY_N`800006JeY_Nf]JJgY[FVmk0P0000M[FVmkJeY[NV]JKg][FP020000
1VmkJeY[NV]JKg][FP80000PKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmk
JeY[NV]J001[FV]jJeY_Nf]JJgY[FP800006JgY[FVmkJeY[NV]J0P00045[NV]JKg][FV]jJeY_Nf]J
JgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]J
Kg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]j005[FP00
AF]J0`000V]J0`00:f]J00P007a5O4ElAP00JeX007a60Wa500L006]JJeX007a5O4H0000RJeX02`00
O4ElAGa5001[FP00O4ElAWa50000:V]J00@007a5O4D000A[FP03001lAGa5008000A[FP04001lAGa6
0004JeX00`00O4ElAP02000EJeX01000O4D0000016]J00<007a5O4D00P000f]J00<007a5O4D00P00
@6]J00004V]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FP80001aJgY[FVmkJeY[NV]J
Kg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]J
JgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]J
Kg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]J
JgY[FVmkJeY[NP00O6H006]jJeY_N`00O6IlA@00JeY[NP02000097a5001[FVmkJeY[NV]JKg][FV]j
JeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_N`80002jO4D0
06]JJgY[FP00O4D006]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[
NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]J001lAGaVO4D006]JKg][FP00O4El
IWa5001[FVmkJeY[NP00O6IlAGaV001_Nf]JJgX007aVO4ElIP00Kg][FV]jJeY_Nf]JJgY[FVmkJeY[
NV]JKg][FV]jJeY_Nf]JJgY[FVmk001lIWa5O6H006]jJeY_N`00O6IlAGaV001[NV]JKg/007aVO4El
IWa5001[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[
NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_
Nf]JJgY[FVmk0F]J000AJeX01000O4ElA@00<F]J00<006]JJeX0<F]J00<006]JJeX00f]J0P001F]J
00<006]JJeX08f]J00<006]JJeX00f]J00<006]JJeX0:F]J00<007a5O4H00Wa500H006]JJeX007a5
O4H2O4D01P00JeY[FV]J001lAP=lA@05001[FV]J001lAP03O4D00`00JeY[FP0BJeX01P00O4ElAGa6
O4D0009[FP06001lAGa5O4IlA@000f]J00<007a5O4H00Wa500<006]JJeX07f]J0P002f]J0P002f]J
0P000V]J00004FmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg/00`000?m_Nf]JJgY[FVmk
JeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]j
JeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_N`00O6H006mkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmk
JeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]j
JeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmk
JeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]j
JeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmk
JeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]j001lIWa5O6H006mkJeY[NP00O6IlAGaV
O4D006]JJgY[FP00O4ElIWa5001[FV]jJeX007a5O6IlAGaV001[NV]JKg][FV]jJeY_Nf]JJgY[FVmk
JeY[NV]JKg][FV]jJeY_Nf]J000003UlAGaVO4D006]JKg][FP00O4ElIWa5001[FVmkJeY[NP00O6Il
AGaV001_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[
FVmkJeY[NV]JKg/007aVO4D00P0000M[NV]JKg][FV]jJeY_N`0200002ga5O6H00000JeY_Nf]JJgY[
FVmkJeX00P0000=lIWa500000F]J0014JeX01000O4ElA@00<V]J00<006]JJeX0;f]J0P001F]J00<0
06]JJeX0:V]J00@007a5O4D000A[FP800003O4ElAP0000=[FP800003O4ElAP0000A[FP800003O4Il
A@0001A[FP80009lA@03001[FV]J009[FP800003O4D006]J00=[FP80009lA@03001[FV]J01i[FP04
001lAGa5O4H2O4D00`00JeY[FP04JeX00`00O4ElAP03O4D00`00JeY[FP04JeX00`00O4IlA@02O4D1
0000000BJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]J0P00035[NV]JKg][FV]jJeY_
Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[
NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NP030000VF]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_
Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[
NV]JKg][FV]j001lIP00JgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_
Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_N`00O6IlA@00JeY[
NV]J001lA@00JeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_
Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NP0200001f]JJgY[FVmkJeY[NV]J0080
0006JgY[FVmkJeY[NV]J0P0000M[NV]JKg][FV]jJeY_N`0200005f]JKg][FV]jJeY_Nf]JJgY[FVmk
JeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeX00P0000m_Nf]JJgY[FVmkJeY[NP00Kg][FV]jJeY_Nf]J
JgX00P00041[FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]j
JeY_Nf]JJgY[FVmkJeX007a5O6IlAGaVO4D006]JJgY[FVmkJeX007a5O6IlAGaVO4ElIP00JgY[FVmk
JeY[NP00O6IlAGaVO4ElIP4000004F]J00@007a5O4D006=[FP05001lAWa5O4D0000^JeX01`00O4El
AWa5001[FP0000=lA@03001[FV]J08m[FP03001lAGa600=lA@03O4IlA@0000A[FP03001lAWa5009l
A@04O4IlAGa50004JeX01@00O4ElAGa5O4H00Wa500004FmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmk
JeY[NV]JKg/00`000?m_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]j
JeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]J001[FVmk
JeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]j
JeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FP00O4ElIP00Kg][FV]jJeY_Nf]JJgY[FVmk
JeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]j
JeY_Nf]JJgY[FVmkJeY[NP00O6IlA@00JeY_N`00O6IlA@00JeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmk
JeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]j
JeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmk
JeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgX004Q[FVmkJeY[NV]JKg][
FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[
FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NP00O6IlAGaVO4ElIWa5O6H006mkJeY[NV]J001l
AGaVO4ElIWa5O6H200002V]JJgY[FVmk001lIWa5O6IlAGaV0Ga50015JeX00`00O4D0000aJeX3000_
JeX40003JeX3000/JeX2000aJeX00`00JeY[FP05JeX2000ZJeX01000O4ElAGa60Wa500<006]JJeX0
16]J00<007a5O4H00ga500<006]JJeX016]J00<007a6O4D00Wa50@000000of]jJeY_Nf]JJgY[FVmk
JeY[NV]JKg][FV]jJeY_Nf]JJgY[FP00JeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]j
JeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmk
JeX007a5O6H006]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]j
JeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmk
JeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]j
JeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmk
JeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]j
JeY_Nf]JJgY[FVmkJeX007a5O6H006]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmk
JeY[NV]JKg][FV]jJeY_N`005V]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg/0
07aV0P0000M[FV]jJeY_N`00O6IlA@020000:6]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]J
JgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]J0P0000=lIWa5O6H0
0P0000I[FV]jJeY_Nf]JJgX200002ga5O6IlA@00JeY[NV]JKg][FV]jJeX00P0000=lIWa500000@00
000AJeX01000O4D00000<6]J0`00Uf]J00<007a5O4H00Wa500<006]JJeX0:f]J00H007a5O4ElAWa5
0002JeX01P00O4ElAGa6O4D002Y[FP<000Y[FP<000Y[FP80009[FP0001=_Nf]JJgY[FVmkJeY[NV]J
Kg][FV]jJeY_Nf]JJgY[FVmk001lIP020000I6]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmk
JeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]j
JeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmk
JeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmk0`0002m_Nf]JJgY[
FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][
FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]j00@0000dJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_
Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[
NV]JKg][FV]j001lIWa5O6H20000<F]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]J
Kg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FP00O4ElIWa5
00800006Kg][FP00O4ElIWa50P0004M_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[
NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_
Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]j005[FP004V]J00<006]J
JeX0<F]J00<006]JJeX0;f]J00D007a5O4ElAP0002i[FP05001lAGa5O4D0000`JeX01000O4ElA@00
;V]J0P000Wa500<006]JJeX00V]J0P0000=lA@00JeX0B6]J0000hF]jJeY_Nf]JJgY[FVmkJeY[NV]J
Kg][FV]jJeY_Nf]JJgY[FP00JeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]J
JgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NP00
O6H006]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]J
JgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FP00O4ElIWa5001[FVmkJeY[NV]J
Kg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]J
JgY[FVmkJeY[NV]JKg][FV]jJeY_N`00O6IlAGaV001[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]J
Kg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]J
JgY[FVmkJeY[NP020000<F]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]j
JeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]J0080001A
Kg][FV]jJeY_Nf]JJgX006mkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]J
JgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]J
Kg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmk005[FP004V]J0P00<6]J00@0
07a6O4D0035[FP<002m[FP@00;U[FP0004E_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmk
001lIWa5001[FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]j
JeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg/00`000?m_Nf]JJgY[FVmk
JeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]j
JeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmk
JeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]j
JeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmk
JeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]j
JeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmk
JeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]j
JeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmk
JeY[NV]JKg][FV]jJeY_Nf]JJgX0021[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][
FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]j0F]J000AJeX3003oJeYEJeX0003oJgY[FVmkJeY[NV]J
Kg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]J
JgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]J
Kg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]J
JgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]J
Kg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]J
JgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]J
Kg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]J
JgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]J
Kg][FV]jJeY_Nf]JJgY[FVmk001XJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_
Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[
NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_
Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_N`5[FP00of]JJF]J
0000ofmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]J
Kg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]J
JgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]J
Kg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]J
JgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]J
Kg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]J
JgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]J
Kg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]J
JgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NP00J6]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[
NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_
Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[
NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_
Nf]JJgX1JeX00001\
\>"],
  ImageRangeCache->{{{140.063, 427.063}, {377.625, 356.5}} -> {-4.08899, \
9.52756, 0.026763, 0.026763}, {{152.75, 172.875}, {377.063, 357}} -> \
{-45.692, 106.449, 0.299068, 0.299068}, {{193, 213.125}, {377.063, 357}} -> \
{-48.108, 88.708, 0.249224, 0.249224}, {{233.25, 253.375}, {377.063, 357}} -> \
{-46.5114, 70.9664, 0.199379, 0.199379}, {{273.5, 293.563}, {377.063, 357}} -> \
{-54.5302, 70.9664, 0.199379, 0.199379}, {{313.688, 333.813}, {377.063, 357}} -> \
{-46.9117, 53.2249, 0.149534, 0.149534}, {{353.938, 374.063}, {377.063, 357}} -> \
{-52.9305, 53.2249, 0.149534, 0.149534}, {{394.188, 414.313}, {377.063, 357}} -> \
{-39.2995, 35.4832, 0.0996895, 0.0996895}}]
}, Open  ]],

Cell[TextData[{
  "The generating function for the size of set ",
  StyleBox["partH", "InlineInput"],
  " is:"
}], "Text"],

Cell[BoxData[
    \(f[H_] := Times\  @@ \ \((\(\((1\/\(1 - x\^#\))\) &\) /@ H)\)\)], "Input",\

  InitializationCell->True],

Cell[CellGroupData[{

Cell[BoxData[
    \(f[Range[11]] + O[x]\^11\)], "Input"],

Cell[BoxData[
    InterpretationBox[
      RowBox[{
      "1", "+", "x", "+", \(2\ x\^2\), "+", \(3\ x\^3\), "+", \(5\ x\^4\), 
        "+", \(7\ x\^5\), "+", \(11\ x\^6\), "+", \(15\ x\^7\), 
        "+", \(22\ x\^8\), "+", \(30\ x\^9\), "+", \(42\ x\^10\), "+", 
        InterpretationBox[\(O[x]\^11\),
          SeriesData[ x, 0, {}, 0, 11, 1]]}],
      SeriesData[ 
      x, 0, {1, 1, 2, 3, 5, 7, 11, 15, 22, 30, 42}, 0, 11, 1]]], "Output"]
}, Open  ]],

Cell[TextData[{
  "This is the fastest way of computing the number of partitions. If we use \
",
  StyleBox["Length[partitions[200]]", "InlineInput"],
  ", for instance, we most probably will produce an error."
}], "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(\(Plot[
        Evaluate[Table[Normal[f[Range[n]] + O[x]\^6], {n, 5}]], {x, \(-3\), 
          3}];\)\)], "Input"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.15873 0.289353 0.00354495 [
[.02381 .27685 -6 -9 ]
[.02381 .27685 6 0 ]
[.18254 .27685 -6 -9 ]
[.18254 .27685 6 0 ]
[.34127 .27685 -6 -9 ]
[.34127 .27685 6 0 ]
[.65873 .27685 -3 -9 ]
[.65873 .27685 3 0 ]
[.81746 .27685 -3 -9 ]
[.81746 .27685 3 0 ]
[.97619 .27685 -3 -9 ]
[.97619 .27685 3 0 ]
[.4875 .02348 -18 -4.5 ]
[.4875 .02348 0 4.5 ]
[.4875 .11211 -18 -4.5 ]
[.4875 .11211 0 4.5 ]
[.4875 .20073 -18 -4.5 ]
[.4875 .20073 0 4.5 ]
[.4875 .37798 -12 -4.5 ]
[.4875 .37798 0 4.5 ]
[.4875 .4666 -12 -4.5 ]
[.4875 .4666 0 4.5 ]
[.4875 .55522 -12 -4.5 ]
[.4875 .55522 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 .28935 m
.02381 .2956 L
s
[(-3)] .02381 .27685 0 1 Mshowa
.18254 .28935 m
.18254 .2956 L
s
[(-2)] .18254 .27685 0 1 Mshowa
.34127 .28935 m
.34127 .2956 L
s
[(-1)] .34127 .27685 0 1 Mshowa
.65873 .28935 m
.65873 .2956 L
s
[(1)] .65873 .27685 0 1 Mshowa
.81746 .28935 m
.81746 .2956 L
s
[(2)] .81746 .27685 0 1 Mshowa
.97619 .28935 m
.97619 .2956 L
s
[(3)] .97619 .27685 0 1 Mshowa
.125 Mabswid
.05556 .28935 m
.05556 .2931 L
s
.0873 .28935 m
.0873 .2931 L
s
.11905 .28935 m
.11905 .2931 L
s
.15079 .28935 m
.15079 .2931 L
s
.21429 .28935 m
.21429 .2931 L
s
.24603 .28935 m
.24603 .2931 L
s
.27778 .28935 m
.27778 .2931 L
s
.30952 .28935 m
.30952 .2931 L
s
.37302 .28935 m
.37302 .2931 L
s
.40476 .28935 m
.40476 .2931 L
s
.43651 .28935 m
.43651 .2931 L
s
.46825 .28935 m
.46825 .2931 L
s
.53175 .28935 m
.53175 .2931 L
s
.56349 .28935 m
.56349 .2931 L
s
.59524 .28935 m
.59524 .2931 L
s
.62698 .28935 m
.62698 .2931 L
s
.69048 .28935 m
.69048 .2931 L
s
.72222 .28935 m
.72222 .2931 L
s
.75397 .28935 m
.75397 .2931 L
s
.78571 .28935 m
.78571 .2931 L
s
.84921 .28935 m
.84921 .2931 L
s
.88095 .28935 m
.88095 .2931 L
s
.9127 .28935 m
.9127 .2931 L
s
.94444 .28935 m
.94444 .2931 L
s
.25 Mabswid
0 .28935 m
1 .28935 L
s
.5 .02348 m
.50625 .02348 L
s
[(-75)] .4875 .02348 1 0 Mshowa
.5 .11211 m
.50625 .11211 L
s
[(-50)] .4875 .11211 1 0 Mshowa
.5 .20073 m
.50625 .20073 L
s
[(-25)] .4875 .20073 1 0 Mshowa
.5 .37798 m
.50625 .37798 L
s
[(25)] .4875 .37798 1 0 Mshowa
.5 .4666 m
.50625 .4666 L
s
[(50)] .4875 .4666 1 0 Mshowa
.5 .55522 m
.50625 .55522 L
s
[(75)] .4875 .55522 1 0 Mshowa
.125 Mabswid
.5 .04121 m
.50375 .04121 L
s
.5 .05893 m
.50375 .05893 L
s
.5 .07666 m
.50375 .07666 L
s
.5 .09438 m
.50375 .09438 L
s
.5 .12983 m
.50375 .12983 L
s
.5 .14756 m
.50375 .14756 L
s
.5 .16528 m
.50375 .16528 L
s
.5 .183 m
.50375 .183 L
s
.5 .21845 m
.50375 .21845 L
s
.5 .23618 m
.50375 .23618 L
s
.5 .2539 m
.50375 .2539 L
s
.5 .27163 m
.50375 .27163 L
s
.5 .30708 m
.50375 .30708 L
s
.5 .3248 m
.50375 .3248 L
s
.5 .34253 m
.50375 .34253 L
s
.5 .36025 m
.50375 .36025 L
s
.5 .3957 m
.50375 .3957 L
s
.5 .41343 m
.50375 .41343 L
s
.5 .43115 m
.50375 .43115 L
s
.5 .44888 m
.50375 .44888 L
s
.5 .48433 m
.50375 .48433 L
s
.5 .50205 m
.50375 .50205 L
s
.5 .51977 m
.50375 .51977 L
s
.5 .5375 m
.50375 .5375 L
s
.5 .00576 m
.50375 .00576 L
s
.5 .57295 m
.50375 .57295 L
s
.5 .59067 m
.50375 .59067 L
s
.5 .6084 m
.50375 .6084 L
s
.25 Mabswid
.5 0 m
.5 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.09141 0 m
.10458 .04769 L
.14264 .14846 L
.16305 .18662 L
.18163 .21374 L
.20078 .23544 L
.22156 .25314 L
.2414 .26549 L
.25153 .2704 L
.26243 .27481 L
.27263 .27822 L
.28196 .28081 L
.30026 .28469 L
.31011 .28624 L
.31925 .2874 L
.32992 .28847 L
.33997 .28926 L
.34983 .28987 L
.36049 .29037 L
.37018 .29072 L
.3791 .29097 L
.39792 .29136 L
.40861 .29152 L
.41859 .29165 L
.45749 .29215 L
.47731 .29245 L
.49886 .29287 L
.51955 .2934 L
.5387 .29404 L
.55737 .29489 L
.56811 .29552 L
.57797 .29622 L
.59731 .29803 L
.60747 .29927 L
.61817 .30086 L
.63791 .30475 L
.65628 .30982 L
.67674 .31765 L
.69532 .32736 L
.71451 .34071 L
.73531 .35999 L
.75518 .38424 L
.77623 .41757 L
.7958 .45718 L
.81411 .50321 L
s
.81411 .50321 m
.84754 .61803 L
s
.16173 0 m
.16305 .00705 L
.18163 .084 L
.2016 .14732 L
.22004 .19121 L
.23877 .22428 L
.24954 .23901 L
.25939 .25016 L
.2788 .26676 L
.28951 .27341 L
.29968 .2784 L
.30927 .2821 L
.31949 .28517 L
.32913 .28736 L
.33787 .28887 L
.3479 .29015 L
.35712 .29098 L
.36195 .29131 L
.36725 .2916 L
.37278 .29183 L
.37794 .292 L
.38295 .29212 L
.38559 .29217 L
.38839 .29222 L
.39084 .29225 L
.39353 .29228 L
.39602 .2923 L
.39829 .29232 L
.40054 .29233 L
.4029 .29234 L
.40413 .29234 L
.40527 .29234 L
.40652 .29235 L
.40722 .29235 L
.40786 .29235 L
.40903 .29235 L
.41029 .29235 L
.4114 .29235 L
.41257 .29235 L
.41362 .29235 L
.41461 .29235 L
.41569 .29235 L
.41685 .29235 L
.42698 .29233 L
.42974 .29233 L
.43233 .29233 L
.43377 .29233 L
.43532 .29233 L
.436 .29232 L
.43673 .29232 L
Mistroke
.43802 .29232 L
.43927 .29232 L
.43996 .29232 L
.4406 .29232 L
.44183 .29232 L
.443 .29232 L
.44366 .29233 L
.44436 .29233 L
.44561 .29233 L
.44697 .29233 L
.44845 .29233 L
.45086 .29234 L
.45345 .29235 L
.45813 .29236 L
.4631 .29239 L
.46772 .29243 L
.47821 .29253 L
.48842 .29267 L
.49932 .29288 L
.50959 .29314 L
.5207 .2935 L
.5312 .29394 L
.54087 .29446 L
.55059 .29512 L
.55967 .2959 L
.56963 .29698 L
.58032 .29848 L
.59048 .3003 L
.60154 .30284 L
.61198 .30591 L
.62165 .30945 L
.64029 .31869 L
.65091 .32572 L
.66089 .33376 L
.68104 .35521 L
.69954 .38259 L
.71844 .42032 L
.73913 .47589 L
.75872 .54562 L
Mfstroke
.75872 .54562 m
.7743 .61803 L
s
.20138 0 m
.22156 .09095 L
.2414 .1564 L
.25153 .18247 L
.26243 .20584 L
.27263 .22391 L
.28196 .23764 L
.30026 .2581 L
.31011 .26621 L
.31925 .27225 L
.32928 .27752 L
.33997 .28182 L
.35025 .28492 L
.36138 .28737 L
.37189 .28901 L
.38155 .29008 L
.38625 .29047 L
.39129 .29083 L
.40038 .29131 L
.40593 .29153 L
.41118 .29169 L
.41587 .29181 L
.42104 .29191 L
.43069 .29205 L
.44095 .29216 L
.45937 .29232 L
.47872 .29253 L
.4896 .29269 L
.49957 .29289 L
.50937 .29313 L
.5185 .29343 L
.5285 .29384 L
.5392 .29444 L
.54944 .2952 L
.56054 .29632 L
.57103 .29774 L
.58069 .29948 L
.59039 .30173 L
.59946 .30442 L
.60941 .30815 L
.6201 .31329 L
.63023 .31947 L
.64127 .32796 L
.65182 .33814 L
.66137 .3494 L
.68108 .38023 L
.6919 .4024 L
.70207 .42735 L
.72219 .49062 L
.74067 .56863 L
Mistroke
Mfstroke
.74067 .56863 m
.74963 .61803 L
s
.20893 0 m
.22156 .06563 L
.2414 .14069 L
.25153 .17044 L
.26243 .19701 L
.27263 .21746 L
.28196 .23292 L
.30026 .25581 L
.31011 .26478 L
.31925 .27143 L
.32928 .27716 L
.33997 .28179 L
.35025 .28508 L
.35566 .28644 L
.36138 .28763 L
.36639 .28851 L
.37189 .2893 L
.38155 .29036 L
.38679 .29078 L
.39176 .2911 L
.39627 .29134 L
.40106 .29154 L
.40626 .29172 L
.41108 .29184 L
.41626 .29194 L
.42198 .29203 L
.42689 .29209 L
.43207 .29214 L
.44132 .2922 L
.45141 .29227 L
.46218 .29235 L
.47252 .29245 L
.48192 .29257 L
.49137 .29272 L
.50029 .2929 L
.51001 .29315 L
.5203 .2935 L
.52909 .29388 L
.53875 .29442 L
.54892 .29519 L
.5582 .29614 L
.56892 .2976 L
.57909 .29949 L
.58871 .30184 L
.59894 .30511 L
.60859 .30912 L
.61734 .31368 L
.63662 .32776 L
.64748 .33878 L
.65746 .35137 L
Mistroke
.67632 .38312 L
.68702 .40677 L
.697 .43323 L
.71739 .50321 L
.73596 .58972 L
Mfstroke
.73596 .58972 m
.74057 .61803 L
s
.22051 0 m
.22156 .00675 L
.2414 .1 L
.25153 .13712 L
.26243 .17038 L
.27263 .19608 L
.28196 .21559 L
.30026 .24462 L
.31011 .25609 L
.31925 .26464 L
.32928 .27206 L
.33997 .2781 L
.35025 .28243 L
.35566 .28423 L
.36138 .28583 L
.36639 .28701 L
.37189 .28809 L
.38155 .28954 L
.38679 .29013 L
.39176 .29058 L
.40106 .29121 L
.40626 .29146 L
.41108 .29164 L
.41636 .2918 L
.42198 .29193 L
.42686 .29201 L
.43135 .29208 L
.44145 .29218 L
.45973 .29233 L
.46888 .29241 L
.47865 .29253 L
.48937 .29269 L
.49935 .29288 L
.50959 .29314 L
.5207 .29351 L
.53118 .29398 L
.54085 .29457 L
.55054 .29535 L
.55961 .29633 L
.56956 .29776 L
.58025 .29986 L
.59038 .30253 L
.60143 .30643 L
.61186 .31132 L
.62153 .31716 L
.63212 .32532 L
.64209 .33503 L
.66071 .35982 L
.6705 .37714 L
.68083 .39933 L
Mistroke
.69931 .45111 L
.71899 .52746 L
Mfstroke
.71899 .52746 m
.73627 .61803 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{35, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0000gQ000`40O003h00O8F]J00<006]JJeX0
5V]J00<006]JJeX02f]J00@006]JJeX000=[FP03001[FV]J065[FP03001[FV]J0;9[FP000?m_Nf]J
JgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]J
Kg/006]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FP00JeY_Nf]J
JgY[FVmkJeY[NV]JKg][FV]jJeX006]JJgX006mkJeY[NP00Kg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]J
Kg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]J
JgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]J
Kg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]j001_Nf]J
JgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]J
Kg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]J
JgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgX006Q[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[
NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_
Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[
NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]j0F]J
000QJeX00`00JeY[FP0FJeX00`00JeY[FP0;JeX01000JeY[FP000f]J00<006]JJeX0HF]J0P00/f]J
0000of]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]J
JgY[FVmkJeY[NV]J001[FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]J
001[FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]j001_Nf]J001[FVmk001[NV]JKg][FV]jJeY_Nf]J
JgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]J
Kg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]J
JgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]J
Kg/006]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]J
JgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]J
Kg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_N`00J6]JJgY[FVmkJeY[NV]JKg][FV]jJeY_
Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[
NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_
Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[
NV]JKg/1JeX0029[FP03001[FV]J01E[FP03001[FV]J00a[FP04001[FV]J0002JeX00`00JeY[FP1Q
JeX00`00JeY[FP2bJeX0003oKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmk
JeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeX006]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]j
JeY_Nf]JJgY[FVmkJeY[NP00Kg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg/006]jJeX006]JJgX006mk
JeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]j
JeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmk
JeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]j
JeY_Nf]JJgY[FVmkJeY[NP00Kg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmk
JeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]j
JeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]j001XJeY_Nf]JJgY[
FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][
FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[
FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][
FV]jJeY_Nf]JJgY[FVmkJeY[NP5[FP008V]J00<006]JJeX05V]J00<006]JJeX02f]J00@006]JJeX0
00=[FP03001[FV]J051[FP03001[FV]J00=[FP@000I[FP03001[FV]J0;9[FP000?m[NV]JKg][FV]j
JeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmk
001[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmk001[NV]JKg][FV]j
JeY_Nf]JJgY[FVmkJeY[NP00Kg][FP00JeY_Nf]J001[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmk
JeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]j
JeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmk
JeY[NV]JKg][FV]jJeY_N`00JgY[FVmkJeX006]JKg][FV]j001_Nf]JJgY[FVmk001[NV]JKg][FV]j
JeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmk
JeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]j
JeY_Nf]JJgY[FVmkJeY[NV]JKg/006Q[FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[
FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][
FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[
FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmk0F]J000SJeX0
0`00JeY[FP0EJeX00`00JeY[FP0<JeX00`00JeX00003JeX00`00JeY[FP1@JeX00`00JeY[FP07JeX0
0`00JeY[FP03JeX00`00JeY[FP2bJeX0002HKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_
Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NP00Kg][FV]jJeY_Nf]JJgY[FVmkJeY[
NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]J001[FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FP00JeY_
N`00JgY[FP00JeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[
NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_
Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FPH0000EJgY[FVmkJeY[NV]J001[FV]jJeY_Nf]J
JgY[FVmk001[NV]JKg][FV]j00<0002aJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]J
Kg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]J
JgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]J
Kg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]J
JgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]J
Kg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]J
JgY[FVmkJeY[NV]JKg][FV]j005[FP008f]J00<006]JJeX05V]J00<006]JJeX02f]J00@006]JJeX0
009[FP03001[FV]J055[FP03001[FV]J009[FP@000I[FP03001[FV]J0;9[FP000?m[NV]JKg][FV]j
JeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmk
JeX006]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeX006]JKg][FV]j
JeY_Nf]JJgY[FVmkJeY[NV]J001[FV]j001_Nf]JJgX006mkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmk
JeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]j
JeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmk
JeY[NV]JKg][FV]jJeY_Nf]JJgX006mkJeY[NP00Kg][FV]jJeY_Nf]JJgY[FVmk001[NV]JKg][FV]j
JeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmk
JeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]j
JeY_Nf]JJgY[FVmkJeY[NV]JKg/006Q[FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[
FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][
FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[
FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmk0F]J000TJeX0
0`00JeY[FP0EJeX00`00JeY[FP0<JeX00`00JeX00003JeX00`00JeY[FP1<JeX00`00JeY[FP02JeX0
1@00JeY[FV]J00002F]J00<006]JJeX0/V]J0000X6mkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[
NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FP00JeY[NV]JKg][FV]jJeY_
Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmk001[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[
NP00Kg/006]jJeY_N`00JgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_
Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[
NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]J1P0000=[NV]J
Kg/01@000;U[NV]JKg][FV]j001_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]J
Kg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]J
JgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]J
Kg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]J
JgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]J
Kg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]J
JgY[FVmkJeY[NV]JKg][FV]j005[FP0096]J00<006]JJeX05V]J00<006]JJeX02f]J00<006]J0000
0f]J00<006]JJeX0Gf]J00<006]JJeX0/V]J0000/f]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_
Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]j001_Nf]JJgY[FVmkJeY[
NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]j001_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_
N`00JgY[FP00JeY[NV]J001[FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[
NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_
Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[
NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg/00P000;9[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[
FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][
FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[
FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][
FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[
FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][
FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_N`5[FP009F]J00<006]JJeX05F]J00<006]JJeX0
2f]J00@006]JJeX000=[FP03001[FV]J05i[FP03001[FV]J0;9[FP000?m_Nf]JJgY[FVmkJeY[NV]J
Kg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_N`00
JgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]J001[FVmkJeY[NV]J
Kg][FV]jJeY_Nf]JJgY[FP00JeX006]JKg][FP00JeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]J
JgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]J
Kg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]J
JgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]j001_Nf]JJgY[FVmkJeY[NV]J
Kg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]J
JgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]J
Kg][FV]jJeY_Nf]JJgX006Q[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_
Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[
NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_
Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]j0F]J000UJeX00`00JeY[
FP0FJeX00`00JeY[FP0;JeX00`00JeX00003JeX00`00JeY[FP1NJeX00`00JeY[FP2bJeX0003oJgY[
FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][
FV]jJeY_Nf]JJgY[FP00JeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[
FP00JeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeX006]J001[FV]jJeX006]JJgY[FVmkJeY[NV]JKg][
FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[
FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][
FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_N`00JgY[
FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][
FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[
FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmk001XJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]J
Kg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]J
JgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]J
Kg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_N`5[
FP009V]J00<006]JJeX05F]J00<006]JJeX02f]J00<006]J000016]J00<006]JJeX0GF]J00<006]J
JeX0/V]J0000/fmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmk
JeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NP00Kg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]j
JeY_Nf]JJgY[FVmkJeY[NP00Kg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]J001[FV]j001_Nf]JJgX006mk
JeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]j
JeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmk
JeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]j
JeY_Nf]JJgX00P000;9[FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]J
Kg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]J
JgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]J
Kg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]J
JgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]J
Kg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]J
JgY[FVmkJeY[NP5[FP009f]J00<006]JJeX05F]J00<006]JJeX02f]J00<006]J00000f]J00<006]J
JeX0GF]J00<006]JJeX0/V]J0000of]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmk
JeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_N`00JgY[FVmkJeY[NV]JKg][FV]j
JeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_N`00JgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgX006mk
001[NV]JKg/006]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]j
JeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmk
JeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]j
JeY_Nf]JJgY[FVmkJeY[NV]JKg/006]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmk
JeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]j
JeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_N`00J6]JJgY[
FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][
FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[
FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][
FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg/1JeX002Q[FP03001[FV]J01A[FP03001[FV]J00][FP03001[
FP0000=[FP03001[FV]J05e[FP03001[FV]J0;9[FP000?m_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_
Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FP00JeY[
NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FP00JeY[NV]JKg][FV]jJeY_
Nf]JJgY[FVmk001[NP00Kg][FV]jJeX006]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[
NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_
Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[
NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]j001_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_
Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[
NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_
Nf]JJgX006Q[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmk
JeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]j
JeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmk
JeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]j0F]J000YJeX00`00JeY[FP0DJeX00`00
JeY[FP0;JeX00`00JeX00003JeX00`00JeY[FP1LJeX00`00JeY[FP2bJeX0003oJgY[FVmkJeY[NV]J
Kg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]J
JgY[FVmkJeY[NP00Kg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeX006]J
Kg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]J001[FP00JeY_Nf]J001[FVmkJeY[NV]JKg][FV]jJeY_Nf]J
JgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]J
Kg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]J
JgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_N`00JgY[FVmkJeY[NV]J
Kg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]J
JgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]J
Kg][FV]jJeY_Nf]JJgY[FVmk001XJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_
Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[
NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_
Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_N`5[FP00:F]J00<0
06]JJeX056]J00<006]JJeX02f]J00<006]J00000f]J00<006]JJeX0G6]J0P00/f]J0000ofmkJeY[
NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_
Nf]JJgY[FVmkJeY[NV]JKg][FP00JeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[
NV]JKg/006]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FP00JeX006]JJgY[FVmk001[NV]JKg][FV]jJeY_
Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[
NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_
Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgX006mkJeY[
NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_
Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[
NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NP00J6]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]j
JeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmk
JeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]j
JeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgX1JeX0
02Y[FP03001[FV]J01A[FP03001[FV]J00Y[FP04001[FV]J0003JeX00`00JeY[FP1KJeX00`00JeY[
FP2bJeX0003oJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[
FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]J001[FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][
FV]jJeY_Nf]JJgY[FVmkJeY[NP00Kg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg/006]j001_Nf]JJgX0
06mkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][
FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[
FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][
FV]jJeY_N`00JgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[
FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][
FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmk001XJeY[NV]JKg][FV]jJeY_Nf]J
JgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]J
Kg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]J
JgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]J
Kg][FV]jJeY_N`5[FP00:f]J00<006]JJeX056]J00<006]JJeX02V]J00<006]J00000f]J00<006]J
JeX0Ff]J00<006]JJeX0/V]J0000ofmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]j
JeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]j001_Nf]JJgY[FVmk
JeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FP00JeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]j
001_N`00JgY[FVmk001[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmk
JeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]j
JeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmk
JeY[NV]JKg][FV]jJeY_Nf]JJgX006mkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]j
JeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmk
JeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NP00J6]JKg][
FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[
FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][
FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[
FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgX1JeX002a[FP03001[FV]J01=[FP03001[FV]J00Y[FP04001[
FV]J0003JeX00`00JeY[FP1JJeX2002cJeX0003oJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmk
JeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FP00
JeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg/006]jJeY_Nf]JJgY[FVmk
JeY[NV]JKg][FP00JeX006]JJgY[FP00JeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]j
JeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmk
JeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]j
JeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_N`00JgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmk
JeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]j
JeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmk
001XJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][
FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[
FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][
FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_N`5[FP00;6]J00<006]JJeX056]J00<006]JJeX0
2V]J00<006]J00000f]J00<006]JJeX0FV]J00<006]JJeX0/V]J0000XFmkJeY[NV]JKg][FV]jJeY_
Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[
NV]JKg][FV]jJeY_N`00JgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]j001_
Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeX006]J001[FVmkJeX006]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[
NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_
Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[
NV]JKg/0100000A[FV]jJeY_N`@0002jJeY[NV]JKg][FV]j001_Nf]JJgY[FVmkJeY[NV]JKg][FV]j
JeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmk
JeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]j
JeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmk
JeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]j
JeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmk
JeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]j0F]J000]JeX00`00JeY[FP0CJeX00`00
JeY[FP0;JeX00`00JeX00003JeX00`00JeY[FP16JeX00`00JeY[FP02JeX01000JeY[FP0016]J00<0
06]JJeX00f]J00<006]JJeX0/V]J0000of]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[
FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]J001[
FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeX006]JKg][FV]jJeY_Nf]JJgY[
FVmkJeY[NP00Kg/006]jJeY_N`00JgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][
FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[
FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NP00Kg][
FP00JeY_Nf]JJgX006mkJeY[NV]JKg/006]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[
FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][
FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_N`00J6]J
JgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]J
Kg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]J
JgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]J
Kg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg/1JeX002i[FP03001[FV]J01=[FP03001[FV]J00Y[FP03
001[FP0000=[FP03001[FV]J03i[FPH000M[FP04001[FV]J0004JeX00`00JeY[FP03JeX3002bJeX0
002QKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_
Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeX006]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[
NV]JKg][FV]jJeY_Nf]JJgY[FP00JeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmk001[NP00Kg][FV]jJeX0
06]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[
NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_
Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_N`040000`V]JJgY[FP00JeY[NV]JKg/006]jJeY_Nf]JJgX0
06mkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][
FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[
FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][
FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[
FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][
FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgX1
JeX002m[FP03001[FV]J01=[FP03001[FV]J00Y[FP03001[FP0000=[FP03001[FV]J04I[FP03001[
FV]J00A[FP03001[FV]J009[FP03001[FV]J00=[FP03001[FV]J0;9[FP000?m[NV]JKg][FV]jJeY_
Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[
NV]JKg][FV]jJeY_Nf]JJgY[FVmk001[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_
Nf]JJgX006mkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FP00JeX006]JKg][FP00JeY_Nf]JJgY[FVmkJeY[
NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_
Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[
NV]JKg][FV]j001_Nf]JJgY[FVmkJeX006]JKg][FV]j001_Nf]JJgY[FVmk001[NV]JKg][FV]jJeY_
Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[
NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_
Nf]JJgY[FVmkJeY[NV]JKg/006Q[FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmk
JeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]j
JeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmk
JeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmk0F]J000`JeX00`00
JeY[FP0BJeX00`00JeY[FP0:JeX00`00JeX00003JeX00`00JeY[FP16JeX50003JeX40006JeX00`00
JeY[FP2bJeX0001CKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]J
Kg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]J001[FV]jJeY_Nf]J
JgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeX006]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NP02
0000of]JJgY[FVmk001[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmk
JeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]j
JeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmk
JeY[NV]JKg][FV]j001_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]j
JeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmk
JeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]j
JeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmk
JeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]j
JeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FP004fmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[
FVmkJeY[NV]JKg][FV]j005[FP00<6]J00<006]JJeX04f]J00<006]JJeX02V]J00<006]J00000f]J
00<006]JJeX0Ef]J00<006]JJeX0/V]J0000/f]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]J
JgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]J
Kg][FV]j001_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]J001[FV]jJeY_Nf]J
JgY[FVmkJeY[NV]JKg/006]j001_Nf]JJgX006mkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]J
Kg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]J
JgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]J
Kg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg/00P000;9[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmk
JeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]j
JeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmk
JeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]j
JeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmk
JeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]j
JeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_N`5[FP00<F]J00<006]JJeX04V]J00<006]JJeX02f]J
0P0016]J00<006]JJeX0EV]J00<006]JJeX0/V]J0000E6mkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmk
JeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]j
JeY_Nf]JJgY[FVmk001[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgX006mk
JeY[NV]JKg][FV]jJeY_Nf]JJgY[FP80003oJgY[FVmkJeX006]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[
NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_
Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[
NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]j001_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_
Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[
NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_
Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[
NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_
Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmk000B
JeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]j0F]J000bJeX00`00JeY[FP0BJeX00`00
JeY[FP0:JeX00`00JeX00003JeX00`00JeY[FP1FJeX00`00JeY[FP2bJeX0003oJgY[FVmkJeY[NV]J
Kg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]J
JgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FP00JeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]J
Kg][FV]jJeY_N`00JgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]J001[FP00JeY[NV]JKg/006]jJeY_Nf]J
JgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]J
Kg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]J
JgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_N`00JgY[FVmkJeY[NV]J
Kg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]J
JgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]J
Kg][FV]jJeY_Nf]JJgY[FVmk001XJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_
Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[
NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_
Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_N`5[FP00<f]J00<0
06]JJeX04V]J00<006]JJeX02V]J0P0016]J00<006]JJeX0EF]J00<006]JJeX0/V]J0000/fmkJeY[
NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_
Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NP00Kg][FV]jJeY_Nf]JJgY[FVmkJeY[
NV]JKg][FV]jJeY_Nf]JJgY[FP00JeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmk001[NP00Kg][FV]j001_
Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[
NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_
Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgX00P000;9[
FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[
FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][
FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[
FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][
FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[
FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NP5[FP00
=6]J00<006]JJeX04F]J00<006]JJeX02V]J00<006]J000016]J00<006]JJeX0E6]J00<006]JJeX0
/V]J0000of]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_
Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]J001[FVmkJeY[
NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]j001_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeX0
06]J001[FVmkJeX006]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[
NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_
Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[
NV]JKg/006]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_
Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[
NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_N`00J6]JJgY[FVmkJeY[NV]JKg][FV]j
JeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmk
JeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]j
JeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmk
JeY[NV]JKg/1JeX003E[FP03001[FV]J015[FP03001[FV]J00Y[FP03001[FP0000=[FP03001[FV]J
05A[FP03001[FV]J0;9[FP000?m_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]J
Kg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]J
JgY[FVmk001[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]J001[FVmkJeY[NV]J
Kg][FV]jJeY_Nf]J001[FP00JeY[NV]JKg/006]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]J
JgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]J
Kg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]J
JgY[FVmkJeY[NV]JKg][FV]j001_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]J
Kg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]J
JgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgX006Q[FVmkJeY[
NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_
Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[
NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_
Nf]JJgY[FVmkJeY[NV]JKg][FV]j0F]J000fJeX00`00JeY[FP0AJeX00`00JeY[FP0:JeX00`00JeX0
0003JeX00`00JeY[FP1CJeX00`00JeY[FP2bJeX0002cJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[
FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][
FV]jJeY_Nf]JJgY[FVmkJeY[NV]J001[FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[
FVmk001[NV]JKg][FV]jJeY_Nf]JJgY[FVmk001[NP00Kg][FV]j001_Nf]JJgY[FVmkJeY[NV]JKg][
FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[
FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][
FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_N`020000/V]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[
NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_
Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[
NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_
Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[
NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_
Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmk0F]J000gJeX00`00JeY[FP0AJeX00`00JeY[
FP0:JeX00`00JeX00003JeX00`00JeY[FP1BJeX00`00JeY[FP2bJeX0003oKg][FV]jJeY_Nf]JJgY[
FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][
FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgX006mkJeY[NV]JKg][FV]jJeY_Nf]JJgY[
FVmkJeY[NV]JKg][FV]jJeX006]JJgY[FVmkJeY[NV]JKg][FV]jJeX006]J001[FVmkJeX006]JKg][
FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[
FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][
FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NP00Kg][FV]jJeY_Nf]JJgY[
FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][
FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[
FVmkJeY[NV]JKg][FV]j001XJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]J
Kg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]J
JgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]J
Kg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NP5[FP00>6]J00<006]J
JeX04F]J00<006]JJeX02V]J0P000f]J00<006]JJeX0DV]J00<006]JJeX0/V]J0000of]jJeY_Nf]J
JgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]J
Kg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeX006]JKg][FV]jJeY_Nf]J
JgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]J001[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgX006mk001[NV]J
Kg/006]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]J
JgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]J
Kg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg/006]jJeY_Nf]J
JgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]J
Kg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]J
JgY[FVmkJeY[NV]JKg][FV]jJeY_N`00J6]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[
NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_
Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[
NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg/1JeX003U[
FP03001[FV]J015[FP03001[FV]J00Y[FP8000=[FP03001[FV]J055[FP03001[FV]J0;9[FP000?m_
Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[
NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg/006]jJeY_
Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmk001[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeX0
06]J001[FV]jJeX006]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_
Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[
NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]j001_
Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[
NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_
Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgX006Q[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmk
JeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]j
JeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmk
JeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]j
0F]J000jJeX00`00JeY[FP0AJeX00`00JeY[FP09JeX00`00JeX00003JeX00`00JeY[FP1@JeX2002c
JeX0001KJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmk
JeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]j
JeX006]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]J001[FV]jJeY_Nf]JJgY[FVmk
JeY[NV]JKg/00P000?m[FVmkJeY[NP00Kg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]J
JgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]J
Kg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]J
JgY[FVmk001[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]J
Kg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]J
JgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]J
Kg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]J
JgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]J
Kg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeX000][NV]JKg][FV]jJeY_
Nf]JJgY[FVmk005[FP00>f]J00<006]JJeX04F]J00<006]JJeX02F]J00<006]J00000f]J00<006]J
JeX0Cf]J00<006]JJeX0/V]J0000G6mkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]j
JeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmk
JeY[NV]JKg][FV]jJeY_Nf]JJgX006mkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]j
001_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeX20000@V]jJeY_Nf]J001[FVmkJeY[NV]JKg][FV]jJeY_
Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[
NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FPD00004JeY[NV]JKg/40000
^V]JJgY[FVmkJeY[NP00Kg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[
NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_
Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[
NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_
Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[
NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_
Nf]JJgY[FVmkJeY[NP5[FP00?6]J00<006]JJeX04F]J00<006]JJeX02F]J00<006]J00000f]J00<0
06]JJeX0>f]J00D006]JJeY[FP0000=[FP03001[FV]J009[FP03001[FV]J00=[FP03001[FV]J0;9[
FP0005e[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][
FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[
FVmkJeY[NP00Kg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]J001[FVmkJeY[NV]JKg][
FV]jJeY_Nf]JJgX00P000?m[FV]jJeX006]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[
NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_
Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgX006mkJeY[NV]JKg][FV]jJeY_Nf]JJgX006mkJeY[
NV]JKg/006]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_
Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[
NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_
Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[
NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_
Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeX000U_Nf]JJgY[FVmk
JeY[NV]JKg/00F]J000nJeX00`00JeY[FP0@JeX00`00JeY[FP09JeX00`00JeX00003JeX00`00JeY[
FP0bJeX60004JeX00`00JeY[FP08JeX00`00JeY[FP03JeX3002bJeX0001NKg][FV]jJeY_Nf]JJgY[
FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][
FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FP00JeY_Nf]JJgY[
FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmk001[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeX20000BFmk
JeY[NP00Kg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]j
JeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmk
JeY[NV]JKg][FV]j001_Nf]JJgY[FVmk00@0002jJeY[NV]JKg][FV]j001_Nf]JJgY[FVmkJeY[NV]J
Kg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]J
JgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]J
Kg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]J
JgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]J
Kg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]J
JgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]j0F]J000oJeX00`00JeY[FP0@
JeX00`00JeY[FP09JeX00`00JeX00003JeX00`00JeY[FP0mJeX00`00JeY[FP02JeX00`00JeY[FP07
JeX00`00JeY[FP2bJeX0001OJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]j
JeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmk
JeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeX006]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]j
JeX006]JJgY[FVmkJeY[NV]JKg][FV]jJeY_N`020000of]JKg][FP00JeY_Nf]JJgY[FVmkJeY[NV]J
Kg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]J
JgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FP00JeY_Nf]J001[FVmkJeY[NP00
Kg][FV]jJeY_Nf]JJgY[FVmk001[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]J
JgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]J
Kg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]J
JgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]J
Kg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]J
JgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]J
Kg][FP001f]jJeY_Nf]JJgY[FVmk005[FP00@6]J00<006]JJeX046]J00<006]JJeX02F]J00<006]J
00000f]J00<006]JJeX0>F]J0`001F]J1@001F]J00<006]JJeX0/V]J0000H6mkJeY[NV]JKg][FV]j
JeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmk
JeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg/006]j
JeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgX006mkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FP80
003oJgY[FVmk001[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[
NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_
Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]j001_Nf]JJgY[FVmkJeY[
NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_
Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[
NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_
Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[
NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_
Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmk0006JeY[NV]JKg][FV]j0F]J0012JeX00`00
JeY[FP0?JeX00`00JeY[FP0:JeX20003JeX00`00JeY[FP1:JeX2002cJeX0003oJgY[FVmkJeY[NV]J
Kg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]J
JgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]J
Kg/006]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]J001[FVmkJeY[NV]JKg][FV]jJeY_Nf]J
JgX006mk001[NV]J001[FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]J
Kg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]J
JgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_N`00JgY[FVmkJeY[NV]J
Kg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]J
JgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]J
Kg][FV]jJeY_Nf]JJgY[FVmk001XJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_
Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[
NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_
Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_N`5[FP00A6]J00<0
06]JJeX03V]J00<006]JJeX02V]J0P000f]J00<006]JJeX0BF]J00<006]JJeX0/V]J0000HfmkJeY[
NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_
Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[
NV]JKg][FV]jJeY_N`00JgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeX006]JKg][FV]jJeY_
Nf]JJgY[FVmkJeY[NP020000of]JJgX006mkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][
FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[
FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NP00Kg][
FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[
FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][
FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[
FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][
FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[
FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FP000fmkJeY[NP01
JeX004I[FP03001[FV]J00e[FP03001[FV]J00Y[FP8000=[FP03001[FV]J04Q[FP03001[FV]J0;9[
FP0006A[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][
FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[
FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmk001[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg/0
06]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FP80003oKg][FP00JeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]j
JeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmk
JeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]j
JeY_N`00JgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmk
JeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]j
JeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmk
JeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]j
JeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmk
JeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]j
005[FP5_N`5[FP00B6]J00<006]JJeX03F]J00<006]JJeX02F]J0P000f]J00<006]JJeX0Af]J00<0
06]JJeX0/V]J0000IFmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[
FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][
FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmk001[NV]JKg][FV]jJeY_Nf]JJgY[
FVmkJeY[NV]J001[FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg/00P0004a[FVmk001[NV]JKg][FV]jJeY_
Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[
NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_
Nf]JJgY[FVmkJeY[NP80002bJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]J
JgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]J
Kg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]J
JgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]J
Kg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]J
JgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]J
Kg][FV]jJeY_Nf]JJgX1JeX004Y[FP03001[FV]J00a[FP03001[FV]J00Y[FP80009[FP03001[FV]J
04I[FP03001[FV]J0;9[FP000?m[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]J
JgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]J
Kg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg/006]jJeY_Nf]J
JgY[FVmkJeY[NV]JKg][FV]jJeX006]JJgY[FVmkJeY[NV]JKg][FV]jJeY_N`00JgY[FP00JeY[NV]J
Kg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]J
JgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]J
Kg][FV]jJeY_Nf]JJgY[FVmk001[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]J
JgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]J
Kg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg/006Q[FV]jJeY_
Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[
NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_
Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[
NV]JKg][FV]jJeY_Nf]JJgY[FVmk0F]J000:JeX3000eJeX50005JeX00`00JeY[FP0<JeX00`00JeY[
FP09JeX20002JeX00`00JeY[FP0>JeX5000bJeX00`00JeY[FP0dJeX5000cJeX5000eJeX30009JeX0
001XKg][FV]jJeY_Nf]JJgY[FVmk001[NV]JKg/006]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_
Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[
NV]JKg][FV]jJeY_Nf]J001[FVmkJeX006]JKg][FV]jJeY_N`00JgY[FVmkJeY[NV]JKg][FV]jJeY_
Nf]JJgY[FP00JeY[NV]JKg][FV]jJeY_Nf]JJgY[FP80003mJgY[FP00JeY[NV]JKg][FV]jJeY_Nf]J
JgY[FVmkJeY[NV]JKg][FP00JeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]J
Kg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]J
JgX006mkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]J
Kg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeX006]J
JgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]J
Kg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeX006]JKg][FP00JeY_Nf]J
JgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]J
Kg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgX006mkJeY[NP00Kg][FV]jJeY_Nf]J
JgX00F]J000=JeX00`00JeY[FP0cJeX00`00JeY[FP08JeX00`00JeY[FP0<JeX00`00JeY[FP09JeX2
0002JeX00`00JeY[FP0>JeX00`00JeY[FP0bJeX00`00JeY[FP0fJeX00`00JeY[FP0dJeX00`00JeY[
FP0iJeX00`00JeY[FP06JeX00003JgX0000000@0000cJeY[NV]JKg][FV]j001_Nf]JJgY[FVmkJeY[
NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_
Nf]JJgY[FVmkJeY[NV]J00H0000cJgY[FVmkJeX006]JKg][FV]jJeY_Nf]JJgY[FVmk001[NV]JKg][
FV]jJeY_Nf]JJgY[FVmkJeY[NV]J001[FV]jJeY_Nf]JJgY[FVmkJeY[NV]J001[FV]jJeX006]JJgY[
FVmk00H0000jJeY_Nf]JJgY[FP00JeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_
Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[
NV]JKg/20000/V]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]J
Kg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]J
001[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]J
Kg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FP00JeY_Nf]J
JgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]J
Kg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg/006]jJeY_Nf]J
JgY[FVmk0F]J000;JeX2000hJeX00`00JeY[FP08JeX2000=JeX00`00JeY[FP08JeX20003JeX00`00
JeY[FP0<JeX00`00JeY[FP0bJeX00`00JeY[FP0fJeX00`00JeY[FP0fJeX00`00JeY[FP0eJeX20009
JeX0001BKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg/006]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]j
JeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmk
JeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeX006]JKg][FV]jJeY_Nf]JJgY[FVmkJeX2000036mkJeY[
NV]JKg][FV]jJeY_Nf]JJgY[FP800009JgY[FVmkJeY[NV]JKg][FV]j0080003jJeY[NV]J001[FV]j
JeY_Nf]JJgY[FVmkJeY[NV]JKg][FP00JeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmk
JeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]j
JeY_Nf]JJgX006mkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmk
JeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]j
JeX006]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmk
JeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FP00
JeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmk
JeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NP00Kg][FV]j
JeY_Nf]JJgX1JeX000U[FP05001[FV]JJeX0000dJeX01@00JeY[FV]J00003F]J0P0036]J00<006]J
JeX01f]J0`000V]J00<006]JJeX026]J0`00=6]J00<006]JJeX0=6]J0`00=F]J00D006]JJeY[FP00
03A[FP05001[FV]JJeX00008JeX0000:JgY[FVmkJeY[NV]JKg][FV]jJeX30000=V]JKg][FV]jJeY_
Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[
NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_N`<0000XKg][FV]jJeY_Nf]JJgY[FVmk
JeY[NV]JKg][FV]jJeX006]JJgY[FVmkJeY[NV]JKg][FV]jJeY_N`00JgY[FVmkJeY[NV]JKg][FV]j
JeX20000/f]jJeX006]JJgY[FVmkJeY[NV]JKg][FV]jJeX006]JJgY[FVmkJeY[NV]JKg][FV]jJeY_
Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[
NV]JKg][FV]jJeY_Nf]JJgY[FVmk001[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_
Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[
NV]JKg][FV]jJeY_Nf]J001[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_
Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[
NV]JKg/00`0003I_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_
Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeX3
000026]JJgY[FVmkJeY[NV]JKg/1JeX005M[FP8000][FP03001[FV]J00U[FP800003JeX006]J03i[
FP03001[FV]J0;9[FP0005U_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][
FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[
FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][
FV]jJeY_Nf]JJgY[FVmk0080000:JeY_Nf]JJgY[FVmkJeY[NV]JKg/200002V]JKg][FV]jJeY_Nf]J
JgY[FVmk0P00041[FP00001[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[
FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][
FV]jJeY_Nf]JJgY[FVmkJeY[NP80002bJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]j
JeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmk
JeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]j
JeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmk
JeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]j
JeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmk
JeY[NV]JKg][FV]jJeY_Nf]JJgX1JeX005][FP8000Y[FP8000U[FP<00003JeX006]J03][FP03001[
FV]J0;9[FP0005e[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[
NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_
Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[
NV]JKg][FV]jJeY_Nf]JJgX00`0000U[NV]JKg][FV]jJeY_Nf]JJgX00P0000Q[FV]jJeY_Nf]JJgY[
FVmk1P000>i[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmk
JeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]j
JeY_N`00JgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmk
JeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]j
JeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmk
JeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]j
JeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmk
JeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]j
JeY_N`5[FP00H6]J10001f]J0P0026]J1`00=f]J00<006]JJeX0/V]J0000I6mkJeY[NV]JKg][FV]j
JeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmk
JeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]j
JeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmk
JeY[NV]J100000E_Nf]JJgY[FVmk00@00007JeY[NV]JKg][FV]jJeX01P000>U[NV]JKg][FV]jJeY_
Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[
NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]j001_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_
Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[
NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_
Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[
NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_
Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[
NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]j005[FP00J6]J1@0016]J0`0026]J1000<f]J
00<006]JJeX0/V]J0000KF]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]J
Kg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]J
JgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]J
Kg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]j00/00006
JgY[FVmkJeY[NV]J2@000>1[FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[
NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmk001[NV]JKg][FV]jJeY_
Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[
NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_
Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[
NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_
Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[
NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmk0F]J003o001X0001JeX0
0023Kg][FV]jJeY_Nf]JJgY[FP00JeY[NV]JKg][FV]jJeY_Nf]JJgY[FP00JeY[NV]JKg][FV]jJeY_
Nf]JJgX006mkJeY[NV]JKg][FV]jJeY_Nf]JJgX006mkJeY[NV]JKg][FV]jJeY_Nf]J001[FVmkJeY[
NV]JKg][FV]jJeY_N`00JgY[FVmkJeY[NV]JKg][FV]jJeY_N`00JgY[FVmkJeY[NV]JKg][FV]jJeX0
06]JJgY[FVmkJeY[NV]JKg][FV]j001_Nf]JJgY[FVmkJeY[NV]JKg][FV]j001_Nf]JJgY[FVmkJeY[
NV]JKg][FP00JeY_Nf]JJgY[FVmkJeY[NP120000XV]JJgY[FVmkJeX006]JKg][FV]jJeY_Nf]JJgY[
FVmk001[NV]JKg][FV]jJeY_Nf]JJgY[FP00JeY[NV]JKg][FV]jJeY_Nf]JJgY[FP00JeY[NV]JKg][
FV]jJeY_Nf]JJgX006mkJeY[NV]JKg][FV]jJeY_Nf]JJgX006mkJeY[NV]JKg][FV]jJeY_Nf]J001[
FVmkJeY[NV]JKg][FV]jJeY_N`00JgY[FVmkJeY[NV]JKg][FV]jJeY_N`00JgY[FVmkJeY[NV]JKg][
FV]jJeX006]JJgY[FVmkJeY[NV]JKg][FV]j001_Nf]JJgY[FVmkJeY[NV]JKg][FV]j001_Nf]JJgY[
FVmkJeY[NV]JKg][FP00JeY_Nf]JJgY[FVmkJeY[NV]JKg][FP00JeY_Nf]JJgY[FVmkJeY[NP5[FP00
26]J00<006]JJeX0=V]J00<006]JJeX0=V]J00<006]JJeX0=V]J00<006]JJeX02F]J50006F]J00<0
06]JJeX0=V]J00<006]JJeX0=V]J00<006]JJeX01f]J0000bV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][
FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[
FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][
FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[
FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][
FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[
FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg/006]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][
FV]jJeY_Nf]JJgY[FVmkJeY[NV]J200000=_N`0000001P0008a[FV]jJeY_Nf]JJgY[FVmkJeY[NV]J
Kg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]J
JgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]J
Kg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]J
JgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]J
Kg][FV]jJeY_Nf]JJgY[FVmk0F]J002cJeX00`00JeY[FP0HJeX70006JeX60027JeX0003DKg][FV]j
JeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmk
JeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]j
JeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmk
JeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]j
JeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmk
JeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NP00Kg][FV]j
JeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FPD0
0008JeY[NV]JKg][FV]jJeY_N`D00021JgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]J
Kg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]J
JgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]J
Kg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]J
JgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]j005[FP00/f]J0P008F]J1`00
2F]J1000OV]J0000f6]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][
FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[
FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][
FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[
FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][
FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[
FVmkJeY[NV]JKg/006]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][
FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FP@0000>JgX00000001[NV]JKg][FV]jJeY_Nf]JJgY[FP<0
001jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[
FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][
FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[
FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][
FV]jJeY_N`5[FP00/f]J00<006]JJeX096]J1@0000=[FP0000002f]J0P00NF]J0000g6mkJeY[NV]J
Kg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]J
JgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]J
Kg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]J
JgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]J
Kg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]J
JgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgX006mkJeY[NV]J
Kg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]J
JgY[FVmkJeY[NV]J100000m_Nf]J000006mkJeY[NV]JKg][FV]jJeY_Nf]JJgX00P0007I[FV]jJeY_
Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[
NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_
Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[
NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NP5[FP00/f]J00<0
06]JJeX0:6]J10000V]J0P002f]J0`00M6]J0000h6]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_
Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[
NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_
Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[
NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_
Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[
NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg/006]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_
Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeX3
00004F]JJgY[FP00JeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeX00P00075_Nf]JJgY[FVmkJeY[NV]J
Kg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]J
JgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]J
Kg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]J
JgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmk005[FP00/f]J0P00;6]J0`000f]J0P003F]J0P00
L6]J0000hVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[
NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_
Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[
NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_
Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[
NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_
Nf]JJgX006mkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[
NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]J1000019[NV]JKg/006]jJeY_Nf]J
JgY[FVmkJeY[NV]JKg][FV]jJeX20000KF]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[
FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][
FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[
FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][
FV]j005[FP00/f]J00<006]JJeX0;F]J0P0000=[FP00JeX00V]J00<006]JJeX03F]J0P00K6]J0000
i6]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[
FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][
FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[
FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][
FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[
FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg/0
06]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[
FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FP800005Kg/006]jJeY_N`020000NV]J
Kg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FP00JeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]J
JgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]J
Kg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]J
JgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]J
Kg/1JeX00;=[FP03001[FV]J031[FP<000A[FP03001[FV]J00e[FP03001[FV]J06Q[FP000>M_Nf]J
JgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]J
Kg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]J
JgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]J
Kg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]J
JgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]J
Kg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]j001_Nf]J
JgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]J
Kg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgX00`0001A[NV]JKg][FP00JeY_Nf]J
JgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]J0P0006M_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[
FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][
FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[
FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NP01JeX0
0;=[FP03001[FV]J039[FP<000A[FP03001[FV]J00i[FP03001[FV]J06E[FP000;=[NV]JKg][FV]j
JeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmk
JeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]j
JeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmk
JeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]j
JeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmk
JeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmk0080000cJeY_Nf]J
JgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]J
Kg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]J0080001mKg/006]jJeY_Nf]J001[FVmk
JeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NP00Kg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]j
JeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmk
JeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]j
JeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_N`01JeX00;=[
FP03001[FV]J03=[FP800003JeX006]J00=[FP03001[FV]J00i[FP03001[FV]J06=[FP000?m_Nf]J
JgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]J
Kg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]J
JgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]J
Kg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]J
JgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]J
Kg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]j001_Nf]J
JgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]J
Kg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeX006]JKg/006]jJeY_Nf]J
001[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgX006Q[FVmkJeY[NP00Kg][FV]jJeY_Nf]JJgY[FVmkJeY[
NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_
Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[
NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]j0F]J
002cJeX00`00JeY[FP0eJeX01000JeY[FP0016]J00<006]JJeX03V]J00<006]JJeX0HF]J0000jf]j
JeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmk
JeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]j
JeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmk
JeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]j
JeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmk
JeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg/006]j
JeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmk
JeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmk0080001jJeX006]J
JgY[FVmkJeX006]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]j001_Nf]JJgY[FVmkJeY[NV]J
Kg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]J
JgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]J
Kg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_N`5[
FP00/f]J00<006]JJeX0=V]J00@006]JJeX000E[FP03001[FV]J00i[FP03001[FV]J05m[FP000;=_
Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[
NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_
Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[
NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_
Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[
NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]j0080
002bJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][
FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_N`00JgY[
FP00JeY[NV]JKg/006]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgX006mkJeY[NV]JKg][
FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[
FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][
FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgX1
JeX00;=[FP03001[FV]J03Q[FP03001[FP0000E[FP03001[FV]J00m[FP03001[FV]J05e[FP000?m[
NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_
Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[
NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_
Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[
NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_
Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmk001[
NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_
Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FP00JeY[
NP00Kg][FV]jJeX006]JJgY[FVmkJeY[NV]JKg/006Q[FV]jJeY_Nf]JJgY[FVmkJeY[NP00Kg][FV]j
JeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmk
JeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]j
JeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmk
0F]J002cJeX00`00JeY[FP0iJeX00`00JeX00005JeX00`00JeY[FP0?JeX00`00JeY[FP1LJeX0002P
Kg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]J
JgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]J
Kg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]J
JgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]J
Kg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]J
JgY[FVmkJeY[NV]JKg][FV]jJeX5000016]JJgY[FVmk10000;Y[FV]jJeY_Nf]JJgX006mkJeY[NV]J
Kg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]J
JgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgX006mkJeX006]J
Kg][FV]jJeX006]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeX006]JKg][FV]jJeY_Nf]J
JgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]J
Kg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]J
JgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgX1JeX00:1[FP05
001[FV]JJeX00003JeX00`00JeY[FP02JeX00`00JeY[FP03JeX00`00JeY[FP0jJeX01000JeY[FP00
16]J00<006]JJeX046]J00<006]JJeX0FV]J0000l6]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_
Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[
NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_
Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[
NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_
Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgX006mkJeY[
NV]JKg][FV]jJeY_Nf]JJgX006mkJeY[NV]JKg/006]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_
Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[
NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FP80001eKg/006]jJeY_Nf]JJgX006mkJeY[NV]J
Kg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FP00JeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]J
JgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]J
Kg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]J
JgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmk005[FP00XV]J00<006]JJeX026]J00<006]JJeX0
0f]J0`00>f]J00@006]JJeX000A[FP03001[FV]J011[FP03001[FV]J05U[FP000:U_Nf]JJgY[FVmk
JeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]j
JeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmk
JeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]j
JeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmk
JeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]j
JeY_Nf]JJgY[FVmkJeY[NP00Kg][FV]jJeY_N`040000A6]JJgY[FVmkJeY[NP00Kg][FV]jJeY_Nf]J
JgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]J
Kg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg/20000M6]JKg/0
06]jJeY_Nf]J001[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg/006]jJeY_Nf]JJgY[
FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][
FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[
FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgX1JeX00:A[FP03001[
FV]J009[FP03001[FV]J00M[FP03001[FV]J03a[FP04001[FV]J0005JeX00`00JeY[FP0@JeX00`00
JeY[FP1GJeX0003bJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]J
JgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]J
Kg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]J
JgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]J
Kg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]J
JgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeX006]JKg][FP00JeY_Nf]JJgX006mkJeY[NV]J
Kg][FV]jJeY_N`00JgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]J
JgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]J
Kg][FV]jJeY_Nf]JJgY[FP80001cJgY[FP00JeY[NV]JKg/006]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][
FV]jJeY_Nf]JJgY[FVmk001[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[
FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][
FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[
FVmkJeY[NV]JKg/00F]J002QJeX30005JeX50005JeX00`00JeY[FP0mJeX01000JeY[FP001F]J00<0
06]JJeX046]J00<006]JJeX0EV]J0000lfmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][
FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[
FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][
FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[
FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][
FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[
FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgX006mkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][
FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[
FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NP020000LV]JJgX006mkJeY[NV]J001[FV]jJeY_
Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FP00JeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[
NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_
Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[
NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NP5[FP00/f]J0P00?f]J00@006]JJeX000E[FP03001[FV]J
015[FP03001[FV]J05A[FP000?A[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]J
JgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]J
Kg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]J
JgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]J
Kg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]J
JgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]J
Kg][FV]jJeY_Nf]JJgY[FVmk001[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]J
JgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]J
Kg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FP80001aKg][FP00JeY_Nf]JJgX006mkJeY[NV]JKg][
FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]j001_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[
FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][
FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[
FVmkJeY[NV]JKg][FV]jJeY_N`01JeX00;=[FP03001[FV]J03i[FP80009[FP03001[FV]J00=[FP03
001[FV]J015[FP03001[FV]J05=[FP000?E_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmk
JeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]j
JeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmk
JeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]j
JeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmk
JeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]j
JeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]j001_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmk
JeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]j
JeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmk0080001`JeX006]JJgY[FVmkJeX006]J
Kg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgX006mkJeY[NV]JKg][FV]jJeY_Nf]J
JgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]J
Kg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]J
JgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgX1JeX00;=[FP03001[FV]J03m[FP80009[FP03001[FV]J
00=[FP03001[FV]J015[FP03001[FV]J059[FP000?E[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]J
Kg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]J
JgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]J
Kg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]J
JgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]J
Kg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]J
JgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmk001[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]J
Kg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]J
JgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]j0080001`JeY[NP00Kg][FV]j
JeY_N`00JgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FP00JeY_Nf]JJgY[FVmk
JeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]j
JeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmk
JeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg/1JeX00;=[FP80045[FP800003JeX006]J00E[
FP03001[FV]J019[FP03001[FV]J051[FP000?I_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[
FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][
FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[
FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][
FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[
FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][
FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]j001_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[
FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][
FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeX20000KfmkJeX006]JKg][FV]j
JeX006]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg/006]jJeY_Nf]JJgY[FVmk
JeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]j
JeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmk
JeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NP01JeX00;=[FP03001[FV]J041[FP05001[FP00JeX0
0006JeX00`00JeY[FP0BJeX00`00JeY[FP1?JeX0003gJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[
FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][
FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[
FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][
FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[
FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][
FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_N`00JgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[
FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][
FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg/00P0006i[FP00JeY[
NV]JKg][FV]j001_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg/006]jJeY_
Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[
NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_
Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmk0F]J002cJeX00`00JeY[FP11JeX01@00JeX0
06]J00001F]J00<006]JJeX04f]J00<006]JJeX0CV]J0000ofmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[
FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][
FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[
FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][
FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[
FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][
FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgX006mkJeY[NV]JKg][FV]jJeY_Nf]JJgY[
FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][
FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]j001_N`00JgX0
06mkJeY[NP00J6]JKg][FP00JeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]J
001[FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]J
JgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]J
Kg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgX1JeX00;=[FP03001[FV]J045[FP03
001[FV]J008000I[FP03001[FV]J01=[FP03001[FV]J04e[FP000;=[NV]JKg][FV]jJeY_Nf]JJgY[
FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][
FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[
FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][
FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[
FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][
FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmk0080002bJeY_Nf]JJgY[FVmkJeY[
NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_
Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeX0
06]J001[FP00JeY_Nf]JJgY[FVmk001[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_
Nf]JJgX006mkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[
NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_
Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg/1JeX00;=[FP03001[FV]J049[
FP05001[FP00JeX00006JeX00`00JeY[FP0CJeX00`00JeY[FP1<JeX0003kKg][FV]jJeY_Nf]JJgY[
FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][
FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[
FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][
FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[
FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][
FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NP00Kg][FV]jJeY_Nf]JJgY[
FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][
FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[
FP00JeY[NP020000JV]JJgY[FVmkJeY[NP00Kg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_
Nf]JJgY[FVmkJeX006]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[
NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_
Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]j0F]J002cJeX00`00JeY[
FP13JeX01@00JeX006]J00001V]J00<006]JJeX04f]J00<006]JJeX0Bf]J0000of]jJeY_Nf]JJgY[
FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][
FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[
FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][
FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[
FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][
FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg/006]jJeY_Nf]JJgY[
FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][
FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[
FVmkJeY[NP00Kg/006]j001_N`00J6]JJgY[FVmkJeX006]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]J
Kg][FV]jJeY_Nf]JJgY[FVmk001[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]J
JgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]J
Kg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg/1JeX00;=[FP03
001[FV]J04=[FP05001[FP00JeX00007JeX00`00JeY[FP0CJeX00`00JeY[FP1:JeX0002cKg][FV]j
JeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmk
JeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]j
JeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmk
JeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]j
JeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmk
JeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NP020000/V]J
JgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]J
Kg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]J
JgY[FVmkJeY[NV]JKg][FP00JeX006]J001[FVmkJeY[NV]JKg/006]jJeY_Nf]JJgY[FVmkJeY[NV]J
Kg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]J001[FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]J
JgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]J
Kg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]j0F]J002c
JeX00`00JeY[FP14JeX01@00JeX006]J00001V]J00<006]JJeX056]J00<006]JJeX0BF]J0000of]j
JeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmk
JeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]j
JeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmk
JeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]j
JeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmk
JeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg/006]j
JeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmk
JeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]j
JeY_Nf]JJgY[FVmkJeY[NV]J001[FP00JeX00000J6]JJgY[FVmkJeY[NV]J001[FV]jJeY_Nf]JJgY[
FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NP00Kg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][
FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[
FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg/1
JeX00:5[FP@000A[FP@000I[FP03001[FV]J04E[FP05001[FP00JeX00006JeX00`00JeY[FP0DJeX0
0`00JeY[FP18JeX0003oKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[
NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_
Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[
NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_
Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[
NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeX006]JJgY[FVmk001[NV]J001[FV]jJeY_
N`00JgY[FVmkJeY[NP00Kg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[
NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_
Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NP00Kg/006]j001X001_Nf]JJgY[FVmk
JeY[NP00Kg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmk001[NV]JKg][FV]j
JeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmk
JeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]j
JeY_Nf]JJgY[FVmkJeY[NP5[FP00YF]J00@006]JJeX000A[FP03001[FV]J00=[FP03001[FV]J04E[
FP03001[FP00009[FP03001[FV]J00A[FP03001[FV]J01A[FP03001[FV]J04M[FP000;=[NV]JKg][
FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[
FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][
FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[
FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][
FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[
FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgX006mkJeX006]JKg][FV]j001_Nf]JJgY[FVmk00<0002aKg][
FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[
FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][
FV]jJeY_Nf]JJgY[FVmk001[NP00Kg][FP00JeY_Nf]JJgY[FVmk001[NV]JKg][FV]jJeY_Nf]JJgY[
FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FP00JeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][
FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[
FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmk005[FP00XF]J
10000f]J00<006]JJeX00V]J00<006]JJeX00f]J00<006]JJeX0AV]J00D006]J001[FP0000M[FP03
001[FV]J01A[FP03001[FV]J04I[FP000?m_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmk
JeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]j
JeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmk
JeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]j
JeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmk
JeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmk001[NV]JKg][FV]j
JeX006]JJgY[FVmk001[NV]JKg][FV]j001_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmk
JeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]j
JeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeX006]J000006Q[
FVmk001[NV]JKg][FV]jJeX006]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][
FV]j001_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[
FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][
FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]j0F]J002QJeX00`00JeY[FP04JeX00`00JeY[FP02JeX0
0`00JeY[FP03JeX00`00JeY[FP16JeX00`00JeX00002JeX00`00JeY[FP05JeX00`00JeY[FP0DJeX0
0`00JeY[FP15JeX0002QJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_
Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[
NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_
Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[
NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_
Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NP0500000fmkJeY[NP040000^V]JKg][
FV]jJeY_N`00JgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[
FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][
FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]J001[FP00JeY[NP00Kg][FV]jJeY_Nf]JJgX0
06mkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]J001[FVmkJeY[NV]JKg][
FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[
FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][
FV]jJeY_N`5[FP00/f]J00<006]JJeX0Af]J00<006]J00000V]J00<006]JJeX016]J00<006]JJeX0
5F]J00<006]JJeX0A6]J0000ofmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_
Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[
NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_
Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[
NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_
Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[
NV]JKg][FV]jJeY_Nf]JJgX006mkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_
Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[
NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmk001[NP00J000Kg][FP00
JeY_Nf]JJgY[FVmkJeX006]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmk
001[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]j
JeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmk
JeY[NV]JKg][FV]jJeY_Nf]JJgX1JeX00;=[FP8004Q[FP03001[FP00009[FP03001[FV]J00E[FP03
001[FV]J01A[FP03001[FV]J04A[FP000?m[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]j
JeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmk
JeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]j
JeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmk
JeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]j
JeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmk
JeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmk001[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]j
JeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmk
JeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NP00Kg/006Q[
FP00JeY_N`00JgY[FVmkJeY[NV]J001[FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[
FVmkJeY[NV]J001[FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][
FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[
FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmk0F]J002cJeX00`00JeY[FP18JeX00`00JeX00002JeX0
0`00JeY[FP04JeX00`00JeY[FP0EJeX00`00JeY[FP13JeX0003oKg][FV]jJeY_Nf]JJgY[FVmkJeY[
NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_
Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[
NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_
Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[
NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_
Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NP00Kg][FV]jJeY_Nf]JJgY[FVmkJeY[
NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_
Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[
NV]JKg][FP00001XJeX006]JJgX006mkJeY[NV]JKg][FV]j001_Nf]JJgY[FVmkJeY[NV]JKg][FV]j
JeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]j001_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmk
JeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]j
JeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NP5[FP00/f]J00<006]JJeX0B6]J
00<006]J00000V]J00<006]JJeX01F]J00<006]JJeX05F]J00<006]JJeX0@V]J0000of]jJeY_Nf]J
JgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]J
Kg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]J
JgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]J
Kg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]J
JgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]J
Kg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg/006]jJeY_Nf]J
JgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]J
Kg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]J
JgY[FVmkJeY[NV]JKg][FV]jJeX00000J6]JJgX006mkJeX006]JKg][FV]jJeY_N`00JgY[FVmkJeY[
NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]J001[FVmkJeY[NV]JKg][FV]jJeY_
Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[
NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg/1JeX00;=[
FP8004Y[FP03001[FP00009[FP03001[FV]J00E[FP03001[FV]J01E[FP03001[FV]J045[FP000?m_
Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[
NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_
Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[
NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_
Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[
NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]j001_
Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[
NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_
Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgX006P006mk001[NV]J001[FV]jJeY_Nf]JJgY[FP00
JeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FP00JeY[NV]JKg][FV]j
JeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmk
JeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]j
0F]J002cJeX00`00JeY[FP19JeX00`00JeX00002JeX00`00JeY[FP05JeX00`00JeY[FP0FJeX00`00
JeY[FP10JeX0003oJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]J
JgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]J
Kg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]J
JgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]J
Kg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]J
JgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]J
Kg][FV]jJeY_N`00JgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]J
JgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]J
Kg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmk001X001[NV]J001[FV]j001_
Nf]JJgY[FVmkJeX006]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[
NP00Kg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_
Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[
NV]JKg][FV]jJeY_N`5[FP00/f]J00<006]JJeX0BV]J00<006]J00000V]J00<006]JJeX01F]J00<0
06]JJeX05F]J00<006]JJeX0@6]J0000ofmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][
FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[
FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][
FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[
FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][
FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[
FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgX006mkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][
FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[
FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NP00J6]J
001[FP00JeY_N`00JgY[FVmkJeY[NV]JKg/006]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]J
JgY[FVmkJeY[NV]JKg/006]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]J
Kg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]J
JgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgX1JeX00;=[FP8004][FP03001[FP00009[FP03001[FV]J
00E[FP03001[FV]J01I[FP03001[FV]J03m[FP000?m[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]J
Kg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]J
JgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]J
Kg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]J
JgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]J
Kg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]J
JgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmk001[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]J
Kg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]J
JgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]J
Kg/006Q[FP00JeY_N`00JgX006mkJeY[NV]JKg][FV]j001_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_
Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeX006]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[
NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_
Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmk0F]J002cJeX00`00JeY[FP1;JeX00`00JeX0
0002JeX00`00JeY[FP05JeX00`00JeY[FP0EJeX00`00JeY[FP0oJeX0003oKg][FV]jJeY_Nf]JJgY[
FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][
FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[
FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][
FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[
FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][
FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NP00Kg][FV]jJeY_Nf]JJgY[
FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][
FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[
FVmkJeY[NV]JKg][FV]j001XJeY_N`00JgX006mkJeX006]JKg][FV]jJeY_Nf]J001[FVmkJeY[NV]J
Kg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]J001[FVmkJeY[NV]JKg][FV]jJeY_Nf]J
JgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]J
Kg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NP5[FP00/f]J00<006]J
JeX0Bf]J00<006]J00000V]J00<006]JJeX01F]J00<006]JJeX05V]J00<006]JJeX0?V]J0000of]j
JeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmk
JeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]j
JeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmk
JeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]j
JeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmk
JeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg/006]j
JeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmk
JeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]j
JeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_N`00J6]JJgX006mk001[NV]J001[FV]jJeY_Nf]JJgY[
FVmk001[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmk001[NV]JKg][
FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[
FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg/1
JeX00;=[FP03001[FV]J04a[FP05001[FP00JeX00008JeX00`00JeY[FP0EJeX00`00JeY[FP0nJeX0
002cKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_
Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[
NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_
Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[
NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_
Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[
NP020000/V]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[
FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][
FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeX006]J001[FV]j001_Nf]JJgY[
FVmkJeY[NP00Kg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NP00Kg][
FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[
FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][
FV]j0F]J002cJeX00`00JeY[FP1<JeX00`00JeX00002JeX00`00JeY[FP05JeX00`00JeY[FP0FJeX0
0`00JeY[FP0mJeX0003oJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_
Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[
NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_
Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[
NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_
Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[
NV]JKg][FV]jJeY_N`00JgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_
Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[
NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmk001XJeY[NV]J001[FP00
JeY_N`00JgY[FVmkJeY[NV]JKg][FP00JeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmk
JeY[NV]JKg][FP00JeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]j
JeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmk
JeY[NV]JKg][FV]jJeY_N`5[FP00Xf]J00<006]JJeX00f]J10001V]J00<006]JJeX0CF]J00D006]J
001[FP0000Q[FP03001[FV]J01E[FP03001[FV]J03e[FP000?m_Nf]JJgY[FVmkJeY[NV]JKg][FV]j
JeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmk
JeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]j
JeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmk
JeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]j
JeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmk
JeY[NP00Kg][FV]jJeX006]JJgY[FVmk001[NV]JKg][FV]j001_Nf]JJgY[FVmkJeY[NV]JKg][FV]j
JeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmk
JeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]j
JeY_Nf]JJgX006Q[FVmkJeY[NP00Kg/006]jJeX006]JJgY[FVmkJeY[NV]J001[FV]jJeY_Nf]JJgY[
FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg/006]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][
FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[
FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]j0F]J002SJeX00`00JeY[FP07JeX0
0`00JeY[FP03JeX00`00JeY[FP1=JeX00`00JeX00002JeX00`00JeY[FP05JeX00`00JeY[FP0FJeX0
0`00JeY[FP0lJeX0002cJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_
Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[
NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_
Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[
NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_
Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FP00JeY_Nf]JJgY[FVmkJeY[
NP00Kg][FV]jJeY_N`030000/FmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_
Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[
NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg/006]j001_
Nf]J001[FVmkJeY[NV]JKg][FV]j001_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[
NV]JKg][FV]j001_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_
Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[
NV]JKg][FV]jJeY_N`01JeX00:A[FP03001[FV]J009[FP@000I[FP03001[FV]J04e[FP06001[FV]J
001[FP0026]J00<006]JJeX05F]J00<006]JJeX0?6]J0000ofmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[
FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][
FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[
FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][
FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[
FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][
FV]jJeY_N`00JgY[FVmk001[NV]JKg][FV]jJeY_Nf]JJgX006mkJeY[NV]JKg][FV]jJeY_Nf]JJgY[
FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][
FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[
FVmkJeY[NP00J6]JKg][FV]jJeX006]J001[FP00JeY[NV]JKg][FV]jJeY_N`00JgY[FVmkJeY[NV]J
Kg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]J001[FVmkJeY[NV]JKg][FV]jJeY_Nf]J
JgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]J
Kg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgX1JeX00:1[FP03001[FV]J009[FP05
001[FV]JJeX00009JeX00`00JeY[FP1>JeX00`00JeX00002JeX00`00JeY[FP05JeX00`00JeY[FP0F
JeX00`00JeY[FP0kJeX0002PJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]j
JeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmk
JeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]j
JeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmk
JeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]j
JeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeX600000fmkJeY[NP050000^FmkJeY[
NV]JKg/006]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_
Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[
NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeX006]J001[FV]j001_
Nf]JJgY[FVmkJeY[NP00Kg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[
NV]J001[FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_
Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[
NV]JKg/00F]J002cJeX00`00JeY[FP1>JeX00`00JeX00002JeX00`00JeY[FP06JeX00`00JeY[FP0E
JeX00`00JeY[FP0kJeX0002cKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmk
JeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]j
JeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmk
JeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]j
JeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmk
JeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]j
JeY_Nf]JJgY[FVmkJeY[NP020000/V]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]J
Kg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]J
JgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]J
Kg/006]j001_N`00JgY[FVmkJeY[NV]JKg][FP00JeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]J
JgY[FVmkJeY[NV]JKg][FV]j001_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]J
Kg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]J
JgY[FVmkJeY[NV]JKg][FV]j0F]J002cJeX00`00JeY[FP1?JeX01@00JeX006]J000026]J00<006]J
JeX05V]J00<006]JJeX0>V]J0000of]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmk
JeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]j
JeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmk
JeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]j
JeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmk
JeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]j
JeY_Nf]JJgY[FVmkJeY[NV]JKg/006]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmk
JeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]j
JeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_N`00J6]JJgY[
FVmkJeY[NP00Kg/006]jJeX006]JJgY[FVmkJeY[NV]J001[FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][
FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg/006]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[
FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][
FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg/1JeX00;=[FP03001[FV]J04m[FP03001[FP00009[FP03001[
FV]J00E[FP03001[FV]J01M[FP03001[FV]J03U[FP000?m_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_
Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[
NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_
Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[
NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_
Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[
NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]j001_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_
Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[
NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_
Nf]JJgX006Q[FVmkJeY[NV]JKg/006]jJeX006]J001[FVmkJeY[NV]JKg][FV]j001_Nf]JJgY[FVmk
JeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeX006]JJgY[FVmkJeY[NV]JKg][FV]j
JeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmk
JeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]j0F]J002cJeX00`00JeY[FP1@JeX01@00
JeX006]J000026]J00<006]JJeX05V]J00<006]JJeX0>F]J0000of]jJeY_Nf]JJgY[FVmkJeY[NV]J
Kg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]J
JgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]J
Kg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]J
JgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]J
Kg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]J
JgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg/006]jJeY_Nf]JJgY[FVmkJeY[NV]J
Kg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]J
JgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]J
Kg][FV]jJeY_N`00J6]JJgY[FVmkJeY[NV]J001[FP00JeX006]JJgY[FVmkJeY[NV]JKg/006]jJeY_
Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FP00JeY_Nf]JJgY[FVmkJeY[
NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_
Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg/1JeX00;=[FP80055[FP05001[
FP00JeX00008JeX00`00JeY[FP0GJeX00`00JeY[FP0hJeX0003oKg][FV]jJeY_Nf]JJgY[FVmkJeY[
NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_
Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[
NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_
Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[
NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_
Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NP00Kg][FV]jJeY_Nf]JJgY[FVmkJeY[
NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_
Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[
NV]JKg][FV]j001XJeY_Nf]JJgY[FVmkJeX006]J001[FV]j001_Nf]JJgY[FVmkJeY[NP00Kg][FV]j
JeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg/006]jJeY_Nf]JJgY[FVmk
JeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]j
JeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NP5[FP00/f]J00<006]JJeX0D6]J
00<006]J00000V]J00<006]JJeX01V]J00<006]JJeX05V]J00<006]JJeX0>6]J0000of]jJeY_Nf]J
JgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]J
Kg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]J
JgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]J
Kg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]J
JgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]J
Kg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg/006]jJeY_Nf]J
JgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]J
Kg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]J
JgY[FVmkJeY[NV]JKg][FV]jJeY_N`0026]JJgY[FVmkJeY[NV]JKg/20000GV]JKg/006]jJeY_Nf]J
JgY[FVmkJeX006]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NP00
Kg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]J
JgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmk0F]J002c
JeX00`00JeY[FP1AJeX01@00JeX006]J000026]J00<006]JJeX05f]J00<006]JJeX0=f]J0000ofmk
JeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]j
JeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmk
JeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]j
JeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmk
JeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]j
JeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgX006mk
JeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]j
JeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmk
JeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NP00J6]JKg][FV]jJeY_Nf]JJgX006mk001[NP00Kg][
FV]jJeY_Nf]JJgY[FP00JeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[
FVmkJeX006]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][
FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgX1
JeX00;=[FP80059[FP05001[FP00JeX00008JeX00`00JeY[FP0GJeX00`00JeY[FP0gJeX0003oJgY[
FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][
FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[
FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][
FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[
FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][
FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_N`00JgY[
FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][
FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[
FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmk0009JeY[NV]JKg][FV]jJeY_Nf]J0080001MKg][FP00
JeY_Nf]JJgY[FVmkJeY[NP00Kg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmk
JeY[NV]J001[FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]j
JeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmk
005[FP00/f]J00<006]JJeX0DV]J0P000V]J00<006]JJeX01V]J00<006]JJeX05f]J00<006]JJeX0
=V]J0000ofmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[
NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_
Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[
NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_
Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[
NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_
Nf]JJgX006mkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[
NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_
Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NP002F]JKg][FV]jJeY_Nf]JJgY[FP02
0000GF]jJeX006]JJgY[FVmkJeY[NV]JKg/006]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]J
JgY[FVmkJeY[NV]JKg][FV]j001_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]J
Kg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]J
JgY[FVmkJeY[NP01JeX00001\
\>"],
  ImageRangeCache->{{{140.063, 427.063}, {284.625, 107.688}} -> {-6.23999, \
24.4834, 0.0220057, 0.985335}}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(asSum\  /@ \ partitionsOdd[10] // TableForm\)], "Input"],

Cell[BoxData[
    InterpretationBox[GridBox[{
          {
            TagBox[
              RowBox[{"1", "+", 
                TagBox[
                  RowBox[{"1", "+", 
                    TagBox[
                      RowBox[{"1", "+", 
                        TagBox[
                          RowBox[{"1", "+", 
                            TagBox[
                              RowBox[{"1", "+", 
                                TagBox[
                                  RowBox[{"1", "+", 
                                    TagBox[
                                      RowBox[{"1", "+", 
                                        TagBox[
                                        RowBox[{"1", "+", 
                                        TagBox[\(1 + 1\),
                                        DisplayForm]}],
                                        DisplayForm]}],
                                      DisplayForm]}],
                                  DisplayForm]}],
                              DisplayForm]}],
                          DisplayForm]}],
                      DisplayForm]}],
                  DisplayForm]}],
              DisplayForm]},
          {
            TagBox[
              RowBox[{"1", "+", 
                TagBox[
                  RowBox[{"1", "+", 
                    TagBox[
                      RowBox[{"1", "+", 
                        TagBox[
                          RowBox[{"1", "+", 
                            TagBox[
                              RowBox[{"1", "+", 
                                TagBox[
                                  RowBox[{"1", "+", 
                                    TagBox[\(1 + 3\),
                                      DisplayForm]}],
                                  DisplayForm]}],
                              DisplayForm]}],
                          DisplayForm]}],
                      DisplayForm]}],
                  DisplayForm]}],
              DisplayForm]},
          {
            TagBox[
              RowBox[{"1", "+", 
                TagBox[
                  RowBox[{"1", "+", 
                    TagBox[
                      RowBox[{"1", "+", 
                        TagBox[
                          RowBox[{"1", "+", 
                            TagBox[\(1 + 5\),
                              DisplayForm]}],
                          DisplayForm]}],
                      DisplayForm]}],
                  DisplayForm]}],
              DisplayForm]},
          {
            TagBox[
              RowBox[{"1", "+", 
                TagBox[
                  RowBox[{"1", "+", 
                    TagBox[
                      RowBox[{"1", "+", 
                        TagBox[
                          RowBox[{"1", "+", 
                            TagBox[\(3 + 3\),
                              DisplayForm]}],
                          DisplayForm]}],
                      DisplayForm]}],
                  DisplayForm]}],
              DisplayForm]},
          {
            TagBox[
              RowBox[{"1", "+", 
                TagBox[
                  RowBox[{"1", "+", 
                    TagBox[\(1 + 7\),
                      DisplayForm]}],
                  DisplayForm]}],
              DisplayForm]},
          {
            TagBox[
              RowBox[{"1", "+", 
                TagBox[
                  RowBox[{"1", "+", 
                    TagBox[\(3 + 5\),
                      DisplayForm]}],
                  DisplayForm]}],
              DisplayForm]},
          {
            TagBox[
              RowBox[{"1", "+", 
                TagBox[
                  RowBox[{"3", "+", 
                    TagBox[\(3 + 3\),
                      DisplayForm]}],
                  DisplayForm]}],
              DisplayForm]},
          {
            TagBox[\(1 + 9\),
              DisplayForm]},
          {
            TagBox[\(3 + 7\),
              DisplayForm]},
          {
            TagBox[\(5 + 5\),
              DisplayForm]}
          },
        RowSpacings->1,
        ColumnSpacings->3,
        RowAlignments->Baseline,
        ColumnAlignments->{Left}],
      TableForm[ {
        DisplayForm[ 
          RowBox[ {"1", "+", 
            DisplayForm[ 
              RowBox[ {"1", "+", 
                DisplayForm[ 
                  RowBox[ {"1", "+", 
                    DisplayForm[ 
                      RowBox[ {"1", "+", 
                        DisplayForm[ 
                          RowBox[ {"1", "+", 
                            DisplayForm[ 
                              RowBox[ {"1", "+", 
                                DisplayForm[ 
                                  RowBox[ {"1", "+", 
                                    DisplayForm[ 
                                      RowBox[ {"1", "+", 
                                        DisplayForm[ 
                                        
                                        RowBox[ {"1", "+", 
                                        "1"}]]}]]}]]}]]}]]}]]}]]}]]}]], 
        DisplayForm[ 
          RowBox[ {"1", "+", 
            DisplayForm[ 
              RowBox[ {"1", "+", 
                DisplayForm[ 
                  RowBox[ {"1", "+", 
                    DisplayForm[ 
                      RowBox[ {"1", "+", 
                        DisplayForm[ 
                          RowBox[ {"1", "+", 
                            DisplayForm[ 
                              RowBox[ {"1", "+", 
                                DisplayForm[ 
                                  RowBox[ {"1", "+", "3"}]]}]]}]]}]]}]]}]]}]],
         
        DisplayForm[ 
          RowBox[ {"1", "+", 
            DisplayForm[ 
              RowBox[ {"1", "+", 
                DisplayForm[ 
                  RowBox[ {"1", "+", 
                    DisplayForm[ 
                      RowBox[ {"1", "+", 
                        DisplayForm[ 
                          RowBox[ {"1", "+", "5"}]]}]]}]]}]]}]], 
        DisplayForm[ 
          RowBox[ {"1", "+", 
            DisplayForm[ 
              RowBox[ {"1", "+", 
                DisplayForm[ 
                  RowBox[ {"1", "+", 
                    DisplayForm[ 
                      RowBox[ {"1", "+", 
                        DisplayForm[ 
                          RowBox[ {"3", "+", "3"}]]}]]}]]}]]}]], 
        DisplayForm[ 
          RowBox[ {"1", "+", 
            DisplayForm[ 
              RowBox[ {"1", "+", 
                DisplayForm[ 
                  RowBox[ {"1", "+", "7"}]]}]]}]], 
        DisplayForm[ 
          RowBox[ {"1", "+", 
            DisplayForm[ 
              RowBox[ {"1", "+", 
                DisplayForm[ 
                  RowBox[ {"3", "+", "5"}]]}]]}]], 
        DisplayForm[ 
          RowBox[ {"1", "+", 
            DisplayForm[ 
              RowBox[ {"3", "+", 
                DisplayForm[ 
                  RowBox[ {"3", "+", "3"}]]}]]}]], 
        DisplayForm[ 
          RowBox[ {"1", "+", "9"}]], 
        DisplayForm[ 
          RowBox[ {"3", "+", "7"}]], 
        DisplayForm[ 
          RowBox[ {"5", "+", "5"}]]}]]], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(Table[Length[partitionsOdd[n]], {n, 20}]\)], "Input"],

Cell[BoxData[
    \({1, 1, 2, 2, 3, 4, 5, 6, 8, 10, 12, 15, 18, 22, 27, 32, 38, 46, 54, 
      64}\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(f[Range[1, 11, 2]] + O[x]\^11\)], "Input"],

Cell[BoxData[
    InterpretationBox[
      RowBox[{
      "1", "+", "x", "+", \(x\^2\), "+", \(2\ x\^3\), "+", \(2\ x\^4\), 
        "+", \(3\ x\^5\), "+", \(4\ x\^6\), "+", \(5\ x\^7\), 
        "+", \(6\ x\^8\), "+", \(8\ x\^9\), "+", \(10\ x\^10\), "+", 
        InterpretationBox[\(O[x]\^11\),
          SeriesData[ x, 0, {}, 0, 11, 1]]}],
      SeriesData[ 
      x, 0, {1, 1, 1, 2, 2, 3, 4, 5, 6, 8, 10}, 0, 11, 1]]], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(asSum\  /@ \ partitionsDif[10] // TableForm\)], "Input"],

Cell[BoxData[
    InterpretationBox[GridBox[{
          {
            TagBox[
              RowBox[{"1", "+", 
                TagBox[
                  RowBox[{"2", "+", 
                    TagBox[\(3 + 4\),
                      DisplayForm]}],
                  DisplayForm]}],
              DisplayForm]},
          {
            TagBox[
              RowBox[{"1", "+", 
                TagBox[\(2 + 7\),
                  DisplayForm]}],
              DisplayForm]},
          {
            TagBox[
              RowBox[{"1", "+", 
                TagBox[\(3 + 6\),
                  DisplayForm]}],
              DisplayForm]},
          {
            TagBox[
              RowBox[{"1", "+", 
                TagBox[\(4 + 5\),
                  DisplayForm]}],
              DisplayForm]},
          {
            TagBox[\(1 + 9\),
              DisplayForm]},
          {
            TagBox[
              RowBox[{"2", "+", 
                TagBox[\(3 + 5\),
                  DisplayForm]}],
              DisplayForm]},
          {
            TagBox[\(2 + 8\),
              DisplayForm]},
          {
            TagBox[\(3 + 7\),
              DisplayForm]},
          {
            TagBox[\(4 + 6\),
              DisplayForm]},
          {"\<\"10\"\>"}
          },
        RowSpacings->1,
        ColumnSpacings->3,
        RowAlignments->Baseline,
        ColumnAlignments->{Left}],
      TableForm[ {
        DisplayForm[ 
          RowBox[ {"1", "+", 
            DisplayForm[ 
              RowBox[ {"2", "+", 
                DisplayForm[ 
                  RowBox[ {"3", "+", "4"}]]}]]}]], 
        DisplayForm[ 
          RowBox[ {"1", "+", 
            DisplayForm[ 
              RowBox[ {"2", "+", "7"}]]}]], 
        DisplayForm[ 
          RowBox[ {"1", "+", 
            DisplayForm[ 
              RowBox[ {"3", "+", "6"}]]}]], 
        DisplayForm[ 
          RowBox[ {"1", "+", 
            DisplayForm[ 
              RowBox[ {"4", "+", "5"}]]}]], 
        DisplayForm[ 
          RowBox[ {"1", "+", "9"}]], 
        DisplayForm[ 
          RowBox[ {"2", "+", 
            DisplayForm[ 
              RowBox[ {"3", "+", "5"}]]}]], 
        DisplayForm[ 
          RowBox[ {"2", "+", "8"}]], 
        DisplayForm[ 
          RowBox[ {"3", "+", "7"}]], 
        DisplayForm[ 
          RowBox[ {"4", "+", "6"}]], "10"}]]], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(Table[Length[partitionsDif[n]], {n, 20}]\)], "Input"],

Cell[BoxData[
    \({1, 1, 2, 2, 3, 4, 5, 6, 8, 10, 12, 15, 18, 22, 27, 32, 38, 46, 54, 
      64}\)], "Output"]
}, Open  ]],

Cell["\<\
Theorem. The number of partitions of n into unequal parts is equal to the \
number of its partitions into odd parts\
\>", "Text"]
}, Closed]],

Cell[CellGroupData[{

Cell["DISTINCTIVE FAMILIES OF PARTITIONS", "Subsection"],

Cell[CellGroupData[{

Cell["BINARY PARTITIONS. ", "Subsubsection"],

Cell["Those are sums of powers of 2.", "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(asSum\  /@ partH[2\^Range[0, 5], 10] // TableForm\)], "Input"],

Cell[BoxData[
    InterpretationBox[GridBox[{
          {
            TagBox[
              RowBox[{"1", "+", 
                TagBox[
                  RowBox[{"1", "+", 
                    TagBox[
                      RowBox[{"1", "+", 
                        TagBox[
                          RowBox[{"1", "+", 
                            TagBox[
                              RowBox[{"1", "+", 
                                TagBox[
                                  RowBox[{"1", "+", 
                                    TagBox[
                                      RowBox[{"1", "+", 
                                        TagBox[
                                        RowBox[{"1", "+", 
                                        TagBox[\(1 + 1\),
                                        DisplayForm]}],
                                        DisplayForm]}],
                                      DisplayForm]}],
                                  DisplayForm]}],
                              DisplayForm]}],
                          DisplayForm]}],
                      DisplayForm]}],
                  DisplayForm]}],
              DisplayForm]},
          {
            TagBox[
              RowBox[{"1", "+", 
                TagBox[
                  RowBox[{"1", "+", 
                    TagBox[
                      RowBox[{"1", "+", 
                        TagBox[
                          RowBox[{"1", "+", 
                            TagBox[
                              RowBox[{"1", "+", 
                                TagBox[
                                  RowBox[{"1", "+", 
                                    TagBox[
                                      RowBox[{"1", "+", 
                                        TagBox[\(1 + 2\),
                                        DisplayForm]}],
                                      DisplayForm]}],
                                  DisplayForm]}],
                              DisplayForm]}],
                          DisplayForm]}],
                      DisplayForm]}],
                  DisplayForm]}],
              DisplayForm]},
          {
            TagBox[
              RowBox[{"1", "+", 
                TagBox[
                  RowBox[{"1", "+", 
                    TagBox[
                      RowBox[{"1", "+", 
                        TagBox[
                          RowBox[{"1", "+", 
                            TagBox[
                              RowBox[{"1", "+", 
                                TagBox[
                                  RowBox[{"1", "+", 
                                    TagBox[\(2 + 2\),
                                      DisplayForm]}],
                                  DisplayForm]}],
                              DisplayForm]}],
                          DisplayForm]}],
                      DisplayForm]}],
                  DisplayForm]}],
              DisplayForm]},
          {
            TagBox[
              RowBox[{"1", "+", 
                TagBox[
                  RowBox[{"1", "+", 
                    TagBox[
                      RowBox[{"1", "+", 
                        TagBox[
                          RowBox[{"1", "+", 
                            TagBox[
                              RowBox[{"1", "+", 
                                TagBox[\(1 + 4\),
                                  DisplayForm]}],
                              DisplayForm]}],
                          DisplayForm]}],
                      DisplayForm]}],
                  DisplayForm]}],
              DisplayForm]},
          {
            TagBox[
              RowBox[{"1", "+", 
                TagBox[
                  RowBox[{"1", "+", 
                    TagBox[
                      RowBox[{"1", "+", 
                        TagBox[
                          RowBox[{"1", "+", 
                            TagBox[
                              RowBox[{"2", "+", 
                                TagBox[\(2 + 2\),
                                  DisplayForm]}],
                              DisplayForm]}],
                          DisplayForm]}],
                      DisplayForm]}],
                  DisplayForm]}],
              DisplayForm]},
          {
            TagBox[
              RowBox[{"1", "+", 
                TagBox[
                  RowBox[{"1", "+", 
                    TagBox[
                      RowBox[{"1", "+", 
                        TagBox[
                          RowBox[{"1", "+", 
                            TagBox[\(2 + 4\),
                              DisplayForm]}],
                          DisplayForm]}],
                      DisplayForm]}],
                  DisplayForm]}],
              DisplayForm]},
          {
            TagBox[
              RowBox[{"1", "+", 
                TagBox[
                  RowBox[{"1", "+", 
                    TagBox[
                      RowBox[{"2", "+", 
                        TagBox[
                          RowBox[{"2", "+", 
                            TagBox[\(2 + 2\),
                              DisplayForm]}],
                          DisplayForm]}],
                      DisplayForm]}],
                  DisplayForm]}],
              DisplayForm]},
          {
            TagBox[
              RowBox[{"1", "+", 
                TagBox[
                  RowBox[{"1", "+", 
                    TagBox[
                      RowBox[{"2", "+", 
                        TagBox[\(2 + 4\),
                          DisplayForm]}],
                      DisplayForm]}],
                  DisplayForm]}],
              DisplayForm]},
          {
            TagBox[
              RowBox[{"1", "+", 
                TagBox[
                  RowBox[{"1", "+", 
                    TagBox[\(4 + 4\),
                      DisplayForm]}],
                  DisplayForm]}],
              DisplayForm]},
          {
            TagBox[
              RowBox[{"1", "+", 
                TagBox[\(1 + 8\),
                  DisplayForm]}],
              DisplayForm]},
          {
            TagBox[
              RowBox[{"2", "+", 
                TagBox[
                  RowBox[{"2", "+", 
                    TagBox[
                      RowBox[{"2", "+", 
                        TagBox[\(2 + 2\),
                          DisplayForm]}],
                      DisplayForm]}],
                  DisplayForm]}],
              DisplayForm]},
          {
            TagBox[
              RowBox[{"2", "+", 
                TagBox[
                  RowBox[{"2", "+", 
                    TagBox[\(2 + 4\),
                      DisplayForm]}],
                  DisplayForm]}],
              DisplayForm]},
          {
            TagBox[
              RowBox[{"2", "+", 
                TagBox[\(4 + 4\),
                  DisplayForm]}],
              DisplayForm]},
          {
            TagBox[\(2 + 8\),
              DisplayForm]}
          },
        RowSpacings->1,
        ColumnSpacings->3,
        RowAlignments->Baseline,
        ColumnAlignments->{Left}],
      TableForm[ {
        DisplayForm[ 
          RowBox[ {"1", "+", 
            DisplayForm[ 
              RowBox[ {"1", "+", 
                DisplayForm[ 
                  RowBox[ {"1", "+", 
                    DisplayForm[ 
                      RowBox[ {"1", "+", 
                        DisplayForm[ 
                          RowBox[ {"1", "+", 
                            DisplayForm[ 
                              RowBox[ {"1", "+", 
                                DisplayForm[ 
                                  RowBox[ {"1", "+", 
                                    DisplayForm[ 
                                      RowBox[ {"1", "+", 
                                        DisplayForm[ 
                                        
                                        RowBox[ {"1", "+", 
                                        "1"}]]}]]}]]}]]}]]}]]}]]}]]}]], 
        DisplayForm[ 
          RowBox[ {"1", "+", 
            DisplayForm[ 
              RowBox[ {"1", "+", 
                DisplayForm[ 
                  RowBox[ {"1", "+", 
                    DisplayForm[ 
                      RowBox[ {"1", "+", 
                        DisplayForm[ 
                          RowBox[ {"1", "+", 
                            DisplayForm[ 
                              RowBox[ {"1", "+", 
                                DisplayForm[ 
                                  RowBox[ {"1", "+", 
                                    DisplayForm[ 
                                      
                                      RowBox[ {"1", "+", 
                                        "2"}]]}]]}]]}]]}]]}]]}]]}]], 
        DisplayForm[ 
          RowBox[ {"1", "+", 
            DisplayForm[ 
              RowBox[ {"1", "+", 
                DisplayForm[ 
                  RowBox[ {"1", "+", 
                    DisplayForm[ 
                      RowBox[ {"1", "+", 
                        DisplayForm[ 
                          RowBox[ {"1", "+", 
                            DisplayForm[ 
                              RowBox[ {"1", "+", 
                                DisplayForm[ 
                                  RowBox[ {"2", "+", "2"}]]}]]}]]}]]}]]}]]}]],
         
        DisplayForm[ 
          RowBox[ {"1", "+", 
            DisplayForm[ 
              RowBox[ {"1", "+", 
                DisplayForm[ 
                  RowBox[ {"1", "+", 
                    DisplayForm[ 
                      RowBox[ {"1", "+", 
                        DisplayForm[ 
                          RowBox[ {"1", "+", 
                            DisplayForm[ 
                              RowBox[ {"1", "+", "4"}]]}]]}]]}]]}]]}]], 
        DisplayForm[ 
          RowBox[ {"1", "+", 
            DisplayForm[ 
              RowBox[ {"1", "+", 
                DisplayForm[ 
                  RowBox[ {"1", "+", 
                    DisplayForm[ 
                      RowBox[ {"1", "+", 
                        DisplayForm[ 
                          RowBox[ {"2", "+", 
                            DisplayForm[ 
                              RowBox[ {"2", "+", "2"}]]}]]}]]}]]}]]}]], 
        DisplayForm[ 
          RowBox[ {"1", "+", 
            DisplayForm[ 
              RowBox[ {"1", "+", 
                DisplayForm[ 
                  RowBox[ {"1", "+", 
                    DisplayForm[ 
                      RowBox[ {"1", "+", 
                        DisplayForm[ 
                          RowBox[ {"2", "+", "4"}]]}]]}]]}]]}]], 
        DisplayForm[ 
          RowBox[ {"1", "+", 
            DisplayForm[ 
              RowBox[ {"1", "+", 
                DisplayForm[ 
                  RowBox[ {"2", "+", 
                    DisplayForm[ 
                      RowBox[ {"2", "+", 
                        DisplayForm[ 
                          RowBox[ {"2", "+", "2"}]]}]]}]]}]]}]], 
        DisplayForm[ 
          RowBox[ {"1", "+", 
            DisplayForm[ 
              RowBox[ {"1", "+", 
                DisplayForm[ 
                  RowBox[ {"2", "+", 
                    DisplayForm[ 
                      RowBox[ {"2", "+", "4"}]]}]]}]]}]], 
        DisplayForm[ 
          RowBox[ {"1", "+", 
            DisplayForm[ 
              RowBox[ {"1", "+", 
                DisplayForm[ 
                  RowBox[ {"4", "+", "4"}]]}]]}]], 
        DisplayForm[ 
          RowBox[ {"1", "+", 
            DisplayForm[ 
              RowBox[ {"1", "+", "8"}]]}]], 
        DisplayForm[ 
          RowBox[ {"2", "+", 
            DisplayForm[ 
              RowBox[ {"2", "+", 
                DisplayForm[ 
                  RowBox[ {"2", "+", 
                    DisplayForm[ 
                      RowBox[ {"2", "+", "2"}]]}]]}]]}]], 
        DisplayForm[ 
          RowBox[ {"2", "+", 
            DisplayForm[ 
              RowBox[ {"2", "+", 
                DisplayForm[ 
                  RowBox[ {"2", "+", "4"}]]}]]}]], 
        DisplayForm[ 
          RowBox[ {"2", "+", 
            DisplayForm[ 
              RowBox[ {"4", "+", "4"}]]}]], 
        DisplayForm[ 
          RowBox[ {"2", "+", "8"}]]}]]], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[{
    \(\(p = partH[2\^Range[0, 7], 25];\)\), "\[IndentingNewLine]", 
    \(\(m = Max[Length\  /@ \ p];\)\), "\[IndentingNewLine]", 
    \(\(u = \(PadRight[#, m] &\)\  /@ \ p;\)\), "\n", 
    \(\(ListDensityPlot[\(-Reverse[u]\), \ Mesh\  \[Rule] \ False, 
        AspectRatio \[Rule] Automatic, 
        FrameTicks \[Rule] None];\)\)}], "Input"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 3.76 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% DensityGraphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0192308 0.0384615 0.0723077 0.0384615 [
[ 0 0 -0.125 0 ]
[ 0 0 -0.125 0 ]
[ 0 3.76 .125 0 ]
[ 1 0 .125 0 ]
[ 0 0 0 0 ]
[ 1 3.76 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
0 0 m
1 0 L
s
0 0 m
0 3.76 L
s
0 3.76 m
1 3.76 L
s
1 0 m
1 3.76 L
s
0 0 m
1 0 L
1 3.76 L
0 3.76 L
closepath
clip
newpath
% Start of gray image
p
.01923 .07231 translate
.96154 3.61538 scale
25 string
25 94 8 [25 0 0 94 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
CC0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
CC000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
CC333300FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
CC33330000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
CC3333333300FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
CC333333333333FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
CC99993300FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
CC9999330000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
CC999933333300FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
CC99993333333333FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
CC9999999900FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
CC999999990000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
CC99999999333300FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
CC9999999933333333FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
CC9999999999993300FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
CC999999999999333333FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
CC999999999999999900FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
CC99999999999999993333FFFFFFFFFFFFFFFFFFFFFFFFFFFF
CC9999999999999999999933FFFFFFFFFFFFFFFFFFFFFFFFFF
CC999999999999999999999999FFFFFFFFFFFFFFFFFFFFFFFF
CCCCCC993300FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
CCCCCC99330000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
CCCCCC9933333300FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
CCCCCC993333333333FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
CCCCCC99999900FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
CCCCCC9999990000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
CCCCCC999999333300FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
CCCCCC99999933333333FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
CCCCCC99999999993300FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
CCCCCC9999999999333333FFFFFFFFFFFFFFFFFFFFFFFFFFFF
CCCCCC9999999999999900FFFFFFFFFFFFFFFFFFFFFFFFFFFF
CCCCCC999999999999993333FFFFFFFFFFFFFFFFFFFFFFFFFF
CCCCCC99999999999999999933FFFFFFFFFFFFFFFFFFFFFFFF
CCCCCC9999999999999999999999FFFFFFFFFFFFFFFFFFFFFF
CCCCCCCCCC3300FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
CCCCCCCCCC330000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
CCCCCCCCCC33333300FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
CCCCCCCCCC3333333333FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
CCCCCCCCCC999900FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
CCCCCCCCCC99990000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
CCCCCCCCCC9999333300FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
CCCCCCCCCC999933333333FFFFFFFFFFFFFFFFFFFFFFFFFFFF
CCCCCCCCCC999999993300FFFFFFFFFFFFFFFFFFFFFFFFFFFF
CCCCCCCCCC99999999333333FFFFFFFFFFFFFFFFFFFFFFFFFF
CCCCCCCCCC99999999999900FFFFFFFFFFFFFFFFFFFFFFFFFF
CCCCCCCCCC9999999999993333FFFFFFFFFFFFFFFFFFFFFFFF
CCCCCCCCCC999999999999999933FFFFFFFFFFFFFFFFFFFFFF
CCCCCCCCCC99999999999999999999FFFFFFFFFFFFFFFFFFFF
CCCCCCCCCCCCCC9900FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
CCCCCCCCCCCCCC990000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
CCCCCCCCCCCCCC99333300FFFFFFFFFFFFFFFFFFFFFFFFFFFF
CCCCCCCCCCCCCC9933333333FFFFFFFFFFFFFFFFFFFFFFFFFF
CCCCCCCCCCCCCC9999993300FFFFFFFFFFFFFFFFFFFFFFFFFF
CCCCCCCCCCCCCC999999333333FFFFFFFFFFFFFFFFFFFFFFFF
CCCCCCCCCCCCCC999999999900FFFFFFFFFFFFFFFFFFFFFFFF
CCCCCCCCCCCCCC99999999993333FFFFFFFFFFFFFFFFFFFFFF
CCCCCCCCCCCCCC9999999999999933FFFFFFFFFFFFFFFFFFFF
CCCCCCCCCCCCCC999999999999999999FFFFFFFFFFFFFFFFFF
CCCCCCCCCCCCCCCCCC00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
CCCCCCCCCCCCCCCCCC0000FFFFFFFFFFFFFFFFFFFFFFFFFFFF
CCCCCCCCCCCCCCCCCC333300FFFFFFFFFFFFFFFFFFFFFFFFFF
CCCCCCCCCCCCCCCCCC33333333FFFFFFFFFFFFFFFFFFFFFFFF
CCCCCCCCCCCCCCCCCC99993300FFFFFFFFFFFFFFFFFFFFFFFF
CCCCCCCCCCCCCCCCCC9999333333FFFFFFFFFFFFFFFFFFFFFF
CCCCCCCCCCCCCCCCCC9999999900FFFFFFFFFFFFFFFFFFFFFF
CCCCCCCCCCCCCCCCCC999999993333FFFFFFFFFFFFFFFFFFFF
CCCCCCCCCCCCCCCCCC99999999999933FFFFFFFFFFFFFFFFFF
CCCCCCCCCCCCCCCCCC9999999999999999FFFFFFFFFFFFFFFF
CCCCCCCCCCCCCCCCCCCCCC993300FFFFFFFFFFFFFFFFFFFFFF
CCCCCCCCCCCCCCCCCCCCCC99333333FFFFFFFFFFFFFFFFFFFF
CCCCCCCCCCCCCCCCCCCCCC99999900FFFFFFFFFFFFFFFFFFFF
CCCCCCCCCCCCCCCCCCCCCC9999993333FFFFFFFFFFFFFFFFFF
CCCCCCCCCCCCCCCCCCCCCC999999999933FFFFFFFFFFFFFFFF
CCCCCCCCCCCCCCCCCCCCCC99999999999999FFFFFFFFFFFFFF
CCCCCCCCCCCCCCCCCCCCCCCCCC3300FFFFFFFFFFFFFFFFFFFF
CCCCCCCCCCCCCCCCCCCCCCCCCC333333FFFFFFFFFFFFFFFFFF
CCCCCCCCCCCCCCCCCCCCCCCCCC999900FFFFFFFFFFFFFFFFFF
CCCCCCCCCCCCCCCCCCCCCCCCCC99993333FFFFFFFFFFFFFFFF
CCCCCCCCCCCCCCCCCCCCCCCCCC9999999933FFFFFFFFFFFFFF
CCCCCCCCCCCCCCCCCCCCCCCCCC999999999999FFFFFFFFFFFF
CCCCCCCCCCCCCCCCCCCCCCCCCCCCCC9900FFFFFFFFFFFFFFFF
CCCCCCCCCCCCCCCCCCCCCCCCCCCCCC993333FFFFFFFFFFFFFF
CCCCCCCCCCCCCCCCCCCCCCCCCCCCCC99999933FFFFFFFFFFFF
CCCCCCCCCCCCCCCCCCCCCCCCCCCCCC9999999999FFFFFFFFFF
CCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCC00FFFFFFFFFFFFFF
CCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCC3333FFFFFFFFFFFF
CCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCC999933FFFFFFFFFF
CCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCC99999999FFFFFFFF
CCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCC9933FFFFFFFF
CCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCC999999FFFFFF
CCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCC33FFFFFF
CCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCC9999FFFF
CCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCC99FF
CCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCC
pop
P
% End of image
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{76.5625, 287.875},
  ImageMargins->{{35, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40001O0001Ia000`40O003h00O05i[NV]JKg][FV]j
JeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmk
JeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]j
JeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FP5_
N`00Gf]J001O00000003001[FV]J05][FP40000005h006]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]J
Kg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]J
JgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]J
Kg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FP40000000<006]JJeX0Ff]J0@00
0000GP00JeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]J
Kg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]J
JgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]J
Kg][FV]jJeY_Nf]J0@0000000`00JeY[FP1KJeX10000001N001[FVmkJeY[NV]JKg][FV]jJeY_Nf]J
JgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]J
Kg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]J
JgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeX100000005001W>F<hIcUS
>007001AOol1JeX100000005001S>6LiHcQW>@07001AOol1JeX100000005001W>F<hIcUS>007001A
Ool1JeX100000005001S>6LiHcQW>@07001AOol1JeX100000005001W>F<hIcUS>00;001=Ool1JeX1
00000005001S>6LiHcQW>@0;001=Ool1JeX100000005001W>F<hIcUS>00;001=Ool1JeX100000005
001S>6LiHcQW>@0;001=Ool1JeX100000006001W>F<hIcUS>1S60aC500<HaQC55<D01000CGoo0F]J
0@0000003000HcQW>F<hIcTDYAS65:DHaQBU6<HDY@@004eoo`5[FP40000000D006LiHcQW>F<h008D
a@056<HDaAC55<DHaP04001=Ool1JeX10000000<001S>6LiHcQW>ABU6<HDYAS65:DHaQBU2000BGoo
0F]J0@0000001P00IcUS>6LiHcPHaP<Da@036<HDaAC500P004Uoo`5[FP40000000`006<hIcUS>6Li
5:DHaQBU6<HDYAS65:D80019Ool1JeX100000005001W>F<hIcUS>0025<D01AS65<DDaAC56<H02000
BGoo0F]J0@0000005000HcQW>F<hIcTDYAS65:DHaQBU6<HDYAS65:DHaQBU6<HDYAS65:D30016Ool1
JeX100000006001W>F<hIcUS>1S60aC500DHaQC55<DDaAS600<Da@036<HDaAC500<004Ioo`5[FP40
000001@006<hIcUS>6Li5:DHaQBU6<HDYAS65:DHaQBU6<HDYAS65:DHaQBU0`00AWoo0F]J0@000000
1@00IcUS>6LiHcP00QC500DHaQC55<DDaAS600<Da@056<HDaAC55<DHaP030016Ool1JeX10000000K
001S>6LiHcQW>ABU6<HDYAS65:DHaQBU6<HDYAS65:DHaQBU6<HDYAS65:DHaQBU6<HDYAS6049oo`5[
FP40000000H006LiHcQW>F<h6<H35<D01AS65<DDaAC56<H00aC500DHaQC55<DDaAS600<Da@036<HD
aGoo045oo`5[FP40000001/006<hIcUS>6Li5:DHaQBU6<HDYAS65:DHaQBU6<HDYAS65:DHaQBU6<HD
YAS65:DHaQBU6<H0@Woo0F]J0@0000001@00IcUS>6LiHcP01dYB0aC500<HaP0000000P00BGoo0F]J
0@0000004000HcQW>F<hIcU:DTicBU9:LTYBCW=:DQS65:DHaQBU1000BGoo0F]J0@0000001@00IcUS
>6LiHcP01dYB00@DaAS65<DDa@@004Uoo`5[FP400000010006<hIcUS>6LiBU9:LTYBCW=:DTYbBU8H
aQBU6<HDY@@004Uoo`5[FP40000000D006LiHcQW>F<h00M:DP<Da@036<H0000000D004Ioo`5[FP40
0000010006<hIcUS>6LiBU9>LdYBBW9:DTicBU8HaQBU6<HDY@L004Ioo`5[FP40000000D006LiHcQW
>F<h00M:DP045<DHaQC55<D70016Ool1JeX10000000G001S>6LiHcQW>DYBBW9:DTicBU9:LTYB6<HD
YAS65:DHaQBU6<HDYAS65:DHaP040012Ool1JeX100000005001W>F<hIcUS>007BU835<D01AS65<DD
aAC56<H00aC51000@Woo0F]J0@0000005`00HcQW>F<hIcU:DTicBU9:LTYBCW=:DQS65:DHaQBU6<HD
YAS65:DHaQBU6<H01000@Woo0F]J0@0000001@00IcUS>6LiHcP01dYB00<DaAS65<D00QC500HHaQC5
5<DDaAS65<D40012Ool1JeX10000000O001S>6LiHcQW>DYBBW9:DTicBU9:LTYB6<HDYAS65:DHaQBU
6<HDYAS65:DHaQBU6<HDYAS65:DHaQBU6<H0?Woo0F]J0@0000001@00IcUS>6LiHcP01dYB0aC500DH
aQC55<DDaAS600<Da@056<HDaAC55<DHaP035<DnOol1JeX10000000O001S>6LiHcQW>DYBCW=:DTYb
BU9>LdYB6<HDYAS65:DHaQBU6<HDYAS65:DHaQBU6<HDYAS65:DHaQBU6<H0?Woo0F]J0@0000001@00
IcUS>6LiHcP01dYB00<DaAS65<D00QC500DHaQC55<DDaAS600<Da@066<HDaAC55<DHaQC5?Woo0F]J
0@0000005000HcQW>F<hIcU:DTYbBU9>LdYBBW9:DTicBU9:LTYBCW=:DTYbBU830016Ool1JeX10000
0005001W>F<hIcUS>00?BU830016Ool1JeX10000000D001S>6LiHcQW>DYBCW=:DTYbBU9>LdYBBW9:
DTicBU9:LTYBCW=:DP<004Ioo`5[FP40000000D006LiHcQW>F<h00m:DPL0049oo`5[FP40000001@0
06<hIcUS>6LiBU9:LTYBCW=:DTYbBU9>LdYBBW9:DTicBU9:LTYB1`00@Woo0F]J0@0000001@00IcUS
>6LiHcP03dYB1`00@Woo0F]J0@0000005000HcQW>F<hIcU:DTicBU9:LTYBCW=:DTYbBU9>LdYBBW9:
DTicBU870012Ool1JeX100000005001W>F<hIcUS>00?BU800aC56<HDa@025<D00aS65<D00003000n
Ool1JeX10000000K001S>6LiHcQW>DYBBW9:DTicBU9:LTYBCW=:DTYbBU9>LdYBBW9:DQS65:DHaQBU
6<HDYAS600@003ioo`5[FP40000000D006LiHcQW>F<h00m:DP<Da@046<HDaAC55<D4000nOol1JeX1
0000000K001S>6LiHcQW>DYBCW=:DTYbBU9>LdYBBW9:DTicBU9:LTYBCW=:DQS65:DHaQBU6<HDYAS6
00@003ioo`5[FP40000000D006LiHcQW>F<h00m:DP035<DHaQC5008Da@056<HDaAC55<DHaP035<D0
0aS6Oomoo`0iOol1JeX10000000R001S>6LiHcQW>DYBBW9:DTicBU9:LTYBCW=:DTYbBU9>LdYBBW9:
DQS65:DHaQBU6<HDYAS65:DHaQBU6<HDYAS65:DkOol1JeX100000005001W>F<hIcUS>00?BU835<D0
1AS65<DDaAC56<H00aC500<HaQC55<D0>goo0F]J0@0000007`00HcQW>F<hIcU:DTicBU9:LTYBCW=:
DTYbBU9>LdYBBW9:DTicBU9:LTYBCW=:DTYbBU9>LaBU6<HDYAS600<003]oo`5[FP40000000D006Li
HcQW>F<h01I:DP8Da@036<HDa@00008003]oo`5[FP40000001l006<hIcUS>6LiBU9:LTYBCW=:DTYb
BU9>LdYBBW9:DTicBU9:LTYBCW=:DTYbBU9>LdYBBW8DYAS65:DHaP03000kOol1JeX100000005001W
>F<hIcUS>00FBU8011S65<DDaAC50`00>goo0F]J0@0000009P00HcQW>F<hIcU:DTicBU9:LTYBCW=:
DTYbBU9>LdYBBW9:DTicBU9:LTYBCW=:DTYbBU9>LaBU6<HDYAS65:DHaQBU6<HDYAS65:DgOol1JeX1
00000005001W>F<hIcUS>00FBU825<D01AS65<DDaAC56<H00aC500<HaWooOol0=Goo0F]J0@000000
9P00HcQW>F<hIcU:DTYbBU9>LdYBBW9:DTicBU9:LTYBCW=:DTYbBU9>LdYBBW9:DTicBU9:LQBU6<HD
YAS65:DHaQBU6<HDYAS65:DgOol1JeX100000005001W>F<hIcUS>00MBU84000gOol1JeX10000000R
001S>6LiHcQW>DYBCW=:DTYbBU9>LdYBBW9:DTicBU9:LTYBCW=:DTYbBU9>LdYBBW9:DTicBU9:LTYB
CW=:DTYbBU84000gOol1JeX100000005001W>F<hIcUS>00MBU84000gOol1JeX10000000R001S>6Li
HcQW>DYBBW9:DTicBU9:LTYBCW=:DTYbBU9>LdYBBW9:DTicBU9:LTYBCW=:DTYbBU9>LdYBBW9:DTic
BU84000gOol1JeX100000005001W>F<hIcUS>00MBU800aC56<HDa@025<D00aS65<DDa@0cOol1JeX1
0000000Z001S>6LiHcQW>DYBCW=:DTYbBU9>LdYBBW9:DTicBU9:LTYBCW=:DTYbBU9>LdYBBW9:DTic
BU9:LTYBCW=:DTYbBU8HaQBU6<HDYAS65:DHaQBU<goo0F]J0@0000001@00IcUS>6LiHcP07DYB0aC5
00DHaQC55<DDaAS603=oo`5[FP40000002X006<hIcUS>6LiBU9:LTYBCW=:DTYbBU9>LdYBBW9:DTic
BU9:LTYBCW=:DTYbBU9>LdYBBW9:DTicBU9:LTYBCW=:DQS65:DHaQBU6<HDYAS65:DcOol1JeX10000
0005001W>F<hIcUS>00UBU800aC56<HDa@0`Ool1JeX10000000]001S>6LiHcQW>DYBCW=:DTYbBU9>
LdYBBW9:DTicBU9:LTYBCW=:DTYbBU9>LdYBBW9:DTicBU9:LTYBCW=:DTYbBU9>LdYBBW9:DTicBU9:
LTYB6<HDYAS6031oo`5[FP40000000D006LiHcQW>F<h02E:DP<DaC1oo`5[FP400000034006<hIcUS
>6LiBU9:LTYBCW=:DTYbBU9>LdYBBW9:DTicBU9:LTYBCW=:DTYbBU9>LdYBBW9:DTicBU9:LTYBCW=:
DTYbBU9>LdYBBW9:DTicBU9:LTYBCW=:DTYbBU9>L`0/Ool1JeX100000005001W>F<hIcUS>00/BU8/
Ool1JeX10000000a001S>6LiHcQW>DYBCW=:DTYbBU9>LdYBBW9:DTicBU9:LTYBCW=:DTYbBU9>LdYB
BW9:DTicBU9:LTYBCW=:DTYbBU9>LdYBBW9:DTicBU9:LTYBCW=:DTYbBU9>LdYBBW80;7oo0F]J0@00
00001@00IcUS>6LiHcP0;4YB;7oo0F]J0@0000005000HcQW>F<hIcUS>6LiHcQW>F<hIcUS>4icBU9:
LTYB6<HDYAS65:D30016Ool1JeX10000000<001W>F<hIcUS>6LiHcQW>F<hIcUS>6Li14YB0aC500@H
aP00000004Ioo`5[FP40000001@006<hIcUS>6LiHcQW>F<hIcUS>6LiHcQ:LTYBCW=:DQS65:DHaQBU
0`00AWoo0F]J0@0000003000IcUS>6LiHcQW>F<hIcUS>6LiHcQW>@A:DP045<DHaQC55<D30016Ool1
JeX10000000D001S>6LiHcQW>F<hIcUS>6LiHcQW>F<hCW=:DTYbBU8HaQBU6<HDY@L0049oo`5[FP40
000000`006LiHcQW>F<hIcUS>6LiHcQW>F<hIcT4BU835<D00aS6000000050012Ool1JeX10000000D
001S>6LiHcQW>F<hIcUS>6LiHcQW>F<hBW9:DTicBU8HaQBU6<HDY@L0049oo`5[FP40000000`006Li
HcQW>F<hIcUS>6LiHcQW>F<hIcT4BU800aC56<HDa@025<D01QS65<DDaAC56<HDa@@003ioo`5[FP40
000001/006<hIcUS>6LiHcQW>F<hIcUS>6LiHcQ>LdYBBW9:DQS65:DHaQBU6<HDYAS65:DHaQBU6<H0
1000?Woo0F]J0@0000003000IcUS>6LiHcQW>F<hIcUS>6LiHcQW>@A:DP<Da@056<HDaAC55<DHaP03
5<D4000nOol1JeX10000000K001S>6LiHcQW>F<hIcUS>6LiHcQW>F<hBW9:DTicBU8HaQBU6<HDYAS6
5:DHaQBU6<HDYAS600@003ioo`5[FP40000000`006LiHcQW>F<hIcUS>6LiHcQW>F<hIcT4BU800aC5
6<HDa@025<D01AS65<DDaAC56<H00aC500DHaQC55<DDaAS603]oo`5[FP400000028006<hIcUS>6Li
HcQW>F<hIcUS>6LiHcQ>LdYBBW9:DQS65:DHaQBU6<HDYAS65:DHaQBU6<HDYAS65:DHaQBU6<HDYC]o
o`5[FP40000000`006LiHcQW>F<hIcUS>6LiHcQW>F<hIcT4BU835<D01AS65<DDaAC56<H00aC500DH
aQC55<DDaAS6008DaC]oo`5[FP40000001L006<hIcUS>6LiHcQW>F<hIcUS>6LiHcQ:LTYBCW=:DTYb
BU9>LdYBBW9:DTic00@0049oo`5[FP40000000`006LiHcQW>F<hIcUS>6LiHcQW>F<hIcT;BU840012
Ool1JeX10000000G001S>6LiHcQW>F<hIcUS>6LiHcQW>F<hCW=:DTYbBU9>LdYBBW9:DTicBU9:LP04
0012Ool1JeX10000000<001W>F<hIcUS>6LiHcQW>F<hIcUS>6Li2dYB1000@Woo0F]J0@0000005`00
HcQW>F<hIcUS>6LiHcQW>F<hIcUS>4YbBU9>LdYBBW9:DTicBU9:LTYBCW<02000?Woo0F]J0@000000
3000IcUS>6LiHcQW>F<hIcUS>6LiHcQW>@]:DPP003ioo`5[FP40000001L006<hIcUS>6LiHcQW>F<h
IcUS>6LiHcQ>LdYBBW9:DTicBU9:LTYBCW=:DTYb00P003ioo`5[FP40000000`006LiHcQW>F<hIcUS
>6LiHcQW>F<hIcT;BU88000nOol1JeX10000000O001S>6LiHcQW>F<hIcUS>6LiHcQW>F<hBW9:DTic
BU9:LTYBCW=:DTYbBU9>LaBU6<HDYAS65:DHaQBU6<H00`00>goo0F]J0@0000003000IcUS>6LiHcQW
>F<hIcUS>6LiHcQW>@]:DP8Da@066<HDaAC55<DHaQC50`00>goo0F]J0@0000007`00HcQW>F<hIcUS
>6LiHcQW>F<hIcUS>4icBU9:LTYBCW=:DTYbBU9>LdYBBW8DYAS65:DHaQBU6<HDYAS600<003]oo`5[
FP40000000`006LiHcQW>F<hIcUS>6LiHcQW>F<hIcT;BU801AS65<DDaAC56<H00aC500DHaQC55<DD
aAS6008DaCMoo`5[FP40000002H006<hIcUS>6LiHcQW>F<hIcUS>6LiHcQ:LTYBCW=:DTYbBU9>LdYB
BW9:DTic5:DHaQBU6<HDYAS65:DHaQBU6<HDYAS65:DHaQBU=goo0F]J0@0000003000IcUS>6LiHcQW
>F<hIcUS>6LiHcQW>@]:DP8Da@056<HDaAC55<DHaP035<D01AS65<DDaAC56<H0=goo0F]J0@000000
9P00HcQW>F<hIcUS>6LiHcQW>F<hIcUS>4icBU9:LTYBCW=:DTYbBU9>LdYBBW8DYAS65:DHaQBU6<HD
YAS65:DHaQBU6<HDYAS65:DgOol1JeX10000000<001W>F<hIcUS>6LiHcQW>F<hIcUS>6Li4dYB00<H
aQC55<D01000=goo0F]J0@0000008P00HcQW>F<hIcUS>6LiHcQW>F<hIcUS>4YbBU9>LdYBBW9:DTic
BU9:LTYBCW=:DTYbBU9>LdYBBW9:DTic5:DHaQBU1000=goo0F]J0@0000003000IcUS>6LiHcQW>F<h
IcUS>6LiHcQW>A=:DP8Da@036<H00000008003Moo`5[FP40000002X006<hIcUS>6LiHcQW>F<hIcUS
>6LiHcQ>LdYBBW9:DTicBU9:LTYBCW=:DTYbBU9>LdYBBW9:DTicBU9:LQBU6<HDYAS65:DHaQBU6<HD
YAS65:DcOol1JeX10000000<001W>F<hIcUS>6LiHcQW>F<hIcUS>6Li4dYB00DHaQC55<DDaAS600<D
a@036<HDaAC503=oo`5[FP40000002X006<hIcUS>6LiHcQW>F<hIcUS>6LiHcQ:LTYBCW=:DTYbBU9>
LdYBBW9:DTicBU9:LTYBCW=:DTYbBU9>LaBU6<HDYAS65:DHaQBU6<HDYAS65:DcOol1JeX10000000<
001W>F<hIcUS>6LiHcQW>F<hIcUS>6Li4dYB0QC500DHaQC55<DDaAS600<Da@036<Ioogoo035oo`5[
FP40000002H006<hIcUS>6LiHcQW>F<hIcUS>6LiHcQ>LdYBBW9:DTicBU9:LTYBCW=:DTYbBU9>LdYB
BW9:DTicBU9:LTYBCW=:DTYbBU9>LdYB1000<goo0F]J0@0000003000IcUS>6LiHcQW>F<hIcUS>6Li
HcQW>AY:DP@003=oo`5[FP40000002H006<hIcUS>6LiHcQW>F<hIcUS>6LiHcQ:LTYBCW=:DTYbBU9>
LdYBBW9:DTicBU9:LTYBCW=:DTYbBU9>LdYBBW9:DTicBU9:LTYB1000<goo0F]J0@0000003000IcUS
>6LiHcQW>F<hIcUS>6LiHcQW>AY:DP@003=oo`5[FP40000002d006<hIcUS>6LiHcQW>F<hIcUS>6Li
HcQ>LdYBBW9:DTicBU9:LTYBCW=:DTYbBU9>LdYBBW9:DTicBU9:LTYBCW=:DTYbBU9>LdYB6<HDYAS6
5:DHaQBU6<H0<7oo0F]J0@0000003000IcUS>6LiHcQW>F<hIcUS>6LiHcQW>AY:DP035<DHaQC5008D
a@036<HDaGoo02moo`5[FP40000002d006<hIcUS>6LiHcQW>F<hIcUS>6LiHcQ:LTYBCW=:DTYbBU9>
LdYBBW9:DTicBU9:LTYBCW=:DTYbBU9>LdYBBW9:DTicBU9:LTYB6<HDYAS65:DHaQBU6<H0<7oo0F]J
0@0000003000IcUS>6LiHcQW>F<hIcUS>6LiHcQW>B5:DP046<HDaAC55<D/Ool1JeX10000000a001S
>6LiHcQW>F<hIcUS>6LiHcQW>F<hCW=:DTYbBU9>LdYBBW9:DTicBU9:LTYBCW=:DTYbBU9>LdYBBW9:
DTicBU9:LTYBCW=:DTYbBU9>LdYBBW9:DTic5:DHaQBU6<H0;7oo0F]J0@0000003000IcUS>6LiHcQW
>F<hIcUS>6LiHcQW>B5:DP8Da@036<HDaGoo02]oo`5[FP400000034006<hIcUS>6LiHcQW>F<hIcUS
>6LiHcQ:LTYBCW=:DTYbBU9>LdYBBW9:DTicBU9:LTYBCW=:DTYbBU9>LdYBBW9:DTicBU9:LTYBCW=:
DTYbBU9>LdYBBW8DYAS65:DHaP0/Ool1JeX10000000<001W>F<hIcUS>6LiHcQW>F<hIcUS>6Li:DYB
:7oo0F]J0@000000=@00HcQW>F<hIcUS>6LiHcQW>F<hIcUS>4icBU9:LTYBCW=:DTYbBU9>LdYBBW9:
DTicBU9:LTYBCW=:DTYbBU9>LdYBBW9:DTicBU9:LTYBCW=:DTYbBU9>LdYBBW9:DTicBU9:LTYBCW<0
:7oo0F]J0@0000003000IcUS>6LiHcQW>F<hIcUS>6LiHcQW>BU:DRQoo`5[FP40000003D006<hIcUS
>6LiHcQW>F<hIcUS>6LiHcQ:LTYBCW=:DTYbBU9>LdYBBW9:DTicBU9:LTYBCW=:DTYbBU9>LdYBBW9:
DTicBU9:LTYBCW=:DTYbBU9>LdYBBW9:DTicBU9:LTYBCW=:DTYb02Qoo`5[FP40000001L006LiHcQW
>F<hIcUS>6LiHcQW>F<hIcUS>6LiHcQW>F<hIcUS>6Li5<DHaQC500@0049oo`5[FP40000001L006<h
IcUS>6LiHcQW>F<hIcUS>6LiHcQW>F<hIcUS>6LiHcQW>F<h6<HDYAS600@0049oo`5[FP40000001@0
06LiHcQW>F<hIcUS>6LiHcQW>F<hIcUS>6LiHcQW>F<hIcUS>6Li0aC51000@Woo0F]J0@0000005`00
HcQW>F<hIcUS>6LiHcQW>F<hIcUS>6LiHcQW>F<hIcUS>6LiHcPHaQBU6<H02000?Woo0F]J0@000000
5`00IcUS>6LiHcQW>F<hIcUS>6LiHcQW>F<hIcUS>6LiHcQW>F<hIcTDaAS65<D02000?Woo0F]J0@00
00005`00HcQW>F<hIcUS>6LiHcQW>F<hIcUS>6LiHcQW>F<hIcUS>6LiHcPHaQBU6<H02000?Woo0F]J
0@0000005000IcUS>6LiHcQW>F<hIcUS>6LiHcQW>F<hIcUS>6LiHcQW>F<hIcT35<D8000nOol1JeX1
0000000O001S>6LiHcQW>F<hIcUS>6LiHcQW>F<hIcUS>6LiHcQW>F<hIcUS>1S65:DHaQBU6<HDYAS6
5:DHaQBU6<H00`00>goo0F]J0@0000005P00IcUS>6LiHcQW>F<hIcUS>6LiHcQW>F<hIcUS>6LiHcQW
>F<hIcTDaAS60aC500HHaQC55<DDaAS65<D3000kOol1JeX10000000O001S>6LiHcQW>F<hIcUS>6Li
HcQW>F<hIcUS>6LiHcQW>F<hIcUS>1S65:DHaQBU6<HDYAS65:DHaQBU6<H00`00>goo0F]J0@000000
5000IcUS>6LiHcQW>F<hIcUS>6LiHcQW>F<hIcUS>6LiHcQW>F<hIcT35<D01AS65<DDaAC56<H00aC5
00DHaQC55<DDaAS6008DaCMoo`5[FP40000002H006<hIcUS>6LiHcQW>F<hIcUS>6LiHcQW>F<hIcUS
>6LiHcQW>F<h6<HDYAS65:DHaQBU6<HDYAS65:DHaQBU6<HDYAS65:DHaQBU=goo0F]J0@0000005P00
IcUS>6LiHcQW>F<hIcUS>6LiHcQW>F<hIcUS>6LiHcQW>F<hIcTDaAS60aC500DHaQC55<DDaAS600<D
a@056<HDaAC55<DHaP0gOol1JeX10000000V001S>6LiHcQW>F<hIcUS>6LiHcQW>F<hIcUS>6LiHcQW
>F<hIcUS>1S65:DHaQBU6<HDYAS65:DHaQBU6<HDYAS65:DHaQBU6<HDYCMoo`5[FP40000001@006Li
HcQW>F<hIcUS>6LiHcQW>F<hIcUS>6LiHcQW>F<hIcUS>6Li1dYB1000?Woo0F]J0@0000006`00HcQW
>F<hIcUS>6LiHcQW>F<hIcUS>6LiHcQW>F<hIcUS>6LiHcQ:LTYBCW=:DTYbBU9>L`04000nOol1JeX1
0000000D001W>F<hIcUS>6LiHcQW>F<hIcUS>6LiHcQW>F<hIcUS>6LiHcQW>@M:DP@003ioo`5[FP40
000001/006<hIcUS>6LiHcQW>F<hIcUS>6LiHcQW>F<hIcUS>6LiHcQW>F<hCW=:DTYbBU9>LdYBBW80
1000?Woo0F]J0@0000005000IcUS>6LiHcQW>F<hIcUS>6LiHcQW>F<hIcUS>6LiHcQW>F<hIcT7BU87
000kOol1JeX10000000K001S>6LiHcQW>F<hIcUS>6LiHcQW>F<hIcUS>6LiHcQW>F<hIcUS>4YbBU9>
LdYBBW9:DTic00L003]oo`5[FP40000001@006LiHcQW>F<hIcUS>6LiHcQW>F<hIcUS>6LiHcQW>F<h
IcUS>6Li1dYB1`00>goo0F]J0@0000008P00HcQW>F<hIcUS>6LiHcQW>F<hIcUS>6LiHcQW>F<hIcUS
>6LiHcQ>LdYBBW9:DTicBU9:LQBU6<HDYAS65:DHaQBU1000=goo0F]J0@0000005000IcUS>6LiHcQW
>F<hIcUS>6LiHcQW>F<hIcUS>6LiHcQW>F<hIcT7BU801AS65<DDaAC56<H00QC51000=goo0F]J0@00
00008P00HcQW>F<hIcUS>6LiHcQW>F<hIcUS>6LiHcQW>F<hIcUS>6LiHcQ:LTYBCW=:DTYbBU9>LaBU
6<HDYAS65:DHaQBU1000=goo0F]J0@0000005000IcUS>6LiHcQW>F<hIcUS>6LiHcQW>F<hIcUS>6Li
HcQW>F<hIcT7BU825<D01AS65<DDaAC56<H01000=goo0F]J0@000000:P00HcQW>F<hIcUS>6LiHcQW
>F<hIcUS>6LiHcQW>F<hIcUS>6LiHcQ>LdYBBW9:DTicBU9:LQBU6<HDYAS65:DHaQBU6<HDYAS65:DH
aQBU6<HDYC=oo`5[FP40000001@006LiHcQW>F<hIcUS>6LiHcQW>F<hIcUS>6LiHcQW>F<hIcUS>6Li
1dYB00DHaQC55<DDaAS600<Da@056<HDaAC55<DHaP025<DcOol1JeX10000000Z001S>6LiHcQW>F<h
IcUS>6LiHcQW>F<hIcUS>6LiHcQW>F<hIcUS>4YbBU9>LdYBBW9:DTic5:DHaQBU6<HDYAS65:DHaQBU
6<HDYAS65:DHaQBU<goo0F]J0@0000005000IcUS>6LiHcQW>F<hIcUS>6LiHcQW>F<hIcUS>6LiHcQW
>F<hIcT7BU825<D01AS65<DDaAC56<H00aC500DHaQC55<DDaAS603=oo`5[FP40000002H006<hIcUS
>6LiHcQW>F<hIcUS>6LiHcQW>F<hIcUS>6LiHcQW>F<hCW=:DTYbBU9>LdYBBW9:DTicBU9:LTYBCW=:
DQS65:DHaQBU1000<goo0F]J0@0000005000IcUS>6LiHcQW>F<hIcUS>6LiHcQW>F<hIcUS>6LiHcQW
>F<hIcT>BU8011C56<HDaAC51000<goo0F]J0@0000009P00HcQW>F<hIcUS>6LiHcQW>F<hIcUS>6Li
HcQW>F<hIcUS>6LiHcQ:LTYBCW=:DTYbBU9>LdYBBW9:DTicBU9:LTYB6<HDYAS65:D4000cOol1JeX1
0000000D001W>F<hIcUS>6LiHcQW>F<hIcUS>6LiHcQW>F<hIcUS>6LiHcQW>@i:DP<Da@056<HDaAC5
5<DHaP035<D`Ool1JeX10000000]001S>6LiHcQW>F<hIcUS>6LiHcQW>F<hIcUS>6LiHcQW>F<hIcUS
>4icBU9:LTYBCW=:DTYbBU9>LdYBBW9:DTicBU8HaQBU6<HDYAS65:DHaQBU6<HDYAS6031oo`5[FP40
000001@006LiHcQW>F<hIcUS>6LiHcQW>F<hIcUS>6LiHcQW>F<hIcUS>6Li3TYB00<DaAS65<D00QC5
00HHaQC55<DDaAS65<D`Ool1JeX10000000]001S>6LiHcQW>F<hIcUS>6LiHcQW>F<hIcUS>6LiHcQW
>F<hIcUS>4YbBU9>LdYBBW9:DTicBU9:LTYBCW=:DTYbBU8HaQBU6<HDYAS65:DHaQBU6<HDYAS6031o
o`5[FP40000001@006LiHcQW>F<hIcUS>6LiHcQW>F<hIcUS>6LiHcQW>F<hIcUS>6Li5TYB0`00<7oo
0F]J0@000000:P00HcQW>F<hIcUS>6LiHcQW>F<hIcUS>6LiHcQW>F<hIcUS>6LiHcQ>LdYBBW9:DTic
BU9:LTYBCW=:DTYbBU9>LdYBBW9:DTicBU9:LTYBCW=:DP<0031oo`5[FP40000001@006LiHcQW>F<h
IcUS>6LiHcQW>F<hIcUS>6LiHcQW>F<hIcUS>6Li5TYB0`00<7oo0F]J0@000000<@00HcQW>F<hIcUS
>6LiHcQW>F<hIcUS>6LiHcQW>F<hIcUS>6LiHcQ:LTYBCW=:DTYbBU9>LdYBBW9:DTicBU9:LTYBCW=:
DTYbBU9>LdYBBW9:DQS65:DHaQBU6<HDYAS602aoo`5[FP40000001@006LiHcQW>F<hIcUS>6LiHcQW
>F<hIcUS>6LiHcQW>F<hIcUS>6Li5TYB0aC500@HaQC55<DDaBaoo`5[FP400000034006<hIcUS>6Li
HcQW>F<hIcUS>6LiHcQW>F<hIcUS>6LiHcQW>F<hCW=:DTYbBU9>LdYBBW9:DTicBU9:LTYBCW=:DTYb
BU9>LdYBBW9:DTicBU8HaQBU6<HDYAS65:DHaP0/Ool1JeX10000000D001W>F<hIcUS>6LiHcQW>F<h
IcUS>6LiHcQW>F<hIcUS>6LiHcQW>AI:DP035<DHaQC5008Da@036<HDaGoo02]oo`5[FP40000003D0
06<hIcUS>6LiHcQW>F<hIcUS>6LiHcQW>F<hIcUS>6LiHcQW>F<hBW9:DTicBU9:LTYBCW=:DTYbBU9>
LdYBBW9:DTicBU9:LTYBCW=:DTYbBU9>LdYBBW9:DTicBU9:LQBU6<HDYAS602Qoo`5[FP40000001@0
06LiHcQW>F<hIcUS>6LiHcQW>F<hIcUS>6LiHcQW>F<hIcUS>6Li7DYB00@HaQC55<DDaBQoo`5[FP40
000003D006<hIcUS>6LiHcQW>F<hIcUS>6LiHcQW>F<hIcUS>6LiHcQW>F<hCW=:DTYbBU9>LdYBBW9:
DTicBU9:LTYBCW=:DTYbBU9>LdYBBW9:DTicBU9:LTYBCW=:DTYbBU9>LaBU6<HDYAS602Qoo`5[FP40
000001@006LiHcQW>F<hIcUS>6LiHcQW>F<hIcUS>6LiHcQW>F<hIcUS>6Li7DYB0QC500<HaQC5Ool0
9goo0F]J0@000000>000HcQW>F<hIcUS>6LiHcQW>F<hIcUS>6LiHcQW>F<hIcUS>6LiHcQ:LTYBCW=:
DTYbBU9>LdYBBW9:DTicBU9:LTYBCW=:DTYbBU9>LdYBBW9:DTicBU9:LTYBCW=:DTYbBU9>LdYBBW9:
DTicBU8UOol1JeX10000000D001W>F<hIcUS>6LiHcQW>F<hIcUS>6LiHcQW>F<hIcUS>6LiHcQW>BA:
DREoo`5[FP40000003P006<hIcUS>6LiHcQW>F<hIcUS>6LiHcQW>F<hIcUS>6LiHcQW>F<hCW=:DTYb
BU9>LdYBBW9:DTicBU9:LTYBCW=:DTYbBU9>LdYBBW9:DTicBU9:LTYBCW=:DTYbBU9>LdYBBW9:DTic
BU9:LTYB9Goo0F]J0@0000006`00IcUS>6LiHcQW>F<hIcUS>6LiHcQW>F<hIcUS>6LiHcQW>F<hIcUS
>6LiHcQW>F<hIcUS>004BU83000kOol1JeX10000000O001S>6LiHcQW>F<hIcUS>6LiHcQW>F<hIcUS
>6LiHcQW>F<hIcUS>6LiHcQW>F<hIcUS>6LiBU9:LTYBCW<00`00>goo0F]J0@0000006`00IcUS>6Li
HcQW>F<hIcUS>6LiHcQW>F<hIcUS>6LiHcQW>F<hIcUS>6LiHcQW>F<hIcUS>004BU83000kOol1JeX1
0000000O001S>6LiHcQW>F<hIcUS>6LiHcQW>F<hIcUS>6LiHcQW>F<hIcUS>6LiHcQW>F<hIcUS>6Li
BU9>LdYBBW800`00>goo0F]J0@0000006`00IcUS>6LiHcQW>F<hIcUS>6LiHcQW>F<hIcUS>6LiHcQW
>F<hIcUS>6LiHcQW>F<hIcUS>004BU87000gOol1JeX10000000O001S>6LiHcQW>F<hIcUS>6LiHcQW
>F<hIcUS>6LiHcQW>F<hIcUS>6LiHcQW>F<hIcUS>6LiBU9:LTYBCW<01`00=goo0F]J0@0000006`00
IcUS>6LiHcQW>F<hIcUS>6LiHcQW>F<hIcUS>6LiHcQW>F<hIcUS>6LiHcQW>F<hIcUS>004BU87000g
Ool1JeX10000000V001S>6LiHcQW>F<hIcUS>6LiHcQW>F<hIcUS>6LiHcQW>F<hIcUS>6LiHcQW>F<h
IcUS>6LiBU9>LdYBBW8DYAS65:DHaQBU6<HDY@@003=oo`5[FP40000001/006LiHcQW>F<hIcUS>6Li
HcQW>F<hIcUS>6LiHcQW>F<hIcUS>6LiHcQW>F<hIcUS>6LiHcP014YB00DHaQC55<DDaAS6008Da@@0
03=oo`5[FP40000002H006<hIcUS>6LiHcQW>F<hIcUS>6LiHcQW>F<hIcUS>6LiHcQW>F<hIcUS>6Li
HcQW>F<hIcU:DTYbBU9>LaBU6<HDYAS65:DHaQBU1000<goo0F]J0@0000006`00IcUS>6LiHcQW>F<h
IcUS>6LiHcQW>F<hIcUS>6LiHcQW>F<hIcUS>6LiHcQW>F<hIcUS>004BU825<D01AS65<DDaAC56<H0
1000<goo0F]J0@000000;@00HcQW>F<hIcUS>6LiHcQW>F<hIcUS>6LiHcQW>F<hIcUS>6LiHcQW>F<h
IcUS>6LiHcQW>DYBCW=:DTYb5:DHaQBU6<HDYAS65:DHaQBU6<HDYAS65:DHaP0`Ool1JeX10000000K
001W>F<hIcUS>6LiHcQW>F<hIcUS>6LiHcQW>F<hIcUS>6LiHcQW>F<hIcUS>6LiHcQW>F<h00A:DP05
6<HDaAC55<DHaP035<D01QS65<DDaAC56<HDaC1oo`5[FP40000002d006<hIcUS>6LiHcQW>F<hIcUS
>6LiHcQW>F<hIcUS>6LiHcQW>F<hIcUS>6LiHcQW>F<hIcU:DTYbBU9>LaBU6<HDYAS65:DHaQBU6<HD
YAS65:DHaQBU6<H0<7oo0F]J0@0000006`00IcUS>6LiHcQW>F<hIcUS>6LiHcQW>F<hIcUS>6LiHcQW
>F<hIcUS>6LiHcQW>F<hIcUS>004BU825<D01AS65<DDaAC56<H00aC500@HaQC55<DDaC1oo`5[FP40
000002X006<hIcUS>6LiHcQW>F<hIcUS>6LiHcQW>F<hIcUS>6LiHcQW>F<hIcUS>6LiHcQW>F<hIcU:
DTicBU9:LTYBCW=:DTYbBU9>LdYB6<HDYAS65:D3000`Ool1JeX10000000K001W>F<hIcUS>6LiHcQW
>F<hIcUS>6LiHcQW>F<hIcUS>6LiHcQW>F<hIcUS>6LiHcQW>F<h00]:DP045<DHaQC55<D3000`Ool1
JeX10000000Z001S>6LiHcQW>F<hIcUS>6LiHcQW>F<hIcUS>6LiHcQW>F<hIcUS>6LiHcQW>F<hIcUS
>6LiBU9:LTYBCW=:DTYbBU9>LdYBBW9:DQS65:DHaQBU0`00<7oo0F]J0@0000006`00IcUS>6LiHcQW
>F<hIcUS>6LiHcQW>F<hIcUS>6LiHcQW>F<hIcUS>6LiHcQW>F<hIcUS>00;BU835<D01AS65<DDaAC5
6<H00aC5;7oo0F]J0@000000<@00HcQW>F<hIcUS>6LiHcQW>F<hIcUS>6LiHcQW>F<hIcUS>6LiHcQW
>F<hIcUS>6LiHcQW>DYBCW=:DTYbBU9>LdYBBW9:DTicBU8HaQBU6<HDYAS65:DHaQBU6<HDYAS602ao
o`5[FP40000001/006LiHcQW>F<hIcUS>6LiHcQW>F<hIcUS>6LiHcQW>F<hIcUS>6LiHcQW>F<hIcUS
>6LiHcP02dYB00<DaAS65<D00QC500HHaQC55<DDaAS65<D/Ool1JeX10000000a001S>6LiHcQW>F<h
IcUS>6LiHcQW>F<hIcUS>6LiHcQW>F<hIcUS>6LiHcQW>F<hIcUS>6LiBU9:LTYBCW=:DTYbBU9>LdYB
BW9:DQS65:DHaQBU6<HDYAS65:DHaQBU6<H0;7oo0F]J0@0000006`00IcUS>6LiHcQW>F<hIcUS>6Li
HcQW>F<hIcUS>6LiHcQW>F<hIcUS>6LiHcQW>F<hIcUS>00BBU84000/Ool1JeX10000000]001S>6Li
HcQW>F<hIcUS>6LiHcQW>F<hIcUS>6LiHcQW>F<hIcUS>6LiHcQW>F<hIcUS>6LiBU9>LdYBBW9:DTic
BU9:LTYBCW=:DTYbBU9>LdYBBW9:DTic00@002aoo`5[FP40000001/006LiHcQW>F<hIcUS>6LiHcQW
>F<hIcUS>6LiHcQW>F<hIcUS>6LiHcQW>F<hIcUS>6LiHcP04TYB1000;7oo0F]J0@000000;@00HcQW
>F<hIcUS>6LiHcQW>F<hIcUS>6LiHcQW>F<hIcUS>6LiHcQW>F<hIcUS>6LiHcQW>DYBBW9:DTicBU9:
LTYBCW=:DTYbBU9>LdYBBW9:DTicBU9:LP04000/Ool1JeX10000000K001W>F<hIcUS>6LiHcQW>F<h
IcUS>6LiHcQW>F<hIcUS>6LiHcQW>F<hIcUS>6LiHcQW>F<h019:DP056<HDaAC55<DHaP035<DXOol1
JeX10000000e001S>6LiHcQW>F<hIcUS>6LiHcQW>F<hIcUS>6LiHcQW>F<hIcUS>6LiHcQW>F<hIcUS
>6LiBU9>LdYBBW9:DTicBU9:LTYBCW=:DTYbBU9>LdYBBW9:DTic5:DHaQBU6<HDYAS65:DHaP0XOol1
JeX10000000K001W>F<hIcUS>6LiHcQW>F<hIcUS>6LiHcQW>F<hIcUS>6LiHcQW>F<hIcUS>6LiHcQW
>F<h019:DP8Da@066<HDaAC55<DHaQC5:7oo0F]J0@000000>000HcQW>F<hIcUS>6LiHcQW>F<hIcUS
>6LiHcQW>F<hIcUS>6LiHcQW>F<hIcUS>6LiHcQW>DYBBW9:DTicBU9:LTYBCW=:DTYbBU9>LdYBBW9:
DTicBU9:LTYBCW=:DTYbBU9>LdYBBW8DYAS65:DUOol1JeX10000000K001W>F<hIcUS>6LiHcQW>F<h
IcUS>6LiHcQW>F<hIcUS>6LiHcQW>F<hIcUS>6LiHcQW>F<h01Y:DP036<HDaAC502Eoo`5[FP400000
03P006<hIcUS>6LiHcQW>F<hIcUS>6LiHcQW>F<hIcUS>6LiHcQW>F<hIcUS>6LiHcQW>F<hIcU:DTic
BU9:LTYBCW=:DTYbBU9>LdYBBW9:DTicBU9:LTYBCW=:DTYbBU9>LdYBBW9:DTic5:DHaQBU9Goo0F]J
0@0000006`00IcUS>6LiHcQW>F<hIcUS>6LiHcQW>F<hIcUS>6LiHcQW>F<hIcUS>6LiHcQW>F<hIcUS
>00JBU825<D00aS6Oomoo`0SOol1JeX10000000l001S>6LiHcQW>F<hIcUS>6LiHcQW>F<hIcUS>6Li
HcQW>F<hIcUS>6LiHcQW>F<hIcUS>6LiBU9:LTYBCW=:DTYbBU9>LdYBBW9:DTicBU9:LTYBCW=:DTYb
BU9>LdYBBW9:DTicBU9:LTYBCW=:DTYbBU9>LdYB8Goo0F]J0@0000006`00IcUS>6LiHcQW>F<hIcUS
>6LiHcQW>F<hIcUS>6LiHcQW>F<hIcUS>6LiHcQW>F<hIcUS>00QBU8QOol1JeX10000000l001S>6Li
HcQW>F<hIcUS>6LiHcQW>F<hIcUS>6LiHcQW>F<hIcUS>6LiHcQW>F<hIcUS>6LiBU9>LdYBBW9:DTic
BU9:LTYBCW=:DTYbBU9>LdYBBW9:DTicBU9:LTYBCW=:DTYbBU9>LdYBBW9:DTicBU9:LTYB8Goo0F]J
0@0000008P00IcUS>6LiHcQW>F<hIcUS>6LiHcQW>F<hIcUS>6LiHcQW>F<hIcUS>6LiHcQW>F<hIcUS
>6LiHcQW>F<hIcUS>6Li1000=goo0F]J0@0000008P00HcQW>F<hIcUS>6LiHcQW>F<hIcUS>6LiHcQW
>F<hIcUS>6LiHcQW>F<hIcUS>6LiHcQW>F<hIcUS>6LiHcQW>F<h1000=goo0F]J0@0000008P00IcUS
>6LiHcQW>F<hIcUS>6LiHcQW>F<hIcUS>6LiHcQW>F<hIcUS>6LiHcQW>F<hIcUS>6LiHcQW>F<hIcUS
>6Li1000=goo0F]J0@0000008P00HcQW>F<hIcUS>6LiHcQW>F<hIcUS>6LiHcQW>F<hIcUS>6LiHcQW
>F<hIcUS>6LiHcQW>F<hIcUS>6LiHcQW>F<h1000=goo0F]J0@0000008P00IcUS>6LiHcQW>F<hIcUS
>6LiHcQW>F<hIcUS>6LiHcQW>F<hIcUS>6LiHcQW>F<hIcUS>6LiHcQW>F<hIcUS>6Li2000<goo0F]J
0@0000008P00HcQW>F<hIcUS>6LiHcQW>F<hIcUS>6LiHcQW>F<hIcUS>6LiHcQW>F<hIcUS>6LiHcQW
>F<hIcUS>6LiHcQW>F<h2000<goo0F]J0@0000008P00IcUS>6LiHcQW>F<hIcUS>6LiHcQW>F<hIcUS
>6LiHcQW>F<hIcUS>6LiHcQW>F<hIcUS>6LiHcQW>F<hIcUS>6Li2000<goo0F]J0@0000008P00HcQW
>F<hIcUS>6LiHcQW>F<hIcUS>6LiHcQW>F<hIcUS>6LiHcQW>F<hIcUS>6LiHcQW>F<hIcUS>6LiHcQW
>F<h2000<goo0F]J0@0000009000IcUS>6LiHcQW>F<hIcUS>6LiHcQW>F<hIcUS>6LiHcQW>F<hIcUS
>6LiHcQW>F<hIcUS>6LiHcQW>F<hIcUS>6Li5<DHaP<Da@036<HDaAC500<0031oo`5[FP40000002X0
06<hIcUS>6LiHcQW>F<hIcUS>6LiHcQW>F<hIcUS>6LiHcQW>F<hIcUS>6LiHcQW>F<hIcUS>6LiHcQW
>F<hIcUS>1S65:DHaQBU6<HDYAS65:D3000`Ool1JeX10000000R001W>F<hIcUS>6LiHcQW>F<hIcUS
>6LiHcQW>F<hIcUS>6LiHcQW>F<hIcUS>6LiHcQW>F<hIcUS>6LiHcQW>F<hIcT35<D01AS65<DDaAC5
6<H00`00<7oo0F]J0@000000<@00HcQW>F<hIcUS>6LiHcQW>F<hIcUS>6LiHcQW>F<hIcUS>6LiHcQW
>F<hIcUS>6LiHcQW>F<hIcUS>6LiHcQW>F<h6<HDYAS65:DHaQBU6<HDYAS65:DHaQBU6<HDYAS602ao
o`5[FP40000002@006LiHcQW>F<hIcUS>6LiHcQW>F<hIcUS>6LiHcQW>F<hIcUS>6LiHcQW>F<hIcUS
>6LiHcQW>F<hIcUS>6LiHcQW>AC56<H35<D01AS65<DDaAC56<H00aC500<HaQC5Ool0:goo0F]J0@00
0000<@00HcQW>F<hIcUS>6LiHcQW>F<hIcUS>6LiHcQW>F<hIcUS>6LiHcQW>F<hIcUS>6LiHcQW>F<h
IcUS>6LiHcQW>F<h6<HDYAS65:DHaQBU6<HDYAS65:DHaQBU6<HDYAS602aoo`5[FP400000028006Li
HcQW>F<hIcUS>6LiHcQW>F<hIcUS>6LiHcQW>F<hIcUS>6LiHcQW>F<hIcUS>6LiHcQW>F<hIcUS>6Li
HcQW>@<Da@056<HDaAC55<DHaP035<D011S65<DDaAC5;7oo0F]J0@000000;@00HcQW>F<hIcUS>6Li
HcQW>F<hIcUS>6LiHcQW>F<hIcUS>6LiHcQW>F<hIcUS>6LiHcQW>F<hIcUS>6LiHcQW>F<hBW9:DTic
BU9:LTYBCW=:DQS65:DHaP04000/Ool1JeX10000000R001W>F<hIcUS>6LiHcQW>F<hIcUS>6LiHcQW
>F<hIcUS>6LiHcQW>F<hIcUS>6LiHcQW>F<hIcUS>6LiHcQW>F<hIcT8BU800aC56<HDa@04000/Ool1
JeX10000000]001S>6LiHcQW>F<hIcUS>6LiHcQW>F<hIcUS>6LiHcQW>F<hIcUS>6LiHcQW>F<hIcUS
>6LiHcQW>F<hIcUS>6LiHcQ>LdYBBW9:DTicBU9:LTYB6<HDYAS600@002aoo`5[FP400000028006Li
HcQW>F<hIcUS>6LiHcQW>F<hIcUS>6LiHcQW>F<hIcUS>6LiHcQW>F<hIcUS>6LiHcQW>F<hIcUS>6Li
HcQW>@Q:DP<Da@@002aoo`5[FP40000003D006<hIcUS>6LiHcQW>F<hIcUS>6LiHcQW>F<hIcUS>6Li
HcQW>F<hIcUS>6LiHcQW>F<hIcUS>6LiHcQW>F<hIcUS>4YbBU9>LdYBBW9:DTicBU8HaQBU6<HDYAS6
5:DHaQBU6<HDYAS602Qoo`5[FP400000028006LiHcQW>F<hIcUS>6LiHcQW>F<hIcUS>6LiHcQW>F<h
IcUS>6LiHcQW>F<hIcUS>6LiHcQW>F<hIcUS>6LiHcQW>@Q:DP035<DHaQC5008Da@066<HDaAC55<DH
aQC5:7oo0F]J0@000000=@00HcQW>F<hIcUS>6LiHcQW>F<hIcUS>6LiHcQW>F<hIcUS>6LiHcQW>F<h
IcUS>6LiHcQW>F<hIcUS>6LiHcQW>F<hCW=:DTYbBU9>LdYBBW9:DQS65:DHaQBU6<HDYAS65:DHaQBU
6<H0:7oo0F]J0@0000008P00IcUS>6LiHcQW>F<hIcUS>6LiHcQW>F<hIcUS>6LiHcQW>F<hIcUS>6Li
HcQW>F<hIcUS>6LiHcQW>F<hIcUS>6Li3dYB1000:7oo0F]J0@000000<@00HcQW>F<hIcUS>6LiHcQW
>F<hIcUS>6LiHcQW>F<hIcUS>6LiHcQW>F<hIcUS>6LiHcQW>F<hIcUS>6LiHcQW>F<hBW9:DTicBU9:
LTYBCW=:DTYbBU9>LdYBBW9:DTic00@002Qoo`5[FP400000028006LiHcQW>F<hIcUS>6LiHcQW>F<h
IcUS>6LiHcQW>F<hIcUS>6LiHcQW>F<hIcUS>6LiHcQW>F<hIcUS>6LiHcQW>@m:DP@002Qoo`5[FP40
0000034006<hIcUS>6LiHcQW>F<hIcUS>6LiHcQW>F<hIcUS>6LiHcQW>F<hIcUS>6LiHcQW>F<hIcUS
>6LiHcQW>F<hIcUS>4icBU9:LTYBCW=:DTYbBU9>LdYBBW9:DTicBU9:LP04000XOol1JeX10000000R
001W>F<hIcUS>6LiHcQW>F<hIcUS>6LiHcQW>F<hIcUS>6LiHcQW>F<hIcUS>6LiHcQW>F<hIcUS>6Li
HcQW>F<hIcT?BU801AS65<DDaAC56<H00QC59Goo0F]J0@000000>000HcQW>F<hIcUS>6LiHcQW>F<h
IcUS>6LiHcQW>F<hIcUS>6LiHcQW>F<hIcUS>6LiHcQW>F<hIcUS>6LiHcQW>F<hBW9:DTicBU9:LTYB
CW=:DTYbBU9>LdYBBW9:DTic5:DHaQBU6<HDYAS65:DUOol1JeX10000000R001W>F<hIcUS>6LiHcQW
>F<hIcUS>6LiHcQW>F<hIcUS>6LiHcQW>F<hIcUS>6LiHcQW>F<hIcUS>6LiHcQW>F<hIcT?BU825<D0
1AS65<DDaAC56<H09Goo0F]J0@000000?000HcQW>F<hIcUS>6LiHcQW>F<hIcUS>6LiHcQW>F<hIcUS
>6LiHcQW>F<hIcUS>6LiHcQW>F<hIcUS>6LiHcQW>F<hCW=:DTYbBU9>LdYBBW9:DTicBU9:LTYBCW=:
DTYbBU9>LdYBBW9:DTicBU8HaQBU6<HDYB5oo`5[FP400000028006LiHcQW>F<hIcUS>6LiHcQW>F<h
IcUS>6LiHcQW>F<hIcUS>6LiHcQW>F<hIcUS>6LiHcQW>F<hIcUS>6LiHcQW>AI:DP045<DHaQC55<DQ
Ool1JeX10000000l001S>6LiHcQW>F<hIcUS>6LiHcQW>F<hIcUS>6LiHcQW>F<hIcUS>6LiHcQW>F<h
IcUS>6LiHcQW>F<hIcUS>6LiHcQ:LTYBCW=:DTYbBU9>LdYBBW9:DTicBU9:LTYBCW=:DTYbBU9>LdYB
BW9:DQS65:DHaQBU8Goo0F]J0@0000008P00IcUS>6LiHcQW>F<hIcUS>6LiHcQW>F<hIcUS>6LiHcQW
>F<hIcUS>6LiHcQW>F<hIcUS>6LiHcQW>F<hIcUS>6Li5TYB0aC500<HaWooOol07goo0F]J0@000000
@000HcQW>F<hIcUS>6LiHcQW>F<hIcUS>6LiHcQW>F<hIcUS>6LiHcQW>F<hIcUS>6LiHcQW>F<hIcUS
>6LiHcQW>F<hCW=:DTYbBU9>LdYBBW9:DTicBU9:LTYBCW=:DTYbBU9>LdYBBW9:DTicBU9:LTYBCW=:
DTYbBU9>LdYB7Goo0F]J0@0000008P00IcUS>6LiHcQW>F<hIcUS>6LiHcQW>F<hIcUS>6LiHcQW>F<h
IcUS>6LiHcQW>F<hIcUS>6LiHcQW>F<hIcUS>6Li7TYB7Goo0F]J0@000000@000HcQW>F<hIcUS>6Li
HcQW>F<hIcUS>6LiHcQW>F<hIcUS>6LiHcQW>F<hIcUS>6LiHcQW>F<hIcUS>6LiHcQW>F<hBW9:DTic
BU9:LTYBCW=:DTYbBU9>LdYBBW9:DTicBU9:LTYBCW=:DTYbBU9>LdYBBW9:DTicBU9:LTYB7Goo0F]J
0@0000008P00IcUS>6LiHcQW>F<hIcUS>6LiHcQW>F<hIcUS>6LiHcQW>F<hIcUS>6LiHcQW>F<hIcUS
>6LiHcQW>F<hIcUS>6Li7TYB7Goo0F]J0@000000<@00HcQW>F<hIcUS>6LiHcQW>F<hIcUS>6LiHcQW
>F<hIcUS>6LiHcQW>F<hIcUS>6LiHcQW>F<hIcUS>6LiHcQW>F<hIcUS>6LiHcQW>F<hIcUS>4icBU9:
LQBU6<HDYAS600@002Qoo`5[FP40000002X006LiHcQW>F<hIcUS>6LiHcQW>F<hIcUS>6LiHcQW>F<h
IcUS>6LiHcQW>F<hIcUS>6LiHcQW>F<hIcUS>6LiHcQW>F<hIcUS>6LiHcQW>F<hIcT3BU8011S65<DD
aAC51000:7oo0F]J0@000000<@00HcQW>F<hIcUS>6LiHcQW>F<hIcUS>6LiHcQW>F<hIcUS>6LiHcQW
>F<hIcUS>6LiHcQW>F<hIcUS>6LiHcQW>F<hIcUS>6LiHcQW>F<hIcUS>4YbBU9>LaBU6<HDYAS600@0
02Qoo`5[FP40000002X006LiHcQW>F<hIcUS>6LiHcQW>F<hIcUS>6LiHcQW>F<hIcUS>6LiHcQW>F<h
IcUS>6LiHcQW>F<hIcUS>6LiHcQW>F<hIcUS>6LiHcQW>F<hIcT3BU825<D01AS65<DDaAC56<H00aC5
00<HaWooOol08goo0F]J0@000000>000HcQW>F<hIcUS>6LiHcQW>F<hIcUS>6LiHcQW>F<hIcUS>6Li
HcQW>F<hIcUS>6LiHcQW>F<hIcUS>6LiHcQW>F<hIcUS>6LiHcQW>F<hIcUS>4icBU9:LQBU6<HDYAS6
5:DHaQBU6<HDYAS65:DUOol1JeX10000000Z001W>F<hIcUS>6LiHcQW>F<hIcUS>6LiHcQW>F<hIcUS
>6LiHcQW>F<hIcUS>6LiHcQW>F<hIcUS>6LiHcQW>F<hIcUS>6LiHcQW>F<hIcUS>6Li0dYB00DHaQC5
5<DDaAS600<Da@036<HDaAC502Eoo`5[FP40000003P006<hIcUS>6LiHcQW>F<hIcUS>6LiHcQW>F<h
IcUS>6LiHcQW>F<hIcUS>6LiHcQW>F<hIcUS>6LiHcQW>F<hIcUS>6LiHcQW>F<hIcUS>6LiHcQ:LTYB
CW<DYAS65:DHaQBU6<HDYAS65:DHaQBU9Goo0F]J0@000000:P00IcUS>6LiHcQW>F<hIcUS>6LiHcQW
>F<hIcUS>6LiHcQW>F<hIcUS>6LiHcQW>F<hIcUS>6LiHcQW>F<hIcUS>6LiHcQW>F<hIcUS>6LiHcQW
>@]:DP<002Eoo`5[FP40000003D006<hIcUS>6LiHcQW>F<hIcUS>6LiHcQW>F<hIcUS>6LiHcQW>F<h
IcUS>6LiHcQW>F<hIcUS>6LiHcQW>F<hIcUS>6LiHcQW>F<hIcUS>6LiHcQ>LdYBBW9:DTicBU9:LTYB
CW=:DTYb00<002Eoo`5[FP40000002X006LiHcQW>F<hIcUS>6LiHcQW>F<hIcUS>6LiHcQW>F<hIcUS
>6LiHcQW>F<hIcUS>6LiHcQW>F<hIcUS>6LiHcQW>F<hIcUS>6LiHcQW>F<hIcT;BU83000UOol1JeX1
0000000l001S>6LiHcQW>F<hIcUS>6LiHcQW>F<hIcUS>6LiHcQW>F<hIcUS>6LiHcQW>F<hIcUS>6Li
HcQW>F<hIcUS>6LiHcQW>F<hIcUS>6LiHcQW>F<hBW9:DTicBU9:LTYBCW=:DTYbBU9>LaBU6<HDYAS6
5:DHaQBU8Goo0F]J0@000000:P00IcUS>6LiHcQW>F<hIcUS>6LiHcQW>F<hIcUS>6LiHcQW>F<hIcUS
>6LiHcQW>F<hIcUS>6LiHcQW>F<hIcUS>6LiHcQW>F<hIcUS>6LiHcQW>@]:DP8Da@056<HDaAC55<DH
aP0QOol1JeX10000000l001S>6LiHcQW>F<hIcUS>6LiHcQW>F<hIcUS>6LiHcQW>F<hIcUS>6LiHcQW
>F<hIcUS>6LiHcQW>F<hIcUS>6LiHcQW>F<hIcUS>6LiHcQW>F<hCW=:DTYbBU9>LdYBBW9:DTicBU9:
LQBU6<HDYAS65:DHaQBU8Goo0F]J0@000000:P00IcUS>6LiHcQW>F<hIcUS>6LiHcQW>F<hIcUS>6Li
HcQW>F<hIcUS>6LiHcQW>F<hIcUS>6LiHcQW>F<hIcUS>6LiHcQW>F<hIcUS>6LiHcQW>@]:DP056<HD
aAC55<DHaP025<DQOol1JeX100000010001S>6LiHcQW>F<hIcUS>6LiHcQW>F<hIcUS>6LiHcQW>F<h
IcUS>6LiHcQW>F<hIcUS>6LiHcQW>F<hIcUS>6LiHcQW>F<hIcUS>6LiHcQW>F<hBW9:DTicBU9:LTYB
CW=:DTYbBU9>LdYBBW9:DTicBU9:LTYB6<HDYAS65:DMOol1JeX10000000Z001W>F<hIcUS>6LiHcQW
>F<hIcUS>6LiHcQW>F<hIcUS>6LiHcQW>F<hIcUS>6LiHcQW>F<hIcUS>6LiHcQW>F<hIcUS>6LiHcQW
>F<hIcUS>6Li4TYB0aC500<HaWooOol06goo0F]J0@000000@000HcQW>F<hIcUS>6LiHcQW>F<hIcUS
>6LiHcQW>F<hIcUS>6LiHcQW>F<hIcUS>6LiHcQW>F<hIcUS>6LiHcQW>F<hIcUS>6LiHcQW>F<hIcUS
>4icBU9:LTYBCW=:DTYbBU9>LdYBBW9:DTicBU9:LTYBCW=:DQS65:DHaQBU7Goo0F]J0@000000:P00
IcUS>6LiHcQW>F<hIcUS>6LiHcQW>F<hIcUS>6LiHcQW>F<hIcUS>6LiHcQW>F<hIcUS>6LiHcQW>F<h
IcUS>6LiHcQW>F<hIcUS>6LiHcQW>A9:DP045<DHaQC55<DMOol1JeX100000013001S>6LiHcQW>F<h
IcUS>6LiHcQW>F<hIcUS>6LiHcQW>F<hIcUS>6LiHcQW>F<hIcUS>6LiHcQW>F<hIcUS>6LiHcQW>F<h
IcUS>6LiHcQW>F<hBW9:DTicBU9:LTYBCW=:DTYbBU9>LdYBBW9:DTicBU9:LTYBCW=:DTYbBU9>LdYB
BW806Woo0F]J0@000000:P00IcUS>6LiHcQW>F<hIcUS>6LiHcQW>F<hIcUS>6LiHcQW>F<hIcUS>6Li
HcQW>F<hIcUS>6LiHcQW>F<hIcUS>6LiHcQW>F<hIcUS>6LiHcQW>AU:DQYoo`5[FP40000004<006<h
IcUS>6LiHcQW>F<hIcUS>6LiHcQW>F<hIcUS>6LiHcQW>F<hIcUS>6LiHcQW>F<hIcUS>6LiHcQW>F<h
IcUS>6LiHcQW>F<hIcUS>6LiHcQ>LdYBBW9:DTicBU9:LTYBCW=:DTYbBU9>LdYBBW9:DTicBU9:LTYB
CW=:DTYbBU9>L`0JOol1JeX10000000b001W>F<hIcUS>6LiHcQW>F<hIcUS>6LiHcQW>F<hIcUS>6Li
HcQW>F<hIcUS>6LiHcQW>F<hIcUS>6LiHcQW>F<hIcUS>6LiHcQW>F<hIcUS>6LiHcQW>F<hIcUS>6Li
HcPHaP<Da@<002Eoo`5[FP40000003D006<hIcUS>6LiHcQW>F<hIcUS>6LiHcQW>F<hIcUS>6LiHcQW
>F<hIcUS>6LiHcQW>F<hIcUS>6LiHcQW>F<hIcUS>6LiHcQW>F<hIcUS>6LiHcQW>F<hIcUS>6LiHcQW
>ABU6<HDYAS600<002Eoo`5[FP400000034006LiHcQW>F<hIcUS>6LiHcQW>F<hIcUS>6LiHcQW>F<h
IcUS>6LiHcQW>F<hIcUS>6LiHcQW>F<hIcUS>6LiHcQW>F<hIcUS>6LiHcQW>F<hIcUS>6LiHcQW>F<h
IcUS>0025<D00aS65<D00002000UOol1JeX10000000e001S>6LiHcQW>F<hIcUS>6LiHcQW>F<hIcUS
>6LiHcQW>F<hIcUS>6LiHcQW>F<hIcUS>6LiHcQW>F<hIcUS>6LiHcQW>F<hIcUS>6LiHcQW>F<hIcUS
>6LiHcQW>F<hIcTDYAS65:DHaP03000UOol1JeX10000000b001W>F<hIcUS>6LiHcQW>F<hIcUS>6Li
HcQW>F<hIcUS>6LiHcQW>F<hIcUS>6LiHcQW>F<hIcUS>6LiHcQW>F<hIcUS>6LiHcQW>F<hIcUS>6Li
HcQW>F<hIcUS>6LiHcPHaP<Da@056<HDaAC55<DHaP025<DQOol1JeX10000000l001S>6LiHcQW>F<h
IcUS>6LiHcQW>F<hIcUS>6LiHcQW>F<hIcUS>6LiHcQW>F<hIcUS>6LiHcQW>F<hIcUS>6LiHcQW>F<h
IcUS>6LiHcQW>F<hIcUS>6LiHcQW>F<hIcTDYAS65:DHaQBU6<HDYAS65:DHaQBU8Goo0F]J0@000000
<@00IcUS>6LiHcQW>F<hIcUS>6LiHcQW>F<hIcUS>6LiHcQW>F<hIcUS>6LiHcQW>F<hIcUS>6LiHcQW
>F<hIcUS>6LiHcQW>F<hIcUS>6LiHcQW>F<hIcUS>6LiHcQW>F<h008Da@056<HDaAC55<DHaP035<D0
0aS6Oomoo`0OOol1JeX10000000l001S>6LiHcQW>F<hIcUS>6LiHcQW>F<hIcUS>6LiHcQW>F<hIcUS
>6LiHcQW>F<hIcUS>6LiHcQW>F<hIcUS>6LiHcQW>F<hIcUS>6LiHcQW>F<hIcUS>6LiHcQW>F<hIcTD
YAS65:DHaQBU6<HDYAS65:DHaQBU8Goo0F]J0@000000<@00IcUS>6LiHcQW>F<hIcUS>6LiHcQW>F<h
IcUS>6LiHcQW>F<hIcUS>6LiHcQW>F<hIcUS>6LiHcQW>F<hIcUS>6LiHcQW>F<hIcUS>6LiHcQW>F<h
IcUS>6LiHcQW>F<h00M:DP@0025oo`5[FP40000003P006<hIcUS>6LiHcQW>F<hIcUS>6LiHcQW>F<h
IcUS>6LiHcQW>F<hIcUS>6LiHcQW>F<hIcUS>6LiHcQW>F<hIcUS>6LiHcQW>F<hIcUS>6LiHcQW>F<h
IcUS>6LiHcQW>DYBBW9:DTicBU9:LTYB10008Goo0F]J0@000000<@00IcUS>6LiHcQW>F<hIcUS>6Li
HcQW>F<hIcUS>6LiHcQW>F<hIcUS>6LiHcQW>F<hIcUS>6LiHcQW>F<hIcUS>6LiHcQW>F<hIcUS>6Li
HcQW>F<hIcUS>6LiHcQW>F<h00M:DP@0025oo`5[FP400000040006<hIcUS>6LiHcQW>F<hIcUS>6Li
HcQW>F<hIcUS>6LiHcQW>F<hIcUS>6LiHcQW>F<hIcUS>6LiHcQW>F<hIcUS>6LiHcQW>F<hIcUS>6Li
HcQW>F<hIcUS>6LiHcQW>DYBCW=:DTYbBU9>LdYB6<HDYAS65:DHaQBU6<HDYAeoo`5[FP4000000340
06LiHcQW>F<hIcUS>6LiHcQW>F<hIcUS>6LiHcQW>F<hIcUS>6LiHcQW>F<hIcUS>6LiHcQW>F<hIcUS
>6LiHcQW>F<hIcUS>6LiHcQW>F<hIcUS>6LiHcQW>F<hIcUS>007BU800aC56<HDa@025<D00aS65<DD
a@0MOol1JeX100000010001S>6LiHcQW>F<hIcUS>6LiHcQW>F<hIcUS>6LiHcQW>F<hIcUS>6LiHcQW
>F<hIcUS>6LiHcQW>F<hIcUS>6LiHcQW>F<hIcUS>6LiHcQW>F<hIcUS>6LiHcQW>F<hIcU:DTYbBU9>
LdYBBW9:DQS65:DHaQBU6<HDYAS65:DMOol1JeX10000000a001W>F<hIcUS>6LiHcQW>F<hIcUS>6Li
HcQW>F<hIcUS>6LiHcQW>F<hIcUS>6LiHcQW>F<hIcUS>6LiHcQW>F<hIcUS>6LiHcQW>F<hIcUS>6Li
HcQW>F<hIcUS>6LiHcP01dYB0aC500DHaQC55<DDaAS601eoo`5[FP40000004<006<hIcUS>6LiHcQW
>F<hIcUS>6LiHcQW>F<hIcUS>6LiHcQW>F<hIcUS>6LiHcQW>F<hIcUS>6LiHcQW>F<hIcUS>6LiHcQW
>F<hIcUS>6LiHcQW>F<hIcUS>6LiHcQW>DYBCW=:DTYbBU9>LdYBBW9:DTicBU9:LTYBCW=:DQS65:DH
aP0JOol1JeX10000000a001W>F<hIcUS>6LiHcQW>F<hIcUS>6LiHcQW>F<hIcUS>6LiHcQW>F<hIcUS
>6LiHcQW>F<hIcUS>6LiHcQW>F<hIcUS>6LiHcQW>F<hIcUS>6LiHcQW>F<hIcUS>6LiHcP03dYB00<D
aAS65<D06Woo0F]J0@000000@`00HcQW>F<hIcUS>6LiHcQW>F<hIcUS>6LiHcQW>F<hIcUS>6LiHcQW
>F<hIcUS>6LiHcQW>F<hIcUS>6LiHcQW>F<hIcUS>6LiHcQW>F<hIcUS>6LiHcQW>F<hIcUS>6LiBU9:
LTYBCW=:DTYbBU9>LdYBBW9:DTicBU9:LTYB6<HDYAS601Yoo`5[FP400000034006LiHcQW>F<hIcUS
>6LiHcQW>F<hIcUS>6LiHcQW>F<hIcUS>6LiHcQW>F<hIcUS>6LiHcQW>F<hIcUS>6LiHcQW>F<hIcUS
>6LiHcQW>F<hIcUS>6LiHcQW>F<hIcUS>00FBU8FOol1JeX100000017001S>6LiHcQW>F<hIcUS>6Li
HcQW>F<hIcUS>6LiHcQW>F<hIcUS>6LiHcQW>F<hIcUS>6LiHcQW>F<hIcUS>6LiHcQW>F<hIcUS>6Li
HcQW>F<hIcUS>6LiHcQW>F<hIcU:DTicBU9:LTYBCW=:DTYbBU9>LdYBBW9:DTicBU9:LTYBCW=:DTYb
BU9>L`0FOol1JeX10000000a001W>F<hIcUS>6LiHcQW>F<hIcUS>6LiHcQW>F<hIcUS>6LiHcQW>F<h
IcUS>6LiHcQW>F<hIcUS>6LiHcQW>F<hIcUS>6LiHcQW>F<hIcUS>6LiHcQW>F<hIcUS>6LiHcP05TYB
5Woo0F]J0@000000A`00HcQW>F<hIcUS>6LiHcQW>F<hIcUS>6LiHcQW>F<hIcUS>6LiHcQW>F<hIcUS
>6LiHcQW>F<hIcUS>6LiHcQW>F<hIcUS>6LiHcQW>F<hIcUS>6LiHcQW>F<hIcUS>6LiBU9:LTYBCW=:
DTYbBU9>LdYBBW9:DTicBU9:LTYBCW=:DTYbBU9>LdYBBW805Woo0F]J0@000000>000IcUS>6LiHcQW
>F<hIcUS>6LiHcQW>F<hIcUS>6LiHcQW>F<hIcUS>6LiHcQW>F<hIcUS>6LiHcQW>F<hIcUS>6LiHcQW
>F<hIcUS>6LiHcQW>F<hIcUS>6LiHcQW>F<hIcUS>6LiHcQW>F<hIcT4BU84000MOol1JeX10000000l
001S>6LiHcQW>F<hIcUS>6LiHcQW>F<hIcUS>6LiHcQW>F<hIcUS>6LiHcQW>F<hIcUS>6LiHcQW>F<h
IcUS>6LiHcQW>F<hIcUS>6LiHcQW>F<hIcUS>6LiHcQW>F<hIcUS>6LiHcQW>F<hIcUS>4YbBU9>LdYB
10007Goo0F]J0@000000>000IcUS>6LiHcQW>F<hIcUS>6LiHcQW>F<hIcUS>6LiHcQW>F<hIcUS>6Li
HcQW>F<hIcUS>6LiHcQW>F<hIcUS>6LiHcQW>F<hIcUS>6LiHcQW>F<hIcUS>6LiHcQW>F<hIcUS>6Li
HcQW>F<hIcT4BU84000MOol1JeX10000000l001S>6LiHcQW>F<hIcUS>6LiHcQW>F<hIcUS>6LiHcQW
>F<hIcUS>6LiHcQW>F<hIcUS>6LiHcQW>F<hIcUS>6LiHcQW>F<hIcUS>6LiHcQW>F<hIcUS>6LiHcQW
>F<hIcUS>6LiHcQW>F<hIcUS>4icBU9:LTYB10007Goo0F]J0@000000>000IcUS>6LiHcQW>F<hIcUS
>6LiHcQW>F<hIcUS>6LiHcQW>F<hIcUS>6LiHcQW>F<hIcUS>6LiHcQW>F<hIcUS>6LiHcQW>F<hIcUS
>6LiHcQW>F<hIcUS>6LiHcQW>F<hIcUS>6LiHcQW>F<hIcT4BU835<D011S65<DDaAC56Woo0F]J0@00
0000@`00HcQW>F<hIcUS>6LiHcQW>F<hIcUS>6LiHcQW>F<hIcUS>6LiHcQW>F<hIcUS>6LiHcQW>F<h
IcUS>6LiHcQW>F<hIcUS>6LiHcQW>F<hIcUS>6LiHcQW>F<hIcUS>6LiHcQW>F<hIcUS>6LiHcQ:LTYB
CW=:DQS65:DHaQBU6<HDYAS601Yoo`5[FP40000003P006LiHcQW>F<hIcUS>6LiHcQW>F<hIcUS>6Li
HcQW>F<hIcUS>6LiHcQW>F<hIcUS>6LiHcQW>F<hIcUS>6LiHcQW>F<hIcUS>6LiHcQW>F<hIcUS>6Li
HcQW>F<hIcUS>6LiHcQW>F<hIcUS>6Li14YB00<DaAS65<D00QC500<HaQC5Ool06Goo0F]J0@000000
A`00HcQW>F<hIcUS>6LiHcQW>F<hIcUS>6LiHcQW>F<hIcUS>6LiHcQW>F<hIcUS>6LiHcQW>F<hIcUS
>6LiHcQW>F<hIcUS>6LiHcQW>F<hIcUS>6LiHcQW>F<hIcUS>6LiHcQW>F<hIcUS>6LiHcQ>LdYBBW9:
DTicBU9:LTYBCW=:DTYb5:DHaQBU6<H05Woo0F]J0@000000>000IcUS>6LiHcQW>F<hIcUS>6LiHcQW
>F<hIcUS>6LiHcQW>F<hIcUS>6LiHcQW>F<hIcUS>6LiHcQW>F<hIcUS>6LiHcQW>F<hIcUS>6LiHcQW
>F<hIcUS>6LiHcQW>F<hIcUS>6LiHcQW>F<hIcT;BU8011S65<DDaAC55Woo0F]J0@000000A`00HcQW
>F<hIcUS>6LiHcQW>F<hIcUS>6LiHcQW>F<hIcUS>6LiHcQW>F<hIcUS>6LiHcQW>F<hIcUS>6LiHcQW
>F<hIcUS>6LiHcQW>F<hIcUS>6LiHcQW>F<hIcUS>6LiHcQW>F<hIcUS>6LiHcQ:LTYBCW=:DTYbBU9>
LdYBBW9:DTic5:DHaQBU6<H05Woo0F]J0@000000>000IcUS>6LiHcQW>F<hIcUS>6LiHcQW>F<hIcUS
>6LiHcQW>F<hIcUS>6LiHcQW>F<hIcUS>6LiHcQW>F<hIcUS>6LiHcQW>F<hIcUS>6LiHcQW>F<hIcUS
>6LiHcQW>F<hIcUS>6LiHcQW>F<hIcT;BU825<D00aS65<Eoo`0EOol1JeX10000001;001S>6LiHcQW
>F<hIcUS>6LiHcQW>F<hIcUS>6LiHcQW>F<hIcUS>6LiHcQW>F<hIcUS>6LiHcQW>F<hIcUS>6LiHcQW
>F<hIcUS>6LiHcQW>F<hIcUS>6LiHcQW>F<hIcUS>6LiHcQW>F<hIcUS>4icBU9:LTYBCW=:DTYbBU9>
LdYBBW9:DTicBU9:LTYBCW=:DTYb019oo`5[FP40000003P006LiHcQW>F<hIcUS>6LiHcQW>F<hIcUS
>6LiHcQW>F<hIcUS>6LiHcQW>F<hIcUS>6LiHcQW>F<hIcUS>6LiHcQW>F<hIcUS>6LiHcQW>F<hIcUS
>6LiHcQW>F<hIcUS>6LiHcQW>F<hIcUS>6Li4dYB4Woo0F]J0@000000B`00HcQW>F<hIcUS>6LiHcQW
>F<hIcUS>6LiHcQW>F<hIcUS>6LiHcQW>F<hIcUS>6LiHcQW>F<hIcUS>6LiHcQW>F<hIcUS>6LiHcQW
>F<hIcUS>6LiHcQW>F<hIcUS>6LiHcQW>F<hIcUS>6LiHcQ:LTYBCW=:DTYbBU9>LdYBBW9:DTicBU9:
LTYBCW=:DTYbBU9>L`0BOol1JeX10000000h001W>F<hIcUS>6LiHcQW>F<hIcUS>6LiHcQW>F<hIcUS
>6LiHcQW>F<hIcUS>6LiHcQW>F<hIcUS>6LiHcQW>F<hIcUS>6LiHcQW>F<hIcUS>6LiHcQW>F<hIcUS
>6LiHcQW>F<hIcUS>6LiHcQW>A=:DQ9oo`5[FP400000040006<hIcUS>6LiHcQW>F<hIcUS>6LiHcQW
>F<hIcUS>6LiHcQW>F<hIcUS>6LiHcQW>F<hIcUS>6LiHcQW>F<hIcUS>6LiHcQW>F<hIcUS>6LiHcQW
>F<hIcUS>6LiHcQW>F<hIcUS>6LiHcQW>F<hIcUS>6LiHcQW>F<hIcUS>0<001Yoo`5[FP4000000400
06LiHcQW>F<hIcUS>6LiHcQW>F<hIcUS>6LiHcQW>F<hIcUS>6LiHcQW>F<hIcUS>6LiHcQW>F<hIcUS
>6LiHcQW>F<hIcUS>6LiHcQW>F<hIcUS>6LiHcQW>F<hIcUS>6LiHcQW>F<hIcUS>6LiHcQW>F<hIcUS
>6LiHcQW>@<001Yoo`5[FP400000040006<hIcUS>6LiHcQW>F<hIcUS>6LiHcQW>F<hIcUS>6LiHcQW
>F<hIcUS>6LiHcQW>F<hIcUS>6LiHcQW>F<hIcUS>6LiHcQW>F<hIcUS>6LiHcQW>F<hIcUS>6LiHcQW
>F<hIcUS>6LiHcQW>F<hIcUS>6LiHcQW>F<hIcUS>0<001Yoo`5[FP400000048006LiHcQW>F<hIcUS
>6LiHcQW>F<hIcUS>6LiHcQW>F<hIcUS>6LiHcQW>F<hIcUS>6LiHcQW>F<hIcUS>6LiHcQW>F<hIcUS
>6LiHcQW>F<hIcUS>6LiHcQW>F<hIcUS>6LiHcQW>F<hIcUS>6LiHcQW>F<hIcUS>6LiHcQW>AC56<H3
5<D00aS65<Eoo`0EOol1JeX100000017001S>6LiHcQW>F<hIcUS>6LiHcQW>F<hIcUS>6LiHcQW>F<h
IcUS>6LiHcQW>F<hIcUS>6LiHcQW>F<hIcUS>6LiHcQW>F<hIcUS>6LiHcQW>F<hIcUS>6LiHcQW>F<h
IcUS>6LiHcQW>F<hIcUS>6LiHcQW>F<hIcUS>6LiHcPHaQBU6<HDYAS65:DHaP0FOol1JeX100000010
001W>F<hIcUS>6LiHcQW>F<hIcUS>6LiHcQW>F<hIcUS>6LiHcQW>F<hIcUS>6LiHcQW>F<hIcUS>6Li
HcQW>F<hIcUS>6LiHcQW>F<hIcUS>6LiHcQW>F<hIcUS>6LiHcQW>F<hIcUS>6LiHcQW>F<hIcUS>6Li
HcQW>F<hIcT35<D011S65<DDaAC55Woo0F]J0@000000A`00HcQW>F<hIcUS>6LiHcQW>F<hIcUS>6Li
HcQW>F<hIcUS>6LiHcQW>F<hIcUS>6LiHcQW>F<hIcUS>6LiHcQW>F<hIcUS>6LiHcQW>F<hIcUS>6Li
HcQW>F<hIcUS>6LiHcQW>F<hIcUS>6LiHcQW>F<hIcUS>6LiHcQW>F<h6<HDYAS65:DHaQBU6<H05Woo
0F]J0@000000@000IcUS>6LiHcQW>F<hIcUS>6LiHcQW>F<hIcUS>6LiHcQW>F<hIcUS>6LiHcQW>F<h
IcUS>6LiHcQW>F<hIcUS>6LiHcQW>F<hIcUS>6LiHcQW>F<hIcUS>6LiHcQW>F<hIcUS>6LiHcQW>F<h
IcUS>6LiHcQW>F<hIcUS>6Li1dYB0QC500<HaQC5Ool04Goo0F]J0@000000B`00HcQW>F<hIcUS>6Li
HcQW>F<hIcUS>6LiHcQW>F<hIcUS>6LiHcQW>F<hIcUS>6LiHcQW>F<hIcUS>6LiHcQW>F<hIcUS>6Li
HcQW>F<hIcUS>6LiHcQW>F<hIcUS>6LiHcQW>F<hIcUS>6LiHcQW>F<hIcUS>6LiHcQW>F<hCW=:DTYb
BU9>LdYBBW8DYAS65:DHaP0BOol1JeX100000010001W>F<hIcUS>6LiHcQW>F<hIcUS>6LiHcQW>F<h
IcUS>6LiHcQW>F<hIcUS>6LiHcQW>F<hIcUS>6LiHcQW>F<hIcUS>6LiHcQW>F<hIcUS>6LiHcQW>F<h
IcUS>6LiHcQW>F<hIcUS>6LiHcQW>F<hIcUS>6LiHcQW>F<hIcT7BU8011S65<DDaAC54Woo0F]J0@00
0000C`00HcQW>F<hIcUS>6LiHcQW>F<hIcUS>6LiHcQW>F<hIcUS>6LiHcQW>F<hIcUS>6LiHcQW>F<h
IcUS>6LiHcQW>F<hIcUS>6LiHcQW>F<hIcUS>6LiHcQW>F<hIcUS>6LiHcQW>F<hIcUS>6LiHcQW>F<h
IcUS>6LiHcQW>F<hBW9:DTicBU9:LTYBCW=:DTYbBU9>LdYBBW9:DTic00ioo`5[FP400000040006Li
HcQW>F<hIcUS>6LiHcQW>F<hIcUS>6LiHcQW>F<hIcUS>6LiHcQW>F<hIcUS>6LiHcQW>F<hIcUS>6Li
HcQW>F<hIcUS>6LiHcQW>F<hIcUS>6LiHcQW>F<hIcUS>6LiHcQW>F<hIcUS>6LiHcQW>F<hIcUS>6Li
HcQW>@m:DPioo`5[FP40000004l006<hIcUS>6LiHcQW>F<hIcUS>6LiHcQW>F<hIcUS>6LiHcQW>F<h
IcUS>6LiHcQW>F<hIcUS>6LiHcQW>F<hIcUS>6LiHcQW>F<hIcUS>6LiHcQW>F<hIcUS>6LiHcQW>F<h
IcUS>6LiHcQW>F<hIcUS>6LiHcQW>F<hIcUS>4icBU9:LTYBCW=:DTYbBU9>LdYBBW9:DTicBU9:LP0>
Ool1JeX100000010001W>F<hIcUS>6LiHcQW>F<hIcUS>6LiHcQW>F<hIcUS>6LiHcQW>F<hIcUS>6Li
HcQW>F<hIcUS>6LiHcQW>F<hIcUS>6LiHcQW>F<hIcUS>6LiHcQW>F<hIcUS>6LiHcQW>F<hIcUS>6Li
HcQW>F<hIcUS>6LiHcQW>F<hIcT?BU8>Ool1JeX10000001?001S>6LiHcQW>F<hIcUS>6LiHcQW>F<h
IcUS>6LiHcQW>F<hIcUS>6LiHcQW>F<hIcUS>6LiHcQW>F<hIcUS>6LiHcQW>F<hIcUS>6LiHcQW>F<h
IcUS>6LiHcQW>F<hIcUS>6LiHcQW>F<hIcUS>6LiHcQW>F<hIcUS>6LiHcQW>F<hIcUS>6LiHcQW>DYB
BW9:DTic5:DHaQBU6<H03Woo0F]J0@000000A`00IcUS>6LiHcQW>F<hIcUS>6LiHcQW>F<hIcUS>6Li
HcQW>F<hIcUS>6LiHcQW>F<hIcUS>6LiHcQW>F<hIcUS>6LiHcQW>F<hIcUS>6LiHcQW>F<hIcUS>6Li
HcQW>F<hIcUS>6LiHcQW>F<hIcUS>6LiHcQW>F<hIcUS>6LiHcQW>F<hIcUS>6LiHcP014YB0QC500<H
aQC5Ool03Goo0F]J0@000000C`00HcQW>F<hIcUS>6LiHcQW>F<hIcUS>6LiHcQW>F<hIcUS>6LiHcQW
>F<hIcUS>6LiHcQW>F<hIcUS>6LiHcQW>F<hIcUS>6LiHcQW>F<hIcUS>6LiHcQW>F<hIcUS>6LiHcQW
>F<hIcUS>6LiHcQW>F<hIcUS>6LiHcQW>F<hIcUS>6LiHcQW>F<hIcU:DTicBU9:LQBU6<HDYAS600io
o`5[FP40000004L006LiHcQW>F<hIcUS>6LiHcQW>F<hIcUS>6LiHcQW>F<hIcUS>6LiHcQW>F<hIcUS
>6LiHcQW>F<hIcUS>6LiHcQW>F<hIcUS>6LiHcQW>F<hIcUS>6LiHcQW>F<hIcUS>6LiHcQW>F<hIcUS
>6LiHcQW>F<hIcUS>6LiHcQW>F<hIcUS>6LiHcQW>F<h00A:DP046<HDaAC55<D>Ool1JeX10000001B
001S>6LiHcQW>F<hIcUS>6LiHcQW>F<hIcUS>6LiHcQW>F<hIcUS>6LiHcQW>F<hIcUS>6LiHcQW>F<h
IcUS>6LiHcQW>F<hIcUS>6LiHcQW>F<hIcUS>6LiHcQW>F<hIcUS>6LiHcQW>F<hIcUS>6LiHcQW>F<h
IcUS>6LiHcQW>F<hIcUS>6LiHcQW>DYBBW9:DTicBU9:LTYBCW=:DTYbBU8;Ool1JeX100000017001W
>F<hIcUS>6LiHcQW>F<hIcUS>6LiHcQW>F<hIcUS>6LiHcQW>F<hIcUS>6LiHcQW>F<hIcUS>6LiHcQW
>F<hIcUS>6LiHcQW>F<hIcUS>6LiHcQW>F<hIcUS>6LiHcQW>F<hIcUS>6LiHcQW>F<hIcUS>6LiHcQW
>F<hIcUS>6LiHcQW>F<hIcUS>00;BU8;Ool1JeX10000001B001S>6LiHcQW>F<hIcUS>6LiHcQW>F<h
IcUS>6LiHcQW>F<hIcUS>6LiHcQW>F<hIcUS>6LiHcQW>F<hIcUS>6LiHcQW>F<hIcUS>6LiHcQW>F<h
IcUS>6LiHcQW>F<hIcUS>6LiHcQW>F<hIcUS>6LiHcQW>F<hIcUS>6LiHcQW>F<hIcUS>6LiHcQW>DYB
CW=:DTYbBU9>LdYBBW9:DTicBU8;Ool1JeX10000001@001W>F<hIcUS>6LiHcQW>F<hIcUS>6LiHcQW
>F<hIcUS>6LiHcQW>F<hIcUS>6LiHcQW>F<hIcUS>6LiHcQW>F<hIcUS>6LiHcQW>F<hIcUS>6LiHcQW
>F<hIcUS>6LiHcQW>F<hIcUS>6LiHcQW>F<hIcUS>6LiHcQW>F<hIcUS>6LiHcQW>F<hIcUS>6LiHcQW
>F<hIcUS>6LiHcPHaP8Da@]oo`5[FP400000058006<hIcUS>6LiHcQW>F<hIcUS>6LiHcQW>F<hIcUS
>6LiHcQW>F<hIcUS>6LiHcQW>F<hIcUS>6LiHcQW>F<hIcUS>6LiHcQW>F<hIcUS>6LiHcQW>F<hIcUS
>6LiHcQW>F<hIcUS>6LiHcQW>F<hIcUS>6LiHcQW>F<hIcUS>6LiHcQW>F<hIcUS>6LiHcQW>F<hIcUS
>6LiHcQW>ABU6<HDY@]oo`5[FP40000004l006LiHcQW>F<hIcUS>6LiHcQW>F<hIcUS>6LiHcQW>F<h
IcUS>6LiHcQW>F<hIcUS>6LiHcQW>F<hIcUS>6LiHcQW>F<hIcUS>6LiHcQW>F<hIcUS>6LiHcQW>F<h
IcUS>6LiHcQW>F<hIcUS>6LiHcQW>F<hIcUS>6LiHcQW>F<hIcUS>6LiHcQW>F<hIcUS>6LiHcQW>F<h
IcUS>0025<D00aS6Oomoo`09Ool1JeX10000001B001S>6LiHcQW>F<hIcUS>6LiHcQW>F<hIcUS>6Li
HcQW>F<hIcUS>6LiHcQW>F<hIcUS>6LiHcQW>F<hIcUS>6LiHcQW>F<hIcUS>6LiHcQW>F<hIcUS>6Li
HcQW>F<hIcUS>6LiHcQW>F<hIcUS>6LiHcQW>F<hIcUS>6LiHcQW>F<hIcUS>6LiHcQW>F<hIcUS>6Li
HcQW>F<hIcTDYAS65:D;Ool1JeX10000001?001W>F<hIcUS>6LiHcQW>F<hIcUS>6LiHcQW>F<hIcUS
>6LiHcQW>F<hIcUS>6LiHcQW>F<hIcUS>6LiHcQW>F<hIcUS>6LiHcQW>F<hIcUS>6LiHcQW>F<hIcUS
>6LiHcQW>F<hIcUS>6LiHcQW>F<hIcUS>6LiHcQW>F<hIcUS>6LiHcQW>F<hIcUS>6LiHcQW>F<hIcUS
>6LiHcP01dYB1goo0F]J0@000000EP00HcQW>F<hIcUS>6LiHcQW>F<hIcUS>6LiHcQW>F<hIcUS>6Li
HcQW>F<hIcUS>6LiHcQW>F<hIcUS>6LiHcQW>F<hIcUS>6LiHcQW>F<hIcUS>6LiHcQW>F<hIcUS>6Li
HcQW>F<hIcUS>6LiHcQW>F<hIcUS>6LiHcQW>F<hIcUS>6LiHcQW>F<hIcUS>6LiHcQW>F<hIcUS>6Li
BU9:LTYBCW=:DTYbBU87Ool1JeX10000001?001W>F<hIcUS>6LiHcQW>F<hIcUS>6LiHcQW>F<hIcUS
>6LiHcQW>F<hIcUS>6LiHcQW>F<hIcUS>6LiHcQW>F<hIcUS>6LiHcQW>F<hIcUS>6LiHcQW>F<hIcUS
>6LiHcQW>F<hIcUS>6LiHcQW>F<hIcUS>6LiHcQW>F<hIcUS>6LiHcQW>F<hIcUS>6LiHcQW>F<hIcUS
>6LiHcP01dYB1goo0F]J0@000000EP00HcQW>F<hIcUS>6LiHcQW>F<hIcUS>6LiHcQW>F<hIcUS>6Li
HcQW>F<hIcUS>6LiHcQW>F<hIcUS>6LiHcQW>F<hIcUS>6LiHcQW>F<hIcUS>6LiHcQW>F<hIcUS>6Li
HcQW>F<hIcUS>6LiHcQW>F<hIcUS>6LiHcQW>F<hIcUS>6LiHcQW>F<hIcUS>6LiHcQW>F<hIcUS>6Li
BU9>LdYBBW9:DTicBU87Ool1JeX10000001F001W>F<hIcUS>6LiHcQW>F<hIcUS>6LiHcQW>F<hIcUS
>6LiHcQW>F<hIcUS>6LiHcQW>F<hIcUS>6LiHcQW>F<hIcUS>6LiHcQW>F<hIcUS>6LiHcQW>F<hIcUS
>6LiHcQW>F<hIcUS>6LiHcQW>F<hIcUS>6LiHcQW>F<hIcUS>6LiHcQW>F<hIcUS>6LiHcQW>F<hIcUS
>6LiHcQW>F<hIcUS>6LiHcQW>@A:DP=oo`5[FP40000005X006<hIcUS>6LiHcQW>F<hIcUS>6LiHcQW
>F<hIcUS>6LiHcQW>F<hIcUS>6LiHcQW>F<hIcUS>6LiHcQW>F<hIcUS>6LiHcQW>F<hIcUS>6LiHcQW
>F<hIcUS>6LiHcQW>F<hIcUS>6LiHcQW>F<hIcUS>6LiHcQW>F<hIcUS>6LiHcQW>F<hIcUS>6LiHcQW
>F<hIcUS>6LiHcQW>F<hIcUS>6LiHcQW>F<hCW=:DTYbBU83Ool1JeX10000001F001W>F<hIcUS>6Li
HcQW>F<hIcUS>6LiHcQW>F<hIcUS>6LiHcQW>F<hIcUS>6LiHcQW>F<hIcUS>6LiHcQW>F<hIcUS>6Li
HcQW>F<hIcUS>6LiHcQW>F<hIcUS>6LiHcQW>F<hIcUS>6LiHcQW>F<hIcUS>6LiHcQW>F<hIcUS>6Li
HcQW>F<hIcUS>6LiHcQW>F<hIcUS>6LiHcQW>F<hIcUS>6LiHcQW>@A:DP=oo`5[FP40000005h006<h
IcUS>6LiHcQW>F<hIcUS>6LiHcQW>F<hIcUS>6LiHcQW>F<hIcUS>6LiHcQW>F<hIcUS>6LiHcQW>F<h
IcUS>6LiHcQW>F<hIcUS>6LiHcQW>F<hIcUS>6LiHcQW>F<hIcUS>6LiHcQW>F<hIcUS>6LiHcQW>F<h
IcUS>6LiHcQW>F<hIcUS>6LiHcQW>F<hIcUS>6LiHcQW>F<hIcUS>6LiHcQW>F<hIcUS>6LiHcQW>F<h
IcU[FP40000005h006LiHcQW>F<hIcUS>6LiHcQW>F<hIcUS>6LiHcQW>F<hIcUS>6LiHcQW>F<hIcUS
>6LiHcQW>F<hIcUS>6LiHcQW>F<hIcUS>6LiHcQW>F<hIcUS>6LiHcQW>F<hIcUS>6LiHcQW>F<hIcUS
>6LiHcQW>F<hIcUS>6LiHcQW>F<hIcUS>6LiHcQW>F<hIcUS>6LiHcQW>F<hIcUS>6LiHcQW>F<hIcUS
>6LiHcQW>F<hIcUS>6LiHcQ[FP40000005h006<hIcUS>6LiHcQW>F<hIcUS>6LiHcQW>F<hIcUS>6Li
HcQW>F<hIcUS>6LiHcQW>F<hIcUS>6LiHcQW>F<hIcUS>6LiHcQW>F<hIcUS>6LiHcQW>F<hIcUS>6Li
HcQW>F<hIcUS>6LiHcQW>F<hIcUS>6LiHcQW>F<hIcUS>6LiHcQW>F<hIcUS>6LiHcQW>F<hIcUS>6Li
HcQW>F<hIcUS>6LiHcQW>F<hIcUS>6LiHcQW>F<hIcU[FP40000005h006LiHcQW>F<hIcUS>6LiHcQW
>F<hIcUS>6LiHcQW>F<hIcUS>6LiHcQW>F<hIcUS>6LiHcQW>F<hIcUS>6LiHcQW>F<hIcUS>6LiHcQW
>F<hIcUS>6LiHcQW>F<hIcUS>6LiHcQW>F<hIcUS>6LiHcQW>F<hIcUS>6LiHcQW>F<hIcUS>6LiHcQW
>F<hIcUS>6LiHcQW>F<hIcUS>6LiHcQW>F<hIcUS>6LiHcQW>F<hIcUS>6LiHcQ[FP40000005h006]J
JgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]J
Kg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]J
JgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]J
Kg][FP40000000<006]JJeX0Ff]J0@000000GP00JeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]J
JgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]J
Kg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]J
JgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]J0@0000000`00JeY[FP1KJeX10000001N
001[FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]J
JgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]J
Kg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]J
JgY[FVmkJeX100000003001[FV]J05][FP40000005h006]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]J
Kg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]J
JgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]J
Kg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FP400000G`000000GVmkJeY[NV]J
Kg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]J
JgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]J
Kg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]J
0F]j0000\
\>"],
  ImageRangeCache->{{{140.063, 215.625}, {449.125, 162.25}} -> {-48.8973, \
53.4947, 0.345232, 0.345232}}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(Table[Length[partH[2\^Range[0, 7], n]], {n, 20}]\)], "Input"],

Cell[BoxData[
    \({1, 2, 2, 4, 4, 6, 6, 10, 10, 14, 14, 20, 20, 26, 26, 36, 36, 46, 46, 
      60}\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(f[2\^Range[0, 7]] + O[x]\^11\)], "Input"],

Cell[BoxData[
    InterpretationBox[
      RowBox[{
      "1", "+", "x", "+", \(2\ x\^2\), "+", \(2\ x\^3\), "+", \(4\ x\^4\), 
        "+", \(4\ x\^5\), "+", \(6\ x\^6\), "+", \(6\ x\^7\), 
        "+", \(10\ x\^8\), "+", \(10\ x\^9\), "+", \(14\ x\^10\), "+", 
        InterpretationBox[\(O[x]\^11\),
          SeriesData[ x, 0, {}, 0, 11, 1]]}],
      SeriesData[ 
      x, 0, {1, 1, 2, 2, 4, 4, 6, 6, 10, 10, 14}, 0, 11, 1]]], "Output"]
}, Open  ]],

Cell[TextData[{
  "Let ",
  StyleBox["c[n]", "InlineInput"],
  " be the number of binary partitions of 2n."
}], "Text"],

Cell[BoxData[{
    \(c[0] := 1\), "\[IndentingNewLine]", 
    \(c[n_] := \(c[n] = 
        c[n - 1] + c[\[LeftFloor]n/2\[RightFloor]]\)\)}], "Input"],

Cell[CellGroupData[{

Cell[BoxData[
    \(Table[c[n], {n, 10}]\)], "Input"],

Cell[BoxData[
    \({2, 4, 6, 10, 14, 20, 26, 36, 46, 60}\)], "Output"]
}, Open  ]],

Cell["\<\
From the 1997, 38th Annual International Mathematical Olympiad:

Let f(n) be the number of ways of representing n as a sum of powers of 2 with \
non-negative integer exponents. Prove that, for n \[GreaterEqual] 3\
\>", "Commentary"],

Cell[TextData[{
  Cell[BoxData[
      \(TraditionalForm\`2\^\(n\^2/4\) < f(2\^n) < 2\^\(n\^2/2\)\)]],
  "\n"
}], "Commentary",
  TextAlignment->Center,
  TextJustification->0]
}, Closed]],

Cell[CellGroupData[{

Cell["SUMMANDS NOT MULTIPLE OF 3", "Subsubsection"],

Cell[CellGroupData[{

Cell[BoxData[
    \(asSum\  /@ partH[Complement[Range[10], 3  Range[10]], 10] // 
      TableForm\)], "Input"],

Cell[BoxData[
    InterpretationBox[GridBox[{
          {
            TagBox[
              RowBox[{"1", "+", 
                TagBox[
                  RowBox[{"1", "+", 
                    TagBox[
                      RowBox[{"1", "+", 
                        TagBox[
                          RowBox[{"1", "+", 
                            TagBox[
                              RowBox[{"1", "+", 
                                TagBox[
                                  RowBox[{"1", "+", 
                                    TagBox[
                                      RowBox[{"1", "+", 
                                        TagBox[
                                        RowBox[{"1", "+", 
                                        TagBox[\(1 + 1\),
                                        DisplayForm]}],
                                        DisplayForm]}],
                                      DisplayForm]}],
                                  DisplayForm]}],
                              DisplayForm]}],
                          DisplayForm]}],
                      DisplayForm]}],
                  DisplayForm]}],
              DisplayForm]},
          {
            TagBox[
              RowBox[{"1", "+", 
                TagBox[
                  RowBox[{"1", "+", 
                    TagBox[
                      RowBox[{"1", "+", 
                        TagBox[
                          RowBox[{"1", "+", 
                            TagBox[
                              RowBox[{"1", "+", 
                                TagBox[
                                  RowBox[{"1", "+", 
                                    TagBox[
                                      RowBox[{"1", "+", 
                                        TagBox[\(1 + 2\),
                                        DisplayForm]}],
                                      DisplayForm]}],
                                  DisplayForm]}],
                              DisplayForm]}],
                          DisplayForm]}],
                      DisplayForm]}],
                  DisplayForm]}],
              DisplayForm]},
          {
            TagBox[
              RowBox[{"1", "+", 
                TagBox[
                  RowBox[{"1", "+", 
                    TagBox[
                      RowBox[{"1", "+", 
                        TagBox[
                          RowBox[{"1", "+", 
                            TagBox[
                              RowBox[{"1", "+", 
                                TagBox[
                                  RowBox[{"1", "+", 
                                    TagBox[\(2 + 2\),
                                      DisplayForm]}],
                                  DisplayForm]}],
                              DisplayForm]}],
                          DisplayForm]}],
                      DisplayForm]}],
                  DisplayForm]}],
              DisplayForm]},
          {
            TagBox[
              RowBox[{"1", "+", 
                TagBox[
                  RowBox[{"1", "+", 
                    TagBox[
                      RowBox[{"1", "+", 
                        TagBox[
                          RowBox[{"1", "+", 
                            TagBox[
                              RowBox[{"1", "+", 
                                TagBox[\(1 + 4\),
                                  DisplayForm]}],
                              DisplayForm]}],
                          DisplayForm]}],
                      DisplayForm]}],
                  DisplayForm]}],
              DisplayForm]},
          {
            TagBox[
              RowBox[{"1", "+", 
                TagBox[
                  RowBox[{"1", "+", 
                    TagBox[
                      RowBox[{"1", "+", 
                        TagBox[
                          RowBox[{"1", "+", 
                            TagBox[\(1 + 5\),
                              DisplayForm]}],
                          DisplayForm]}],
                      DisplayForm]}],
                  DisplayForm]}],
              DisplayForm]},
          {
            TagBox[
              RowBox[{"1", "+", 
                TagBox[
                  RowBox[{"1", "+", 
                    TagBox[
                      RowBox[{"1", "+", 
                        TagBox[
                          RowBox[{"1", "+", 
                            TagBox[
                              RowBox[{"2", "+", 
                                TagBox[\(2 + 2\),
                                  DisplayForm]}],
                              DisplayForm]}],
                          DisplayForm]}],
                      DisplayForm]}],
                  DisplayForm]}],
              DisplayForm]},
          {
            TagBox[
              RowBox[{"1", "+", 
                TagBox[
                  RowBox[{"1", "+", 
                    TagBox[
                      RowBox[{"1", "+", 
                        TagBox[
                          RowBox[{"1", "+", 
                            TagBox[\(2 + 4\),
                              DisplayForm]}],
                          DisplayForm]}],
                      DisplayForm]}],
                  DisplayForm]}],
              DisplayForm]},
          {
            TagBox[
              RowBox[{"1", "+", 
                TagBox[
                  RowBox[{"1", "+", 
                    TagBox[
                      RowBox[{"1", "+", 
                        TagBox[\(2 + 5\),
                          DisplayForm]}],
                      DisplayForm]}],
                  DisplayForm]}],
              DisplayForm]},
          {
            TagBox[
              RowBox[{"1", "+", 
                TagBox[
                  RowBox[{"1", "+", 
                    TagBox[\(1 + 7\),
                      DisplayForm]}],
                  DisplayForm]}],
              DisplayForm]},
          {
            TagBox[
              RowBox[{"1", "+", 
                TagBox[
                  RowBox[{"1", "+", 
                    TagBox[
                      RowBox[{"2", "+", 
                        TagBox[
                          RowBox[{"2", "+", 
                            TagBox[\(2 + 2\),
                              DisplayForm]}],
                          DisplayForm]}],
                      DisplayForm]}],
                  DisplayForm]}],
              DisplayForm]},
          {
            TagBox[
              RowBox[{"1", "+", 
                TagBox[
                  RowBox[{"1", "+", 
                    TagBox[
                      RowBox[{"2", "+", 
                        TagBox[\(2 + 4\),
                          DisplayForm]}],
                      DisplayForm]}],
                  DisplayForm]}],
              DisplayForm]},
          {
            TagBox[
              RowBox[{"1", "+", 
                TagBox[
                  RowBox[{"1", "+", 
                    TagBox[\(4 + 4\),
                      DisplayForm]}],
                  DisplayForm]}],
              DisplayForm]},
          {
            TagBox[
              RowBox[{"1", "+", 
                TagBox[\(1 + 8\),
                  DisplayForm]}],
              DisplayForm]},
          {
            TagBox[
              RowBox[{"1", "+", 
                TagBox[
                  RowBox[{"2", "+", 
                    TagBox[\(2 + 5\),
                      DisplayForm]}],
                  DisplayForm]}],
              DisplayForm]},
          {
            TagBox[
              RowBox[{"1", "+", 
                TagBox[\(2 + 7\),
                  DisplayForm]}],
              DisplayForm]},
          {
            TagBox[
              RowBox[{"1", "+", 
                TagBox[\(4 + 5\),
                  DisplayForm]}],
              DisplayForm]},
          {
            TagBox[
              RowBox[{"2", "+", 
                TagBox[
                  RowBox[{"2", "+", 
                    TagBox[
                      RowBox[{"2", "+", 
                        TagBox[\(2 + 2\),
                          DisplayForm]}],
                      DisplayForm]}],
                  DisplayForm]}],
              DisplayForm]},
          {
            TagBox[
              RowBox[{"2", "+", 
                TagBox[
                  RowBox[{"2", "+", 
                    TagBox[\(2 + 4\),
                      DisplayForm]}],
                  DisplayForm]}],
              DisplayForm]},
          {
            TagBox[
              RowBox[{"2", "+", 
                TagBox[\(4 + 4\),
                  DisplayForm]}],
              DisplayForm]},
          {
            TagBox[\(2 + 8\),
              DisplayForm]},
          {
            TagBox[\(5 + 5\),
              DisplayForm]},
          {"\<\"10\"\>"}
          },
        RowSpacings->1,
        ColumnSpacings->3,
        RowAlignments->Baseline,
        ColumnAlignments->{Left}],
      TableForm[ {
        DisplayForm[ 
          RowBox[ {"1", "+", 
            DisplayForm[ 
              RowBox[ {"1", "+", 
                DisplayForm[ 
                  RowBox[ {"1", "+", 
                    DisplayForm[ 
                      RowBox[ {"1", "+", 
                        DisplayForm[ 
                          RowBox[ {"1", "+", 
                            DisplayForm[ 
                              RowBox[ {"1", "+", 
                                DisplayForm[ 
                                  RowBox[ {"1", "+", 
                                    DisplayForm[ 
                                      RowBox[ {"1", "+", 
                                        DisplayForm[ 
                                        
                                        RowBox[ {"1", "+", 
                                        "1"}]]}]]}]]}]]}]]}]]}]]}]]}]], 
        DisplayForm[ 
          RowBox[ {"1", "+", 
            DisplayForm[ 
              RowBox[ {"1", "+", 
                DisplayForm[ 
                  RowBox[ {"1", "+", 
                    DisplayForm[ 
                      RowBox[ {"1", "+", 
                        DisplayForm[ 
                          RowBox[ {"1", "+", 
                            DisplayForm[ 
                              RowBox[ {"1", "+", 
                                DisplayForm[ 
                                  RowBox[ {"1", "+", 
                                    DisplayForm[ 
                                      
                                      RowBox[ {"1", "+", 
                                        "2"}]]}]]}]]}]]}]]}]]}]]}]], 
        DisplayForm[ 
          RowBox[ {"1", "+", 
            DisplayForm[ 
              RowBox[ {"1", "+", 
                DisplayForm[ 
                  RowBox[ {"1", "+", 
                    DisplayForm[ 
                      RowBox[ {"1", "+", 
                        DisplayForm[ 
                          RowBox[ {"1", "+", 
                            DisplayForm[ 
                              RowBox[ {"1", "+", 
                                DisplayForm[ 
                                  RowBox[ {"2", "+", "2"}]]}]]}]]}]]}]]}]]}]],
         
        DisplayForm[ 
          RowBox[ {"1", "+", 
            DisplayForm[ 
              RowBox[ {"1", "+", 
                DisplayForm[ 
                  RowBox[ {"1", "+", 
                    DisplayForm[ 
                      RowBox[ {"1", "+", 
                        DisplayForm[ 
                          RowBox[ {"1", "+", 
                            DisplayForm[ 
                              RowBox[ {"1", "+", "4"}]]}]]}]]}]]}]]}]], 
        DisplayForm[ 
          RowBox[ {"1", "+", 
            DisplayForm[ 
              RowBox[ {"1", "+", 
                DisplayForm[ 
                  RowBox[ {"1", "+", 
                    DisplayForm[ 
                      RowBox[ {"1", "+", 
                        DisplayForm[ 
                          RowBox[ {"1", "+", "5"}]]}]]}]]}]]}]], 
        DisplayForm[ 
          RowBox[ {"1", "+", 
            DisplayForm[ 
              RowBox[ {"1", "+", 
                DisplayForm[ 
                  RowBox[ {"1", "+", 
                    DisplayForm[ 
                      RowBox[ {"1", "+", 
                        DisplayForm[ 
                          RowBox[ {"2", "+", 
                            DisplayForm[ 
                              RowBox[ {"2", "+", "2"}]]}]]}]]}]]}]]}]], 
        DisplayForm[ 
          RowBox[ {"1", "+", 
            DisplayForm[ 
              RowBox[ {"1", "+", 
                DisplayForm[ 
                  RowBox[ {"1", "+", 
                    DisplayForm[ 
                      RowBox[ {"1", "+", 
                        DisplayForm[ 
                          RowBox[ {"2", "+", "4"}]]}]]}]]}]]}]], 
        DisplayForm[ 
          RowBox[ {"1", "+", 
            DisplayForm[ 
              RowBox[ {"1", "+", 
                DisplayForm[ 
                  RowBox[ {"1", "+", 
                    DisplayForm[ 
                      RowBox[ {"2", "+", "5"}]]}]]}]]}]], 
        DisplayForm[ 
          RowBox[ {"1", "+", 
            DisplayForm[ 
              RowBox[ {"1", "+", 
                DisplayForm[ 
                  RowBox[ {"1", "+", "7"}]]}]]}]], 
        DisplayForm[ 
          RowBox[ {"1", "+", 
            DisplayForm[ 
              RowBox[ {"1", "+", 
                DisplayForm[ 
                  RowBox[ {"2", "+", 
                    DisplayForm[ 
                      RowBox[ {"2", "+", 
                        DisplayForm[ 
                          RowBox[ {"2", "+", "2"}]]}]]}]]}]]}]], 
        DisplayForm[ 
          RowBox[ {"1", "+", 
            DisplayForm[ 
              RowBox[ {"1", "+", 
                DisplayForm[ 
                  RowBox[ {"2", "+", 
                    DisplayForm[ 
                      RowBox[ {"2", "+", "4"}]]}]]}]]}]], 
        DisplayForm[ 
          RowBox[ {"1", "+", 
            DisplayForm[ 
              RowBox[ {"1", "+", 
                DisplayForm[ 
                  RowBox[ {"4", "+", "4"}]]}]]}]], 
        DisplayForm[ 
          RowBox[ {"1", "+", 
            DisplayForm[ 
              RowBox[ {"1", "+", "8"}]]}]], 
        DisplayForm[ 
          RowBox[ {"1", "+", 
            DisplayForm[ 
              RowBox[ {"2", "+", 
                DisplayForm[ 
                  RowBox[ {"2", "+", "5"}]]}]]}]], 
        DisplayForm[ 
          RowBox[ {"1", "+", 
            DisplayForm[ 
              RowBox[ {"2", "+", "7"}]]}]], 
        DisplayForm[ 
          RowBox[ {"1", "+", 
            DisplayForm[ 
              RowBox[ {"4", "+", "5"}]]}]], 
        DisplayForm[ 
          RowBox[ {"2", "+", 
            DisplayForm[ 
              RowBox[ {"2", "+", 
                DisplayForm[ 
                  RowBox[ {"2", "+", 
                    DisplayForm[ 
                      RowBox[ {"2", "+", "2"}]]}]]}]]}]], 
        DisplayForm[ 
          RowBox[ {"2", "+", 
            DisplayForm[ 
              RowBox[ {"2", "+", 
                DisplayForm[ 
                  RowBox[ {"2", "+", "4"}]]}]]}]], 
        DisplayForm[ 
          RowBox[ {"2", "+", 
            DisplayForm[ 
              RowBox[ {"4", "+", "4"}]]}]], 
        DisplayForm[ 
          RowBox[ {"2", "+", "8"}]], 
        DisplayForm[ 
          RowBox[ {"5", "+", "5"}]], "10"}]]], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[{
    \(\(p = 
        partH[Complement[Range[10], 3  Range[10]], 
          15];\)\), "\[IndentingNewLine]", 
    \(\(m = Max[Length\  /@ \ p];\)\), "\[IndentingNewLine]", 
    \(\(u = \(PadRight[#, m] &\)\  /@ \ p;\)\), "\n", 
    \(\(ListDensityPlot[\(-Reverse[u]\), \ Mesh\  \[Rule] \ False, 
        AspectRatio \[Rule] Automatic, 
        FrameTicks \[Rule] None];\)\)}], "Input"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 4.2 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% DensityGraphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0192308 0.0641026 0.0807692 0.0641026 [
[ 0 0 -0.125 0 ]
[ 0 0 -0.125 0 ]
[ 0 4.2 .125 0 ]
[ 1 0 .125 0 ]
[ 0 0 0 0 ]
[ 1 4.2 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
0 0 m
1 0 L
s
0 0 m
0 4.2 L
s
0 4.2 m
1 4.2 L
s
1 0 m
1 4.2 L
s
0 0 m
1 0 L
1 4.2 L
0 4.2 L
closepath
clip
newpath
% Start of gray image
p
.01923 .08077 translate
.96154 4.03846 scale
15 string
15 63 8 [15 0 0 63 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
0000FFFFFFFFFFFFFFFFFFFFFFFFFF
0000FFFFFFFFFFFFFFFFFFFFFFFFFF
000000FFFFFFFFFFFFFFFFFFFFFFFF
333300FFFFFFFFFFFFFFFFFFFFFFFF
990000FFFFFFFFFFFFFFFFFFFFFFFF
99333300FFFFFFFFFFFFFFFFFFFFFF
99993300FFFFFFFFFFFFFFFFFFFFFF
9999993300FFFFFFFFFFFFFFFFFFFF
9999999900FFFFFFFFFFFFFFFFFFFF
999999999900FFFFFFFFFFFFFFFFFF
CC0000FFFFFFFFFFFFFFFFFFFFFFFF
CC3300FFFFFFFFFFFFFFFFFFFFFFFF
CC330000FFFFFFFFFFFFFFFFFFFFFF
CC990000FFFFFFFFFFFFFFFFFFFFFF
CC993300FFFFFFFFFFFFFFFFFFFFFF
CC99333333FFFFFFFFFFFFFFFFFFFF
CC999900FFFFFFFFFFFFFFFFFFFFFF
CC99990000FFFFFFFFFFFFFFFFFFFF
CC99999900FFFFFFFFFFFFFFFFFFFF
CC9999993333FFFFFFFFFFFFFFFFFF
CC999999999933FFFFFFFFFFFFFFFF
CC99999999999999FFFFFFFFFFFFFF
CCCC0000FFFFFFFFFFFFFFFFFFFFFF
CCCC333300FFFFFFFFFFFFFFFFFFFF
CCCC993300FFFFFFFFFFFFFFFFFFFF
CCCC99993300FFFFFFFFFFFFFFFFFF
CCCC99999900FFFFFFFFFFFFFFFFFF
CCCC9999999900FFFFFFFFFFFFFFFF
CCCCCC0000FFFFFFFFFFFFFFFFFFFF
CCCCCC3300FFFFFFFFFFFFFFFFFFFF
CCCCCC333333FFFFFFFFFFFFFFFFFF
CCCCCC9900FFFFFFFFFFFFFFFFFFFF
CCCCCC990000FFFFFFFFFFFFFFFFFF
CCCCCC999900FFFFFFFFFFFFFFFFFF
CCCCCC99993333FFFFFFFFFFFFFFFF
CCCCCC9999999933FFFFFFFFFFFFFF
CCCCCC999999999999FFFFFFFFFFFF
CCCCCCCC3300FFFFFFFFFFFFFFFFFF
CCCCCCCC993300FFFFFFFFFFFFFFFF
CCCCCCCC999900FFFFFFFFFFFFFFFF
CCCCCCCC99999900FFFFFFFFFFFFFF
CCCCCCCCCC00FFFFFFFFFFFFFFFFFF
CCCCCCCCCC0000FFFFFFFFFFFFFFFF
CCCCCCCCCC9900FFFFFFFFFFFFFFFF
CCCCCCCCCC993333FFFFFFFFFFFFFF
CCCCCCCCCC99999933FFFFFFFFFFFF
CCCCCCCCCC9999999999FFFFFFFFFF
CCCCCCCCCCCC3300FFFFFFFFFFFFFF
CCCCCCCCCCCC9900FFFFFFFFFFFFFF
CCCCCCCCCCCC999900FFFFFFFFFFFF
CCCCCCCCCCCCCC00FFFFFFFFFFFFFF
CCCCCCCCCCCCCC3333FFFFFFFFFFFF
CCCCCCCCCCCCCC999933FFFFFFFFFF
CCCCCCCCCCCCCC99999999FFFFFFFF
CCCCCCCCCCCCCCCC00FFFFFFFFFFFF
CCCCCCCCCCCCCCCC9900FFFFFFFFFF
CCCCCCCCCCCCCCCCCC9933FFFFFFFF
CCCCCCCCCCCCCCCCCC999999FFFFFF
CCCCCCCCCCCCCCCCCCCC00FFFFFFFF
CCCCCCCCCCCCCCCCCCCCCC33FFFFFF
CCCCCCCCCCCCCCCCCCCCCC9999FFFF
CCCCCCCCCCCCCCCCCCCCCCCCCC99FF
CCCCCCCCCCCCCCCCCCCCCCCCCCCCCC
pop
P
% End of image
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{35.5, 149.063},
  ImageMargins->{{35, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40000/0000^Q000`40O003h00O;6]J0000:fmkJeY[
NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_
Nf]JJgY[FVmkJeY[NV]JKg][FV]j005[FP00;0000000:`00JeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]j
JeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmk
0040000000<006]JJeX0:6]J0@000000:`00JeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][
FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]j0040000000<0
06]JJeX0:6]J0@000006000TOol1Kg/1000000H002Aoo`5[FP4000001P0097oo0F]j0@000006000T
Ool1JeX1000000H002Aoo`5_N`4000001P0097oo0F]J0@000008000ROol1JgX1000000P0029oo`5[
FP4000001QS60P008Woo0Fmk0@0000066<H2000ROol1JeX1000000HHaP80029oo`5[NP4000000dic
1@008Woo0F]J0@000003CW<5000ROol1Kg/1000000=>L`D0029oo`5[FP4000000dic1AS60`007goo
0F]j0@000003CW<56<H3000OOol1JeX1000000=>L`DHaP<001moo`5_N`4000001Tic0QS60`007goo
0F]J0@000006CW<26<H3000OOol1JgX1000000Q>L`<HaP<001aoo`5[FP40000024ic0aS60`0077oo
0Fmk0@000008CW<36<H3000LOol1JeX1000000]>L`<001aoo`5[NP4000002dic0`0077oo0F]J0@00
000;CW<3000LOol1Kg/1000000i>L`<001Uoo`5[FP4000003Tic0`006Goo0F]j0@00000>CW<3000I
Ool1JeX1000000=W>@D0029oo`5_N`4000000fLi1@008Woo0F]J0@000003IcT36<H2000ROol1JgX1
000000=W>@<HaP80029oo`5[FP4000000fLi0aS60P008Woo0Fmk0@000003IcT36<H5000OOol1JeX1
000000=W>@<HaPD001moo`5[NP4000000fLi0aS61@007goo0F]J0@000003IcT3CW<5000OOol1Kg/1
000000=W>@=>L`D001moo`5[FP4000000fLi0dic1@007goo0F]j0@000003IcT3CW<26<H3000OOol1
JeX1000000=W>@=>L`8HaP<001moo`5_N`4000000fLi0dic21S677oo0F]J0@000003IcT3CW<86<HL
Ool1JgX1000000=W>@=>L`PHaQaoo`5[FP4000000fLi1Dic0`007goo0Fmk0@000003IcT5CW<3000O
Ool1JeX1000000=W>@E>L`<001moo`5[NP4000000fLi1Dic1P0077oo0F]J0@000003IcT5CW<6000L
Ool1Kg/1000000=W>@E>L`H001aoo`5[FP4000000fLi24ic0`0077oo0F]j0@000003IcT8CW<3000L
Ool1JeX1000000=W>@Q>L`HHaQUoo`5_N`4000000fLi24ic1QS66Goo0F]J0@000003IcT8CW<66<HI
Ool1JgX1000000=W>@i>L`<HaQIoo`5[FP4000000fLi3Tic0aS65Woo0Fmk0@000003IcT>CW<36<HF
Ool1JeX1000000=W>A=>LaAoo`5[NP4000000fLi4dic57oo0F]J0@000003IcTCCW<DOol1Kg/10000
00IW>@D001moo`5[FP4000001VLi1@007goo0F]j0@000006IcT5000OOol1JeX1000000IW>@DHaP<0
01aoo`5_N`4000001VLi1AS60`0077oo0F]J0@000006IcT2CW<36<H3000LOol1JgX1000000IW>@9>
L`<HaP<001aoo`5[FP4000001VLi0Tic0aS60`0077oo0Fmk0@000006IcT5CW<36<H3000IOol1JeX1
000000IW>@E>L`<HaP<001Uoo`5[NP4000001VLi1Dic0aS60`006Goo0F]J0@000006IcT8CW<3000I
Ool1Kg/1000000IW>@Q>L`<001Uoo`5[FP4000001VLi24ic0`006Goo0F]j0@000006IcT;CW<3000F
Ool1JeX1000000IW>@]>L`<001Ioo`5_N`40000026Li1P0077oo0F]J0@000008IcT6000LOol1JgX1
000000QW>@H001aoo`5[FP40000026Li0aS60`0077oo0Fmk0@000008IcT36<H3000LOol1JeX10000
00QW>@<HaP<001aoo`5[NP40000026Li2AS66Goo0F]J0@000008IcT96<HIOol1Kg/1000000QW>@TH
aQUoo`5[FP40000026Li0dic0`0077oo0F]j0@000008IcT3CW<3000LOol1JeX1000000QW>@=>L`H0
01Uoo`5_N`40000026Li0dic1P006Goo0F]J0@000008IcT3CW<6000IOol1JgX1000000QW>@I>L`<0
01Uoo`5[FP40000026Li1Tic0`006Goo0Fmk0@000008IcT6CW<3000IOol1JeX1000000QW>@I>L`HH
aQIoo`5[NP40000026Li1Tic1QS65Woo0F]J0@000008IcT6CW<66<HFOol1Kg/1000000QW>@a>L`8H
aQAoo`5[FP40000026Li34ic0QS657oo0F]j0@000008IcTACW<AOol1JeX1000000QW>A5>La5oo`5_
N`40000026Li4Dic4Goo0F]J0@00000;IcT36<H3000IOol1JgX1000000]W>@<HaP<001Uoo`5[FP40
00002fLi0aS60`006Goo0Fmk0@00000;IcT3CW<36<H3000FOol1JeX1000000]W>@=>L`<HaP<001Io
o`5[NP4000002fLi0dic0aS60`005Woo0F]J0@00000;IcT6CW<3000FOol1Kg/1000000]W>@I>L`<0
01Ioo`5[FP4000002fLi2Dic0P0057oo0F]j0@00000;IcT9CW<2000DOol1JeX1000000]W>@U>L`80
01Aoo`5_N`4000003VLi0`006Goo0F]J0@00000>IcT3000IOol1JgX1000000iW>@<001Uoo`5[FP40
00003VLi1P005Woo0Fmk0@00000>IcT6000FOol1JeX1000000iW>@H001Ioo`5[NP4000003VLi0dic
0`005Woo0F]J0@00000>IcT3CW<3000FOol1Kg/1000000iW>@=>L`<001Ioo`5[FP4000003VLi0dic
1AS657oo0F]j0@00000>IcT3CW<56<HDOol1JeX1000000iW>@Q>L`<HaQ5oo`5_N`4000003VLi24ic
0aS64Goo0F]J0@00000>IcT8CW<36<HAOol1JgX1000000iW>@i>L`ioo`5[FP4000003VLi3Tic3Woo
0Fmk0@00000>IcT>CW<>Ool1JeX10000015W>@<HaP8001Aoo`5[NP4000004FLi0aS60P0057oo0F]J
0@00000AIcT36<H2000DOol1Kg/10000015W>@=>L`8001Aoo`5[FP4000004FLi0dic0P0057oo0F]j
0@00000AIcT5CW<3000AOol1JeX10000015W>@E>L`<0015oo`5_N`4000004FLi1Dic0`004Goo0F]J
0@00000DIcT2000DOol1JgX1000001AW>@8001Aoo`5[FP40000056Li0P0057oo0Fmk0@00000DIcT5
6<HAOol1JeX1000001AW>@DHaQ5oo`5[NP40000056Li1AS64Goo0F]J0@00000DIcT5CW<36<H>Ool1
Kg/1000001AW>@E>L`<HaPioo`5[FP40000056Li2dic2goo0F]j0@00000DIcT;CW<;Ool1JeX10000
01AW>@]>L`]oo`5_N`4000005VLi0`004Goo0F]J0@00000FIcT3000AOol1JgX1000001IW>@<0015o
o`5[FP4000005VLi0dic0`003Woo0Fmk0@00000FIcT3CW<3000>Ool1JeX1000001IW>@=>L`<000io
o`5[NP4000006FLi0dic0aS62goo0F]J0@00000IIcT3CW<36<H;Ool1Kg/1000001UW>@U>L`Qoo`5[
FP4000006FLi2Dic27oo0F]j0@00000IIcT9CW<8Ool1JeX1000001aW>@<000]oo`5_N`40000076Li
0`002goo0F]J0@00000LIcT3000;Ool1JgX1000001mW>@<HaPQoo`5[FP4000007fLi0aS627oo0Fmk
0@00000OIcT36<H8Ool1JeX1000001mW>@E>L`Ioo`5[NP4000007fLi1Dic1Woo0F]J0@00000TIcT3
CW<3Ool1Kg/1000002AW>@=>L`=oo`5[FP40000096Li0dic0goo0F]j0@00000ZIcT1JeX1000002YW
>@5_N`400000:VLi0F]J0@000000:`00JeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]j
JeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]j0040000000<006]J
JeX0:6]J0@00000/000002a[FP0002]_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[
NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NP01JeX00001\
\>"],
  ImageRangeCache->{{{140.063, 174.563}, {310.125, 162.063}} -> {-64.1525, \
71.5963, 0.455479, 0.455479}}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(Table[
      Length[partH[Complement[Range[n], 3  Range[n]], n]], {n, 
        20}]\)], "Input"],

Cell[BoxData[
    \({1, 2, 2, 4, 5, 7, 9, 13, 16, 22, 27, 36, 44, 57, 70, 89, 108, 135, 
      163, 202}\)], "Output"]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{

Cell["SELF-CONJUGATE PARTITIONS. ", "Subsubsection"],

Cell["They correspond to partitions into odd and unequal parts", "Text"],

Cell[BoxData[
    \(selfConjugate[n_] := 
      partitionsOdd[n] \[Intersection] partitionsUnEqual[n]\)], "Input"],

Cell[CellGroupData[{

Cell[BoxData[
    \(asSum\  /@ selfConjugate[15]\)], "Input"],

Cell[BoxData[
    RowBox[{"{", 
      RowBox[{"\<\"15\"\>", ",", 
        TagBox[
          RowBox[{"1", "+", 
            TagBox[\(3 + 11\),
              DisplayForm]}],
          DisplayForm], ",", 
        TagBox[
          RowBox[{"1", "+", 
            TagBox[\(5 + 9\),
              DisplayForm]}],
          DisplayForm], ",", 
        TagBox[
          RowBox[{"3", "+", 
            TagBox[\(5 + 7\),
              DisplayForm]}],
          DisplayForm]}], "}"}]], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(Table[Length[selfConjugate[n]], {n, 20}]\)], "Input"],

Cell[BoxData[
    \({1, 0, 1, 1, 1, 1, 1, 2, 2, 2, 2, 3, 3, 3, 4, 5, 5, 5, 6, 
      7}\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(Times\  @@ \ \((1 + x\^Range[1, 20, 2])\) + \ O[x]\^21\)], "Input"],

Cell[BoxData[
    InterpretationBox[
      RowBox[{
      "1", "+", "x", "+", \(x\^3\), "+", \(x\^4\), "+", \(x\^5\), 
        "+", \(x\^6\), "+", \(x\^7\), "+", \(2\ x\^8\), "+", \(2\ x\^9\), 
        "+", \(2\ x\^10\), "+", \(2\ x\^11\), "+", \(3\ x\^12\), 
        "+", \(3\ x\^13\), "+", \(3\ x\^14\), "+", \(4\ x\^15\), 
        "+", \(5\ x\^16\), "+", \(5\ x\^17\), "+", \(5\ x\^18\), 
        "+", \(6\ x\^19\), "+", \(7\ x\^20\), "+", 
        InterpretationBox[\(O[x]\^21\),
          SeriesData[ x, 0, {}, 0, 21, 1]]}],
      SeriesData[ 
      x, 0, {1, 1, 0, 1, 1, 1, 1, 1, 2, 2, 2, 2, 3, 3, 3, 4, 5, 5, 5, 6, 7}, 
        0, 21, 1]]], "Output"]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{

Cell["PARTITIONS WITH MINIMAL DIFFERENCE 2", "Subsubsection"],

Cell[BoxData[
    \(partitionsMinDif2[n_] := 
      Select[partitionsDif[n], 
        Not[MemberQ[Rest[#] - Rest[RotateRight[#]], 1]] &]\)], "Input"],

Cell[CellGroupData[{

Cell[BoxData[
    \(asSum\  /@ partitionsMinDif2[9] // TableForm\)], "Input"],

Cell[BoxData[
    InterpretationBox[GridBox[{
          {
            TagBox[
              RowBox[{"1", "+", 
                TagBox[\(3 + 5\),
                  DisplayForm]}],
              DisplayForm]},
          {
            TagBox[\(1 + 8\),
              DisplayForm]},
          {
            TagBox[\(2 + 7\),
              DisplayForm]},
          {
            TagBox[\(3 + 6\),
              DisplayForm]},
          {"\<\"9\"\>"}
          },
        RowSpacings->1,
        ColumnSpacings->3,
        RowAlignments->Baseline,
        ColumnAlignments->{Left}],
      TableForm[ {
        DisplayForm[ 
          RowBox[ {"1", "+", 
            DisplayForm[ 
              RowBox[ {"3", "+", "5"}]]}]], 
        DisplayForm[ 
          RowBox[ {"1", "+", "8"}]], 
        DisplayForm[ 
          RowBox[ {"2", "+", "7"}]], 
        DisplayForm[ 
          RowBox[ {"3", "+", "6"}]], "9"}]]], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(Table[Length[partitionsMinDif2[n]], {n, 20}]\)], "Input"],

Cell[BoxData[
    \({1, 1, 1, 2, 2, 3, 3, 4, 5, 6, 7, 9, 10, 12, 14, 17, 19, 23, 26, 
      31}\)], "Output"]
}, Open  ]],

Cell["\<\
Theorem. The number of partitions of n with minimal difference 2 is equal to \
the number of partitions of n into parts of the form 5m+1 and 5m+4\
\>", "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(asSum\  /@ 
        Select[partitions[
            9], \((And\  @@ \ \((\(MemberQ[{1, 4}, 
                        Mod[#, 5]] &\)\  /@ \ #)\))\) &]\  // 
      TableForm\)], "Input"],

Cell[BoxData[
    InterpretationBox[GridBox[{
          {
            TagBox[
              RowBox[{"1", "+", 
                TagBox[
                  RowBox[{"1", "+", 
                    TagBox[
                      RowBox[{"1", "+", 
                        TagBox[
                          RowBox[{"1", "+", 
                            TagBox[
                              RowBox[{"1", "+", 
                                TagBox[
                                  RowBox[{"1", "+", 
                                    TagBox[
                                      RowBox[{"1", "+", 
                                        TagBox[\(1 + 1\),
                                        DisplayForm]}],
                                      DisplayForm]}],
                                  DisplayForm]}],
                              DisplayForm]}],
                          DisplayForm]}],
                      DisplayForm]}],
                  DisplayForm]}],
              DisplayForm]},
          {
            TagBox[
              RowBox[{"1", "+", 
                TagBox[
                  RowBox[{"1", "+", 
                    TagBox[
                      RowBox[{"1", "+", 
                        TagBox[
                          RowBox[{"1", "+", 
                            TagBox[\(1 + 4\),
                              DisplayForm]}],
                          DisplayForm]}],
                      DisplayForm]}],
                  DisplayForm]}],
              DisplayForm]},
          {
            TagBox[
              RowBox[{"1", "+", 
                TagBox[
                  RowBox[{"1", "+", 
                    TagBox[\(1 + 6\),
                      DisplayForm]}],
                  DisplayForm]}],
              DisplayForm]},
          {
            TagBox[
              RowBox[{"1", "+", 
                TagBox[\(4 + 4\),
                  DisplayForm]}],
              DisplayForm]},
          {"\<\"9\"\>"}
          },
        RowSpacings->1,
        ColumnSpacings->3,
        RowAlignments->Baseline,
        ColumnAlignments->{Left}],
      TableForm[ {
        DisplayForm[ 
          RowBox[ {"1", "+", 
            DisplayForm[ 
              RowBox[ {"1", "+", 
                DisplayForm[ 
                  RowBox[ {"1", "+", 
                    DisplayForm[ 
                      RowBox[ {"1", "+", 
                        DisplayForm[ 
                          RowBox[ {"1", "+", 
                            DisplayForm[ 
                              RowBox[ {"1", "+", 
                                DisplayForm[ 
                                  RowBox[ {"1", "+", 
                                    DisplayForm[ 
                                      
                                      RowBox[ {"1", "+", 
                                        "1"}]]}]]}]]}]]}]]}]]}]]}]], 
        DisplayForm[ 
          RowBox[ {"1", "+", 
            DisplayForm[ 
              RowBox[ {"1", "+", 
                DisplayForm[ 
                  RowBox[ {"1", "+", 
                    DisplayForm[ 
                      RowBox[ {"1", "+", 
                        DisplayForm[ 
                          RowBox[ {"1", "+", "4"}]]}]]}]]}]]}]], 
        DisplayForm[ 
          RowBox[ {"1", "+", 
            DisplayForm[ 
              RowBox[ {"1", "+", 
                DisplayForm[ 
                  RowBox[ {"1", "+", "6"}]]}]]}]], 
        DisplayForm[ 
          RowBox[ {"1", "+", 
            DisplayForm[ 
              RowBox[ {"4", "+", "4"}]]}]], "9"}]]], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(Times\  @@ \ \((1/
            Map[\((1 - x\^#)\) &, 
              Join[Range[1, 20, 5], Range[4, 20, 5]]])\) + 
      O[x]\^20\)], "Input"],

Cell[BoxData[
    InterpretationBox[
      RowBox[{
      "1", "+", "x", "+", \(x\^2\), "+", \(x\^3\), "+", \(2\ x\^4\), 
        "+", \(2\ x\^5\), "+", \(3\ x\^6\), "+", \(3\ x\^7\), 
        "+", \(4\ x\^8\), "+", \(5\ x\^9\), "+", \(6\ x\^10\), 
        "+", \(7\ x\^11\), "+", \(9\ x\^12\), "+", \(10\ x\^13\), 
        "+", \(12\ x\^14\), "+", \(14\ x\^15\), "+", \(17\ x\^16\), 
        "+", \(19\ x\^17\), "+", \(23\ x\^18\), "+", \(26\ x\^19\), "+", 
        InterpretationBox[\(O[x]\^20\),
          SeriesData[ x, 0, {}, 0, 20, 1]]}],
      SeriesData[ 
      x, 0, {1, 1, 1, 1, 2, 2, 3, 3, 4, 5, 6, 7, 9, 10, 12, 14, 17, 19, 23, 
        26}, 0, 20, 1]]], "Output"]
}, Open  ]],

Cell["\<\
Theorem. The number of partitions of n into parts no less than 2 and with \
minimal difference 2 is equal to the number of partitions of n into parts of \
the form 5m+2 and 5m+3\
\>", "Text"]
}, Closed]],

Cell[CellGroupData[{

Cell["PARTITIONS IN WHICH NO SUMMAND APPEARS MORE THAN TWICE", "Subsubsection"],

Cell[BoxData[
    \(atMostTwice[n_] := 
      DeleteCases[partitions[n], {___, x_, ___, x_, ___, x_, ___}]\)], "Input",\

  PageWidth->Infinity,
  FontFamily->"Courier New",
  FontSize->12,
  FontWeight->"Bold",
  FontColor->GrayLevel[0],
  Background->GrayLevel[1]],

Cell[CellGroupData[{

Cell[BoxData[
    \(asSum\  /@ atMostTwice[8]\)], "Input"],

Cell[BoxData[
    RowBox[{"{", 
      RowBox[{
        TagBox[
          RowBox[{"1", "+", 
            TagBox[
              RowBox[{"1", "+", 
                TagBox[\(2 + 4\),
                  DisplayForm]}],
              DisplayForm]}],
          DisplayForm], ",", 
        TagBox[
          RowBox[{"1", "+", 
            TagBox[
              RowBox[{"1", "+", 
                TagBox[\(3 + 3\),
                  DisplayForm]}],
              DisplayForm]}],
          DisplayForm], ",", 
        TagBox[
          RowBox[{"1", "+", 
            TagBox[\(1 + 6\),
              DisplayForm]}],
          DisplayForm], ",", 
        TagBox[
          RowBox[{"1", "+", 
            TagBox[
              RowBox[{"2", "+", 
                TagBox[\(2 + 3\),
                  DisplayForm]}],
              DisplayForm]}],
          DisplayForm], ",", 
        TagBox[
          RowBox[{"1", "+", 
            TagBox[\(2 + 5\),
              DisplayForm]}],
          DisplayForm], ",", 
        TagBox[
          RowBox[{"1", "+", 
            TagBox[\(3 + 4\),
              DisplayForm]}],
          DisplayForm], ",", 
        TagBox[\(1 + 7\),
          DisplayForm], ",", 
        TagBox[
          RowBox[{"2", "+", 
            TagBox[\(2 + 4\),
              DisplayForm]}],
          DisplayForm], ",", 
        TagBox[
          RowBox[{"2", "+", 
            TagBox[\(3 + 3\),
              DisplayForm]}],
          DisplayForm], ",", 
        TagBox[\(2 + 6\),
          DisplayForm], ",", 
        TagBox[\(3 + 5\),
          DisplayForm], ",", 
        TagBox[\(4 + 4\),
          DisplayForm], ",", "\<\"8\"\>"}], "}"}]], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(Table[Length[atMostTwice[n]], {n, 20}]\)], "Input"],

Cell[BoxData[
    \({1, 2, 2, 4, 5, 7, 9, 13, 16, 22, 27, 36, 44, 57, 70, 89, 108, 135, 
      163, 202}\)], "Output"]
}, Open  ]]
}, Closed]]
}, Open  ]],

Cell[CellGroupData[{

Cell["BOUNDED PARTITIONS", "Subsection"],

Cell[TextData[{
  "There are ",
  Cell[BoxData[
      FormBox[
        RowBox[{"(", "\[NegativeThinSpace]", GridBox[{
              {\(n + r - 1\)},
              {"n"}
              }], "\[NegativeThinSpace]", ")"}], TraditionalForm]]],
  " partitions of n of size at most r. The first ",
  Cell[BoxData[
      FormBox[
        RowBox[{"(", "\[NegativeThinSpace]", GridBox[{
              {\(n + r - 2\)},
              {"n"}
              }], "\[NegativeThinSpace]", ")"}], TraditionalForm]]],
  " start with 0. In general, there are ",
  Cell[BoxData[
      FormBox[
        RowBox[{"(", "\[NegativeThinSpace]", GridBox[{
              {\(n + r - i - 2\)},
              {\(n - i\)}
              }], "\[NegativeThinSpace]", ")"}], TraditionalForm]]],
  " partitions starting with i. "
}], "Text"],

Cell[BoxData[{
    \(part\_\(n_, 1\) := {{n}}\), "\n", 
    \(part\_\(n_, r_\) := 
      Module[{ans = {}, 
          i}, \[IndentingNewLine]Do[\[IndentingNewLine]AppendTo[
            ans, \((Join[{i}, #] &)\) /@ part\_\(n - i, r - 1\)], {i, 0, 
            n}]; \[IndentingNewLine]Flatten[ans, 1]]\)}], "Input",
  PageWidth->Infinity,
  AspectRatioFixed->True],

Cell[CellGroupData[{

Cell[BoxData[
    \(asSum\  /@ \ part\_\(5, 3\)\)], "Input",
  PageWidth->Infinity,
  AspectRatioFixed->True],

Cell[BoxData[
    RowBox[{"{", 
      RowBox[{
        TagBox[
          RowBox[{"0", "+", 
            TagBox[\(0 + 5\),
              DisplayForm]}],
          DisplayForm], ",", 
        TagBox[
          RowBox[{"0", "+", 
            TagBox[\(1 + 4\),
              DisplayForm]}],
          DisplayForm], ",", 
        TagBox[
          RowBox[{"0", "+", 
            TagBox[\(2 + 3\),
              DisplayForm]}],
          DisplayForm], ",", 
        TagBox[
          RowBox[{"0", "+", 
            TagBox[\(3 + 2\),
              DisplayForm]}],
          DisplayForm], ",", 
        TagBox[
          RowBox[{"0", "+", 
            TagBox[\(4 + 1\),
              DisplayForm]}],
          DisplayForm], ",", 
        TagBox[
          RowBox[{"0", "+", 
            TagBox[\(5 + 0\),
              DisplayForm]}],
          DisplayForm], ",", 
        TagBox[
          RowBox[{"1", "+", 
            TagBox[\(0 + 4\),
              DisplayForm]}],
          DisplayForm], ",", 
        TagBox[
          RowBox[{"1", "+", 
            TagBox[\(1 + 3\),
              DisplayForm]}],
          DisplayForm], ",", 
        TagBox[
          RowBox[{"1", "+", 
            TagBox[\(2 + 2\),
              DisplayForm]}],
          DisplayForm], ",", 
        TagBox[
          RowBox[{"1", "+", 
            TagBox[\(3 + 1\),
              DisplayForm]}],
          DisplayForm], ",", 
        TagBox[
          RowBox[{"1", "+", 
            TagBox[\(4 + 0\),
              DisplayForm]}],
          DisplayForm], ",", 
        TagBox[
          RowBox[{"2", "+", 
            TagBox[\(0 + 3\),
              DisplayForm]}],
          DisplayForm], ",", 
        TagBox[
          RowBox[{"2", "+", 
            TagBox[\(1 + 2\),
              DisplayForm]}],
          DisplayForm], ",", 
        TagBox[
          RowBox[{"2", "+", 
            TagBox[\(2 + 1\),
              DisplayForm]}],
          DisplayForm], ",", 
        TagBox[
          RowBox[{"2", "+", 
            TagBox[\(3 + 0\),
              DisplayForm]}],
          DisplayForm], ",", 
        TagBox[
          RowBox[{"3", "+", 
            TagBox[\(0 + 2\),
              DisplayForm]}],
          DisplayForm], ",", 
        TagBox[
          RowBox[{"3", "+", 
            TagBox[\(1 + 1\),
              DisplayForm]}],
          DisplayForm], ",", 
        TagBox[
          RowBox[{"3", "+", 
            TagBox[\(2 + 0\),
              DisplayForm]}],
          DisplayForm], ",", 
        TagBox[
          RowBox[{"4", "+", 
            TagBox[\(0 + 1\),
              DisplayForm]}],
          DisplayForm], ",", 
        TagBox[
          RowBox[{"4", "+", 
            TagBox[\(1 + 0\),
              DisplayForm]}],
          DisplayForm], ",", 
        TagBox[
          RowBox[{"5", "+", 
            TagBox[\(0 + 0\),
              DisplayForm]}],
          DisplayForm]}], "}"}]], "Output"]
}, Open  ]],

Cell["To obtain the i-th partition", "Text"],

Cell[BoxData[{
    \(numPart[n_, r_] := Binomial[n + r - 1, n]\n\), "\n", 
    \(ithPart\_\(n_, r_\)[i_] := "\<Out of Range\>"\  /; \ 
        i > numPart[n, r]\), "\n", 
    \(ithPart\_\(n_, 1\)[1] := {n}\), "\n", 
    \(ithPart\_\(n_, r_\)[i_] := 
      Module[{j, k, t}, \[IndentingNewLine]t = 
          Table[0, {n + 
                1}]; \[IndentingNewLine]t\[LeftDoubleBracket]1\
\[RightDoubleBracket] = 
          numPart[n, 
            r - 1]; \[IndentingNewLine]Do[\[IndentingNewLine]t\
\[LeftDoubleBracket]j + 1\[RightDoubleBracket] = 
            t\[LeftDoubleBracket]j\[RightDoubleBracket] + 
              numPart[n - j, r - 1], {j, n}]; \[IndentingNewLine]PrependTo[t, 
          0]; \[IndentingNewLine]j = 1; \[IndentingNewLine]While[\ 
          t\[LeftDoubleBracket]j\[RightDoubleBracket] < 
            i, \(j++\)]; \[IndentingNewLine]Join[{j - 2}, 
          ithPart\_\(n - j + 2, r - 1\)[
            i - t\[LeftDoubleBracket]j - 
                  1\[RightDoubleBracket]]]]\)}], "Input"],

Cell[CellGroupData[{

Cell[BoxData[
    \(asSum\  /@ \ Table[ithPart\_\(5, 3\)[i], {i, numPart[5, 3]}]\)], "Input"],

Cell[BoxData[
    RowBox[{"{", 
      RowBox[{
        TagBox[
          RowBox[{"0", "+", 
            TagBox[\(0 + 5\),
              DisplayForm]}],
          DisplayForm], ",", 
        TagBox[
          RowBox[{"0", "+", 
            TagBox[\(1 + 4\),
              DisplayForm]}],
          DisplayForm], ",", 
        TagBox[
          RowBox[{"0", "+", 
            TagBox[\(2 + 3\),
              DisplayForm]}],
          DisplayForm], ",", 
        TagBox[
          RowBox[{"0", "+", 
            TagBox[\(3 + 2\),
              DisplayForm]}],
          DisplayForm], ",", 
        TagBox[
          RowBox[{"0", "+", 
            TagBox[\(4 + 1\),
              DisplayForm]}],
          DisplayForm], ",", 
        TagBox[
          RowBox[{"0", "+", 
            TagBox[\(5 + 0\),
              DisplayForm]}],
          DisplayForm], ",", 
        TagBox[
          RowBox[{"1", "+", 
            TagBox[\(0 + 4\),
              DisplayForm]}],
          DisplayForm], ",", 
        TagBox[
          RowBox[{"1", "+", 
            TagBox[\(1 + 3\),
              DisplayForm]}],
          DisplayForm], ",", 
        TagBox[
          RowBox[{"1", "+", 
            TagBox[\(2 + 2\),
              DisplayForm]}],
          DisplayForm], ",", 
        TagBox[
          RowBox[{"1", "+", 
            TagBox[\(3 + 1\),
              DisplayForm]}],
          DisplayForm], ",", 
        TagBox[
          RowBox[{"1", "+", 
            TagBox[\(4 + 0\),
              DisplayForm]}],
          DisplayForm], ",", 
        TagBox[
          RowBox[{"2", "+", 
            TagBox[\(0 + 3\),
              DisplayForm]}],
          DisplayForm], ",", 
        TagBox[
          RowBox[{"2", "+", 
            TagBox[\(1 + 2\),
              DisplayForm]}],
          DisplayForm], ",", 
        TagBox[
          RowBox[{"2", "+", 
            TagBox[\(2 + 1\),
              DisplayForm]}],
          DisplayForm], ",", 
        TagBox[
          RowBox[{"2", "+", 
            TagBox[\(3 + 0\),
              DisplayForm]}],
          DisplayForm], ",", 
        TagBox[
          RowBox[{"3", "+", 
            TagBox[\(0 + 2\),
              DisplayForm]}],
          DisplayForm], ",", 
        TagBox[
          RowBox[{"3", "+", 
            TagBox[\(1 + 1\),
              DisplayForm]}],
          DisplayForm], ",", 
        TagBox[
          RowBox[{"3", "+", 
            TagBox[\(2 + 0\),
              DisplayForm]}],
          DisplayForm], ",", 
        TagBox[
          RowBox[{"4", "+", 
            TagBox[\(0 + 1\),
              DisplayForm]}],
          DisplayForm], ",", 
        TagBox[
          RowBox[{"4", "+", 
            TagBox[\(1 + 0\),
              DisplayForm]}],
          DisplayForm], ",", 
        TagBox[
          RowBox[{"5", "+", 
            TagBox[\(0 + 0\),
              DisplayForm]}],
          DisplayForm]}], "}"}]], "Output"]
}, Open  ]],

Cell["\<\
For example, to find the millionth partition of 100 of size 6.\
\>", "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(asSum[ithPart\_\(100, 6\)[1000000]]\)], "Input"],

Cell[BoxData[
    TagBox[
      RowBox[{"0", "+", 
        TagBox[
          RowBox[{"6", "+", 
            TagBox[
              RowBox[{"3", "+", 
                TagBox[
                  RowBox[{"8", "+", 
                    TagBox[\(49 + 34\),
                      DisplayForm]}],
                  DisplayForm]}],
              DisplayForm]}],
          DisplayForm]}],
      DisplayForm]], "Output"]
}, Open  ]],

Cell["A random partition:", "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(asSum[
      ithPart\_\(Random[Integer, {500, 800}], Random[Integer, {5, 10}]\)[
        Random[Integer, {10\^8, 10\^10}]]]\)], "Input"],

Cell[BoxData[
    TagBox[
      RowBox[{"0", "+", 
        TagBox[
          RowBox[{"0", "+", 
            TagBox[
              RowBox[{"0", "+", 
                TagBox[
                  RowBox[{"1", "+", 
                    TagBox[
                      RowBox[{"145", "+", 
                        TagBox[
                          RowBox[{"63", "+", 
                            TagBox[
                              RowBox[{"285", "+", 
                                TagBox[\(43 + 13\),
                                  DisplayForm]}],
                              DisplayForm]}],
                          DisplayForm]}],
                      DisplayForm]}],
                  DisplayForm]}],
              DisplayForm]}],
          DisplayForm]}],
      DisplayForm]], "Output"]
}, Open  ]],

Cell["\<\
These random partitions are not really of the required size. We would like to \
disregard the 0 and consider the restricted partitions of n, that is, \
partitions of n into at most r parts each one being at most m.\
\>", "Text"],

Cell[BoxData[
    \(restrictedPartitions[m_, r_, n_] := 
      Select[partH[Range[m], n], \((Length[#] \[LessEqual] r)\) &]\)], "Input"],

Cell[CellGroupData[{

Cell[BoxData[
    \(asSum\  /@ \ restrictedPartitions[5, 3, 5]\)], "Input"],

Cell[BoxData[
    RowBox[{"{", 
      RowBox[{
        TagBox[
          RowBox[{"1", "+", 
            TagBox[\(1 + 3\),
              DisplayForm]}],
          DisplayForm], ",", 
        TagBox[
          RowBox[{"1", "+", 
            TagBox[\(2 + 2\),
              DisplayForm]}],
          DisplayForm], ",", 
        TagBox[\(1 + 4\),
          DisplayForm], ",", 
        TagBox[\(2 + 3\),
          DisplayForm], ",", "\<\"5\"\>"}], "}"}]], "Output"]
}, Open  ]],

Cell["\<\
The number of partitions of n into at most 4 parts each one being at most 5 \
is\
\>", "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(Table[Length[restrictedPartitions[5, 4, n]], {n, 25}]\)], "Input"],

Cell[BoxData[
    \({1, 2, 3, 5, 6, 8, 9, 11, 11, 12, 11, 11, 9, 8, 6, 5, 3, 2, 1, 1, 0, 0, 
      0, 0, 0}\)], "Output"]
}, Open  ]],

Cell["\<\
In general, from the (mr+1)-th element on all of them are zero.\
\>", "Text"],

Cell[BoxData[
    \(G[m_, 
        r_] := \(\[Product]\+\(i = r + 1\)\%\(r + m\)\((1 - x\^i)\)\)\/\(\
\[Product]\+\(i = 1\)\%m\((1 - x\^i)\)\)\)], "Input"],

Cell[CellGroupData[{

Cell[BoxData[
    \(G[5, 4] + O[x]\^26\)], "Input"],

Cell[BoxData[
    InterpretationBox[
      RowBox[{
      "1", "+", "x", "+", \(2\ x\^2\), "+", \(3\ x\^3\), "+", \(5\ x\^4\), 
        "+", \(6\ x\^5\), "+", \(8\ x\^6\), "+", \(9\ x\^7\), 
        "+", \(11\ x\^8\), "+", \(11\ x\^9\), "+", \(12\ x\^10\), 
        "+", \(11\ x\^11\), "+", \(11\ x\^12\), "+", \(9\ x\^13\), 
        "+", \(8\ x\^14\), "+", \(6\ x\^15\), "+", \(5\ x\^16\), 
        "+", \(3\ x\^17\), "+", \(2\ x\^18\), "+", \(x\^19\), "+", \(x\^20\), 
        "+", 
        InterpretationBox[\(O[x]\^26\),
          SeriesData[ x, 0, {}, 0, 26, 1]]}],
      SeriesData[ 
      x, 0, {1, 1, 2, 3, 5, 6, 8, 9, 11, 11, 12, 11, 11, 9, 8, 6, 5, 3, 2, 1, 
        1}, 0, 26, 1]]], "Output"]
}, Open  ]],

Cell["\<\
In general, the number of partitions of n into two parts is equal to \
\[LeftFloor]n/2\[RightFloor]+1 \
\>", "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(Table[Length[restrictedPartitions[n, 2, n]], {n, 10}]\)], "Input"],

Cell[BoxData[
    \({1, 2, 2, 3, 3, 4, 4, 5, 5, 6}\)], "Output"]
}, Open  ]],

Cell[TextData[{
  "The number of partitions of n into three parts is equal to the nearest \
integer to ",
  Cell[BoxData[
      \(TraditionalForm\`\((n + 3)\)\^2\)]],
  "/12."
}], "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(Table[Length[restrictedPartitions[n, 3, n]], {n, 10}]\)], "Input"],

Cell[BoxData[
    \({1, 2, 3, 4, 5, 7, 8, 10, 12, 14}\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(Table[Round[\((n + 3)\)\^2\/12], {n, 10}]\)], "Input"],

Cell[BoxData[
    \({1, 2, 3, 4, 5, 7, 8, 10, 12, 14}\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[{
    \(\(p = restrictedPartitions[15, 3, 15];\)\), "\[IndentingNewLine]", 
    \(\(m = Max[Length\  /@ \ p];\)\), "\[IndentingNewLine]", 
    \(\(u = \(PadRight[#, m] &\)\  /@ \ p;\)\), "\n", 
    \(\(ListDensityPlot[\(-Reverse[u]\), \ Mesh\  \[Rule] \ False, 
        AspectRatio \[Rule] Automatic, 
        FrameTicks \[Rule] None];\)\)}], "Input"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 9 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% DensityGraphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0192308 0.320513 0.173077 0.320513 [
[ 0 0 -0.125 0 ]
[ 0 0 -0.125 0 ]
[ 0 9 .125 0 ]
[ 1 0 .125 0 ]
[ 0 0 0 0 ]
[ 1 9 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
0 0 m
1 0 L
s
0 0 m
0 9 L
s
0 9 m
1 9 L
s
1 0 m
1 9 L
s
0 0 m
1 0 L
1 9 L
0 9 L
closepath
clip
newpath
% Start of gray image
p
.01923 .17308 translate
.96154 8.65384 scale
3 string
3 27 8 [3 0 0 27 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
00FFFF
8877FF
9966FF
AA55FF
AAAAAA
BB44FF
BBAA99
BBBB88
CC33FF
CC9999
CCAA88
CCBB77
CCCC66
DD22FF
DD9988
DDAA77
DDBB66
DDCC55
DDDD44
EE11FF
EE8888
EE9977
EEAA66
EEBB55
EECC44
EEDD33
EEEE22
pop
P
% End of image
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{21.3125, 191.813},
  ImageMargins->{{35, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40000J0000ka000`40O003h00O01U[NV]JKg][FV]j
JeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NP01JeX001Y[FP0001U_Nf]JJgY[
FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_N`01JeX001Y[FP0001U[NV]J
Kg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NP01JeX001X0000001T0
06]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_N`0100000003001[
FV]J01I[FP40000001T006]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmk
JeY[NP0100000003001[FV]J01I[FP40000001T006]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[
FVmkJeY[NV]JKg][FV]jJeY_N`01000000T0011oo`4000002@0047oo0@000009000@Ool1000000T0
011oo`4000002@0047oo0@000009000@Ool1000000T0011oo`4000002@0047oo0@000009@Q08>Lh8
Ool1000000U24005=LdicSW>>Lhec@03>Lh8Ool1000000U240PicPQoo`4000002D8@0SW>00HecCW>
>LhicSG=>Lh8Ool1000000U240PicPQoo`4000002D8@00DecCW>>LhicSG=00<icPQoo`4000002D8@
23W>27oo0@000009@Q02>Lh01SG=>LhicSW>=LdicPQoo`4000002DYB236<27oo0@0000004DYbBU9>
LdYBBW9:DTicBU9:LRf;<H`]Rc6<;H/aS2f;<H`027oo0@000009BU88<H`8Ool10000000ACW=:DTYb
BU9>LdYBBW9:DTic;H/aS2f;<H`]Rc6<;H/aS008Ool1000000U:DPPaS0Qoo`400000015:LTYBCW=:
DTYbBU9>LdYBBW8]Rc6<;H/aS2f;<H`]Rc6<00Qoo`4000002DYB236<27oo0@0000004DicBU9:LTYB
CW=:DTYbBU9>Lbf;<H`]Rc6<;H/aS2f;<H`027oo0@0000002E:DD[ABU5:dDYAB]5:DD[ABU003:DX0
1BE9:DXYBRU:9DT027oo0@0000004EJeDYAF]E:DE[EBU5JeDYAF]BE9:DXUBBU:9DTYBRE9:DX027oo
0@0000002e:DD[ABU5:dDYAB]5:DD[ABU2U:9DT00bU:00<UBBU::DX027oo0@0000004EJeDYAF]E:D
E[EBU5JeDYAF]BE9:DXUBBU:9DTYBRE9:DX027oo0@0000002E:DD[ABU5:dDYAB]5:DD[ABU003:DX0
1BE9:DXYBRU:9DT027oo0@0000004EJeDYAF]E:DE[EBU5JeDYAF]BE9:DXUBBU:9DTYBRE9:DX027oo
0@0000002e:DD[ABU5:dDYAB]5:DD[ABU2U:9DT00bU:00<UBBU::DX027oo0@0000004EJeDYAF]E:D
E[EBU5JeDYAF]BE9:DXUBBU:9DTYBRE9:DX027oo0@0000006E:DD[ABU5:dDYAB]5:DD[ABU5:dDYAB
]5:DD[ABU5:dDYAB]5:DD[ABU5:dDYAB]5:D0040000001UF]E:DE[EBU5JeDYAF]E:DE[EBU5JeDYAF
]E:DE[EBU5JeDYAF]E:DE[EBU5JeDYAF]@010000000IDYAB]5:DD[ABU5:dDYAB]5:DD[ABU5:dDYAB
]5:DD[ABU5:dDYAB]5:DD[ABU5:dDY@00@0000006EJeDYAF]E:DE[EBU5JeDYAF]E:DE[EBU5JeDYAF
]E:DE[EBU5JeDYAF]E:DE[EBU5Je0040000001UBU5:dDYAB]5:DD[ABU5:dDYAB]5:DD[ABU5:dDYAB
]5:DD[ABU5:dDYAB]5:DD[ABU0010000000IE[EBU5JeDYAF]E:DE[EBU5JeDYAF]E:DE[EBU5JeDYAF
]E:DE[EBU5JeDYAF]E:DE[D00@0000006E:DD[ABU5:dDYAB]5:DD[ABU5:dDYAB]5:DD[ABU5:dDYAB
]5:DD[ABU5:dDYAB]5:D0040000001UF]E:DE[EBU5JeDYAF]E:DE[EBU5JeDYAF]E:DE[EBU5JeDYAF
]E:DE[EBU5JeDYAF]@01000000=JmP0>G_MJmU[fF_INme[f8@PM1b487@LQ21d78@PM1`Qoo`400000
015Nme[FG_MJeUkgF]INme[FG_LM1b487@LQ21d78@PM1b4800Qoo`40000000=JmUkgF_H00U[f00aN
me[fF_IJmR487@LQ21d78@PM1b487@L8Ool10000000AG_MJeUkgF]INme[FG_MJeUkg7@LQ21d78@PM
1b487@LQ2008Ool1000000=JmP0>G_MJmU[fF_INme[f8@PM1b487@LQ21d78@PM1`Qoo`400000015N
me[FG_MJeUkgF]INme[FG_LM1b487@LQ21d78@PM1b4800Qoo`40000000=JmUkgF_H00U[f00aNme[f
F_IJmR487@LQ21d78@PM1b487@L8Ool10000000AG_MJeUkgF]INme[FG_MJeUkg7@LQ21d78@PM1b48
7@LQ2008Ool1000000=JmP0>G_MJmU[fF_INme[fD[ABU5:dDYAB]5:DD[ABU0Q:DP40000001UNme[F
G_MJeUkgF]INme[FG_MBU5JeDYAF]E:DE[EBU5JeBU9>LdYBBW9:DTicBU9:LP0100000003F_INme[f
009JmP0<G_MJmU[fF_IB]5:DD[ABU5:dDYAB]5:D24YB0@0000006EkgF]INme[FG_MJeUkgF]INme:D
E[EBU5JeDYAF]E:DE[E:DTYbBU9>LdYBBW9:DTic004000000e[f00iNme[fF_IJmUkgF_IB]5:DD[AB
U5:dDYAB]5:D24YB0@0000006EkgF]INme[FG_MJeUkgF]INme:DE[EBU5JeDYAF]E:DE[E:DTicBU9:
LTYBCW=:DTYb0040000000=JmUkgF_H00U[f00aNme[fF_IJmU:dDYAB]5:DD[ABU5:dDY@8BU810000
000IG_MJeUkgF]INme[FG_MJeUkgDYAF]E:DE[EBU5JeDYAF]DYBBW9:DTicBU9:LTYBCW<00@000003
F_H01EkgF_IJmU[fG_L00e[f00INme[fF_IJmUkgF_H8@Q010000000AG_MJeUkgF]INme[FG_MJeUkg
F]INme[FG_MJeUkgF]INm`08@Q0100000003F_INme[f009JmP05G_MJmU[fF_INm`03F_H015kgF_IJ
mU[f248@0@0000004EkgF]INme[FG_MJeUkgF]INme[FG_MJeUkgF]INme[FG_L0248@0@000003F_H0
1EkgF_IJmU[fG_L00e[f00INme[fF_IJmUkgF_H8@Q010000000AG_MJeUkgF]INme[FG_MJeUkgF]IN
me[FG_MJeUkgF]INm`08@Q0100000003F_INme[f009JmP05G_MJmU[fF_INm`03F_H015kgF_IJmU[f
248@0@0000004EkgF]INme[FG_MJeUkgF]INme[FG_MJeUkgF]INme[FG_L0248@0@0000002F<hIcUS
>6LiHcQW>F<hIcUS>0025<D01QS65<DDaAC56<HDa@Qoo`400000015W>F<hIcUS>6LiHcQW>F<hIcTD
YAS65:DHaQBU6<HDYAS600Qoo`40000000YS>6LiHcQW>F<hIcUS>6LiHcPHaP<Da@046<HDaAC55<D8
Ool10000000AIcUS>6LiHcQW>F<hIcUS>6Li5:DHaQBU6<HDYAS65:DHaP08Ool100000009HcQW>F<h
IcUS>6LiHcQW>F<h008Da@066<HDaAC55<DHaQC527oo0@0000004FLiHcQW>F<hIcUS>6LiHcQW>ABU
6<HDYAS65:DHaQBU6<H027oo0@0000002V<hIcUS>6LiHcQW>F<hIcUS>1S60aC500@HaQC55<DDa@Qo
o`400000015W>F<hIcUS>6LiHcQW>F<hIcTDYAS65:DHaQBU6<HDYAS600Qoo`40000000US>6LiHcQW
>F<hIcUS>6LiHcP044YB0@0000006FLiHcQW>F<hIcUS>6LiHcQW>DYBCW=:DTYbBU9>LdYBBW9:DTic
BU9:LTYBCW=:DTYb0040000000US>6LiHcQW>F<hIcUS>6LiHcP044YB0@0000006FLiHcQW>F<hIcUS
>6LiHcQW>DYBBW9:DTicBU9:LTYBCW=:DTYbBU9>LdYBBW9:DTic0040000000US>6LiHcQW>F<hIcUS
>6LiHcP044YB0@0000006FLiHcQW>F<hIcUS>6LiHcQW>DYBCW=:DTYbBU9>LdYBBW9:DTicBU9:LTYB
CW=:DTYb0040000000US>6LiHcQW>F<hIcUS>6LiHcP044YB0@0000006FLiHcQW>F<hIcUS>6LiHcQW
>DYBBW9:DTicBU9:LTYBCW=:DTYbBU9>LdYBBW9:DTic00400000015S>6LiHcQW>F<hIcUS>6LiHcQB
]5:DD[ABU5:dDYAB]5:D00Q240400000015W>F<hIcUS>6LiHcQW>F<hIcUBU5JeDYAF]E:DE[EBU5Je
00Q240400000015S>6LiHcQW>F<hIcUS>6LiHcQB]5:DD[ABU5:dDYAB]5:D00Q240400000015W>F<h
IcUS>6LiHcQW>F<hIcUBU5JeDYAF]E:DE[EBU5Je00Q240400000015S>6LiHcQW>F<hIcUS>6LiHcQB
]5:DD[ABU5:dDYAB]5:D00Q240400000015W>F<hIcUS>6LiHcQW>F<hIcUBU5JeDYAF]E:DE[EBU5Je
00Q240400000015S>6LiHcQW>F<hIcUS>6LiHcQB]5:DD[ABU5:dDYAB]5:D00Q240400000015W>F<h
IcUS>6LiHcQW>F<hIcUBU5JeDYAF]E:DE[EBU5Je00Q24040000000US>6LiHcQW>F<hIcUS>6LiHcP0
0U[f00INme[fF_IJmUkgF_H8>Lh10000000BIcUS>6LiHcQW>F<hIcUS>6LiF]INme[FG_MJeUkgF]IN
mcG=0cW>00@ecCW>>LhicP40000000YS>6LiHcQW>F<hIcUS>6LiHcQNm`=JmP04G_MJmU[fF_H8>Lh1
0000000AIcUS>6LiHcQW>F<hIcUS>6LiF]INme[FG_MJeUkgF]INm`02>Lh01SG=>LhicSW>=LdicP40
000000US>6LiHcQW>F<hIcUS>6LiHcP00U[f00INme[fF_IJmUkgF_H8>Lh10000000BIcUS>6LiHcQW
>F<hIcUS>6LiF]INme[FG_MJeUkgF]INmcG=0cW>00@ecCW>>LhicP40000000YS>6LiHcQW>F<hIcUS
>6LiHcQNm`=JmP04G_MJmU[fF_H8>Lh10000000AIcUS>6LiHcQW>F<hIcUS>6LiF]INme[FG_MJeUkg
F]INm`02>Lh01SG=>LhicSW>=LdicP40000000US>6LiHcQW>F<hIcUS>6LiHcP00U[f00INme[fF_IJ
mUkgF_H8>Lh10000000IIcUS>6LiHcQW>F<hIcUS>6LiHcQW>F<hIcUS>6LiHcQW>Bf;<H`]Rc6<;H/a
S2f;<H`00@0000004F<hIcUS>6LiHcQW>F<hIcUS>6LiHcQW>F<hIcUS>6LiHcP0236<0@0000006FLi
HcQW>F<hIcUS>6LiHcQW>F<hIcUS>6LiHcQW>F<hIcT]Rc6<;H/aS2f;<H`]Rc6<00400000015S>6Li
HcQW>F<hIcUS>6LiHcQW>F<hIcUS>6LiHcQW>F<h00PaS040000001UW>F<hIcUS>6LiHcQW>F<hIcUS
>6LiHcQW>F<hIcUS>6Li;H/aS2f;<H`]Rc6<;H/aS0010000000AHcQW>F<hIcUS>6LiHcQW>F<hIcUS
>6LiHcQW>F<hIcUS>008<H`10000000IIcUS>6LiHcQW>F<hIcUS>6LiHcQW>F<hIcUS>6LiHcQW>Bf;
<H`]Rc6<;H/aS2f;<H`00@0000004F<hIcUS>6LiHcQW>F<hIcUS>6LiHcQW>F<hIcUS>6LiHcP0236<
0@0000004FmkJgY_Nf]jKg][NVmkJgY_N`aS48@<Ha2436<@Q0aS48@027oo0@000002Kg/01F]jKg]_
NfmkJgX00Vmk00P<P`aS38<<H`b336<<P`aS27oo0@0000004FmkJgY_Nf]jKg][NVmkJgY_N`aS48@<
Ha2436<@Q0aS48@027oo0@0000001F]jKg]_NfmkJgX00fmk00U[NPb336<<P`aS38<<H`b336<027oo
0@0000004FmkJgY_Nf]jKg][NVmkJgY_N`aS48@<Ha2436<@Q0aS48@027oo0@000002Kg/01F]jKg]_
NfmkJgX00Vmk00P<P`aS38<<H`b336<<P`aS27oo0@0000004FmkJgY_Nf]jKg][NVmkJgY_N`aS48@<
Ha2436<@Q0aS48@027oo0@0000001F]jKg]_NfmkJgX00fmk00U[NPb336<<P`aS38<<H`b336<027oo
0@0000004FmkJgY_Nf]jKg][NVmkJgY_NdYBCW=:DTYbBU9>LdYBBW80248@0@000002Kg/01F]jKg]_
NfmkJgX00Vmk24YB248@0@0000004FmkJgY_Nf]jKg][NVmkJgY_NdYBBW9:DTicBU9:LTYBCW<0248@
0@0000001F]jKg]_NfmkJgX00fmk00=[NTYBBU801TYB248@0@0000004FmkJgY_Nf]jKg][NVmkJgY_
NdYBCW=:DTYbBU9>LdYBBW80248@0@000002Kg/01F]jKg]_NfmkJgX00Vmk24YB248@0@0000004Fmk
JgY_Nf]jKg][NVmkJgY_NdYBBW9:DTicBU9:LTYBCW<0248@0@0000001F]jKg]_NfmkJgX00fmk00=[
NTYBBU801TYB248@0@0000004VmkJgY_Nf]jKg][NVmkJgY_Ne:DE[EBU5JeDYAF]E:DE[Dec@<icP04
=LdicSW>>Lh10000009_N`05JgY_NfmkKg][NP02Kg/025:dDYAB]5:DD[ABU5:dDY@8>Lh10000000A
Kg][NVmkJgY_Nf]jKg][NVmkDYAF]E:DE[EBU5JeDYAF]@02>Lh01SG=>LhicSW>=LdicP40000000E[
NVmkKg]_Nf]j00=_N`09JgYB]5:DD[ABU5:dDYAB]5:D00PicP400000019_Nf]jKg][NVmkJgY_Nf]j
Kg]BU5JeDYAF]E:DE[EBU5Je=Ld3>Lh013G=>LhicSW>0@000002Kg/01F]jKg]_NfmkJgX00Vmk00QB
]5:DD[ABU5:dDYAB]5:D23W>0@0000004FmkJgY_Nf]jKg][NVmkJgY_Ne:DE[EBU5JeDYAF]E:DE[D0
0SW>00HecCW>>LhicSG=>Lh100000005JgY_NfmkKg][NP03Kg/02F]jD[ABU5:dDYAB]5:DD[ABU008
>Lh10000000IKg][NVmkJgY_Nf]jKg][NVmkF]INme[FG_MJeUkgF]INmbf;<H`]Rc6<;H/aS2f;<H`0
0@000002Kg/01F]jKg]_NfmkJgX00Vmk00ENme[fF_IJmUkg00=JmPPaS040000001U_Nf]jKg][NVmk
JgY_Nf]jKg]JeUkgF]INme[FG_MJeUkg;H/aS2f;<H`]Rc6<;H/aS00100000005JgY_NfmkKg][NP03
Kg/016]jF_IJmUkg0e[f00=Nme[f<H`01c6<0@0000006FmkJgY_Nf]jKg][NVmkJgY_Ne[FG_MJeUkg
F]INme[FG_L]Rc6<;H/aS2f;<H`]Rc6<004000000Vmk00E[NVmkKg]_Nf]j009_N`05G_MJmU[fF_IN
m`03F_H8<H`10000000IKg][NVmkJgY_Nf]jKg][NVmkF]INme[FG_MJeUkgF]INmbf;<H`]Rc6<;H/a
S2f;<H`00@0000001F]jKg]_NfmkJgX00fmk00A[NU[fF_INm`=JmP03G_MJmS6<00LaS040000001U_
Nf]jKg][NVmkJgY_Nf]jKg]S>6LiHcQW>F<hIcUS>6Li9DTYBRE9:DXUBBU:9DTYBP010000009_N`05
JgY_NfmkKg][NP02Kg/02VLiHcQW>F<hIcUS>6LiHcPYBRE90bU:00<UBBU::DX00@0000006FmkJgY_
Nf]jKg][NVmkJgY_Nf<hIcUS>6LiHcQW>F<hIcTUBBU:9DTYBRE9:DXUBBU:0040000000E[NVmkKg]_
Nf]j00=_N`09JgYW>F<hIcUS>6LiHcQW>F<h00<YBP059DTYBRU::DXUB@010000000IKg][NVmkJgY_
Nf]jKg][NVmkHcQW>F<hIcUS>6LiHcQW>BE9:DXUBBU:9DTYBRE9:DX00@000002Kg/01F]jKg]_Nfmk
JgX00Vmk00YW>F<hIcUS>6LiHcQW>F<h:DXUB@<YBP039DTYBRU:0040000001U_Nf]jKg][NVmkJgY_
Nf]jKg]S>6LiHcQW>F<hIcUS>6Li9DTYBRE9:DXUBBU:9DTYBP0100000005JgY_NfmkKg][NP03Kg/0
2F]jIcUS>6LiHcQW>F<hIcUS>003:DX01BE9:DXYBRU:9DT00@0000006FmkJgY_Nf]jKg][NVmkJgY_
Nf]jKg][NVmkJgY_Nf]jKg/M1b487@LQ21d78@PM1b48004000000Vmk00E[NVmkKg]_Nf]j00=_N`05
JgY_NfmkKg][NP02Kg/022487@LQ21d78@PM1b487@L10000000IKg][NVmkJgY_Nf]jKg][NVmkJgY_
Nf]jKg][NVmkJgY_Nad78@PM1b487@LQ21d78@P00@0000001F]jKg]_NfmkJgX00fmk00E[NVmkKg]_
Nf]j00=_N`09JgXQ21d78@PM1b487@LQ21d70040000001U_Nf]jKg][NVmkJgY_Nf]jKg][NVmkJgY_
Nf]jKg][NVmk7@LQ21d78@PM1b487@LQ20010000009_N`05JgY_NfmkKg][NP03Kg/01F]jKg]_Nfmk
JgX00Vmk00PQ21d78@PM1b487@LQ21d70@0000006FmkJgY_Nf]jKg][NVmkJgY_Nf]jKg][NVmkJgY_
Nf]jKg/M1b487@LQ21d78@PM1b480040000000E[NVmkKg]_Nf]j00=_N`05JgY_NfmkKg][NP03Kg/0
2F]j8@PM1b487@LQ21d78@PM1`010000000AMkec_7NmLkag_G>lMkec_7Nm1248@P@Q14448@Q21244
@@08Ool1000000Ug_@P48@Qoo`400000015g_G>lMkec_7NmLkag_G>lMkd48@A11248@P@Q14448@Q2
00Qoo`4000002GNm20@Q27oo0@0000004GNmLkag_G>lMkec_7NmLkag_@@Q24848@A11248@P@Q1440
27oo0@000009Mkd81248Ool10000000AMkec_7NmLkag_G>lMkec_7Nm1244@@@Q24848@A11248@P08
Ool1000000Ug_@P48@Qoo`40000000Ug_G>lMkec_7NmLkag_G>lMkd0448@0@000009Mkd@@Q010000
0009Mkec_7NmLkag_G>lMkec_7Nm0112404000002GNm448@0@0000002GNmLkag_G>lMkec_7NmLkag
_@0@@Q01000000Ug_A124040000000Ug_G>lMkec_7NmLkag_G>lMkd0448@0@000009Mkd@@Q010000
000BMkec_7NmLkag_G>lMkec_7NmBU9>LdYBBW9:DTicBU9:LSG=0cW>00@ecCW>>LhicP4000002GNm
24YB23W>0@0000004GNmLkag_G>lMkec_7NmLkag_DYBBW9:DTicBU9:LTYBCW<00SW>00HecCW>>Lhi
cSG=>Lh1000000Ug_@Q:DPPicP400000019g_G>lMkec_7NmLkag_G>lMke:DTicBU9:LTYBCW=:DTYb
=Ld3>Lh013G=>LhicSW>0@000009Mkd8BU88>Lh10000000AMkec_7NmLkag_G>lMkec_7NmBU9:LTYB
CW=:DTYbBU9>L`02>Lh01SG=>LhicSW>=LdicP4000002GNm24YB23W>0@0000006GNmLkag_G>lMkec
_7NmLkag_E:DE[EBU5JeDYAF]E:DE[D]Rc6<;H/aS2f;<H`]Rc6<004000002GNm00QB]5:DD[ABU5:d
DYAB]5:D236<0@0000006GNmLkag_G>lMkec_7NmLkag_E:DE[EBU5JeDYAF]E:DE[D]Rc6<;H/aS2f;
<H`]Rc6<004000002GNm00QB]5:DD[ABU5:dDYAB]5:D236<0@0000006GNmLkag_G>lMkec_7NmLkag
_E:DE[EBU5JeDYAF]E:DE[D]Rc6<;H/aS2f;<H`]Rc6<004000002GNm00QB]5:DD[ABU5:dDYAB]5:D
236<0@0000006GNmLkag_G>lMkec_7NmLkag_E:DE[EBU5JeDYAF]E:DE[D]Rc6<;H/aS2f;<H`]Rc6<
004000002GNm00QB]5:DD[ABU5:dDYAB]5:D236<0@0000006GNmLkag_G>lMkec_7NmLkag_E[FG_MJ
eUkgF]INme[FG_LUBBU:9DTYBRE9:DXUBBU:004000002GNm00ENme[fF_IJmUkg00=JmP03:DXUBBU:
008YBP039DTYBRU:0040000001Ug_G>lMkec_7NmLkag_G>lMkeJeUkgF]INme[FG_MJeUkg9DTYBRE9
:DXUBBU:9DTYBP01000000Ug_@9JmP06G_MJmU[fF_INme[f0bU:00DUBBU::DXYBRE90040000001Ug
_G>lMkec_7NmLkag_G>lMkeJeUkgF]INme[FG_MJeUkg9DTYBRE9:DXUBBU:9DTYBP01000000Ug_@05
G_MJmU[fF_INm`03F_H00bU:9DTYBP02:DX00bE9:DXYBP010000000IMkec_7NmLkag_G>lMkec_7Nm
F]INme[FG_MJeUkgF]INmbE9:DXUBBU:9DTYBRE9:DX00@000009Mkd2F_H01UkgF_IJmU[fG_MJmP<Y
BP059DTYBRU::DXUB@010000000IMkec_7NmLkag_G>lMkec_7NmHcQW>F<hIcUS>6LiHcQW>Ad78@PM
1b487@LQ21d78@P00@000009Mkd046LiHcQW>F<hIcUS>6LiHcPQ21d78@PM1b487@LQ21d70@000000
6GNmLkag_G>lMkec_7NmLkag_F<hIcUS>6LiHcQW>F<hIcTM1b487@LQ21d78@PM1b48004000002GNm
011W>F<hIcUS>6LiHcQW>F<h8@PM1b487@LQ21d78@PM1`40000001Ug_G>lMkec_7NmLkag_G>lMkeS
>6LiHcQW>F<hIcUS>6Li7@LQ21d78@PM1b487@LQ2001000000Ug_@0@IcUS>6LiHcQW>F<hIcUS>248
7@LQ21d78@PM1b487@L10000000IMkec_7NmLkag_G>lMkec_7NmHcQW>F<hIcUS>6LiHcQW>Ad78@PM
1b487@LQ21d78@P00@000009Mkd046LiHcQW>F<hIcUS>6LiHcPQ21d78@PM1b487@LQ21d70@000000
6GNmLkag_G>lMkec_7NmLkag_F<hIcUS>6LiHcQW>F<hIcTM1b487@LQ21d78@PM1b48004000002GNm
00=_Nf]jKg/00Vmk00A[NVmkKg/HaP<Da@046<HDaAC55<D10000000IMkec_7NmLkag_G>lMkec_7Nm
JgY_Nf]jKg][NVmkJgY_NaBU6<HDYAS65:DHaQBU6<H00@000009Mkd3Kg/01F]jKg]_NfmkJgX00QC5
00HHaQC55<DDaAS65<D10000000IMkec_7NmLkag_G>lMkec_7NmJgY_Nf]jKg][NVmkJgY_NaBU6<HD
YAS65:DHaQBU6<H00@000009Mkd00fmkJgY_N`02Kg/016]jKg]_NaS60aC500@HaQC55<DDa@400000
01Ug_G>lMkec_7NmLkag_G>lMke[NVmkJgY_Nf]jKg][NVmk5:DHaQBU6<HDYAS65:DHaP01000000Ug
_@=_N`05JgY_NfmkKg][NP025<D01QS65<DDaAC56<HDa@40000001Ug_G>lMkec_7NmLkag_G>lMke[
NVmkJgY_Nf]jKg][NVmk5:DHaQBU6<HDYAS65:DHaP010000015g_@0838<<H`b336<<P`aS38<<H`40
000001Ug_G>lMkec_7NmLkag_G>lMkec_7NmLkag_G>lMkec_7Nm36<@Q0aS48@<Ha2436<@Q0010000
015g_@0838<<H`b336<<P`aS38<<H`40000001Ug_G>lMkec_7NmLkag_G>lMkec_7NmLkag_G>lMkec
_7Nm36<@Q0aS48@<Ha2436<@Q0010000015g_@0838<<H`b336<<P`aS38<<H`40000001Ug_G>lMkec
_7NmLkag_G>lMkec_7NmLkag_G>lMkec_7Nm36<@Q0aS48@<Ha2436<@Q0010000015g_@0838<<H`b3
36<<P`aS38<<H`40000001Ug_G>lMkec_7NmLkag_G>lMkec_7NmLkag_G>lMkec_7Nm36<@Q0aS48@<
Ha2436<@Q00100000003001[FV]J01I[FP40000001T006]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]J
JgY[FVmkJeY[NV]JKg][FV]jJeY_N`0100000003001[FV]J01I[FP40000001T006]JKg][FV]jJeY_
Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NP01000001X0000001U_Nf]JJgY[FVmk
JeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_N`01JeX001Y[FP0001U[NV]JKg][
FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NP01JeX001Y[FP0001U_Nf]J
JgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_N`01JeX00001\
\>"],
  ImageRangeCache->{{{140.063, 160.375}, {626.875, 436.063}} -> {-21.8613, \
66.4773, 0.155515, 0.155515}}]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{

Cell["EHRENFEST TECHNIQUES IN NUMBER THEORY", "Subsection"],

Cell["\<\
The motivation for this section was to illustrate the following result: \
\>", "Text"],

Cell["\<\
For every pair of numbers n and k, each partition of n!k into parts not \
exceeding n is actually a sum of k partitions of n!\
\>", "Commentary"],

Cell[TextData[{
  "Let us first solve the following problem: Given a list of positive \
integers, how do you partition it into k parts with equal sums? Providing \
that the problem has a solution, we can assume that each part forms a \
non-decreasing sequence.\n\nWe apply a technique akin to the solution of the \
Ehrenfest urn problem. After constructing an approximately optimum starting \
configuration we proceed to interchange numbers from one partition to another \
facilitating the convergence to a stable configuration, which is the \
(non-unique) solution we seek. The choice of which urns are going to be the \
\"sender\" and the \"recipient\" in an interchange is based on their relative \
sizes. As this method is probabilistic, the time to reach convergence might \
be relatively large and for that reason, a safety net is provided as an \
optional parameter in function ",
  StyleBox["Ehrenfest", "InlineInput"],
  "; after our experience with urn problems though, we expect a fast \
convergence. The following output was timed on a 500-MHz pentium pc."
}], "Text"],

Cell[BoxData[
    \(Ehrenfest[li_, k_, safetyNet_:  1000] := 
      Module[{s, t = Table[{}, {k}], i = 1, r, from, to, tot, 
          j = 1}, \[IndentingNewLine]Map[\((AppendTo[
                t\[LeftDoubleBracket]i\[RightDoubleBracket], #]; \ 
              i = 1 + Mod[i, k])\) &, 
          Sort[li]]; \[IndentingNewLine]s = \(Plus\  @@ \ # &\)\  /@ \ 
            t; \[IndentingNewLine]tot = 
          Plus\  @@ s; \[IndentingNewLine]While[\((j < 
                safetyNet)\) && \((Length[Union[s]] > 
                1)\), \[IndentingNewLine]r = 
            Flatten[Table[
                Table[i, {s\[LeftDoubleBracket]i\[RightDoubleBracket]}], {i, 
                  Length[s]}]]; \[IndentingNewLine]While[\(\((from = 
                r\[LeftDoubleBracket]Random[
                    Integer, {1, Length[r]}]\[RightDoubleBracket])\); 
            Length[t\[LeftDoubleBracket]from\[RightDoubleBracket]] \[Equal] 
              1\)\(,\)]; \[IndentingNewLine]s = 
            tot - s; \[IndentingNewLine]r = 
            Flatten[Table[
                Table[i, {s\[LeftDoubleBracket]i\[RightDoubleBracket]}], {i, 
                  Length[s]}]]; \[IndentingNewLine]While[\(\((to = 
                  r\[LeftDoubleBracket]Random[
                      Integer, {1, Length[r]}]\[RightDoubleBracket])\) == 
              from\)\(,\)]; \[IndentingNewLine]i = 
            Random[Integer, {1, 
                Length[t\[LeftDoubleBracket]
                    from\[RightDoubleBracket]]}]; \[IndentingNewLine]AppendTo[
            t\[LeftDoubleBracket]to\[RightDoubleBracket], 
            t\[LeftDoubleBracket]from, 
              i\[RightDoubleBracket]]; \[IndentingNewLine]t = 
            Delete[t, {from, 
                i}]; \[IndentingNewLine]s = \(Plus\  @@ \ # &\)\  /@ \ 
              t; \[IndentingNewLine]\(j++\)\[IndentingNewLine]]; \
\[IndentingNewLine]If[j < safetyNet, Sort[Sort\  /@ \ t], {}]]\)], "Input"],

Cell[CellGroupData[{

Cell[BoxData[
    \(Ehrenfest[{1, 1, 1, 1, 1, 1, 1, 2, 2, 2, 2, 3}, 3] // Timing\)], "Input"],

Cell[BoxData[
    \({0.`\ Second, {{1, 2, 3}, {1, 1, 2, 2}, {1, 1, 1, 1, 2}}}\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(Ehrenfest[{1, 1, 1, 1, 1, 1, 1, 2, 2, 2, 2, 3}, 3] // Timing\)], "Input"],

Cell[BoxData[
    \({0.05999999999994543`\ Second, {{1, 1, 1, 3}, {1, 1, 2, 2}, {1, 1, 2, 
          2}}}\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(Ehrenfest[{1, 1, 1, 1, 1, 1, 1, 2, 2, 2, 2, 3, 6}, 4] // 
      Timing\)], "Input"],

Cell[BoxData[
    \({0.10999999999967258`\ Second, {{6}, {1, 2, 3}, {1, 1, 2, 2}, {1, 1, 1, 
          1, 2}}}\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(Ehrenfest[{2, 2, 2, 3, 3, 3, 3}, 3] // Timing\)], "Input"],

Cell[BoxData[
    \({0.17000000000007276`\ Second, {{3, 3}, {3, 3}, {2, 2, 2}}}\)], "Output"]
}, Open  ]],

Cell["\<\
The following illustrates the problem that motivated this section.\
\>", "Text"],

Cell[CellGroupData[{

Cell[BoxData[{
    \(\(n = 3;\)\), "\[IndentingNewLine]", 
    \(\(k = 3;\)\), "\[IndentingNewLine]", 
    \(\(p = partH[Range[n], \(n!\) k];\)\), "\[IndentingNewLine]", 
    \(asSum\  /@ \ p // \ TableForm\), "\[IndentingNewLine]", 
    \(\(asSum\  /@ \ \((Ehrenfest[#, k])\) &\)\  /@ \ p // 
      TableForm\)}], "Input"],

Cell[BoxData[
    InterpretationBox[GridBox[{
          {
            TagBox[
              RowBox[{"1", "+", 
                TagBox[
                  RowBox[{"1", "+", 
                    TagBox[
                      RowBox[{"1", "+", 
                        TagBox[
                          RowBox[{"1", "+", 
                            TagBox[
                              RowBox[{"1", "+", 
                                TagBox[
                                  RowBox[{"1", "+", 
                                    TagBox[
                                      RowBox[{"1", "+", 
                                        TagBox[
                                        RowBox[{"1", "+", 
                                        TagBox[
                                        RowBox[{"1", "+", 
                                        TagBox[
                                        RowBox[{"1", "+", 
                                        TagBox[
                                        RowBox[{"1", "+", 
                                        TagBox[
                                        RowBox[{"1", "+", 
                                        TagBox[
                                        RowBox[{"1", "+", 
                                        TagBox[
                                        RowBox[{"1", "+", 
                                        TagBox[
                                        RowBox[{"1", "+", 
                                        TagBox[
                                        RowBox[{"1", "+", 
                                        TagBox[\(1 + 1\),
                                        DisplayForm]}],
                                        DisplayForm]}],
                                        DisplayForm]}],
                                        DisplayForm]}],
                                        DisplayForm]}],
                                        DisplayForm]}],
                                        DisplayForm]}],
                                        DisplayForm]}],
                                        DisplayForm]}],
                                        DisplayForm]}],
                                      DisplayForm]}],
                                  DisplayForm]}],
                              DisplayForm]}],
                          DisplayForm]}],
                      DisplayForm]}],
                  DisplayForm]}],
              DisplayForm]},
          {
            TagBox[
              RowBox[{"1", "+", 
                TagBox[
                  RowBox[{"1", "+", 
                    TagBox[
                      RowBox[{"1", "+", 
                        TagBox[
                          RowBox[{"1", "+", 
                            TagBox[
                              RowBox[{"1", "+", 
                                TagBox[
                                  RowBox[{"1", "+", 
                                    TagBox[
                                      RowBox[{"1", "+", 
                                        TagBox[
                                        RowBox[{"1", "+", 
                                        TagBox[
                                        RowBox[{"1", "+", 
                                        TagBox[
                                        RowBox[{"1", "+", 
                                        TagBox[
                                        RowBox[{"1", "+", 
                                        TagBox[
                                        RowBox[{"1", "+", 
                                        TagBox[
                                        RowBox[{"1", "+", 
                                        TagBox[
                                        RowBox[{"1", "+", 
                                        TagBox[
                                        RowBox[{"1", "+", 
                                        TagBox[\(1 + 2\),
                                        DisplayForm]}],
                                        DisplayForm]}],
                                        DisplayForm]}],
                                        DisplayForm]}],
                                        DisplayForm]}],
                                        DisplayForm]}],
                                        DisplayForm]}],
                                        DisplayForm]}],
                                        DisplayForm]}],
                                      DisplayForm]}],
                                  DisplayForm]}],
                              DisplayForm]}],
                          DisplayForm]}],
                      DisplayForm]}],
                  DisplayForm]}],
              DisplayForm]},
          {
            TagBox[
              RowBox[{"1", "+", 
                TagBox[
                  RowBox[{"1", "+", 
                    TagBox[
                      RowBox[{"1", "+", 
                        TagBox[
                          RowBox[{"1", "+", 
                            TagBox[
                              RowBox[{"1", "+", 
                                TagBox[
                                  RowBox[{"1", "+", 
                                    TagBox[
                                      RowBox[{"1", "+", 
                                        TagBox[
                                        RowBox[{"1", "+", 
                                        TagBox[
                                        RowBox[{"1", "+", 
                                        TagBox[
                                        RowBox[{"1", "+", 
                                        TagBox[
                                        RowBox[{"1", "+", 
                                        TagBox[
                                        RowBox[{"1", "+", 
                                        TagBox[
                                        RowBox[{"1", "+", 
                                        TagBox[
                                        RowBox[{"1", "+", 
                                        TagBox[\(1 + 3\),
                                        DisplayForm]}],
                                        DisplayForm]}],
                                        DisplayForm]}],
                                        DisplayForm]}],
                                        DisplayForm]}],
                                        DisplayForm]}],
                                        DisplayForm]}],
                                        DisplayForm]}],
                                      DisplayForm]}],
                                  DisplayForm]}],
                              DisplayForm]}],
                          DisplayForm]}],
                      DisplayForm]}],
                  DisplayForm]}],
              DisplayForm]},
          {
            TagBox[
              RowBox[{"1", "+", 
                TagBox[
                  RowBox[{"1", "+", 
                    TagBox[
                      RowBox[{"1", "+", 
                        TagBox[
                          RowBox[{"1", "+", 
                            TagBox[
                              RowBox[{"1", "+", 
                                TagBox[
                                  RowBox[{"1", "+", 
                                    TagBox[
                                      RowBox[{"1", "+", 
                                        TagBox[
                                        RowBox[{"1", "+", 
                                        TagBox[
                                        RowBox[{"1", "+", 
                                        TagBox[
                                        RowBox[{"1", "+", 
                                        TagBox[
                                        RowBox[{"1", "+", 
                                        TagBox[
                                        RowBox[{"1", "+", 
                                        TagBox[
                                        RowBox[{"1", "+", 
                                        TagBox[
                                        RowBox[{"1", "+", 
                                        TagBox[\(2 + 2\),
                                        DisplayForm]}],
                                        DisplayForm]}],
                                        DisplayForm]}],
                                        DisplayForm]}],
                                        DisplayForm]}],
                                        DisplayForm]}],
                                        DisplayForm]}],
                                        DisplayForm]}],
                                      DisplayForm]}],
                                  DisplayForm]}],
                              DisplayForm]}],
                          DisplayForm]}],
                      DisplayForm]}],
                  DisplayForm]}],
              DisplayForm]},
          {
            TagBox[
              RowBox[{"1", "+", 
                TagBox[
                  RowBox[{"1", "+", 
                    TagBox[
                      RowBox[{"1", "+", 
                        TagBox[
                          RowBox[{"1", "+", 
                            TagBox[
                              RowBox[{"1", "+", 
                                TagBox[
                                  RowBox[{"1", "+", 
                                    TagBox[
                                      RowBox[{"1", "+", 
                                        TagBox[
                                        RowBox[{"1", "+", 
                                        TagBox[
                                        RowBox[{"1", "+", 
                                        TagBox[
                                        RowBox[{"1", "+", 
                                        TagBox[
                                        RowBox[{"1", "+", 
                                        TagBox[
                                        RowBox[{"1", "+", 
                                        TagBox[
                                        RowBox[{"1", "+", 
                                        TagBox[\(2 + 3\),
                                        DisplayForm]}],
                                        DisplayForm]}],
                                        DisplayForm]}],
                                        DisplayForm]}],
                                        DisplayForm]}],
                                        DisplayForm]}],
                                        DisplayForm]}],
                                      DisplayForm]}],
                                  DisplayForm]}],
                              DisplayForm]}],
                          DisplayForm]}],
                      DisplayForm]}],
                  DisplayForm]}],
              DisplayForm]},
          {
            TagBox[
              RowBox[{"1", "+", 
                TagBox[
                  RowBox[{"1", "+", 
                    TagBox[
                      RowBox[{"1", "+", 
                        TagBox[
                          RowBox[{"1", "+", 
                            TagBox[
                              RowBox[{"1", "+", 
                                TagBox[
                                  RowBox[{"1", "+", 
                                    TagBox[
                                      RowBox[{"1", "+", 
                                        TagBox[
                                        RowBox[{"1", "+", 
                                        TagBox[
                                        RowBox[{"1", "+", 
                                        TagBox[
                                        RowBox[{"1", "+", 
                                        TagBox[
                                        RowBox[{"1", "+", 
                                        TagBox[
                                        RowBox[{"1", "+", 
                                        TagBox[
                                        RowBox[{"2", "+", 
                                        TagBox[\(2 + 2\),
                                        DisplayForm]}],
                                        DisplayForm]}],
                                        DisplayForm]}],
                                        DisplayForm]}],
                                        DisplayForm]}],
                                        DisplayForm]}],
                                        DisplayForm]}],
                                      DisplayForm]}],
                                  DisplayForm]}],
                              DisplayForm]}],
                          DisplayForm]}],
                      DisplayForm]}],
                  DisplayForm]}],
              DisplayForm]},
          {
            TagBox[
              RowBox[{"1", "+", 
                TagBox[
                  RowBox[{"1", "+", 
                    TagBox[
                      RowBox[{"1", "+", 
                        TagBox[
                          RowBox[{"1", "+", 
                            TagBox[
                              RowBox[{"1", "+", 
                                TagBox[
                                  RowBox[{"1", "+", 
                                    TagBox[
                                      RowBox[{"1", "+", 
                                        TagBox[
                                        RowBox[{"1", "+", 
                                        TagBox[
                                        RowBox[{"1", "+", 
                                        TagBox[
                                        RowBox[{"1", "+", 
                                        TagBox[
                                        RowBox[{"1", "+", 
                                        TagBox[
                                        RowBox[{"1", "+", 
                                        TagBox[\(3 + 3\),
                                        DisplayForm]}],
                                        DisplayForm]}],
                                        DisplayForm]}],
                                        DisplayForm]}],
                                        DisplayForm]}],
                                        DisplayForm]}],
                                      DisplayForm]}],
                                  DisplayForm]}],
                              DisplayForm]}],
                          DisplayForm]}],
                      DisplayForm]}],
                  DisplayForm]}],
              DisplayForm]},
          {
            TagBox[
              RowBox[{"1", "+", 
                TagBox[
                  RowBox[{"1", "+", 
                    TagBox[
                      RowBox[{"1", "+", 
                        TagBox[
                          RowBox[{"1", "+", 
                            TagBox[
                              RowBox[{"1", "+", 
                                TagBox[
                                  RowBox[{"1", "+", 
                                    TagBox[
                                      RowBox[{"1", "+", 
                                        TagBox[
                                        RowBox[{"1", "+", 
                                        TagBox[
                                        RowBox[{"1", "+", 
                                        TagBox[
                                        RowBox[{"1", "+", 
                                        TagBox[
                                        RowBox[{"1", "+", 
                                        TagBox[
                                        RowBox[{"2", "+", 
                                        TagBox[\(2 + 3\),
                                        DisplayForm]}],
                                        DisplayForm]}],
                                        DisplayForm]}],
                                        DisplayForm]}],
                                        DisplayForm]}],
                                        DisplayForm]}],
                                      DisplayForm]}],
                                  DisplayForm]}],
                              DisplayForm]}],
                          DisplayForm]}],
                      DisplayForm]}],
                  DisplayForm]}],
              DisplayForm]},
          {
            TagBox[
              RowBox[{"1", "+", 
                TagBox[
                  RowBox[{"1", "+", 
                    TagBox[
                      RowBox[{"1", "+", 
                        TagBox[
                          RowBox[{"1", "+", 
                            TagBox[
                              RowBox[{"1", "+", 
                                TagBox[
                                  RowBox[{"1", "+", 
                                    TagBox[
                                      RowBox[{"1", "+", 
                                        TagBox[
                                        RowBox[{"1", "+", 
                                        TagBox[
                                        RowBox[{"1", "+", 
                                        TagBox[
                                        RowBox[{"1", "+", 
                                        TagBox[
                                        RowBox[{"2", "+", 
                                        TagBox[
                                        RowBox[{"2", "+", 
                                        TagBox[\(2 + 2\),
                                        DisplayForm]}],
                                        DisplayForm]}],
                                        DisplayForm]}],
                                        DisplayForm]}],
                                        DisplayForm]}],
                                        DisplayForm]}],
                                      DisplayForm]}],
                                  DisplayForm]}],
                              DisplayForm]}],
                          DisplayForm]}],
                      DisplayForm]}],
                  DisplayForm]}],
              DisplayForm]},
          {
            TagBox[
              RowBox[{"1", "+", 
                TagBox[
                  RowBox[{"1", "+", 
                    TagBox[
                      RowBox[{"1", "+", 
                        TagBox[
                          RowBox[{"1", "+", 
                            TagBox[
                              RowBox[{"1", "+", 
                                TagBox[
                                  RowBox[{"1", "+", 
                                    TagBox[
                                      RowBox[{"1", "+", 
                                        TagBox[
                                        RowBox[{"1", "+", 
                                        TagBox[
                                        RowBox[{"1", "+", 
                                        TagBox[
                                        RowBox[{"1", "+", 
                                        TagBox[
                                        RowBox[{"2", "+", 
                                        TagBox[\(3 + 3\),
                                        DisplayForm]}],
                                        DisplayForm]}],
                                        DisplayForm]}],
                                        DisplayForm]}],
                                        DisplayForm]}],
                                      DisplayForm]}],
                                  DisplayForm]}],
                              DisplayForm]}],
                          DisplayForm]}],
                      DisplayForm]}],
                  DisplayForm]}],
              DisplayForm]},
          {
            TagBox[
              RowBox[{"1", "+", 
                TagBox[
                  RowBox[{"1", "+", 
                    TagBox[
                      RowBox[{"1", "+", 
                        TagBox[
                          RowBox[{"1", "+", 
                            TagBox[
                              RowBox[{"1", "+", 
                                TagBox[
                                  RowBox[{"1", "+", 
                                    TagBox[
                                      RowBox[{"1", "+", 
                                        TagBox[
                                        RowBox[{"1", "+", 
                                        TagBox[
                                        RowBox[{"1", "+", 
                                        TagBox[
                                        RowBox[{"2", "+", 
                                        TagBox[
                                        RowBox[{"2", "+", 
                                        TagBox[\(2 + 3\),
                                        DisplayForm]}],
                                        DisplayForm]}],
                                        DisplayForm]}],
                                        DisplayForm]}],
                                        DisplayForm]}],
                                      DisplayForm]}],
                                  DisplayForm]}],
                              DisplayForm]}],
                          DisplayForm]}],
                      DisplayForm]}],
                  DisplayForm]}],
              DisplayForm]},
          {
            TagBox[
              RowBox[{"1", "+", 
                TagBox[
                  RowBox[{"1", "+", 
                    TagBox[
                      RowBox[{"1", "+", 
                        TagBox[
                          RowBox[{"1", "+", 
                            TagBox[
                              RowBox[{"1", "+", 
                                TagBox[
                                  RowBox[{"1", "+", 
                                    TagBox[
                                      RowBox[{"1", "+", 
                                        TagBox[
                                        RowBox[{"1", "+", 
                                        TagBox[
                                        RowBox[{"1", "+", 
                                        TagBox[
                                        RowBox[{"3", "+", 
                                        TagBox[\(3 + 3\),
                                        DisplayForm]}],
                                        DisplayForm]}],
                                        DisplayForm]}],
                                        DisplayForm]}],
                                      DisplayForm]}],
                                  DisplayForm]}],
                              DisplayForm]}],
                          DisplayForm]}],
                      DisplayForm]}],
                  DisplayForm]}],
              DisplayForm]},
          {
            TagBox[
              RowBox[{"1", "+", 
                TagBox[
                  RowBox[{"1", "+", 
                    TagBox[
                      RowBox[{"1", "+", 
                        TagBox[
                          RowBox[{"1", "+", 
                            TagBox[
                              RowBox[{"1", "+", 
                                TagBox[
                                  RowBox[{"1", "+", 
                                    TagBox[
                                      RowBox[{"1", "+", 
                                        TagBox[
                                        RowBox[{"1", "+", 
                                        TagBox[
                                        RowBox[{"2", "+", 
                                        TagBox[
                                        RowBox[{"2", "+", 
                                        TagBox[
                                        RowBox[{"2", "+", 
                                        TagBox[\(2 + 2\),
                                        DisplayForm]}],
                                        DisplayForm]}],
                                        DisplayForm]}],
                                        DisplayForm]}],
                                        DisplayForm]}],
                                      DisplayForm]}],
                                  DisplayForm]}],
                              DisplayForm]}],
                          DisplayForm]}],
                      DisplayForm]}],
                  DisplayForm]}],
              DisplayForm]},
          {
            TagBox[
              RowBox[{"1", "+", 
                TagBox[
                  RowBox[{"1", "+", 
                    TagBox[
                      RowBox[{"1", "+", 
                        TagBox[
                          RowBox[{"1", "+", 
                            TagBox[
                              RowBox[{"1", "+", 
                                TagBox[
                                  RowBox[{"1", "+", 
                                    TagBox[
                                      RowBox[{"1", "+", 
                                        TagBox[
                                        RowBox[{"1", "+", 
                                        TagBox[
                                        RowBox[{"2", "+", 
                                        TagBox[
                                        RowBox[{"2", "+", 
                                        TagBox[\(3 + 3\),
                                        DisplayForm]}],
                                        DisplayForm]}],
                                        DisplayForm]}],
                                        DisplayForm]}],
                                      DisplayForm]}],
                                  DisplayForm]}],
                              DisplayForm]}],
                          DisplayForm]}],
                      DisplayForm]}],
                  DisplayForm]}],
              DisplayForm]},
          {
            TagBox[
              RowBox[{"1", "+", 
                TagBox[
                  RowBox[{"1", "+", 
                    TagBox[
                      RowBox[{"1", "+", 
                        TagBox[
                          RowBox[{"1", "+", 
                            TagBox[
                              RowBox[{"1", "+", 
                                TagBox[
                                  RowBox[{"1", "+", 
                                    TagBox[
                                      RowBox[{"1", "+", 
                                        TagBox[
                                        RowBox[{"2", "+", 
                                        TagBox[
                                        RowBox[{"2", "+", 
                                        TagBox[
                                        RowBox[{"2", "+", 
                                        TagBox[\(2 + 3\),
                                        DisplayForm]}],
                                        DisplayForm]}],
                                        DisplayForm]}],
                                        DisplayForm]}],
                                      DisplayForm]}],
                                  DisplayForm]}],
                              DisplayForm]}],
                          DisplayForm]}],
                      DisplayForm]}],
                  DisplayForm]}],
              DisplayForm]},
          {
            TagBox[
              RowBox[{"1", "+", 
                TagBox[
                  RowBox[{"1", "+", 
                    TagBox[
                      RowBox[{"1", "+", 
                        TagBox[
                          RowBox[{"1", "+", 
                            TagBox[
                              RowBox[{"1", "+", 
                                TagBox[
                                  RowBox[{"1", "+", 
                                    TagBox[
                                      RowBox[{"1", "+", 
                                        TagBox[
                                        RowBox[{"2", "+", 
                                        TagBox[
                                        RowBox[{"3", "+", 
                                        TagBox[\(3 + 3\),
                                        DisplayForm]}],
                                        DisplayForm]}],
                                        DisplayForm]}],
                                      DisplayForm]}],
                                  DisplayForm]}],
                              DisplayForm]}],
                          DisplayForm]}],
                      DisplayForm]}],
                  DisplayForm]}],
              DisplayForm]},
          {
            TagBox[
              RowBox[{"1", "+", 
                TagBox[
                  RowBox[{"1", "+", 
                    TagBox[
                      RowBox[{"1", "+", 
                        TagBox[
                          RowBox[{"1", "+", 
                            TagBox[
                              RowBox[{"1", "+", 
                                TagBox[
                                  RowBox[{"1", "+", 
                                    TagBox[
                                      RowBox[{"2", "+", 
                                        TagBox[
                                        RowBox[{"2", "+", 
                                        TagBox[
                                        RowBox[{"2", "+", 
                                        TagBox[
                                        RowBox[{"2", "+", 
                                        TagBox[\(2 + 2\),
                                        DisplayForm]}],
                                        DisplayForm]}],
                                        DisplayForm]}],
                                        DisplayForm]}],
                                      DisplayForm]}],
                                  DisplayForm]}],
                              DisplayForm]}],
                          DisplayForm]}],
                      DisplayForm]}],
                  DisplayForm]}],
              DisplayForm]},
          {
            TagBox[
              RowBox[{"1", "+", 
                TagBox[
                  RowBox[{"1", "+", 
                    TagBox[
                      RowBox[{"1", "+", 
                        TagBox[
                          RowBox[{"1", "+", 
                            TagBox[
                              RowBox[{"1", "+", 
                                TagBox[
                                  RowBox[{"1", "+", 
                                    TagBox[
                                      RowBox[{"2", "+", 
                                        TagBox[
                                        RowBox[{"2", "+", 
                                        TagBox[
                                        RowBox[{"2", "+", 
                                        TagBox[\(3 + 3\),
                                        DisplayForm]}],
                                        DisplayForm]}],
                                        DisplayForm]}],
                                      DisplayForm]}],
                                  DisplayForm]}],
                              DisplayForm]}],
                          DisplayForm]}],
                      DisplayForm]}],
                  DisplayForm]}],
              DisplayForm]},
          {
            TagBox[
              RowBox[{"1", "+", 
                TagBox[
                  RowBox[{"1", "+", 
                    TagBox[
                      RowBox[{"1", "+", 
                        TagBox[
                          RowBox[{"1", "+", 
                            TagBox[
                              RowBox[{"1", "+", 
                                TagBox[
                                  RowBox[{"1", "+", 
                                    TagBox[
                                      RowBox[{"3", "+", 
                                        TagBox[
                                        RowBox[{"3", "+", 
                                        TagBox[\(3 + 3\),
                                        DisplayForm]}],
                                        DisplayForm]}],
                                      DisplayForm]}],
                                  DisplayForm]}],
                              DisplayForm]}],
                          DisplayForm]}],
                      DisplayForm]}],
                  DisplayForm]}],
              DisplayForm]},
          {
            TagBox[
              RowBox[{"1", "+", 
                TagBox[
                  RowBox[{"1", "+", 
                    TagBox[
                      RowBox[{"1", "+", 
                        TagBox[
                          RowBox[{"1", "+", 
                            TagBox[
                              RowBox[{"1", "+", 
                                TagBox[
                                  RowBox[{"2", "+", 
                                    TagBox[
                                      RowBox[{"2", "+", 
                                        TagBox[
                                        RowBox[{"2", "+", 
                                        TagBox[
                                        RowBox[{"2", "+", 
                                        TagBox[\(2 + 3\),
                                        DisplayForm]}],
                                        DisplayForm]}],
                                        DisplayForm]}],
                                      DisplayForm]}],
                                  DisplayForm]}],
                              DisplayForm]}],
                          DisplayForm]}],
                      DisplayForm]}],
                  DisplayForm]}],
              DisplayForm]},
          {
            TagBox[
              RowBox[{"1", "+", 
                TagBox[
                  RowBox[{"1", "+", 
                    TagBox[
                      RowBox[{"1", "+", 
                        TagBox[
                          RowBox[{"1", "+", 
                            TagBox[
                              RowBox[{"1", "+", 
                                TagBox[
                                  RowBox[{"2", "+", 
                                    TagBox[
                                      RowBox[{"2", "+", 
                                        TagBox[
                                        RowBox[{"3", "+", 
                                        TagBox[\(3 + 3\),
                                        DisplayForm]}],
                                        DisplayForm]}],
                                      DisplayForm]}],
                                  DisplayForm]}],
                              DisplayForm]}],
                          DisplayForm]}],
                      DisplayForm]}],
                  DisplayForm]}],
              DisplayForm]},
          {
            TagBox[
              RowBox[{"1", "+", 
                TagBox[
                  RowBox[{"1", "+", 
                    TagBox[
                      RowBox[{"1", "+", 
                        TagBox[
                          RowBox[{"1", "+", 
                            TagBox[
                              RowBox[{"2", "+", 
                                TagBox[
                                  RowBox[{"2", "+", 
                                    TagBox[
                                      RowBox[{"2", "+", 
                                        TagBox[
                                        RowBox[{"2", "+", 
                                        TagBox[
                                        RowBox[{"2", "+", 
                                        TagBox[\(2 + 2\),
                                        DisplayForm]}],
                                        DisplayForm]}],
                                        DisplayForm]}],
                                      DisplayForm]}],
                                  DisplayForm]}],
                              DisplayForm]}],
                          DisplayForm]}],
                      DisplayForm]}],
                  DisplayForm]}],
              DisplayForm]},
          {
            TagBox[
              RowBox[{"1", "+", 
                TagBox[
                  RowBox[{"1", "+", 
                    TagBox[
                      RowBox[{"1", "+", 
                        TagBox[
                          RowBox[{"1", "+", 
                            TagBox[
                              RowBox[{"2", "+", 
                                TagBox[
                                  RowBox[{"2", "+", 
                                    TagBox[
                                      RowBox[{"2", "+", 
                                        TagBox[
                                        RowBox[{"2", "+", 
                                        TagBox[\(3 + 3\),
                                        DisplayForm]}],
                                        DisplayForm]}],
                                      DisplayForm]}],
                                  DisplayForm]}],
                              DisplayForm]}],
                          DisplayForm]}],
                      DisplayForm]}],
                  DisplayForm]}],
              DisplayForm]},
          {
            TagBox[
              RowBox[{"1", "+", 
                TagBox[
                  RowBox[{"1", "+", 
                    TagBox[
                      RowBox[{"1", "+", 
                        TagBox[
                          RowBox[{"1", "+", 
                            TagBox[
                              RowBox[{"2", "+", 
                                TagBox[
                                  RowBox[{"3", "+", 
                                    TagBox[
                                      RowBox[{"3", "+", 
                                        TagBox[\(3 + 3\),
                                        DisplayForm]}],
                                      DisplayForm]}],
                                  DisplayForm]}],
                              DisplayForm]}],
                          DisplayForm]}],
                      DisplayForm]}],
                  DisplayForm]}],
              DisplayForm]},
          {
            TagBox[
              RowBox[{"1", "+", 
                TagBox[
                  RowBox[{"1", "+", 
                    TagBox[
                      RowBox[{"1", "+", 
                        TagBox[
                          RowBox[{"2", "+", 
                            TagBox[
                              RowBox[{"2", "+", 
                                TagBox[
                                  RowBox[{"2", "+", 
                                    TagBox[
                                      RowBox[{"2", "+", 
                                        TagBox[
                                        RowBox[{"2", "+", 
                                        TagBox[\(2 + 3\),
                                        DisplayForm]}],
                                        DisplayForm]}],
                                      DisplayForm]}],
                                  DisplayForm]}],
                              DisplayForm]}],
                          DisplayForm]}],
                      DisplayForm]}],
                  DisplayForm]}],
              DisplayForm]},
          {
            TagBox[
              RowBox[{"1", "+", 
                TagBox[
                  RowBox[{"1", "+", 
                    TagBox[
                      RowBox[{"1", "+", 
                        TagBox[
                          RowBox[{"2", "+", 
                            TagBox[
                              RowBox[{"2", "+", 
                                TagBox[
                                  RowBox[{"2", "+", 
                                    TagBox[
                                      RowBox[{"3", "+", 
                                        TagBox[\(3 + 3\),
                                        DisplayForm]}],
                                      DisplayForm]}],
                                  DisplayForm]}],
                              DisplayForm]}],
                          DisplayForm]}],
                      DisplayForm]}],
                  DisplayForm]}],
              DisplayForm]},
          {
            TagBox[
              RowBox[{"1", "+", 
                TagBox[
                  RowBox[{"1", "+", 
                    TagBox[
                      RowBox[{"1", "+", 
                        TagBox[
                          RowBox[{"3", "+", 
                            TagBox[
                              RowBox[{"3", "+", 
                                TagBox[
                                  RowBox[{"3", "+", 
                                    TagBox[\(3 + 3\),
                                      DisplayForm]}],
                                  DisplayForm]}],
                              DisplayForm]}],
                          DisplayForm]}],
                      DisplayForm]}],
                  DisplayForm]}],
              DisplayForm]},
          {
            TagBox[
              RowBox[{"1", "+", 
                TagBox[
                  RowBox[{"1", "+", 
                    TagBox[
                      RowBox[{"2", "+", 
                        TagBox[
                          RowBox[{"2", "+", 
                            TagBox[
                              RowBox[{"2", "+", 
                                TagBox[
                                  RowBox[{"2", "+", 
                                    TagBox[
                                      RowBox[{"2", "+", 
                                        TagBox[
                                        RowBox[{"2", "+", 
                                        TagBox[\(2 + 2\),
                                        DisplayForm]}],
                                        DisplayForm]}],
                                      DisplayForm]}],
                                  DisplayForm]}],
                              DisplayForm]}],
                          DisplayForm]}],
                      DisplayForm]}],
                  DisplayForm]}],
              DisplayForm]},
          {
            TagBox[
              RowBox[{"1", "+", 
                TagBox[
                  RowBox[{"1", "+", 
                    TagBox[
                      RowBox[{"2", "+", 
                        TagBox[
                          RowBox[{"2", "+", 
                            TagBox[
                              RowBox[{"2", "+", 
                                TagBox[
                                  RowBox[{"2", "+", 
                                    TagBox[
                                      RowBox[{"2", "+", 
                                        TagBox[\(3 + 3\),
                                        DisplayForm]}],
                                      DisplayForm]}],
                                  DisplayForm]}],
                              DisplayForm]}],
                          DisplayForm]}],
                      DisplayForm]}],
                  DisplayForm]}],
              DisplayForm]},
          {
            TagBox[
              RowBox[{"1", "+", 
                TagBox[
                  RowBox[{"1", "+", 
                    TagBox[
                      RowBox[{"2", "+", 
                        TagBox[
                          RowBox[{"2", "+", 
                            TagBox[
                              RowBox[{"3", "+", 
                                TagBox[
                                  RowBox[{"3", "+", 
                                    TagBox[\(3 + 3\),
                                      DisplayForm]}],
                                  DisplayForm]}],
                              DisplayForm]}],
                          DisplayForm]}],
                      DisplayForm]}],
                  DisplayForm]}],
              DisplayForm]},
          {
            TagBox[
              RowBox[{"1", "+", 
                TagBox[
                  RowBox[{"2", "+", 
                    TagBox[
                      RowBox[{"2", "+", 
                        TagBox[
                          RowBox[{"2", "+", 
                            TagBox[
                              RowBox[{"2", "+", 
                                TagBox[
                                  RowBox[{"2", "+", 
                                    TagBox[
                                      RowBox[{"2", "+", 
                                        TagBox[\(2 + 3\),
                                        DisplayForm]}],
                                      DisplayForm]}],
                                  DisplayForm]}],
                              DisplayForm]}],
                          DisplayForm]}],
                      DisplayForm]}],
                  DisplayForm]}],
              DisplayForm]},
          {
            TagBox[
              RowBox[{"1", "+", 
                TagBox[
                  RowBox[{"2", "+", 
                    TagBox[
                      RowBox[{"2", "+", 
                        TagBox[
                          RowBox[{"2", "+", 
                            TagBox[
                              RowBox[{"2", "+", 
                                TagBox[
                                  RowBox[{"3", "+", 
                                    TagBox[\(3 + 3\),
                                      DisplayForm]}],
                                  DisplayForm]}],
                              DisplayForm]}],
                          DisplayForm]}],
                      DisplayForm]}],
                  DisplayForm]}],
              DisplayForm]},
          {
            TagBox[
              RowBox[{"1", "+", 
                TagBox[
                  RowBox[{"2", "+", 
                    TagBox[
                      RowBox[{"3", "+", 
                        TagBox[
                          RowBox[{"3", "+", 
                            TagBox[
                              RowBox[{"3", "+", 
                                TagBox[\(3 + 3\),
                                  DisplayForm]}],
                              DisplayForm]}],
                          DisplayForm]}],
                      DisplayForm]}],
                  DisplayForm]}],
              DisplayForm]},
          {
            TagBox[
              RowBox[{"2", "+", 
                TagBox[
                  RowBox[{"2", "+", 
                    TagBox[
                      RowBox[{"2", "+", 
                        TagBox[
                          RowBox[{"2", "+", 
                            TagBox[
                              RowBox[{"2", "+", 
                                TagBox[
                                  RowBox[{"2", "+", 
                                    TagBox[
                                      RowBox[{"2", "+", 
                                        TagBox[\(2 + 2\),
                                        DisplayForm]}],
                                      DisplayForm]}],
                                  DisplayForm]}],
                              DisplayForm]}],
                          DisplayForm]}],
                      DisplayForm]}],
                  DisplayForm]}],
              DisplayForm]},
          {
            TagBox[
              RowBox[{"2", "+", 
                TagBox[
                  RowBox[{"2", "+", 
                    TagBox[
                      RowBox[{"2", "+", 
                        TagBox[
                          RowBox[{"2", "+", 
                            TagBox[
                              RowBox[{"2", "+", 
                                TagBox[
                                  RowBox[{"2", "+", 
                                    TagBox[\(3 + 3\),
                                      DisplayForm]}],
                                  DisplayForm]}],
                              DisplayForm]}],
                          DisplayForm]}],
                      DisplayForm]}],
                  DisplayForm]}],
              DisplayForm]},
          {
            TagBox[
              RowBox[{"2", "+", 
                TagBox[
                  RowBox[{"2", "+", 
                    TagBox[
                      RowBox[{"2", "+", 
                        TagBox[
                          RowBox[{"3", "+", 
                            TagBox[
                              RowBox[{"3", "+", 
                                TagBox[\(3 + 3\),
                                  DisplayForm]}],
                              DisplayForm]}],
                          DisplayForm]}],
                      DisplayForm]}],
                  DisplayForm]}],
              DisplayForm]},
          {
            TagBox[
              RowBox[{"3", "+", 
                TagBox[
                  RowBox[{"3", "+", 
                    TagBox[
                      RowBox[{"3", "+", 
                        TagBox[
                          RowBox[{"3", "+", 
                            TagBox[\(3 + 3\),
                              DisplayForm]}],
                          DisplayForm]}],
                      DisplayForm]}],
                  DisplayForm]}],
              DisplayForm]}
          },
        RowSpacings->1,
        ColumnSpacings->3,
        RowAlignments->Baseline,
        ColumnAlignments->{Left}],
      TableForm[ {
        DisplayForm[ 
          RowBox[ {"1", "+", 
            DisplayForm[ 
              RowBox[ {"1", "+", 
                DisplayForm[ 
                  RowBox[ {"1", "+", 
                    DisplayForm[ 
                      RowBox[ {"1", "+", 
                        DisplayForm[ 
                          RowBox[ {"1", "+", 
                            DisplayForm[ 
                              RowBox[ {"1", "+", 
                                DisplayForm[ 
                                  RowBox[ {"1", "+", 
                                    DisplayForm[ 
                                      RowBox[ {"1", "+", 
                                        DisplayForm[ 
                                        RowBox[ {"1", "+", 
                                        DisplayForm[ 
                                        RowBox[ {"1", "+", 
                                        DisplayForm[ 
                                        RowBox[ {"1", "+", 
                                        DisplayForm[ 
                                        RowBox[ {"1", "+", 
                                        DisplayForm[ 
                                        RowBox[ {"1", "+", 
                                        DisplayForm[ 
                                        RowBox[ {"1", "+", 
                                        DisplayForm[ 
                                        RowBox[ {"1", "+", 
                                        DisplayForm[ 
                                        RowBox[ {"1", "+", 
                                        DisplayForm[ 
                                        
                                        RowBox[ {"1", "+", 
                                        "1"}]]}]]}]]}]]}]]}]]}]]}]]}]]}]]}]]}]\
]}]]}]]}]]}]]}]], 
        DisplayForm[ 
          RowBox[ {"1", "+", 
            DisplayForm[ 
              RowBox[ {"1", "+", 
                DisplayForm[ 
                  RowBox[ {"1", "+", 
                    DisplayForm[ 
                      RowBox[ {"1", "+", 
                        DisplayForm[ 
                          RowBox[ {"1", "+", 
                            DisplayForm[ 
                              RowBox[ {"1", "+", 
                                DisplayForm[ 
                                  RowBox[ {"1", "+", 
                                    DisplayForm[ 
                                      RowBox[ {"1", "+", 
                                        DisplayForm[ 
                                        RowBox[ {"1", "+", 
                                        DisplayForm[ 
                                        RowBox[ {"1", "+", 
                                        DisplayForm[ 
                                        RowBox[ {"1", "+", 
                                        DisplayForm[ 
                                        RowBox[ {"1", "+", 
                                        DisplayForm[ 
                                        RowBox[ {"1", "+", 
                                        DisplayForm[ 
                                        RowBox[ {"1", "+", 
                                        DisplayForm[ 
                                        RowBox[ {"1", "+", 
                                        DisplayForm[ 
                                        
                                        RowBox[ {"1", "+", 
                                        "2"}]]}]]}]]}]]}]]}]]}]]}]]}]]}]]}]]}]\
]}]]}]]}]]}]], 
        DisplayForm[ 
          RowBox[ {"1", "+", 
            DisplayForm[ 
              RowBox[ {"1", "+", 
                DisplayForm[ 
                  RowBox[ {"1", "+", 
                    DisplayForm[ 
                      RowBox[ {"1", "+", 
                        DisplayForm[ 
                          RowBox[ {"1", "+", 
                            DisplayForm[ 
                              RowBox[ {"1", "+", 
                                DisplayForm[ 
                                  RowBox[ {"1", "+", 
                                    DisplayForm[ 
                                      RowBox[ {"1", "+", 
                                        DisplayForm[ 
                                        RowBox[ {"1", "+", 
                                        DisplayForm[ 
                                        RowBox[ {"1", "+", 
                                        DisplayForm[ 
                                        RowBox[ {"1", "+", 
                                        DisplayForm[ 
                                        RowBox[ {"1", "+", 
                                        DisplayForm[ 
                                        RowBox[ {"1", "+", 
                                        DisplayForm[ 
                                        RowBox[ {"1", "+", 
                                        DisplayForm[ 
                                        
                                        RowBox[ {"1", "+", 
                                        "3"}]]}]]}]]}]]}]]}]]}]]}]]}]]}]]}]]}]\
]}]]}]]}]], 
        DisplayForm[ 
          RowBox[ {"1", "+", 
            DisplayForm[ 
              RowBox[ {"1", "+", 
                DisplayForm[ 
                  RowBox[ {"1", "+", 
                    DisplayForm[ 
                      RowBox[ {"1", "+", 
                        DisplayForm[ 
                          RowBox[ {"1", "+", 
                            DisplayForm[ 
                              RowBox[ {"1", "+", 
                                DisplayForm[ 
                                  RowBox[ {"1", "+", 
                                    DisplayForm[ 
                                      RowBox[ {"1", "+", 
                                        DisplayForm[ 
                                        RowBox[ {"1", "+", 
                                        DisplayForm[ 
                                        RowBox[ {"1", "+", 
                                        DisplayForm[ 
                                        RowBox[ {"1", "+", 
                                        DisplayForm[ 
                                        RowBox[ {"1", "+", 
                                        DisplayForm[ 
                                        RowBox[ {"1", "+", 
                                        DisplayForm[ 
                                        RowBox[ {"1", "+", 
                                        DisplayForm[ 
                                        
                                        RowBox[ {"2", "+", 
                                        "2"}]]}]]}]]}]]}]]}]]}]]}]]}]]}]]}]]}]\
]}]]}]]}]], 
        DisplayForm[ 
          RowBox[ {"1", "+", 
            DisplayForm[ 
              RowBox[ {"1", "+", 
                DisplayForm[ 
                  RowBox[ {"1", "+", 
                    DisplayForm[ 
                      RowBox[ {"1", "+", 
                        DisplayForm[ 
                          RowBox[ {"1", "+", 
                            DisplayForm[ 
                              RowBox[ {"1", "+", 
                                DisplayForm[ 
                                  RowBox[ {"1", "+", 
                                    DisplayForm[ 
                                      RowBox[ {"1", "+", 
                                        DisplayForm[ 
                                        RowBox[ {"1", "+", 
                                        DisplayForm[ 
                                        RowBox[ {"1", "+", 
                                        DisplayForm[ 
                                        RowBox[ {"1", "+", 
                                        DisplayForm[ 
                                        RowBox[ {"1", "+", 
                                        DisplayForm[ 
                                        RowBox[ {"1", "+", 
                                        DisplayForm[ 
                                        
                                        RowBox[ {"2", "+", 
                                        "3"}]]}]]}]]}]]}]]}]]}]]}]]}]]}]]}]]}]\
]}]]}]], 
        DisplayForm[ 
          RowBox[ {"1", "+", 
            DisplayForm[ 
              RowBox[ {"1", "+", 
                DisplayForm[ 
                  RowBox[ {"1", "+", 
                    DisplayForm[ 
                      RowBox[ {"1", "+", 
                        DisplayForm[ 
                          RowBox[ {"1", "+", 
                            DisplayForm[ 
                              RowBox[ {"1", "+", 
                                DisplayForm[ 
                                  RowBox[ {"1", "+", 
                                    DisplayForm[ 
                                      RowBox[ {"1", "+", 
                                        DisplayForm[ 
                                        RowBox[ {"1", "+", 
                                        DisplayForm[ 
                                        RowBox[ {"1", "+", 
                                        DisplayForm[ 
                                        RowBox[ {"1", "+", 
                                        DisplayForm[ 
                                        RowBox[ {"1", "+", 
                                        DisplayForm[ 
                                        RowBox[ {"2", "+", 
                                        DisplayForm[ 
                                        
                                        RowBox[ {"2", "+", 
                                        "2"}]]}]]}]]}]]}]]}]]}]]}]]}]]}]]}]]}]\
]}]]}]], 
        DisplayForm[ 
          RowBox[ {"1", "+", 
            DisplayForm[ 
              RowBox[ {"1", "+", 
                DisplayForm[ 
                  RowBox[ {"1", "+", 
                    DisplayForm[ 
                      RowBox[ {"1", "+", 
                        DisplayForm[ 
                          RowBox[ {"1", "+", 
                            DisplayForm[ 
                              RowBox[ {"1", "+", 
                                DisplayForm[ 
                                  RowBox[ {"1", "+", 
                                    DisplayForm[ 
                                      RowBox[ {"1", "+", 
                                        DisplayForm[ 
                                        RowBox[ {"1", "+", 
                                        DisplayForm[ 
                                        RowBox[ {"1", "+", 
                                        DisplayForm[ 
                                        RowBox[ {"1", "+", 
                                        DisplayForm[ 
                                        RowBox[ {"1", "+", 
                                        DisplayForm[ 
                                        
                                        RowBox[ {"3", "+", 
                                        "3"}]]}]]}]]}]]}]]}]]}]]}]]}]]}]]}]]}]\
]}]], 
        DisplayForm[ 
          RowBox[ {"1", "+", 
            DisplayForm[ 
              RowBox[ {"1", "+", 
                DisplayForm[ 
                  RowBox[ {"1", "+", 
                    DisplayForm[ 
                      RowBox[ {"1", "+", 
                        DisplayForm[ 
                          RowBox[ {"1", "+", 
                            DisplayForm[ 
                              RowBox[ {"1", "+", 
                                DisplayForm[ 
                                  RowBox[ {"1", "+", 
                                    DisplayForm[ 
                                      RowBox[ {"1", "+", 
                                        DisplayForm[ 
                                        RowBox[ {"1", "+", 
                                        DisplayForm[ 
                                        RowBox[ {"1", "+", 
                                        DisplayForm[ 
                                        RowBox[ {"1", "+", 
                                        DisplayForm[ 
                                        RowBox[ {"2", "+", 
                                        DisplayForm[ 
                                        RowBox[ {"2", "+", 
                                        "3"}]]}]]}]]}]]}]]}]]}]]}]]}]]}]]}]]}]\
]}]], 
        DisplayForm[ 
          RowBox[ {"1", "+", 
            DisplayForm[ 
              RowBox[ {"1", "+", 
                DisplayForm[ 
                  RowBox[ {"1", "+", 
                    DisplayForm[ 
                      RowBox[ {"1", "+", 
                        DisplayForm[ 
                          RowBox[ {"1", "+", 
                            DisplayForm[ 
                              RowBox[ {"1", "+", 
                                DisplayForm[ 
                                  RowBox[ {"1", "+", 
                                    DisplayForm[ 
                                      RowBox[ {"1", "+", 
                                        DisplayForm[ 
                                        RowBox[ {"1", "+", 
                                        DisplayForm[ 
                                        RowBox[ {"1", "+", 
                                        DisplayForm[ 
                                        RowBox[ {"2", "+", 
                                        DisplayForm[ 
                                        RowBox[ {"2", "+", 
                                        DisplayForm[ 
                                        
                                        RowBox[ {"2", "+", 
                                        "2"}]]}]]}]]}]]}]]}]]}]]}]]}]]}]]}]]}]\
]}]], 
        DisplayForm[ 
          RowBox[ {"1", "+", 
            DisplayForm[ 
              RowBox[ {"1", "+", 
                DisplayForm[ 
                  RowBox[ {"1", "+", 
                    DisplayForm[ 
                      RowBox[ {"1", "+", 
                        DisplayForm[ 
                          RowBox[ {"1", "+", 
                            DisplayForm[ 
                              RowBox[ {"1", "+", 
                                DisplayForm[ 
                                  RowBox[ {"1", "+", 
                                    DisplayForm[ 
                                      RowBox[ {"1", "+", 
                                        DisplayForm[ 
                                        RowBox[ {"1", "+", 
                                        DisplayForm[ 
                                        RowBox[ {"1", "+", 
                                        DisplayForm[ 
                                        RowBox[ {"2", "+", 
                                        DisplayForm[ 
                                        
                                        RowBox[ {"3", "+", 
                                        "3"}]]}]]}]]}]]}]]}]]}]]}]]}]]}]]}]]}]\
], 
        DisplayForm[ 
          RowBox[ {"1", "+", 
            DisplayForm[ 
              RowBox[ {"1", "+", 
                DisplayForm[ 
                  RowBox[ {"1", "+", 
                    DisplayForm[ 
                      RowBox[ {"1", "+", 
                        DisplayForm[ 
                          RowBox[ {"1", "+", 
                            DisplayForm[ 
                              RowBox[ {"1", "+", 
                                DisplayForm[ 
                                  RowBox[ {"1", "+", 
                                    DisplayForm[ 
                                      RowBox[ {"1", "+", 
                                        DisplayForm[ 
                                        RowBox[ {"1", "+", 
                                        DisplayForm[ 
                                        RowBox[ {"2", "+", 
                                        DisplayForm[ 
                                        RowBox[ {"2", "+", 
                                        DisplayForm[ 
                                        
                                        RowBox[ {"2", "+", 
                                        "3"}]]}]]}]]}]]}]]}]]}]]}]]}]]}]]}]]}]\
], 
        DisplayForm[ 
          RowBox[ {"1", "+", 
            DisplayForm[ 
              RowBox[ {"1", "+", 
                DisplayForm[ 
                  RowBox[ {"1", "+", 
                    DisplayForm[ 
                      RowBox[ {"1", "+", 
                        DisplayForm[ 
                          RowBox[ {"1", "+", 
                            DisplayForm[ 
                              RowBox[ {"1", "+", 
                                DisplayForm[ 
                                  RowBox[ {"1", "+", 
                                    DisplayForm[ 
                                      RowBox[ {"1", "+", 
                                        DisplayForm[ 
                                        RowBox[ {"1", "+", 
                                        DisplayForm[ 
                                        RowBox[ {"3", "+", 
                                        DisplayForm[ 
                                        
                                        RowBox[ {"3", "+", 
                                        "3"}]]}]]}]]}]]}]]}]]}]]}]]}]]}]]}]], 
        
        DisplayForm[ 
          RowBox[ {"1", "+", 
            DisplayForm[ 
              RowBox[ {"1", "+", 
                DisplayForm[ 
                  RowBox[ {"1", "+", 
                    DisplayForm[ 
                      RowBox[ {"1", "+", 
                        DisplayForm[ 
                          RowBox[ {"1", "+", 
                            DisplayForm[ 
                              RowBox[ {"1", "+", 
                                DisplayForm[ 
                                  RowBox[ {"1", "+", 
                                    DisplayForm[ 
                                      RowBox[ {"1", "+", 
                                        DisplayForm[ 
                                        RowBox[ {"2", "+", 
                                        DisplayForm[ 
                                        RowBox[ {"2", "+", 
                                        DisplayForm[ 
                                        RowBox[ {"2", "+", 
                                        DisplayForm[ 
                                        
                                        RowBox[ {"2", "+", 
                                        "2"}]]}]]}]]}]]}]]}]]}]]}]]}]]}]]}]]}]\
], 
        DisplayForm[ 
          RowBox[ {"1", "+", 
            DisplayForm[ 
              RowBox[ {"1", "+", 
                DisplayForm[ 
                  RowBox[ {"1", "+", 
                    DisplayForm[ 
                      RowBox[ {"1", "+", 
                        DisplayForm[ 
                          RowBox[ {"1", "+", 
                            DisplayForm[ 
                              RowBox[ {"1", "+", 
                                DisplayForm[ 
                                  RowBox[ {"1", "+", 
                                    DisplayForm[ 
                                      RowBox[ {"1", "+", 
                                        DisplayForm[ 
                                        RowBox[ {"2", "+", 
                                        DisplayForm[ 
                                        RowBox[ {"2", "+", 
                                        DisplayForm[ 
                                        
                                        RowBox[ {"3", "+", 
                                        "3"}]]}]]}]]}]]}]]}]]}]]}]]}]]}]]}]], 
        
        DisplayForm[ 
          RowBox[ {"1", "+", 
            DisplayForm[ 
              RowBox[ {"1", "+", 
                DisplayForm[ 
                  RowBox[ {"1", "+", 
                    DisplayForm[ 
                      RowBox[ {"1", "+", 
                        DisplayForm[ 
                          RowBox[ {"1", "+", 
                            DisplayForm[ 
                              RowBox[ {"1", "+", 
                                DisplayForm[ 
                                  RowBox[ {"1", "+", 
                                    DisplayForm[ 
                                      RowBox[ {"2", "+", 
                                        DisplayForm[ 
                                        RowBox[ {"2", "+", 
                                        DisplayForm[ 
                                        RowBox[ {"2", "+", 
                                        DisplayForm[ 
                                        
                                        RowBox[ {"2", "+", 
                                        "3"}]]}]]}]]}]]}]]}]]}]]}]]}]]}]]}]], 
        
        DisplayForm[ 
          RowBox[ {"1", "+", 
            DisplayForm[ 
              RowBox[ {"1", "+", 
                DisplayForm[ 
                  RowBox[ {"1", "+", 
                    DisplayForm[ 
                      RowBox[ {"1", "+", 
                        DisplayForm[ 
                          RowBox[ {"1", "+", 
                            DisplayForm[ 
                              RowBox[ {"1", "+", 
                                DisplayForm[ 
                                  RowBox[ {"1", "+", 
                                    DisplayForm[ 
                                      RowBox[ {"2", "+", 
                                        DisplayForm[ 
                                        RowBox[ {"3", "+", 
                                        DisplayForm[ 
                                        
                                        RowBox[ {"3", "+", 
                                        "3"}]]}]]}]]}]]}]]}]]}]]}]]}]]}]], 
        DisplayForm[ 
          RowBox[ {"1", "+", 
            DisplayForm[ 
              RowBox[ {"1", "+", 
                DisplayForm[ 
                  RowBox[ {"1", "+", 
                    DisplayForm[ 
                      RowBox[ {"1", "+", 
                        DisplayForm[ 
                          RowBox[ {"1", "+", 
                            DisplayForm[ 
                              RowBox[ {"1", "+", 
                                DisplayForm[ 
                                  RowBox[ {"2", "+", 
                                    DisplayForm[ 
                                      RowBox[ {"2", "+", 
                                        DisplayForm[ 
                                        RowBox[ {"2", "+", 
                                        DisplayForm[ 
                                        RowBox[ {"2", "+", 
                                        DisplayForm[ 
                                        
                                        RowBox[ {"2", "+", 
                                        "2"}]]}]]}]]}]]}]]}]]}]]}]]}]]}]]}]], 
        
        DisplayForm[ 
          RowBox[ {"1", "+", 
            DisplayForm[ 
              RowBox[ {"1", "+", 
                DisplayForm[ 
                  RowBox[ {"1", "+", 
                    DisplayForm[ 
                      RowBox[ {"1", "+", 
                        DisplayForm[ 
                          RowBox[ {"1", "+", 
                            DisplayForm[ 
                              RowBox[ {"1", "+", 
                                DisplayForm[ 
                                  RowBox[ {"2", "+", 
                                    DisplayForm[ 
                                      RowBox[ {"2", "+", 
                                        DisplayForm[ 
                                        RowBox[ {"2", "+", 
                                        DisplayForm[ 
                                        
                                        RowBox[ {"3", "+", 
                                        "3"}]]}]]}]]}]]}]]}]]}]]}]]}]]}]], 
        DisplayForm[ 
          RowBox[ {"1", "+", 
            DisplayForm[ 
              RowBox[ {"1", "+", 
                DisplayForm[ 
                  RowBox[ {"1", "+", 
                    DisplayForm[ 
                      RowBox[ {"1", "+", 
                        DisplayForm[ 
                          RowBox[ {"1", "+", 
                            DisplayForm[ 
                              RowBox[ {"1", "+", 
                                DisplayForm[ 
                                  RowBox[ {"3", "+", 
                                    DisplayForm[ 
                                      RowBox[ {"3", "+", 
                                        DisplayForm[ 
                                        
                                        RowBox[ {"3", "+", 
                                        "3"}]]}]]}]]}]]}]]}]]}]]}]]}]], 
        DisplayForm[ 
          RowBox[ {"1", "+", 
            DisplayForm[ 
              RowBox[ {"1", "+", 
                DisplayForm[ 
                  RowBox[ {"1", "+", 
                    DisplayForm[ 
                      RowBox[ {"1", "+", 
                        DisplayForm[ 
                          RowBox[ {"1", "+", 
                            DisplayForm[ 
                              RowBox[ {"2", "+", 
                                DisplayForm[ 
                                  RowBox[ {"2", "+", 
                                    DisplayForm[ 
                                      RowBox[ {"2", "+", 
                                        DisplayForm[ 
                                        RowBox[ {"2", "+", 
                                        DisplayForm[ 
                                        
                                        RowBox[ {"2", "+", 
                                        "3"}]]}]]}]]}]]}]]}]]}]]}]]}]]}]], 
        DisplayForm[ 
          RowBox[ {"1", "+", 
            DisplayForm[ 
              RowBox[ {"1", "+", 
                DisplayForm[ 
                  RowBox[ {"1", "+", 
                    DisplayForm[ 
                      RowBox[ {"1", "+", 
                        DisplayForm[ 
                          RowBox[ {"1", "+", 
                            DisplayForm[ 
                              RowBox[ {"2", "+", 
                                DisplayForm[ 
                                  RowBox[ {"2", "+", 
                                    DisplayForm[ 
                                      RowBox[ {"3", "+", 
                                        DisplayForm[ 
                                        
                                        RowBox[ {"3", "+", 
                                        "3"}]]}]]}]]}]]}]]}]]}]]}]]}]], 
        DisplayForm[ 
          RowBox[ {"1", "+", 
            DisplayForm[ 
              RowBox[ {"1", "+", 
                DisplayForm[ 
                  RowBox[ {"1", "+", 
                    DisplayForm[ 
                      RowBox[ {"1", "+", 
                        DisplayForm[ 
                          RowBox[ {"2", "+", 
                            DisplayForm[ 
                              RowBox[ {"2", "+", 
                                DisplayForm[ 
                                  RowBox[ {"2", "+", 
                                    DisplayForm[ 
                                      RowBox[ {"2", "+", 
                                        DisplayForm[ 
                                        RowBox[ {"2", "+", 
                                        DisplayForm[ 
                                        
                                        RowBox[ {"2", "+", 
                                        "2"}]]}]]}]]}]]}]]}]]}]]}]]}]]}]], 
        DisplayForm[ 
          RowBox[ {"1", "+", 
            DisplayForm[ 
              RowBox[ {"1", "+", 
                DisplayForm[ 
                  RowBox[ {"1", "+", 
                    DisplayForm[ 
                      RowBox[ {"1", "+", 
                        DisplayForm[ 
                          RowBox[ {"2", "+", 
                            DisplayForm[ 
                              RowBox[ {"2", "+", 
                                DisplayForm[ 
                                  RowBox[ {"2", "+", 
                                    DisplayForm[ 
                                      RowBox[ {"2", "+", 
                                        DisplayForm[ 
                                        
                                        RowBox[ {"3", "+", 
                                        "3"}]]}]]}]]}]]}]]}]]}]]}]]}]], 
        DisplayForm[ 
          RowBox[ {"1", "+", 
            DisplayForm[ 
              RowBox[ {"1", "+", 
                DisplayForm[ 
                  RowBox[ {"1", "+", 
                    DisplayForm[ 
                      RowBox[ {"1", "+", 
                        DisplayForm[ 
                          RowBox[ {"2", "+", 
                            DisplayForm[ 
                              RowBox[ {"3", "+", 
                                DisplayForm[ 
                                  RowBox[ {"3", "+", 
                                    DisplayForm[ 
                                      
                                      RowBox[ {"3", "+", 
                                        "3"}]]}]]}]]}]]}]]}]]}]]}]], 
        DisplayForm[ 
          RowBox[ {"1", "+", 
            DisplayForm[ 
              RowBox[ {"1", "+", 
                DisplayForm[ 
                  RowBox[ {"1", "+", 
                    DisplayForm[ 
                      RowBox[ {"2", "+", 
                        DisplayForm[ 
                          RowBox[ {"2", "+", 
                            DisplayForm[ 
                              RowBox[ {"2", "+", 
                                DisplayForm[ 
                                  RowBox[ {"2", "+", 
                                    DisplayForm[ 
                                      RowBox[ {"2", "+", 
                                        DisplayForm[ 
                                        
                                        RowBox[ {"2", "+", 
                                        "3"}]]}]]}]]}]]}]]}]]}]]}]]}]], 
        DisplayForm[ 
          RowBox[ {"1", "+", 
            DisplayForm[ 
              RowBox[ {"1", "+", 
                DisplayForm[ 
                  RowBox[ {"1", "+", 
                    DisplayForm[ 
                      RowBox[ {"2", "+", 
                        DisplayForm[ 
                          RowBox[ {"2", "+", 
                            DisplayForm[ 
                              RowBox[ {"2", "+", 
                                DisplayForm[ 
                                  RowBox[ {"3", "+", 
                                    DisplayForm[ 
                                      
                                      RowBox[ {"3", "+", 
                                        "3"}]]}]]}]]}]]}]]}]]}]]}]], 
        DisplayForm[ 
          RowBox[ {"1", "+", 
            DisplayForm[ 
              RowBox[ {"1", "+", 
                DisplayForm[ 
                  RowBox[ {"1", "+", 
                    DisplayForm[ 
                      RowBox[ {"3", "+", 
                        DisplayForm[ 
                          RowBox[ {"3", "+", 
                            DisplayForm[ 
                              RowBox[ {"3", "+", 
                                DisplayForm[ 
                                  RowBox[ {"3", "+", "3"}]]}]]}]]}]]}]]}]]}]],
         
        DisplayForm[ 
          RowBox[ {"1", "+", 
            DisplayForm[ 
              RowBox[ {"1", "+", 
                DisplayForm[ 
                  RowBox[ {"2", "+", 
                    DisplayForm[ 
                      RowBox[ {"2", "+", 
                        DisplayForm[ 
                          RowBox[ {"2", "+", 
                            DisplayForm[ 
                              RowBox[ {"2", "+", 
                                DisplayForm[ 
                                  RowBox[ {"2", "+", 
                                    DisplayForm[ 
                                      RowBox[ {"2", "+", 
                                        DisplayForm[ 
                                        
                                        RowBox[ {"2", "+", 
                                        "2"}]]}]]}]]}]]}]]}]]}]]}]]}]], 
        DisplayForm[ 
          RowBox[ {"1", "+", 
            DisplayForm[ 
              RowBox[ {"1", "+", 
                DisplayForm[ 
                  RowBox[ {"2", "+", 
                    DisplayForm[ 
                      RowBox[ {"2", "+", 
                        DisplayForm[ 
                          RowBox[ {"2", "+", 
                            DisplayForm[ 
                              RowBox[ {"2", "+", 
                                DisplayForm[ 
                                  RowBox[ {"2", "+", 
                                    DisplayForm[ 
                                      
                                      RowBox[ {"3", "+", 
                                        "3"}]]}]]}]]}]]}]]}]]}]]}]], 
        DisplayForm[ 
          RowBox[ {"1", "+", 
            DisplayForm[ 
              RowBox[ {"1", "+", 
                DisplayForm[ 
                  RowBox[ {"2", "+", 
                    DisplayForm[ 
                      RowBox[ {"2", "+", 
                        DisplayForm[ 
                          RowBox[ {"3", "+", 
                            DisplayForm[ 
                              RowBox[ {"3", "+", 
                                DisplayForm[ 
                                  RowBox[ {"3", "+", "3"}]]}]]}]]}]]}]]}]]}]],
         
        DisplayForm[ 
          RowBox[ {"1", "+", 
            DisplayForm[ 
              RowBox[ {"2", "+", 
                DisplayForm[ 
                  RowBox[ {"2", "+", 
                    DisplayForm[ 
                      RowBox[ {"2", "+", 
                        DisplayForm[ 
                          RowBox[ {"2", "+", 
                            DisplayForm[ 
                              RowBox[ {"2", "+", 
                                DisplayForm[ 
                                  RowBox[ {"2", "+", 
                                    DisplayForm[ 
                                      
                                      RowBox[ {"2", "+", 
                                        "3"}]]}]]}]]}]]}]]}]]}]]}]], 
        DisplayForm[ 
          RowBox[ {"1", "+", 
            DisplayForm[ 
              RowBox[ {"2", "+", 
                DisplayForm[ 
                  RowBox[ {"2", "+", 
                    DisplayForm[ 
                      RowBox[ {"2", "+", 
                        DisplayForm[ 
                          RowBox[ {"2", "+", 
                            DisplayForm[ 
                              RowBox[ {"3", "+", 
                                DisplayForm[ 
                                  RowBox[ {"3", "+", "3"}]]}]]}]]}]]}]]}]]}]],
         
        DisplayForm[ 
          RowBox[ {"1", "+", 
            DisplayForm[ 
              RowBox[ {"2", "+", 
                DisplayForm[ 
                  RowBox[ {"3", "+", 
                    DisplayForm[ 
                      RowBox[ {"3", "+", 
                        DisplayForm[ 
                          RowBox[ {"3", "+", 
                            DisplayForm[ 
                              RowBox[ {"3", "+", "3"}]]}]]}]]}]]}]]}]], 
        DisplayForm[ 
          RowBox[ {"2", "+", 
            DisplayForm[ 
              RowBox[ {"2", "+", 
                DisplayForm[ 
                  RowBox[ {"2", "+", 
                    DisplayForm[ 
                      RowBox[ {"2", "+", 
                        DisplayForm[ 
                          RowBox[ {"2", "+", 
                            DisplayForm[ 
                              RowBox[ {"2", "+", 
                                DisplayForm[ 
                                  RowBox[ {"2", "+", 
                                    DisplayForm[ 
                                      
                                      RowBox[ {"2", "+", 
                                        "2"}]]}]]}]]}]]}]]}]]}]]}]], 
        DisplayForm[ 
          RowBox[ {"2", "+", 
            DisplayForm[ 
              RowBox[ {"2", "+", 
                DisplayForm[ 
                  RowBox[ {"2", "+", 
                    DisplayForm[ 
                      RowBox[ {"2", "+", 
                        DisplayForm[ 
                          RowBox[ {"2", "+", 
                            DisplayForm[ 
                              RowBox[ {"2", "+", 
                                DisplayForm[ 
                                  RowBox[ {"3", "+", "3"}]]}]]}]]}]]}]]}]]}]],
         
        DisplayForm[ 
          RowBox[ {"2", "+", 
            DisplayForm[ 
              RowBox[ {"2", "+", 
                DisplayForm[ 
                  RowBox[ {"2", "+", 
                    DisplayForm[ 
                      RowBox[ {"3", "+", 
                        DisplayForm[ 
                          RowBox[ {"3", "+", 
                            DisplayForm[ 
                              RowBox[ {"3", "+", "3"}]]}]]}]]}]]}]]}]], 
        DisplayForm[ 
          RowBox[ {"3", "+", 
            DisplayForm[ 
              RowBox[ {"3", "+", 
                DisplayForm[ 
                  RowBox[ {"3", "+", 
                    DisplayForm[ 
                      RowBox[ {"3", "+", 
                        DisplayForm[ 
                          RowBox[ {"3", "+", "3"}]]}]]}]]}]]}]]}]]], "Output"],

Cell[BoxData[
    TagBox[GridBox[{
          {
            TagBox[
              RowBox[{"1", "+", 
                TagBox[
                  RowBox[{"1", "+", 
                    TagBox[
                      RowBox[{"1", "+", 
                        TagBox[
                          RowBox[{"1", "+", 
                            TagBox[\(1 + 1\),
                              DisplayForm]}],
                          DisplayForm]}],
                      DisplayForm]}],
                  DisplayForm]}],
              DisplayForm], 
            TagBox[
              RowBox[{"1", "+", 
                TagBox[
                  RowBox[{"1", "+", 
                    TagBox[
                      RowBox[{"1", "+", 
                        TagBox[
                          RowBox[{"1", "+", 
                            TagBox[\(1 + 1\),
                              DisplayForm]}],
                          DisplayForm]}],
                      DisplayForm]}],
                  DisplayForm]}],
              DisplayForm], 
            TagBox[
              RowBox[{"1", "+", 
                TagBox[
                  RowBox[{"1", "+", 
                    TagBox[
                      RowBox[{"1", "+", 
                        TagBox[
                          RowBox[{"1", "+", 
                            TagBox[\(1 + 1\),
                              DisplayForm]}],
                          DisplayForm]}],
                      DisplayForm]}],
                  DisplayForm]}],
              DisplayForm]},
          {
            TagBox[
              RowBox[{"1", "+", 
                TagBox[
                  RowBox[{"1", "+", 
                    TagBox[
                      RowBox[{"1", "+", 
                        TagBox[\(1 + 2\),
                          DisplayForm]}],
                      DisplayForm]}],
                  DisplayForm]}],
              DisplayForm], 
            TagBox[
              RowBox[{"1", "+", 
                TagBox[
                  RowBox[{"1", "+", 
                    TagBox[
                      RowBox[{"1", "+", 
                        TagBox[
                          RowBox[{"1", "+", 
                            TagBox[\(1 + 1\),
                              DisplayForm]}],
                          DisplayForm]}],
                      DisplayForm]}],
                  DisplayForm]}],
              DisplayForm], 
            TagBox[
              RowBox[{"1", "+", 
                TagBox[
                  RowBox[{"1", "+", 
                    TagBox[
                      RowBox[{"1", "+", 
                        TagBox[
                          RowBox[{"1", "+", 
                            TagBox[\(1 + 1\),
                              DisplayForm]}],
                          DisplayForm]}],
                      DisplayForm]}],
                  DisplayForm]}],
              DisplayForm]},
          {
            TagBox[
              RowBox[{"1", "+", 
                TagBox[
                  RowBox[{"1", "+", 
                    TagBox[\(1 + 3\),
                      DisplayForm]}],
                  DisplayForm]}],
              DisplayForm], 
            TagBox[
              RowBox[{"1", "+", 
                TagBox[
                  RowBox[{"1", "+", 
                    TagBox[
                      RowBox[{"1", "+", 
                        TagBox[
                          RowBox[{"1", "+", 
                            TagBox[\(1 + 1\),
                              DisplayForm]}],
                          DisplayForm]}],
                      DisplayForm]}],
                  DisplayForm]}],
              DisplayForm], 
            TagBox[
              RowBox[{"1", "+", 
                TagBox[
                  RowBox[{"1", "+", 
                    TagBox[
                      RowBox[{"1", "+", 
                        TagBox[
                          RowBox[{"1", "+", 
                            TagBox[\(1 + 1\),
                              DisplayForm]}],
                          DisplayForm]}],
                      DisplayForm]}],
                  DisplayForm]}],
              DisplayForm]},
          {
            TagBox[
              RowBox[{"1", "+", 
                TagBox[
                  RowBox[{"1", "+", 
                    TagBox[
                      RowBox[{"1", "+", 
                        TagBox[\(1 + 2\),
                          DisplayForm]}],
                      DisplayForm]}],
                  DisplayForm]}],
              DisplayForm], 
            TagBox[
              RowBox[{"1", "+", 
                TagBox[
                  RowBox[{"1", "+", 
                    TagBox[
                      RowBox[{"1", "+", 
                        TagBox[\(1 + 2\),
                          DisplayForm]}],
                      DisplayForm]}],
                  DisplayForm]}],
              DisplayForm], 
            TagBox[
              RowBox[{"1", "+", 
                TagBox[
                  RowBox[{"1", "+", 
                    TagBox[
                      RowBox[{"1", "+", 
                        TagBox[
                          RowBox[{"1", "+", 
                            TagBox[\(1 + 1\),
                              DisplayForm]}],
                          DisplayForm]}],
                      DisplayForm]}],
                  DisplayForm]}],
              DisplayForm]},
          {
            TagBox[
              RowBox[{"1", "+", 
                TagBox[
                  RowBox[{"1", "+", 
                    TagBox[\(1 + 3\),
                      DisplayForm]}],
                  DisplayForm]}],
              DisplayForm], 
            TagBox[
              RowBox[{"1", "+", 
                TagBox[
                  RowBox[{"1", "+", 
                    TagBox[
                      RowBox[{"1", "+", 
                        TagBox[\(1 + 2\),
                          DisplayForm]}],
                      DisplayForm]}],
                  DisplayForm]}],
              DisplayForm], 
            TagBox[
              RowBox[{"1", "+", 
                TagBox[
                  RowBox[{"1", "+", 
                    TagBox[
                      RowBox[{"1", "+", 
                        TagBox[
                          RowBox[{"1", "+", 
                            TagBox[\(1 + 1\),
                              DisplayForm]}],
                          DisplayForm]}],
                      DisplayForm]}],
                  DisplayForm]}],
              DisplayForm]},
          {
            TagBox[
              RowBox[{"1", "+", 
                TagBox[
                  RowBox[{"1", "+", 
                    TagBox[
                      RowBox[{"1", "+", 
                        TagBox[\(1 + 2\),
                          DisplayForm]}],
                      DisplayForm]}],
                  DisplayForm]}],
              DisplayForm], 
            TagBox[
              RowBox[{"1", "+", 
                TagBox[
                  RowBox[{"1", "+", 
                    TagBox[
                      RowBox[{"1", "+", 
                        TagBox[\(1 + 2\),
                          DisplayForm]}],
                      DisplayForm]}],
                  DisplayForm]}],
              DisplayForm], 
            TagBox[
              RowBox[{"1", "+", 
                TagBox[
                  RowBox[{"1", "+", 
                    TagBox[
                      RowBox[{"1", "+", 
                        TagBox[\(1 + 2\),
                          DisplayForm]}],
                      DisplayForm]}],
                  DisplayForm]}],
              DisplayForm]},
          {
            TagBox[\(3 + 3\),
              DisplayForm], 
            TagBox[
              RowBox[{"1", "+", 
                TagBox[
                  RowBox[{"1", "+", 
                    TagBox[
                      RowBox[{"1", "+", 
                        TagBox[
                          RowBox[{"1", "+", 
                            TagBox[\(1 + 1\),
                              DisplayForm]}],
                          DisplayForm]}],
                      DisplayForm]}],
                  DisplayForm]}],
              DisplayForm], 
            TagBox[
              RowBox[{"1", "+", 
                TagBox[
                  RowBox[{"1", "+", 
                    TagBox[
                      RowBox[{"1", "+", 
                        TagBox[
                          RowBox[{"1", "+", 
                            TagBox[\(1 + 1\),
                              DisplayForm]}],
                          DisplayForm]}],
                      DisplayForm]}],
                  DisplayForm]}],
              DisplayForm]},
          {
            TagBox[
              RowBox[{"1", "+", 
                TagBox[\(2 + 3\),
                  DisplayForm]}],
              DisplayForm], 
            TagBox[
              RowBox[{"1", "+", 
                TagBox[
                  RowBox[{"1", "+", 
                    TagBox[
                      RowBox[{"1", "+", 
                        TagBox[\(1 + 2\),
                          DisplayForm]}],
                      DisplayForm]}],
                  DisplayForm]}],
              DisplayForm], 
            TagBox[
              RowBox[{"1", "+", 
                TagBox[
                  RowBox[{"1", "+", 
                    TagBox[
                      RowBox[{"1", "+", 
                        TagBox[
                          RowBox[{"1", "+", 
                            TagBox[\(1 + 1\),
                              DisplayForm]}],
                          DisplayForm]}],
                      DisplayForm]}],
                  DisplayForm]}],
              DisplayForm]},
          {
            TagBox[
              RowBox[{"1", "+", 
                TagBox[
                  RowBox[{"1", "+", 
                    TagBox[\(2 + 2\),
                      DisplayForm]}],
                  DisplayForm]}],
              DisplayForm], 
            TagBox[
              RowBox[{"1", "+", 
                TagBox[
                  RowBox[{"1", "+", 
                    TagBox[\(2 + 2\),
                      DisplayForm]}],
                  DisplayForm]}],
              DisplayForm], 
            TagBox[
              RowBox[{"1", "+", 
                TagBox[
                  RowBox[{"1", "+", 
                    TagBox[
                      RowBox[{"1", "+", 
                        TagBox[
                          RowBox[{"1", "+", 
                            TagBox[\(1 + 1\),
                              DisplayForm]}],
                          DisplayForm]}],
                      DisplayForm]}],
                  DisplayForm]}],
              DisplayForm]},
          {
            TagBox[
              RowBox[{"1", "+", 
                TagBox[
                  RowBox[{"1", "+", 
                    TagBox[\(1 + 3\),
                      DisplayForm]}],
                  DisplayForm]}],
              DisplayForm], 
            TagBox[
              RowBox[{"1", "+", 
                TagBox[
                  RowBox[{"1", "+", 
                    TagBox[\(1 + 3\),
                      DisplayForm]}],
                  DisplayForm]}],
              DisplayForm], 
            TagBox[
              RowBox[{"1", "+", 
                TagBox[
                  RowBox[{"1", "+", 
                    TagBox[
                      RowBox[{"1", "+", 
                        TagBox[\(1 + 2\),
                          DisplayForm]}],
                      DisplayForm]}],
                  DisplayForm]}],
              DisplayForm]},
          {
            TagBox[
              RowBox[{"1", "+", 
                TagBox[\(2 + 3\),
                  DisplayForm]}],
              DisplayForm], 
            TagBox[
              RowBox[{"1", "+", 
                TagBox[
                  RowBox[{"1", "+", 
                    TagBox[
                      RowBox[{"1", "+", 
                        TagBox[\(1 + 2\),
                          DisplayForm]}],
                      DisplayForm]}],
                  DisplayForm]}],
              DisplayForm], 
            TagBox[
              RowBox[{"1", "+", 
                TagBox[
                  RowBox[{"1", "+", 
                    TagBox[
                      RowBox[{"1", "+", 
                        TagBox[\(1 + 2\),
                          DisplayForm]}],
                      DisplayForm]}],
                  DisplayForm]}],
              DisplayForm]},
          {
            TagBox[
              RowBox[{"1", "+", 
                TagBox[
                  RowBox[{"1", "+", 
                    TagBox[\(1 + 3\),
                      DisplayForm]}],
                  DisplayForm]}],
              DisplayForm], 
            TagBox[
              RowBox[{"1", "+", 
                TagBox[
                  RowBox[{"1", "+", 
                    TagBox[\(1 + 3\),
                      DisplayForm]}],
                  DisplayForm]}],
              DisplayForm], 
            TagBox[
              RowBox[{"1", "+", 
                TagBox[
                  RowBox[{"1", "+", 
                    TagBox[\(1 + 3\),
                      DisplayForm]}],
                  DisplayForm]}],
              DisplayForm]},
          {
            TagBox[
              RowBox[{"1", "+", 
                TagBox[
                  RowBox[{"1", "+", 
                    TagBox[\(2 + 2\),
                      DisplayForm]}],
                  DisplayForm]}],
              DisplayForm], 
            TagBox[
              RowBox[{"1", "+", 
                TagBox[
                  RowBox[{"1", "+", 
                    TagBox[\(2 + 2\),
                      DisplayForm]}],
                  DisplayForm]}],
              DisplayForm], 
            TagBox[
              RowBox[{"1", "+", 
                TagBox[
                  RowBox[{"1", "+", 
                    TagBox[
                      RowBox[{"1", "+", 
                        TagBox[\(1 + 2\),
                          DisplayForm]}],
                      DisplayForm]}],
                  DisplayForm]}],
              DisplayForm]},
          {
            TagBox[
              RowBox[{"1", "+", 
                TagBox[
                  RowBox[{"1", "+", 
                    TagBox[\(1 + 3\),
                      DisplayForm]}],
                  DisplayForm]}],
              DisplayForm], 
            TagBox[
              RowBox[{"1", "+", 
                TagBox[
                  RowBox[{"1", "+", 
                    TagBox[\(1 + 3\),
                      DisplayForm]}],
                  DisplayForm]}],
              DisplayForm], 
            TagBox[
              RowBox[{"1", "+", 
                TagBox[
                  RowBox[{"1", "+", 
                    TagBox[\(2 + 2\),
                      DisplayForm]}],
                  DisplayForm]}],
              DisplayForm]},
          {
            TagBox[
              RowBox[{"1", "+", 
                TagBox[\(2 + 3\),
                  DisplayForm]}],
              DisplayForm], 
            TagBox[
              RowBox[{"1", "+", 
                TagBox[
                  RowBox[{"1", "+", 
                    TagBox[\(2 + 2\),
                      DisplayForm]}],
                  DisplayForm]}],
              DisplayForm], 
            TagBox[
              RowBox[{"1", "+", 
                TagBox[
                  RowBox[{"1", "+", 
                    TagBox[
                      RowBox[{"1", "+", 
                        TagBox[\(1 + 2\),
                          DisplayForm]}],
                      DisplayForm]}],
                  DisplayForm]}],
              DisplayForm]},
          {
            TagBox[
              RowBox[{"1", "+", 
                TagBox[\(2 + 3\),
                  DisplayForm]}],
              DisplayForm], 
            TagBox[
              RowBox[{"1", "+", 
                TagBox[
                  RowBox[{"1", "+", 
                    TagBox[\(1 + 3\),
                      DisplayForm]}],
                  DisplayForm]}],
              DisplayForm], 
            TagBox[
              RowBox[{"1", "+", 
                TagBox[
                  RowBox[{"1", "+", 
                    TagBox[\(1 + 3\),
                      DisplayForm]}],
                  DisplayForm]}],
              DisplayForm]},
          {
            TagBox[
              RowBox[{"1", "+", 
                TagBox[
                  RowBox[{"1", "+", 
                    TagBox[\(2 + 2\),
                      DisplayForm]}],
                  DisplayForm]}],
              DisplayForm], 
            TagBox[
              RowBox[{"1", "+", 
                TagBox[
                  RowBox[{"1", "+", 
                    TagBox[\(2 + 2\),
                      DisplayForm]}],
                  DisplayForm]}],
              DisplayForm], 
            TagBox[
              RowBox[{"1", "+", 
                TagBox[
                  RowBox[{"1", "+", 
                    TagBox[\(2 + 2\),
                      DisplayForm]}],
                  DisplayForm]}],
              DisplayForm]},
          {
            TagBox[
              RowBox[{"1", "+", 
                TagBox[\(2 + 3\),
                  DisplayForm]}],
              DisplayForm], 
            TagBox[
              RowBox[{"1", "+", 
                TagBox[
                  RowBox[{"1", "+", 
                    TagBox[\(1 + 3\),
                      DisplayForm]}],
                  DisplayForm]}],
              DisplayForm], 
            TagBox[
              RowBox[{"1", "+", 
                TagBox[
                  RowBox[{"1", "+", 
                    TagBox[\(2 + 2\),
                      DisplayForm]}],
                  DisplayForm]}],
              DisplayForm]},
          {
            TagBox[\(3 + 3\),
              DisplayForm], 
            TagBox[
              RowBox[{"1", "+", 
                TagBox[
                  RowBox[{"1", "+", 
                    TagBox[\(1 + 3\),
                      DisplayForm]}],
                  DisplayForm]}],
              DisplayForm], 
            TagBox[
              RowBox[{"1", "+", 
                TagBox[
                  RowBox[{"1", "+", 
                    TagBox[\(1 + 3\),
                      DisplayForm]}],
                  DisplayForm]}],
              DisplayForm]},
          {
            TagBox[
              RowBox[{"1", "+", 
                TagBox[\(2 + 3\),
                  DisplayForm]}],
              DisplayForm], 
            TagBox[
              RowBox[{"1", "+", 
                TagBox[
                  RowBox[{"1", "+", 
                    TagBox[\(2 + 2\),
                      DisplayForm]}],
                  DisplayForm]}],
              DisplayForm], 
            TagBox[
              RowBox[{"1", "+", 
                TagBox[
                  RowBox[{"1", "+", 
                    TagBox[\(2 + 2\),
                      DisplayForm]}],
                  DisplayForm]}],
              DisplayForm]},
          {
            TagBox[\(3 + 3\),
              DisplayForm], 
            TagBox[
              RowBox[{"1", "+", 
                TagBox[
                  RowBox[{"1", "+", 
                    TagBox[\(1 + 3\),
                      DisplayForm]}],
                  DisplayForm]}],
              DisplayForm], 
            TagBox[
              RowBox[{"1", "+", 
                TagBox[
                  RowBox[{"1", "+", 
                    TagBox[\(2 + 2\),
                      DisplayForm]}],
                  DisplayForm]}],
              DisplayForm]},
          {
            TagBox[
              RowBox[{"2", "+", 
                TagBox[\(2 + 2\),
                  DisplayForm]}],
              DisplayForm], 
            TagBox[
              RowBox[{"1", "+", 
                TagBox[
                  RowBox[{"1", "+", 
                    TagBox[\(2 + 2\),
                      DisplayForm]}],
                  DisplayForm]}],
              DisplayForm], 
            TagBox[
              RowBox[{"1", "+", 
                TagBox[
                  RowBox[{"1", "+", 
                    TagBox[\(2 + 2\),
                      DisplayForm]}],
                  DisplayForm]}],
              DisplayForm]},
          {
            TagBox[
              RowBox[{"1", "+", 
                TagBox[\(2 + 3\),
                  DisplayForm]}],
              DisplayForm], 
            TagBox[
              RowBox[{"1", "+", 
                TagBox[\(2 + 3\),
                  DisplayForm]}],
              DisplayForm], 
            TagBox[
              RowBox[{"1", "+", 
                TagBox[
                  RowBox[{"1", "+", 
                    TagBox[\(2 + 2\),
                      DisplayForm]}],
                  DisplayForm]}],
              DisplayForm]},
          {
            TagBox[\(3 + 3\),
              DisplayForm], 
            TagBox[
              RowBox[{"1", "+", 
                TagBox[\(2 + 3\),
                  DisplayForm]}],
              DisplayForm], 
            TagBox[
              RowBox[{"1", "+", 
                TagBox[
                  RowBox[{"1", "+", 
                    TagBox[\(1 + 3\),
                      DisplayForm]}],
                  DisplayForm]}],
              DisplayForm]},
          {
            TagBox[
              RowBox[{"1", "+", 
                TagBox[\(2 + 3\),
                  DisplayForm]}],
              DisplayForm], 
            TagBox[
              RowBox[{"2", "+", 
                TagBox[\(2 + 2\),
                  DisplayForm]}],
              DisplayForm], 
            TagBox[
              RowBox[{"1", "+", 
                TagBox[
                  RowBox[{"1", "+", 
                    TagBox[\(2 + 2\),
                      DisplayForm]}],
                  DisplayForm]}],
              DisplayForm]},
          {
            TagBox[
              RowBox[{"1", "+", 
                TagBox[\(2 + 3\),
                  DisplayForm]}],
              DisplayForm], 
            TagBox[
              RowBox[{"1", "+", 
                TagBox[\(2 + 3\),
                  DisplayForm]}],
              DisplayForm], 
            TagBox[
              RowBox[{"1", "+", 
                TagBox[\(2 + 3\),
                  DisplayForm]}],
              DisplayForm]},
          {
            TagBox[\(3 + 3\),
              DisplayForm], 
            TagBox[\(3 + 3\),
              DisplayForm], 
            TagBox[
              RowBox[{"1", "+", 
                TagBox[
                  RowBox[{"1", "+", 
                    TagBox[\(1 + 3\),
                      DisplayForm]}],
                  DisplayForm]}],
              DisplayForm]},
          {
            TagBox[
              RowBox[{"2", "+", 
                TagBox[\(2 + 2\),
                  DisplayForm]}],
              DisplayForm], 
            TagBox[
              RowBox[{"2", "+", 
                TagBox[\(2 + 2\),
                  DisplayForm]}],
              DisplayForm], 
            TagBox[
              RowBox[{"1", "+", 
                TagBox[
                  RowBox[{"1", "+", 
                    TagBox[\(2 + 2\),
                      DisplayForm]}],
                  DisplayForm]}],
              DisplayForm]},
          {
            TagBox[
              RowBox[{"1", "+", 
                TagBox[\(2 + 3\),
                  DisplayForm]}],
              DisplayForm], 
            TagBox[
              RowBox[{"1", "+", 
                TagBox[\(2 + 3\),
                  DisplayForm]}],
              DisplayForm], 
            TagBox[
              RowBox[{"2", "+", 
                TagBox[\(2 + 2\),
                  DisplayForm]}],
              DisplayForm]},
          {
            TagBox[\(3 + 3\),
              DisplayForm], 
            TagBox[\(3 + 3\),
              DisplayForm], 
            TagBox[
              RowBox[{"1", "+", 
                TagBox[
                  RowBox[{"1", "+", 
                    TagBox[\(2 + 2\),
                      DisplayForm]}],
                  DisplayForm]}],
              DisplayForm]},
          {
            TagBox[
              RowBox[{"1", "+", 
                TagBox[\(2 + 3\),
                  DisplayForm]}],
              DisplayForm], 
            TagBox[
              RowBox[{"2", "+", 
                TagBox[\(2 + 2\),
                  DisplayForm]}],
              DisplayForm], 
            TagBox[
              RowBox[{"2", "+", 
                TagBox[\(2 + 2\),
                  DisplayForm]}],
              DisplayForm]},
          {
            TagBox[\(3 + 3\),
              DisplayForm], 
            TagBox[
              RowBox[{"1", "+", 
                TagBox[\(2 + 3\),
                  DisplayForm]}],
              DisplayForm], 
            TagBox[
              RowBox[{"2", "+", 
                TagBox[\(2 + 2\),
                  DisplayForm]}],
              DisplayForm]},
          {
            TagBox[\(3 + 3\),
              DisplayForm], 
            TagBox[\(3 + 3\),
              DisplayForm], 
            TagBox[
              RowBox[{"1", "+", 
                TagBox[\(2 + 3\),
                  DisplayForm]}],
              DisplayForm]},
          {
            TagBox[
              RowBox[{"2", "+", 
                TagBox[\(2 + 2\),
                  DisplayForm]}],
              DisplayForm], 
            TagBox[
              RowBox[{"2", "+", 
                TagBox[\(2 + 2\),
                  DisplayForm]}],
              DisplayForm], 
            TagBox[
              RowBox[{"2", "+", 
                TagBox[\(2 + 2\),
                  DisplayForm]}],
              DisplayForm]},
          {
            TagBox[\(3 + 3\),
              DisplayForm], 
            TagBox[
              RowBox[{"2", "+", 
                TagBox[\(2 + 2\),
                  DisplayForm]}],
              DisplayForm], 
            TagBox[
              RowBox[{"2", "+", 
                TagBox[\(2 + 2\),
                  DisplayForm]}],
              DisplayForm]},
          {
            TagBox[\(3 + 3\),
              DisplayForm], 
            TagBox[\(3 + 3\),
              DisplayForm], 
            TagBox[
              RowBox[{"2", "+", 
                TagBox[\(2 + 2\),
                  DisplayForm]}],
              DisplayForm]},
          {
            TagBox[\(3 + 3\),
              DisplayForm], 
            TagBox[\(3 + 3\),
              DisplayForm], 
            TagBox[\(3 + 3\),
              DisplayForm]}
          },
        RowSpacings->1,
        ColumnSpacings->3,
        RowAlignments->Baseline,
        ColumnAlignments->{Left}],
      (TableForm[ #]&)]], "Output"]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{

Cell["COMPOSITIONS", "Subsection"],

Cell["Compositions are partitions in which the order is important", "Text"],

Cell[BoxData[{
    \(compositions[0] := {{}}\), "\n", 
    \(compositions[n_] := \(compositions[n] = 
        Module[{i}, \n\t\tFlatten[
            Table[\((Join[{i}, #1] &)\) /@ \ compositions[n - i], {i, n}], 
            1]]\)\)}], "Input",
  PageWidth->Infinity],

Cell[CellGroupData[{

Cell[BoxData[
    \(asSum\  /@ \ compositions[5]\  // \ TableForm\)], "Input",
  PageWidth->Infinity],

Cell[BoxData[
    InterpretationBox[GridBox[{
          {
            TagBox[
              RowBox[{"1", "+", 
                TagBox[
                  RowBox[{"1", "+", 
                    TagBox[
                      RowBox[{"1", "+", 
                        TagBox[\(1 + 1\),
                          DisplayForm]}],
                      DisplayForm]}],
                  DisplayForm]}],
              DisplayForm]},
          {
            TagBox[
              RowBox[{"1", "+", 
                TagBox[
                  RowBox[{"1", "+", 
                    TagBox[\(1 + 2\),
                      DisplayForm]}],
                  DisplayForm]}],
              DisplayForm]},
          {
            TagBox[
              RowBox[{"1", "+", 
                TagBox[
                  RowBox[{"1", "+", 
                    TagBox[\(2 + 1\),
                      DisplayForm]}],
                  DisplayForm]}],
              DisplayForm]},
          {
            TagBox[
              RowBox[{"1", "+", 
                TagBox[\(1 + 3\),
                  DisplayForm]}],
              DisplayForm]},
          {
            TagBox[
              RowBox[{"1", "+", 
                TagBox[
                  RowBox[{"2", "+", 
                    TagBox[\(1 + 1\),
                      DisplayForm]}],
                  DisplayForm]}],
              DisplayForm]},
          {
            TagBox[
              RowBox[{"1", "+", 
                TagBox[\(2 + 2\),
                  DisplayForm]}],
              DisplayForm]},
          {
            TagBox[
              RowBox[{"1", "+", 
                TagBox[\(3 + 1\),
                  DisplayForm]}],
              DisplayForm]},
          {
            TagBox[\(1 + 4\),
              DisplayForm]},
          {
            TagBox[
              RowBox[{"2", "+", 
                TagBox[
                  RowBox[{"1", "+", 
                    TagBox[\(1 + 1\),
                      DisplayForm]}],
                  DisplayForm]}],
              DisplayForm]},
          {
            TagBox[
              RowBox[{"2", "+", 
                TagBox[\(1 + 2\),
                  DisplayForm]}],
              DisplayForm]},
          {
            TagBox[
              RowBox[{"2", "+", 
                TagBox[\(2 + 1\),
                  DisplayForm]}],
              DisplayForm]},
          {
            TagBox[\(2 + 3\),
              DisplayForm]},
          {
            TagBox[
              RowBox[{"3", "+", 
                TagBox[\(1 + 1\),
                  DisplayForm]}],
              DisplayForm]},
          {
            TagBox[\(3 + 2\),
              DisplayForm]},
          {
            TagBox[\(4 + 1\),
              DisplayForm]},
          {"\<\"5\"\>"}
          },
        RowSpacings->1,
        ColumnSpacings->3,
        RowAlignments->Baseline,
        ColumnAlignments->{Left}],
      TableForm[ {
        DisplayForm[ 
          RowBox[ {"1", "+", 
            DisplayForm[ 
              RowBox[ {"1", "+", 
                DisplayForm[ 
                  RowBox[ {"1", "+", 
                    DisplayForm[ 
                      RowBox[ {"1", "+", "1"}]]}]]}]]}]], 
        DisplayForm[ 
          RowBox[ {"1", "+", 
            DisplayForm[ 
              RowBox[ {"1", "+", 
                DisplayForm[ 
                  RowBox[ {"1", "+", "2"}]]}]]}]], 
        DisplayForm[ 
          RowBox[ {"1", "+", 
            DisplayForm[ 
              RowBox[ {"1", "+", 
                DisplayForm[ 
                  RowBox[ {"2", "+", "1"}]]}]]}]], 
        DisplayForm[ 
          RowBox[ {"1", "+", 
            DisplayForm[ 
              RowBox[ {"1", "+", "3"}]]}]], 
        DisplayForm[ 
          RowBox[ {"1", "+", 
            DisplayForm[ 
              RowBox[ {"2", "+", 
                DisplayForm[ 
                  RowBox[ {"1", "+", "1"}]]}]]}]], 
        DisplayForm[ 
          RowBox[ {"1", "+", 
            DisplayForm[ 
              RowBox[ {"2", "+", "2"}]]}]], 
        DisplayForm[ 
          RowBox[ {"1", "+", 
            DisplayForm[ 
              RowBox[ {"3", "+", "1"}]]}]], 
        DisplayForm[ 
          RowBox[ {"1", "+", "4"}]], 
        DisplayForm[ 
          RowBox[ {"2", "+", 
            DisplayForm[ 
              RowBox[ {"1", "+", 
                DisplayForm[ 
                  RowBox[ {"1", "+", "1"}]]}]]}]], 
        DisplayForm[ 
          RowBox[ {"2", "+", 
            DisplayForm[ 
              RowBox[ {"1", "+", "2"}]]}]], 
        DisplayForm[ 
          RowBox[ {"2", "+", 
            DisplayForm[ 
              RowBox[ {"2", "+", "1"}]]}]], 
        DisplayForm[ 
          RowBox[ {"2", "+", "3"}]], 
        DisplayForm[ 
          RowBox[ {"3", "+", 
            DisplayForm[ 
              RowBox[ {"1", "+", "1"}]]}]], 
        DisplayForm[ 
          RowBox[ {"3", "+", "2"}]], 
        DisplayForm[ 
          RowBox[ {"4", "+", "1"}]], "5"}]]], "Output"]
}, Open  ]],

Cell[TextData[{
  "In general, the number of compositions of n with m parts is equal to ",
  Cell[BoxData[
      RowBox[{"(", "\[NegativeThinSpace]", GridBox[{
            {\(n - 1\)},
            {\(m - 1\)}
            }], "\[NegativeThinSpace]", ")"}]]],
  ". More generally, the number of compositions of n into exactly m parts \
each one at least k is equal to ",
  Cell[BoxData[
      RowBox[{"(", "\[NegativeThinSpace]", GridBox[{
            {\(n - \((k - 1)\) m - 1\)},
            {\(m - 1\)}
            }], "\[NegativeThinSpace]", ")"}]]],
  ". For instance, there are ",
  Cell[BoxData[
      RowBox[{
        RowBox[{"(", "\[NegativeThinSpace]", GridBox[{
              {\(5 - 1\)},
              {\(3 - 1\)}
              }], "\[NegativeThinSpace]", ")"}], "=", "6"}]]],
  " compositions of 5 into three parts and ",
  Cell[BoxData[
      RowBox[{
        RowBox[{"(", "\[NegativeThinSpace]", GridBox[{
              {\(5 - \((2 - 1)\) 2 - 1\)},
              {\(2 - 1\)}
              }], "\[NegativeThinSpace]", ")"}], "=", "2"}]]],
  " compositions of 5 into two parts each one at least equal to 2 as shown in \
the previous output. Also, there are ",
  Cell[BoxData[
      \(2\^\(n - 1\)\)]],
  " unrestricted compositions of n."
}], "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(Table[Length[compositions[n]], {n, 10}]\)], "Input"],

Cell[BoxData[
    \({1, 2, 4, 8, 16, 32, 64, 128, 256, 512}\)], "Output"]
}, Open  ]],

Cell["\<\
There is a one-to-one correspondence between subsets, binary numbers, \
positive integer numbers (their decimal equivalents) and compositions.\
\>", "Text"],

Cell[BoxData[{
    \(subSets[0] := {{}}\), "\n", 
    \(subSets[n_] := 
      Module[{s = subSets[n - 1]}, \[IndentingNewLine]Join[s, 
          Map[Append[#, n] &, 
            s]]]\[IndentingNewLine]\), "\[IndentingNewLine]", 
    \(binary[n_, s_] := 
      Module[{bn = Table[0, {n}]}, \[IndentingNewLine]bn\[LeftDoubleBracket]
            s\[RightDoubleBracket] = 
          1; \[IndentingNewLine]bn]\[IndentingNewLine]\), \
"\[IndentingNewLine]", 
    \(dec[{}] := 0\), "\n", 
    \(dec[{x___, 
          t_}] := \(\(2\ dec[{x}]\)\(+\)\(t\)\(\[IndentingNewLine]\)\)\), "\
\[IndentingNewLine]", 
    \(composit[u_] := \ 
      Module[{v}, \[IndentingNewLine]v = 
          Append[u, 
              0]\  //. \ \ {{a___, 1, 0, c___} \[Rule] {a, 2, "\<+\>", 
                  c}, \[IndentingNewLine]{a___, 1, b_, "\<+\>", 
                  c___} \[Rule] {a, b + 1, "\<+\>", 
                  c}, \[IndentingNewLine]{a___, 0, c___} \[Rule] {a, 
                  1, "\<+\>", c}}; \[IndentingNewLine]StringJoin[
          ToString\  /@ \ Drop[v, \(-1\)]]]\)}], "Input"],

Cell[CellGroupData[{

Cell[BoxData[
    \(Map[{#, u = binary[4, #]; \ StringJoin[ToString\  /@ \ u], dec[u], 
            composit[u]} &, subSets[4]]\  // \ MatrixForm\)], "Input"],

Cell[BoxData[
    TagBox[
      RowBox[{"(", "\[NoBreak]", GridBox[{
            {\({}\), "\<\"0000\"\>", "0", "\<\"1+1+1+1+1\"\>"},
            {\({1}\), "\<\"1000\"\>", "8", "\<\"2+1+1+1\"\>"},
            {\({2}\), "\<\"0100\"\>", "4", "\<\"1+2+1+1\"\>"},
            {\({1, 2}\), "\<\"1100\"\>", "12", "\<\"3+1+1\"\>"},
            {\({3}\), "\<\"0010\"\>", "2", "\<\"1+1+2+1\"\>"},
            {\({1, 3}\), "\<\"1010\"\>", "10", "\<\"2+2+1\"\>"},
            {\({2, 3}\), "\<\"0110\"\>", "6", "\<\"1+3+1\"\>"},
            {\({1, 2, 3}\), "\<\"1110\"\>", "14", "\<\"4+1\"\>"},
            {\({4}\), "\<\"0001\"\>", "1", "\<\"1+1+1+2\"\>"},
            {\({1, 4}\), "\<\"1001\"\>", "9", "\<\"2+1+2\"\>"},
            {\({2, 4}\), "\<\"0101\"\>", "5", "\<\"1+2+2\"\>"},
            {\({1, 2, 4}\), "\<\"1101\"\>", "13", "\<\"3+2\"\>"},
            {\({3, 4}\), "\<\"0011\"\>", "3", "\<\"1+1+3\"\>"},
            {\({1, 3, 4}\), "\<\"1011\"\>", "11", "\<\"2+3\"\>"},
            {\({2, 3, 4}\), "\<\"0111\"\>", "7", "\<\"1+4\"\>"},
            {\({1, 2, 3, 4}\), "\<\"1111\"\>", "15", "\<\"5\"\>"}
            }], "\[NoBreak]", ")"}],
      (MatrixForm[ #]&)]], "Output"]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{

Cell["GOLDBACH'S CONJECTURE", "Subsection"],

Cell["\<\
Goldbach's conjecture claims that every odd number greater than 7 is equal to \
the sum of three primes. Euler modified it to: every even number greater than \
3 is equal to the sum of two primes. The latter implies the former but not \
vice-versa.\
\>", "Text"],

Cell[BoxData[
    \(Goldbach[n_] := 
      Module[{p, a}, \[IndentingNewLine]p = 
          Select[Range[2, n], PrimeQ]; \[IndentingNewLine]a = 
          First[Select[n - p, PrimeQ, 1]]; \[IndentingNewLine]{n - a, 
          a}]\)], "Input"],

Cell[CellGroupData[{

Cell[BoxData[
    \(Table[{n, asSum[Goldbach[n]]}, {n, 4, 50, 2}] // TableForm\)], "Input"],

Cell[BoxData[
    TagBox[GridBox[{
          {"4", 
            TagBox[\(2 + 2\),
              DisplayForm]},
          {"6", 
            TagBox[\(3 + 3\),
              DisplayForm]},
          {"8", 
            TagBox[\(3 + 5\),
              DisplayForm]},
          {"10", 
            TagBox[\(3 + 7\),
              DisplayForm]},
          {"12", 
            TagBox[\(5 + 7\),
              DisplayForm]},
          {"14", 
            TagBox[\(3 + 11\),
              DisplayForm]},
          {"16", 
            TagBox[\(3 + 13\),
              DisplayForm]},
          {"18", 
            TagBox[\(5 + 13\),
              DisplayForm]},
          {"20", 
            TagBox[\(3 + 17\),
              DisplayForm]},
          {"22", 
            TagBox[\(3 + 19\),
              DisplayForm]},
          {"24", 
            TagBox[\(5 + 19\),
              DisplayForm]},
          {"26", 
            TagBox[\(3 + 23\),
              DisplayForm]},
          {"28", 
            TagBox[\(5 + 23\),
              DisplayForm]},
          {"30", 
            TagBox[\(7 + 23\),
              DisplayForm]},
          {"32", 
            TagBox[\(3 + 29\),
              DisplayForm]},
          {"34", 
            TagBox[\(3 + 31\),
              DisplayForm]},
          {"36", 
            TagBox[\(5 + 31\),
              DisplayForm]},
          {"38", 
            TagBox[\(7 + 31\),
              DisplayForm]},
          {"40", 
            TagBox[\(3 + 37\),
              DisplayForm]},
          {"42", 
            TagBox[\(5 + 37\),
              DisplayForm]},
          {"44", 
            TagBox[\(3 + 41\),
              DisplayForm]},
          {"46", 
            TagBox[\(3 + 43\),
              DisplayForm]},
          {"48", 
            TagBox[\(5 + 43\),
              DisplayForm]},
          {"50", 
            TagBox[\(3 + 47\),
              DisplayForm]}
          },
        RowSpacings->1,
        ColumnSpacings->3,
        RowAlignments->Baseline,
        ColumnAlignments->{Left}],
      (TableForm[ #]&)]], "Output"]
}, Open  ]]
}, Closed]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Sums of Squares", "Section"],

Cell[CellGroupData[{

Cell["SUMS OF TWO SQUARES", "Subsection"],

Cell[TextData[{
  "If N is the sum of two unequal positive square numbers, then every power \
of N is the sum of two squares. For instance, if N=",
  Cell[BoxData[
      \(TraditionalForm\`n\^2\)]],
  "+",
  Cell[BoxData[
      \(TraditionalForm\`m\^2\)]],
  " then ",
  Cell[BoxData[
      \(TraditionalForm\`N\^2\)]],
  "=",
  Cell[BoxData[
      FormBox[
        SuperscriptBox[
          RowBox[{"(", 
            RowBox[{
              FormBox[\(n\^2\),
                "TraditionalForm"], "-", 
              FormBox[\(m\^2\),
                "TraditionalForm"]}], ")"}], "2"], TraditionalForm]]],
  "+",
  Cell[BoxData[
      \(TraditionalForm\`\((2  mn)\)\^2\)]],
  ".\n\nIf N exceeds the sum of two unequal positive squares by k>0, then \
every power of N is the sum of k+2 positive squares.\n\nTheorem (Fermat). \
Write the canonical factorization of n in the form"
}], "Text"],

Cell[BoxData[
    RowBox[{"n", "=", 
      RowBox[{
        FormBox[\(2\^\[Alpha]\),
          "TraditionalForm"], " ", 
        FormBox[\(\[Product]\+\(p \[Congruent] 1\ \((mod\ 4)\)\)p\^\[Beta]\),
          "TraditionalForm"], " ", 
        FormBox[\(\[Product]\+\(q\  \[Congruent] 3\ \((mod\ 4)\)\)q\^\[Gamma]\
\),
          "TraditionalForm"]}]}]], "Text",
  TextAlignment->Center,
  TextJustification->0],

Cell["\<\
The n can be expressed as a sum of two squares of integers iff all exponents \
\[Gamma] are even.

If p is an odd prime then p is representable as a sum of two squares if and \
only if p\[Congruent] 1 (mod 4). The set of positive integers which are sums \
of two squares is closed under multiplication. 
\
\>", "Text"],

Cell[BoxData[
    \(sum2Squares[n_] := 
      Module[{f = FactorInteger[n]}, \[IndentingNewLine]And\  @@ \ 
          EvenQ[Last\  /@ \ 
              Select[f, \((Mod[First[#], 4] == 3)\) &]]]\)], "Input",
  InitializationCell->True],

Cell[CellGroupData[{

Cell[BoxData[
    \(Select[Range[100], sum2Squares]\)], "Input"],

Cell[BoxData[
    \({1, 2, 4, 5, 8, 9, 10, 13, 16, 17, 18, 20, 25, 26, 29, 32, 34, 36, 37, 
      40, 41, 45, 49, 50, 52, 53, 58, 61, 64, 65, 68, 72, 73, 74, 80, 81, 82, 
      85, 89, 90, 97, 98, 100}\)], "Output"]
}, Open  ]],

Cell[BoxData[
    \(sumTwoSquares[n_] := 
      Module[{t, i, j}, \[IndentingNewLine]t = 
          Table[\[IndentingNewLine]j = \@\(n - i\^2\); \[IndentingNewLine]If[
              IntegerQ[
                j], {{i, 
                  j}, {i, \(-j\)}}, {}], {i, \[LeftCeiling]\(-\@n\)\
\[RightCeiling], \[LeftFloor]\@n\[RightFloor]}]; \[IndentingNewLine]Union[
          Sort\  /@ \ Partition[Flatten[t], 2]]]\)], "Input"],

Cell[CellGroupData[{

Cell[BoxData[
    \(Do[Print[n, "\<  \>", \(asSum[#, 2] &\)\  /@ \ sumTwoSquares[n]], {n, 
        10}]\)], "Input"],

Cell[BoxData[
    InterpretationBox[
      RowBox[{"1", "\[InvisibleSpace]", "\<\"  \"\>", "\[InvisibleSpace]", 
        RowBox[{"{", 
          RowBox[{
            TagBox[\("-1"\^2 + "0"\^2\),
              DisplayForm], ",", 
            TagBox[\("0"\^2 + "1"\^2\),
              DisplayForm]}], "}"}]}],
      SequenceForm[ 1, "  ", {
        DisplayForm[ 
          RowBox[ {
            Power[ "-1", 2], "+", 
            Power[ "0", 2]}]], 
        DisplayForm[ 
          RowBox[ {
            Power[ "0", 2], "+", 
            Power[ "1", 2]}]]}],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      RowBox[{"2", "\[InvisibleSpace]", "\<\"  \"\>", "\[InvisibleSpace]", 
        RowBox[{"{", 
          RowBox[{
            TagBox[\("-1"\^2 + "-1"\^2\),
              DisplayForm], ",", 
            TagBox[\("-1"\^2 + "1"\^2\),
              DisplayForm], ",", 
            TagBox[\("1"\^2 + "1"\^2\),
              DisplayForm]}], "}"}]}],
      SequenceForm[ 2, "  ", {
        DisplayForm[ 
          RowBox[ {
            Power[ "-1", 2], "+", 
            Power[ "-1", 2]}]], 
        DisplayForm[ 
          RowBox[ {
            Power[ "-1", 2], "+", 
            Power[ "1", 2]}]], 
        DisplayForm[ 
          RowBox[ {
            Power[ "1", 2], "+", 
            Power[ "1", 2]}]]}],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[\(3\[InvisibleSpace]"  "\[InvisibleSpace]{}\),
      SequenceForm[ 3, "  ", {}],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      RowBox[{"4", "\[InvisibleSpace]", "\<\"  \"\>", "\[InvisibleSpace]", 
        RowBox[{"{", 
          RowBox[{
            TagBox[\("-2"\^2 + "0"\^2\),
              DisplayForm], ",", 
            TagBox[\("0"\^2 + "2"\^2\),
              DisplayForm]}], "}"}]}],
      SequenceForm[ 4, "  ", {
        DisplayForm[ 
          RowBox[ {
            Power[ "-2", 2], "+", 
            Power[ "0", 2]}]], 
        DisplayForm[ 
          RowBox[ {
            Power[ "0", 2], "+", 
            Power[ "2", 2]}]]}],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      RowBox[{"5", "\[InvisibleSpace]", "\<\"  \"\>", "\[InvisibleSpace]", 
        RowBox[{"{", 
          RowBox[{
            TagBox[\("-2"\^2 + "-1"\^2\),
              DisplayForm], ",", 
            TagBox[\("-2"\^2 + "1"\^2\),
              DisplayForm], ",", 
            TagBox[\("-1"\^2 + "2"\^2\),
              DisplayForm], ",", 
            TagBox[\("1"\^2 + "2"\^2\),
              DisplayForm]}], "}"}]}],
      SequenceForm[ 5, "  ", {
        DisplayForm[ 
          RowBox[ {
            Power[ "-2", 2], "+", 
            Power[ "-1", 2]}]], 
        DisplayForm[ 
          RowBox[ {
            Power[ "-2", 2], "+", 
            Power[ "1", 2]}]], 
        DisplayForm[ 
          RowBox[ {
            Power[ "-1", 2], "+", 
            Power[ "2", 2]}]], 
        DisplayForm[ 
          RowBox[ {
            Power[ "1", 2], "+", 
            Power[ "2", 2]}]]}],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[\(6\[InvisibleSpace]"  "\[InvisibleSpace]{}\),
      SequenceForm[ 6, "  ", {}],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[\(7\[InvisibleSpace]"  "\[InvisibleSpace]{}\),
      SequenceForm[ 7, "  ", {}],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      RowBox[{"8", "\[InvisibleSpace]", "\<\"  \"\>", "\[InvisibleSpace]", 
        RowBox[{"{", 
          RowBox[{
            TagBox[\("-2"\^2 + "-2"\^2\),
              DisplayForm], ",", 
            TagBox[\("-2"\^2 + "2"\^2\),
              DisplayForm], ",", 
            TagBox[\("2"\^2 + "2"\^2\),
              DisplayForm]}], "}"}]}],
      SequenceForm[ 8, "  ", {
        DisplayForm[ 
          RowBox[ {
            Power[ "-2", 2], "+", 
            Power[ "-2", 2]}]], 
        DisplayForm[ 
          RowBox[ {
            Power[ "-2", 2], "+", 
            Power[ "2", 2]}]], 
        DisplayForm[ 
          RowBox[ {
            Power[ "2", 2], "+", 
            Power[ "2", 2]}]]}],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      RowBox[{"9", "\[InvisibleSpace]", "\<\"  \"\>", "\[InvisibleSpace]", 
        RowBox[{"{", 
          RowBox[{
            TagBox[\("-3"\^2 + "0"\^2\),
              DisplayForm], ",", 
            TagBox[\("0"\^2 + "3"\^2\),
              DisplayForm]}], "}"}]}],
      SequenceForm[ 9, "  ", {
        DisplayForm[ 
          RowBox[ {
            Power[ "-3", 2], "+", 
            Power[ "0", 2]}]], 
        DisplayForm[ 
          RowBox[ {
            Power[ "0", 2], "+", 
            Power[ "3", 2]}]]}],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      RowBox[{"10", "\[InvisibleSpace]", "\<\"  \"\>", "\[InvisibleSpace]", 
        RowBox[{"{", 
          RowBox[{
            TagBox[\("-3"\^2 + "-1"\^2\),
              DisplayForm], ",", 
            TagBox[\("-3"\^2 + "1"\^2\),
              DisplayForm], ",", 
            TagBox[\("-1"\^2 + "3"\^2\),
              DisplayForm], ",", 
            TagBox[\("1"\^2 + "3"\^2\),
              DisplayForm]}], "}"}]}],
      SequenceForm[ 10, "  ", {
        DisplayForm[ 
          RowBox[ {
            Power[ "-3", 2], "+", 
            Power[ "-1", 2]}]], 
        DisplayForm[ 
          RowBox[ {
            Power[ "-3", 2], "+", 
            Power[ "1", 2]}]], 
        DisplayForm[ 
          RowBox[ {
            Power[ "-1", 2], "+", 
            Power[ "3", 2]}]], 
        DisplayForm[ 
          RowBox[ {
            Power[ "1", 2], "+", 
            Power[ "3", 2]}]]}],
      Editable->False]], "Print"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(Table[Length[sumTwoSquares[n]], {n, 35}]\)], "Input"],

Cell[BoxData[
    \({2, 3, 0, 2, 4, 0, 0, 3, 2, 4, 0, 0, 4, 0, 0, 2, 4, 3, 0, 4, 0, 0, 0, 
      0, 6, 4, 0, 0, 4, 0, 0, 3, 0, 4, 0}\)], "Output"],

Cell[BoxData[
    \({4, 4, 0, 4, 8, 0, 0, 4, 4, 8, 0, 0, 8, 0, 0, 4, 8, 4, 0, 8, 0, 0, 0, 
      0, 12, 8, 0, 0, 8, 0}\)], "Output"]
}, Open  ]],

Cell[TextData[{
  "One surprising technique using the Gaussian integer divisors of n is the \
following (Solution by Stan Wagon Macalester College - see ",
  StyleBox["MathSource",
    FontSlant->"Italic"],
  " item # 0207-616)"
}], "Text"],

Cell[BoxData[
    \(\(\(SumSquares[
        n_]\)\(\ \)\(:=\)\(\ \)\(Union[\(Sort[{Re[#], \ Im[#]}]\  &\)\  /@ 
          Select[Divisors[n, \ GaussianIntegers \[Rule] True], \ 
            Abs[#]\^2\  == \ n\  &]]\)\(\ \)\)\)], "Input"],

Cell[CellGroupData[{

Cell[BoxData[
    \(Do[Print[n, "\<  \>", \(asSum[#, 2] &\)\  /@ \ SumSquares[n]], {n, 
        10}]\)], "Input"],

Cell[BoxData[
    InterpretationBox[
      RowBox[{"1", "\[InvisibleSpace]", "\<\"  \"\>", "\[InvisibleSpace]", 
        RowBox[{"{", 
          TagBox[\("0"\^2 + "1"\^2\),
            DisplayForm], "}"}]}],
      SequenceForm[ 1, "  ", {
        DisplayForm[ 
          RowBox[ {
            Power[ "0", 2], "+", 
            Power[ "1", 2]}]]}],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      RowBox[{"2", "\[InvisibleSpace]", "\<\"  \"\>", "\[InvisibleSpace]", 
        RowBox[{"{", 
          TagBox[\("1"\^2 + "1"\^2\),
            DisplayForm], "}"}]}],
      SequenceForm[ 2, "  ", {
        DisplayForm[ 
          RowBox[ {
            Power[ "1", 2], "+", 
            Power[ "1", 2]}]]}],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[\(3\[InvisibleSpace]"  "\[InvisibleSpace]{}\),
      SequenceForm[ 3, "  ", {}],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      RowBox[{"4", "\[InvisibleSpace]", "\<\"  \"\>", "\[InvisibleSpace]", 
        RowBox[{"{", 
          TagBox[\("0"\^2 + "2"\^2\),
            DisplayForm], "}"}]}],
      SequenceForm[ 4, "  ", {
        DisplayForm[ 
          RowBox[ {
            Power[ "0", 2], "+", 
            Power[ "2", 2]}]]}],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      RowBox[{"5", "\[InvisibleSpace]", "\<\"  \"\>", "\[InvisibleSpace]", 
        RowBox[{"{", 
          TagBox[\("1"\^2 + "2"\^2\),
            DisplayForm], "}"}]}],
      SequenceForm[ 5, "  ", {
        DisplayForm[ 
          RowBox[ {
            Power[ "1", 2], "+", 
            Power[ "2", 2]}]]}],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[\(6\[InvisibleSpace]"  "\[InvisibleSpace]{}\),
      SequenceForm[ 6, "  ", {}],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[\(7\[InvisibleSpace]"  "\[InvisibleSpace]{}\),
      SequenceForm[ 7, "  ", {}],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      RowBox[{"8", "\[InvisibleSpace]", "\<\"  \"\>", "\[InvisibleSpace]", 
        RowBox[{"{", 
          TagBox[\("2"\^2 + "2"\^2\),
            DisplayForm], "}"}]}],
      SequenceForm[ 8, "  ", {
        DisplayForm[ 
          RowBox[ {
            Power[ "2", 2], "+", 
            Power[ "2", 2]}]]}],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      RowBox[{"9", "\[InvisibleSpace]", "\<\"  \"\>", "\[InvisibleSpace]", 
        RowBox[{"{", 
          TagBox[\("0"\^2 + "3"\^2\),
            DisplayForm], "}"}]}],
      SequenceForm[ 9, "  ", {
        DisplayForm[ 
          RowBox[ {
            Power[ "0", 2], "+", 
            Power[ "3", 2]}]]}],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      RowBox[{"10", "\[InvisibleSpace]", "\<\"  \"\>", "\[InvisibleSpace]", 
        RowBox[{"{", 
          TagBox[\("1"\^2 + "3"\^2\),
            DisplayForm], "}"}]}],
      SequenceForm[ 10, "  ", {
        DisplayForm[ 
          RowBox[ {
            Power[ "1", 2], "+", 
            Power[ "3", 2]}]]}],
      Editable->False]], "Print"]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{

Cell["ON THE NUMBER OF REPRESENTATIONS", "Subsection"],

Cell[TextData[{
  "If ",
  Cell[BoxData[
      \(TraditionalForm\`\(d\_\(r, \ m\)\)(n)\)]],
  " denotes the number of divisors d of n with d \[Congruent] r (mod n), then \
\n\n(Jacobi, 1828). The number of representations of the number n \
\[GreaterEqual] 1 as the sum of two squares is "
}], "Text"],

Cell[TextData[{
  "4( ",
  Cell[BoxData[
      \(TraditionalForm\`\(d\_\(1, \ 4\)\)(n)\)]],
  " - ",
  Cell[BoxData[
      \(TraditionalForm\`d\_\(3, \ 4\)\)]],
  "(n) )"
}], "Text",
  TextAlignment->Center,
  TextJustification->0],

Cell[BoxData[
    \(d\_\(r_, m_\)[n_] := 
      Length[Select[Divisors[n], \((Mod[#, m] \[Equal] r)\) &]]\)], "Input"],

Cell[CellGroupData[{

Cell[BoxData[
    \(t = Table[4 \((d\_\(1, 4\)[n] - d\_\(3, 4\)[n])\), {n, 30}]\)], "Input"],

Cell[BoxData[
    \({4, 4, 0, 4, 8, 0, 0, 4, 4, 8, 0, 0, 8, 0, 0, 4, 8, 4, 0, 8, 0, 0, 0, 
      0, 12, 8, 0, 0, 8, 0}\)], "Output"]
}, Open  ]],

Cell["Note that negative squares are taken into account.", "Text"],

Cell[TextData[{
  Cell[BoxData[
      \(TraditionalForm\`lim\+\(n \[RightArrow]  \[Proportional] \)\)]],
  Cell[BoxData[
      \(TraditionalForm\`1\/n\)]],
  Cell[BoxData[
      \(TraditionalForm\`\[Sum]\+\(i = 0\)\%n t\ [i]\)]],
  " = \[Pi]"
}], "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(Plus\  @@ \ t\/30 // N\)], "Input"],

Cell[BoxData[
    \(3.2`\)], "Output"]
}, Open  ]],

Cell["\<\
t represents the number of lattice points that lie on a circle centered at \
the origin an integral radius.(Gauss)

(Dirichlet, 1840) The number of representations of n \[GreaterEqual] 1 as the \
sum of a square and twice a square is \
\>", "Text"],

Cell[TextData[{
  "2( ",
  Cell[BoxData[
      \(TraditionalForm\`\(d\_\(1, \ 8\)\)(n)\)]],
  " + ",
  Cell[BoxData[
      \(TraditionalForm\`d\_\(3, \ 8\)\)]],
  "(n) - ",
  Cell[BoxData[
      \(TraditionalForm\`\(d\_\(5, \ 8\)\)(n)\)]],
  " - ",
  Cell[BoxData[
      \(TraditionalForm\`d\_\(7, \ 8\)\)]],
  "(n) )"
}], "Text",
  TextAlignment->Center,
  TextJustification->0],

Cell[CellGroupData[{

Cell[BoxData[{
    \(\(n = 9;\)\), "\[IndentingNewLine]", 
    \(\(u = 
        Map[{{#, \@\(n - 2  #\^2\)}, {#, \(-\@\(n - 2  #\^2\)\)}} &, 
          Select[Range[\[LeftCeiling]\(-n\)\/2\[RightCeiling], n\/2], 
            IntegerQ[\@\(n - 2  #\^2\)] &]];\)\), "\[IndentingNewLine]", 
    \(\(asSum[#, 2] &\) /@ \ 
      Map[{"\<2\[Times]\>" <> ToString[First[#]], Last[#]} &, 
        Union[Flatten[u, 1]]]\)}], "Input"],

Cell[BoxData[
    RowBox[{"{", 
      RowBox[{
        TagBox[\("2\[Times]-2"\^2 + "-1"\^2\),
          DisplayForm], ",", 
        TagBox[\("2\[Times]-2"\^2 + "1"\^2\),
          DisplayForm], ",", 
        TagBox[\("2\[Times]0"\^2 + "-3"\^2\),
          DisplayForm], ",", 
        TagBox[\("2\[Times]0"\^2 + "3"\^2\),
          DisplayForm], ",", 
        TagBox[\("2\[Times]2"\^2 + "-1"\^2\),
          DisplayForm], ",", 
        TagBox[\("2\[Times]2"\^2 + "1"\^2\),
          DisplayForm]}], "}"}]], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(Table[
      2 \((d\_\(1, 8\)[n] + d\_\(3, 8\)[n] - d\_\(5, 8\)[n] - 
            d\_\(7, 8\)[n])\), {n, 20}]\)], "Input"],

Cell[BoxData[
    \({2, 2, 4, 2, 0, 4, 0, 2, 6, 0, 4, 4, 0, 0, 0, 2, 4, 6, 4, 
      0}\)], "Output"]
}, Open  ]],

Cell["\<\
(Lorenz,1829) The number of representations of n\[GreaterEqual]1 as the sum \
of a square and three times a square is\
\>", "Text"],

Cell[TextData[{
  "2( ",
  Cell[BoxData[
      \(TraditionalForm\`d\_\(1, \ 3\)\)]],
  "(n) - ",
  Cell[BoxData[
      \(TraditionalForm\`d\_\(2, \ 3\)\)]],
  "(n) ) + 4( ",
  Cell[BoxData[
      \(TraditionalForm\`d\_\(4, \ 12\)\)]],
  "(n) - ",
  Cell[BoxData[
      \(TraditionalForm\`d\_\(8, \ 12\)\)]],
  "(n) )"
}], "Text",
  TextAlignment->Center,
  TextJustification->0],

Cell[CellGroupData[{

Cell[BoxData[{
    \(\(n = 12;\)\), "\[IndentingNewLine]", 
    \(\(u = 
        Map[{{#, \@\(n - 3  #\^2\)}, {#, \(-\@\(n - 3  #\^2\)\)}} &, 
          Select[Range[\[LeftCeiling]\(-n\)\/3\[RightCeiling], n\/3], 
            IntegerQ[\@\(n - 3  #\^2\)] &]];\)\), "\[IndentingNewLine]", 
    \(\(asSum[#, 2] &\) /@ \ 
      Map[{"\<3\[Times]\>" <> ToString[First[#]], Last[#]} &, 
        Union[Flatten[u, 1]]]\)}], "Input"],

Cell[BoxData[
    RowBox[{"{", 
      RowBox[{
        TagBox[\("3\[Times]-2"\^2 + "0"\^2\),
          DisplayForm], ",", 
        TagBox[\("3\[Times]-1"\^2 + "-3"\^2\),
          DisplayForm], ",", 
        TagBox[\("3\[Times]-1"\^2 + "3"\^2\),
          DisplayForm], ",", 
        TagBox[\("3\[Times]1"\^2 + "-3"\^2\),
          DisplayForm], ",", 
        TagBox[\("3\[Times]1"\^2 + "3"\^2\),
          DisplayForm], ",", 
        TagBox[\("3\[Times]2"\^2 + "0"\^2\),
          DisplayForm]}], "}"}]], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(Table[
      2 \((d\_\(1, 3\)[n] - d\_\(2, 3\)[n])\) + 
        4 \((d\_\(4, 12\)[n] - d\_\(8, 12\)[n])\), {n, 20}]\)], "Input"],

Cell[BoxData[
    \({2, 0, 2, 6, 0, 0, 4, 0, 2, 0, 0, 6, 4, 0, 0, 6, 0, 0, 4, 
      0}\)], "Output"]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{

Cell["SUMS OF THREE SQUARES", "Subsection"],

Cell[TextData[{
  "An integer is a sum of 3 squares if it is not of the form ",
  Cell[BoxData[
      \(TraditionalForm\`4\^n\)]],
  "(8m+7), n, m \[GreaterEqual] 0. We include 0 among the powers."
}], "Text"],

Cell[BoxData[
    \(sumThreeSquares[n_] := 
      Module[{t, i, j, k}, \[IndentingNewLine]t = 
          Table[\[IndentingNewLine]k = \@\(n - i\^2 - j\^2\); \
\[IndentingNewLine]If[
              IntegerQ[k], {i, j, 
                k}, {}], {i, \[LeftCeiling]\(-\@n\)\[RightCeiling], \
\[LeftFloor]\@n\[RightFloor]}, {j, \[LeftCeiling]\(-\@\(n - i\^2\)\)\
\[RightCeiling], \[LeftFloor]\@\(n - i\^2\)\[RightFloor]}]; \
\[IndentingNewLine]Union[Sort\  /@ \ Partition[Flatten[t], 3]]]\)], "Input"],

Cell[CellGroupData[{

Cell[BoxData[
    \(Do[Print[n, "\<  \>", \(asSum[#, 2] &\)\  /@ \ sumThreeSquares[n]], {n, 
        10}]\)], "Input"],

Cell[BoxData[
    InterpretationBox[
      RowBox[{"1", "\[InvisibleSpace]", "\<\"  \"\>", "\[InvisibleSpace]", 
        RowBox[{"{", 
          RowBox[{
            TagBox[
              RowBox[{\("-1"\^2\), "+", 
                TagBox[\("0"\^2 + "0"\^2\),
                  DisplayForm]}],
              DisplayForm], ",", 
            TagBox[
              RowBox[{\("0"\^2\), "+", 
                TagBox[\("0"\^2 + "1"\^2\),
                  DisplayForm]}],
              DisplayForm]}], "}"}]}],
      SequenceForm[ 1, "  ", {
        DisplayForm[ 
          RowBox[ {
            Power[ "-1", 2], "+", 
            DisplayForm[ 
              RowBox[ {
                Power[ "0", 2], "+", 
                Power[ "0", 2]}]]}]], 
        DisplayForm[ 
          RowBox[ {
            Power[ "0", 2], "+", 
            DisplayForm[ 
              RowBox[ {
                Power[ "0", 2], "+", 
                Power[ "1", 2]}]]}]]}],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      RowBox[{"2", "\[InvisibleSpace]", "\<\"  \"\>", "\[InvisibleSpace]", 
        RowBox[{"{", 
          RowBox[{
            TagBox[
              RowBox[{\("-1"\^2\), "+", 
                TagBox[\("-1"\^2 + "0"\^2\),
                  DisplayForm]}],
              DisplayForm], ",", 
            TagBox[
              RowBox[{\("-1"\^2\), "+", 
                TagBox[\("0"\^2 + "1"\^2\),
                  DisplayForm]}],
              DisplayForm], ",", 
            TagBox[
              RowBox[{\("0"\^2\), "+", 
                TagBox[\("1"\^2 + "1"\^2\),
                  DisplayForm]}],
              DisplayForm]}], "}"}]}],
      SequenceForm[ 2, "  ", {
        DisplayForm[ 
          RowBox[ {
            Power[ "-1", 2], "+", 
            DisplayForm[ 
              RowBox[ {
                Power[ "-1", 2], "+", 
                Power[ "0", 2]}]]}]], 
        DisplayForm[ 
          RowBox[ {
            Power[ "-1", 2], "+", 
            DisplayForm[ 
              RowBox[ {
                Power[ "0", 2], "+", 
                Power[ "1", 2]}]]}]], 
        DisplayForm[ 
          RowBox[ {
            Power[ "0", 2], "+", 
            DisplayForm[ 
              RowBox[ {
                Power[ "1", 2], "+", 
                Power[ "1", 2]}]]}]]}],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      RowBox[{"3", "\[InvisibleSpace]", "\<\"  \"\>", "\[InvisibleSpace]", 
        RowBox[{"{", 
          RowBox[{
            TagBox[
              RowBox[{\("-1"\^2\), "+", 
                TagBox[\("-1"\^2 + "1"\^2\),
                  DisplayForm]}],
              DisplayForm], ",", 
            TagBox[
              RowBox[{\("-1"\^2\), "+", 
                TagBox[\("1"\^2 + "1"\^2\),
                  DisplayForm]}],
              DisplayForm], ",", 
            TagBox[
              RowBox[{\("1"\^2\), "+", 
                TagBox[\("1"\^2 + "1"\^2\),
                  DisplayForm]}],
              DisplayForm]}], "}"}]}],
      SequenceForm[ 3, "  ", {
        DisplayForm[ 
          RowBox[ {
            Power[ "-1", 2], "+", 
            DisplayForm[ 
              RowBox[ {
                Power[ "-1", 2], "+", 
                Power[ "1", 2]}]]}]], 
        DisplayForm[ 
          RowBox[ {
            Power[ "-1", 2], "+", 
            DisplayForm[ 
              RowBox[ {
                Power[ "1", 2], "+", 
                Power[ "1", 2]}]]}]], 
        DisplayForm[ 
          RowBox[ {
            Power[ "1", 2], "+", 
            DisplayForm[ 
              RowBox[ {
                Power[ "1", 2], "+", 
                Power[ "1", 2]}]]}]]}],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      RowBox[{"4", "\[InvisibleSpace]", "\<\"  \"\>", "\[InvisibleSpace]", 
        RowBox[{"{", 
          RowBox[{
            TagBox[
              RowBox[{\("-2"\^2\), "+", 
                TagBox[\("0"\^2 + "0"\^2\),
                  DisplayForm]}],
              DisplayForm], ",", 
            TagBox[
              RowBox[{\("0"\^2\), "+", 
                TagBox[\("0"\^2 + "2"\^2\),
                  DisplayForm]}],
              DisplayForm]}], "}"}]}],
      SequenceForm[ 4, "  ", {
        DisplayForm[ 
          RowBox[ {
            Power[ "-2", 2], "+", 
            DisplayForm[ 
              RowBox[ {
                Power[ "0", 2], "+", 
                Power[ "0", 2]}]]}]], 
        DisplayForm[ 
          RowBox[ {
            Power[ "0", 2], "+", 
            DisplayForm[ 
              RowBox[ {
                Power[ "0", 2], "+", 
                Power[ "2", 2]}]]}]]}],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      RowBox[{"5", "\[InvisibleSpace]", "\<\"  \"\>", "\[InvisibleSpace]", 
        RowBox[{"{", 
          RowBox[{
            TagBox[
              RowBox[{\("-2"\^2\), "+", 
                TagBox[\("-1"\^2 + "0"\^2\),
                  DisplayForm]}],
              DisplayForm], ",", 
            TagBox[
              RowBox[{\("-2"\^2\), "+", 
                TagBox[\("0"\^2 + "1"\^2\),
                  DisplayForm]}],
              DisplayForm], ",", 
            TagBox[
              RowBox[{\("-1"\^2\), "+", 
                TagBox[\("0"\^2 + "2"\^2\),
                  DisplayForm]}],
              DisplayForm], ",", 
            TagBox[
              RowBox[{\("0"\^2\), "+", 
                TagBox[\("1"\^2 + "2"\^2\),
                  DisplayForm]}],
              DisplayForm]}], "}"}]}],
      SequenceForm[ 5, "  ", {
        DisplayForm[ 
          RowBox[ {
            Power[ "-2", 2], "+", 
            DisplayForm[ 
              RowBox[ {
                Power[ "-1", 2], "+", 
                Power[ "0", 2]}]]}]], 
        DisplayForm[ 
          RowBox[ {
            Power[ "-2", 2], "+", 
            DisplayForm[ 
              RowBox[ {
                Power[ "0", 2], "+", 
                Power[ "1", 2]}]]}]], 
        DisplayForm[ 
          RowBox[ {
            Power[ "-1", 2], "+", 
            DisplayForm[ 
              RowBox[ {
                Power[ "0", 2], "+", 
                Power[ "2", 2]}]]}]], 
        DisplayForm[ 
          RowBox[ {
            Power[ "0", 2], "+", 
            DisplayForm[ 
              RowBox[ {
                Power[ "1", 2], "+", 
                Power[ "2", 2]}]]}]]}],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      RowBox[{"6", "\[InvisibleSpace]", "\<\"  \"\>", "\[InvisibleSpace]", 
        RowBox[{"{", 
          RowBox[{
            TagBox[
              RowBox[{\("-2"\^2\), "+", 
                TagBox[\("-1"\^2 + "1"\^2\),
                  DisplayForm]}],
              DisplayForm], ",", 
            TagBox[
              RowBox[{\("-2"\^2\), "+", 
                TagBox[\("1"\^2 + "1"\^2\),
                  DisplayForm]}],
              DisplayForm], ",", 
            TagBox[
              RowBox[{\("-1"\^2\), "+", 
                TagBox[\("-1"\^2 + "2"\^2\),
                  DisplayForm]}],
              DisplayForm], ",", 
            TagBox[
              RowBox[{\("-1"\^2\), "+", 
                TagBox[\("1"\^2 + "2"\^2\),
                  DisplayForm]}],
              DisplayForm], ",", 
            TagBox[
              RowBox[{\("1"\^2\), "+", 
                TagBox[\("1"\^2 + "2"\^2\),
                  DisplayForm]}],
              DisplayForm]}], "}"}]}],
      SequenceForm[ 6, "  ", {
        DisplayForm[ 
          RowBox[ {
            Power[ "-2", 2], "+", 
            DisplayForm[ 
              RowBox[ {
                Power[ "-1", 2], "+", 
                Power[ "1", 2]}]]}]], 
        DisplayForm[ 
          RowBox[ {
            Power[ "-2", 2], "+", 
            DisplayForm[ 
              RowBox[ {
                Power[ "1", 2], "+", 
                Power[ "1", 2]}]]}]], 
        DisplayForm[ 
          RowBox[ {
            Power[ "-1", 2], "+", 
            DisplayForm[ 
              RowBox[ {
                Power[ "-1", 2], "+", 
                Power[ "2", 2]}]]}]], 
        DisplayForm[ 
          RowBox[ {
            Power[ "-1", 2], "+", 
            DisplayForm[ 
              RowBox[ {
                Power[ "1", 2], "+", 
                Power[ "2", 2]}]]}]], 
        DisplayForm[ 
          RowBox[ {
            Power[ "1", 2], "+", 
            DisplayForm[ 
              RowBox[ {
                Power[ "1", 2], "+", 
                Power[ "2", 2]}]]}]]}],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[\(7\[InvisibleSpace]"  "\[InvisibleSpace]{}\),
      SequenceForm[ 7, "  ", {}],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      RowBox[{"8", "\[InvisibleSpace]", "\<\"  \"\>", "\[InvisibleSpace]", 
        RowBox[{"{", 
          RowBox[{
            TagBox[
              RowBox[{\("-2"\^2\), "+", 
                TagBox[\("-2"\^2 + "0"\^2\),
                  DisplayForm]}],
              DisplayForm], ",", 
            TagBox[
              RowBox[{\("-2"\^2\), "+", 
                TagBox[\("0"\^2 + "2"\^2\),
                  DisplayForm]}],
              DisplayForm], ",", 
            TagBox[
              RowBox[{\("0"\^2\), "+", 
                TagBox[\("2"\^2 + "2"\^2\),
                  DisplayForm]}],
              DisplayForm]}], "}"}]}],
      SequenceForm[ 8, "  ", {
        DisplayForm[ 
          RowBox[ {
            Power[ "-2", 2], "+", 
            DisplayForm[ 
              RowBox[ {
                Power[ "-2", 2], "+", 
                Power[ "0", 2]}]]}]], 
        DisplayForm[ 
          RowBox[ {
            Power[ "-2", 2], "+", 
            DisplayForm[ 
              RowBox[ {
                Power[ "0", 2], "+", 
                Power[ "2", 2]}]]}]], 
        DisplayForm[ 
          RowBox[ {
            Power[ "0", 2], "+", 
            DisplayForm[ 
              RowBox[ {
                Power[ "2", 2], "+", 
                Power[ "2", 2]}]]}]]}],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      RowBox[{"9", "\[InvisibleSpace]", "\<\"  \"\>", "\[InvisibleSpace]", 
        RowBox[{"{", 
          RowBox[{
            TagBox[
              RowBox[{\("-3"\^2\), "+", 
                TagBox[\("0"\^2 + "0"\^2\),
                  DisplayForm]}],
              DisplayForm], ",", 
            TagBox[
              RowBox[{\("-2"\^2\), "+", 
                TagBox[\("-2"\^2 + "1"\^2\),
                  DisplayForm]}],
              DisplayForm], ",", 
            TagBox[
              RowBox[{\("-2"\^2\), "+", 
                TagBox[\("-1"\^2 + "2"\^2\),
                  DisplayForm]}],
              DisplayForm], ",", 
            TagBox[
              RowBox[{\("-2"\^2\), "+", 
                TagBox[\("1"\^2 + "2"\^2\),
                  DisplayForm]}],
              DisplayForm], ",", 
            TagBox[
              RowBox[{\("-1"\^2\), "+", 
                TagBox[\("2"\^2 + "2"\^2\),
                  DisplayForm]}],
              DisplayForm], ",", 
            TagBox[
              RowBox[{\("0"\^2\), "+", 
                TagBox[\("0"\^2 + "3"\^2\),
                  DisplayForm]}],
              DisplayForm], ",", 
            TagBox[
              RowBox[{\("1"\^2\), "+", 
                TagBox[\("2"\^2 + "2"\^2\),
                  DisplayForm]}],
              DisplayForm]}], "}"}]}],
      SequenceForm[ 9, "  ", {
        DisplayForm[ 
          RowBox[ {
            Power[ "-3", 2], "+", 
            DisplayForm[ 
              RowBox[ {
                Power[ "0", 2], "+", 
                Power[ "0", 2]}]]}]], 
        DisplayForm[ 
          RowBox[ {
            Power[ "-2", 2], "+", 
            DisplayForm[ 
              RowBox[ {
                Power[ "-2", 2], "+", 
                Power[ "1", 2]}]]}]], 
        DisplayForm[ 
          RowBox[ {
            Power[ "-2", 2], "+", 
            DisplayForm[ 
              RowBox[ {
                Power[ "-1", 2], "+", 
                Power[ "2", 2]}]]}]], 
        DisplayForm[ 
          RowBox[ {
            Power[ "-2", 2], "+", 
            DisplayForm[ 
              RowBox[ {
                Power[ "1", 2], "+", 
                Power[ "2", 2]}]]}]], 
        DisplayForm[ 
          RowBox[ {
            Power[ "-1", 2], "+", 
            DisplayForm[ 
              RowBox[ {
                Power[ "2", 2], "+", 
                Power[ "2", 2]}]]}]], 
        DisplayForm[ 
          RowBox[ {
            Power[ "0", 2], "+", 
            DisplayForm[ 
              RowBox[ {
                Power[ "0", 2], "+", 
                Power[ "3", 2]}]]}]], 
        DisplayForm[ 
          RowBox[ {
            Power[ "1", 2], "+", 
            DisplayForm[ 
              RowBox[ {
                Power[ "2", 2], "+", 
                Power[ "2", 2]}]]}]]}],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      RowBox[{"10", "\[InvisibleSpace]", "\<\"  \"\>", "\[InvisibleSpace]", 
        RowBox[{"{", 
          RowBox[{
            TagBox[
              RowBox[{\("-3"\^2\), "+", 
                TagBox[\("-1"\^2 + "0"\^2\),
                  DisplayForm]}],
              DisplayForm], ",", 
            TagBox[
              RowBox[{\("-3"\^2\), "+", 
                TagBox[\("0"\^2 + "1"\^2\),
                  DisplayForm]}],
              DisplayForm], ",", 
            TagBox[
              RowBox[{\("-1"\^2\), "+", 
                TagBox[\("0"\^2 + "3"\^2\),
                  DisplayForm]}],
              DisplayForm], ",", 
            TagBox[
              RowBox[{\("0"\^2\), "+", 
                TagBox[\("1"\^2 + "3"\^2\),
                  DisplayForm]}],
              DisplayForm]}], "}"}]}],
      SequenceForm[ 10, "  ", {
        DisplayForm[ 
          RowBox[ {
            Power[ "-3", 2], "+", 
            DisplayForm[ 
              RowBox[ {
                Power[ "-1", 2], "+", 
                Power[ "0", 2]}]]}]], 
        DisplayForm[ 
          RowBox[ {
            Power[ "-3", 2], "+", 
            DisplayForm[ 
              RowBox[ {
                Power[ "0", 2], "+", 
                Power[ "1", 2]}]]}]], 
        DisplayForm[ 
          RowBox[ {
            Power[ "-1", 2], "+", 
            DisplayForm[ 
              RowBox[ {
                Power[ "0", 2], "+", 
                Power[ "3", 2]}]]}]], 
        DisplayForm[ 
          RowBox[ {
            Power[ "0", 2], "+", 
            DisplayForm[ 
              RowBox[ {
                Power[ "1", 2], "+", 
                Power[ "3", 2]}]]}]]}],
      Editable->False]], "Print"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(Table[Length[sumThreeSquares[n]], {n, 35}]\)], "Input"],

Cell[BoxData[
    \({2, 3, 3, 2, 4, 5, 0, 3, 7, 4, 5, 3, 4, 7, 0, 2, 9, 8, 5, 4, 7, 5, 0, 
      5, 6, 11, 8, 0, 11, 7, 0, 3, 10, 9, 7}\)], "Output"]
}, Open  ]],

Cell["The positions of the zeroes are:", "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(Select[
      Range[50], \((n = #; \ While[IntegerQ[n/4], n = n/4]; \ 
          Mod[n, 8] == 7)\) &]\)], "Input"],

Cell[BoxData[
    \({7, 15, 23, 28, 31, 39, 47}\)], "Output"]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{

Cell["SUMS OF FOUR SQUARES", "Subsection"],

Cell["\<\
(Jacobi,1829) Every positive integer can be represented as a sum of four \
squares. The number of these representations of n\[GreaterEqual]1 is:\
\>", "Text"],

Cell[TextData[{
  "8 ",
  Cell[BoxData[
      \(TraditionalForm\`\[Sum]\+\(\(d\)\(\ \)\)d\)]]
}], "Text",
  TextAlignment->Center,
  TextJustification->0],

Cell["\<\
where the sum is taken over all divisors of n that are not multiples of 4.\
\>", "Text"],

Cell[BoxData[
    \(sumFourSquares[n_] := 
      Module[{t, i, j, k, l}, \[IndentingNewLine]t = 
          Table[\[IndentingNewLine]l = \@\(n - i\^2 - j\^2 - k\^2\); \
\[IndentingNewLine]If[
              IntegerQ[
                l], {{i, j, k, l}, {i, j, 
                  k, \(-l\)}}, {}], {i, \
\[LeftCeiling]\(-\@n\)\[RightCeiling], \[LeftFloor]\@n\[RightFloor]}, {j, \
\[LeftCeiling]\(-\@\(n - i\^2\)\)\[RightCeiling], \[LeftFloor]\@\(n - i\^2\)\
\[RightFloor]}, {k, \[LeftCeiling]\(-\@\(n - i\^2 - j\^2\)\)\[RightCeiling], \
\[LeftFloor]\@\(n - i\^2 - j\^2\)\[RightFloor]}]; \[IndentingNewLine]Union[
          Partition[Flatten[t], 4]]]\)], "Input"],

Cell[CellGroupData[{

Cell[BoxData[
    \(Do[Print[i, "\<  \>", \(asSum[#, 2] &\)\  /@ \ sumFourSquares[i]], {i, 
        2}]\)], "Input"],

Cell[BoxData[
    InterpretationBox[
      RowBox[{"1", "\[InvisibleSpace]", "\<\"  \"\>", "\[InvisibleSpace]", 
        RowBox[{"{", 
          RowBox[{
            TagBox[
              RowBox[{\("-1"\^2\), "+", 
                TagBox[
                  RowBox[{\("0"\^2\), "+", 
                    TagBox[\("0"\^2 + "0"\^2\),
                      DisplayForm]}],
                  DisplayForm]}],
              DisplayForm], ",", 
            TagBox[
              RowBox[{\("0"\^2\), "+", 
                TagBox[
                  RowBox[{\("-1"\^2\), "+", 
                    TagBox[\("0"\^2 + "0"\^2\),
                      DisplayForm]}],
                  DisplayForm]}],
              DisplayForm], ",", 
            TagBox[
              RowBox[{\("0"\^2\), "+", 
                TagBox[
                  RowBox[{\("0"\^2\), "+", 
                    TagBox[\("-1"\^2 + "0"\^2\),
                      DisplayForm]}],
                  DisplayForm]}],
              DisplayForm], ",", 
            TagBox[
              RowBox[{\("0"\^2\), "+", 
                TagBox[
                  RowBox[{\("0"\^2\), "+", 
                    TagBox[\("0"\^2 + "-1"\^2\),
                      DisplayForm]}],
                  DisplayForm]}],
              DisplayForm], ",", 
            TagBox[
              RowBox[{\("0"\^2\), "+", 
                TagBox[
                  RowBox[{\("0"\^2\), "+", 
                    TagBox[\("0"\^2 + "1"\^2\),
                      DisplayForm]}],
                  DisplayForm]}],
              DisplayForm], ",", 
            TagBox[
              RowBox[{\("0"\^2\), "+", 
                TagBox[
                  RowBox[{\("0"\^2\), "+", 
                    TagBox[\("1"\^2 + "0"\^2\),
                      DisplayForm]}],
                  DisplayForm]}],
              DisplayForm], ",", 
            TagBox[
              RowBox[{\("0"\^2\), "+", 
                TagBox[
                  RowBox[{\("1"\^2\), "+", 
                    TagBox[\("0"\^2 + "0"\^2\),
                      DisplayForm]}],
                  DisplayForm]}],
              DisplayForm], ",", 
            TagBox[
              RowBox[{\("1"\^2\), "+", 
                TagBox[
                  RowBox[{\("0"\^2\), "+", 
                    TagBox[\("0"\^2 + "0"\^2\),
                      DisplayForm]}],
                  DisplayForm]}],
              DisplayForm]}], "}"}]}],
      SequenceForm[ 1, "  ", {
        DisplayForm[ 
          RowBox[ {
            Power[ "-1", 2], "+", 
            DisplayForm[ 
              RowBox[ {
                Power[ "0", 2], "+", 
                DisplayForm[ 
                  RowBox[ {
                    Power[ "0", 2], "+", 
                    Power[ "0", 2]}]]}]]}]], 
        DisplayForm[ 
          RowBox[ {
            Power[ "0", 2], "+", 
            DisplayForm[ 
              RowBox[ {
                Power[ "-1", 2], "+", 
                DisplayForm[ 
                  RowBox[ {
                    Power[ "0", 2], "+", 
                    Power[ "0", 2]}]]}]]}]], 
        DisplayForm[ 
          RowBox[ {
            Power[ "0", 2], "+", 
            DisplayForm[ 
              RowBox[ {
                Power[ "0", 2], "+", 
                DisplayForm[ 
                  RowBox[ {
                    Power[ "-1", 2], "+", 
                    Power[ "0", 2]}]]}]]}]], 
        DisplayForm[ 
          RowBox[ {
            Power[ "0", 2], "+", 
            DisplayForm[ 
              RowBox[ {
                Power[ "0", 2], "+", 
                DisplayForm[ 
                  RowBox[ {
                    Power[ "0", 2], "+", 
                    Power[ "-1", 2]}]]}]]}]], 
        DisplayForm[ 
          RowBox[ {
            Power[ "0", 2], "+", 
            DisplayForm[ 
              RowBox[ {
                Power[ "0", 2], "+", 
                DisplayForm[ 
                  RowBox[ {
                    Power[ "0", 2], "+", 
                    Power[ "1", 2]}]]}]]}]], 
        DisplayForm[ 
          RowBox[ {
            Power[ "0", 2], "+", 
            DisplayForm[ 
              RowBox[ {
                Power[ "0", 2], "+", 
                DisplayForm[ 
                  RowBox[ {
                    Power[ "1", 2], "+", 
                    Power[ "0", 2]}]]}]]}]], 
        DisplayForm[ 
          RowBox[ {
            Power[ "0", 2], "+", 
            DisplayForm[ 
              RowBox[ {
                Power[ "1", 2], "+", 
                DisplayForm[ 
                  RowBox[ {
                    Power[ "0", 2], "+", 
                    Power[ "0", 2]}]]}]]}]], 
        DisplayForm[ 
          RowBox[ {
            Power[ "1", 2], "+", 
            DisplayForm[ 
              RowBox[ {
                Power[ "0", 2], "+", 
                DisplayForm[ 
                  RowBox[ {
                    Power[ "0", 2], "+", 
                    Power[ "0", 2]}]]}]]}]]}],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      RowBox[{"2", "\[InvisibleSpace]", "\<\"  \"\>", "\[InvisibleSpace]", 
        RowBox[{"{", 
          RowBox[{
            TagBox[
              RowBox[{\("-1"\^2\), "+", 
                TagBox[
                  RowBox[{\("-1"\^2\), "+", 
                    TagBox[\("0"\^2 + "0"\^2\),
                      DisplayForm]}],
                  DisplayForm]}],
              DisplayForm], ",", 
            TagBox[
              RowBox[{\("-1"\^2\), "+", 
                TagBox[
                  RowBox[{\("0"\^2\), "+", 
                    TagBox[\("-1"\^2 + "0"\^2\),
                      DisplayForm]}],
                  DisplayForm]}],
              DisplayForm], ",", 
            TagBox[
              RowBox[{\("-1"\^2\), "+", 
                TagBox[
                  RowBox[{\("0"\^2\), "+", 
                    TagBox[\("0"\^2 + "-1"\^2\),
                      DisplayForm]}],
                  DisplayForm]}],
              DisplayForm], ",", 
            TagBox[
              RowBox[{\("-1"\^2\), "+", 
                TagBox[
                  RowBox[{\("0"\^2\), "+", 
                    TagBox[\("0"\^2 + "1"\^2\),
                      DisplayForm]}],
                  DisplayForm]}],
              DisplayForm], ",", 
            TagBox[
              RowBox[{\("-1"\^2\), "+", 
                TagBox[
                  RowBox[{\("0"\^2\), "+", 
                    TagBox[\("1"\^2 + "0"\^2\),
                      DisplayForm]}],
                  DisplayForm]}],
              DisplayForm], ",", 
            TagBox[
              RowBox[{\("-1"\^2\), "+", 
                TagBox[
                  RowBox[{\("1"\^2\), "+", 
                    TagBox[\("0"\^2 + "0"\^2\),
                      DisplayForm]}],
                  DisplayForm]}],
              DisplayForm], ",", 
            TagBox[
              RowBox[{\("0"\^2\), "+", 
                TagBox[
                  RowBox[{\("-1"\^2\), "+", 
                    TagBox[\("-1"\^2 + "0"\^2\),
                      DisplayForm]}],
                  DisplayForm]}],
              DisplayForm], ",", 
            TagBox[
              RowBox[{\("0"\^2\), "+", 
                TagBox[
                  RowBox[{\("-1"\^2\), "+", 
                    TagBox[\("0"\^2 + "-1"\^2\),
                      DisplayForm]}],
                  DisplayForm]}],
              DisplayForm], ",", 
            TagBox[
              RowBox[{\("0"\^2\), "+", 
                TagBox[
                  RowBox[{\("-1"\^2\), "+", 
                    TagBox[\("0"\^2 + "1"\^2\),
                      DisplayForm]}],
                  DisplayForm]}],
              DisplayForm], ",", 
            TagBox[
              RowBox[{\("0"\^2\), "+", 
                TagBox[
                  RowBox[{\("-1"\^2\), "+", 
                    TagBox[\("1"\^2 + "0"\^2\),
                      DisplayForm]}],
                  DisplayForm]}],
              DisplayForm], ",", 
            TagBox[
              RowBox[{\("0"\^2\), "+", 
                TagBox[
                  RowBox[{\("0"\^2\), "+", 
                    TagBox[\("-1"\^2 + "-1"\^2\),
                      DisplayForm]}],
                  DisplayForm]}],
              DisplayForm], ",", 
            TagBox[
              RowBox[{\("0"\^2\), "+", 
                TagBox[
                  RowBox[{\("0"\^2\), "+", 
                    TagBox[\("-1"\^2 + "1"\^2\),
                      DisplayForm]}],
                  DisplayForm]}],
              DisplayForm], ",", 
            TagBox[
              RowBox[{\("0"\^2\), "+", 
                TagBox[
                  RowBox[{\("0"\^2\), "+", 
                    TagBox[\("1"\^2 + "-1"\^2\),
                      DisplayForm]}],
                  DisplayForm]}],
              DisplayForm], ",", 
            TagBox[
              RowBox[{\("0"\^2\), "+", 
                TagBox[
                  RowBox[{\("0"\^2\), "+", 
                    TagBox[\("1"\^2 + "1"\^2\),
                      DisplayForm]}],
                  DisplayForm]}],
              DisplayForm], ",", 
            TagBox[
              RowBox[{\("0"\^2\), "+", 
                TagBox[
                  RowBox[{\("1"\^2\), "+", 
                    TagBox[\("-1"\^2 + "0"\^2\),
                      DisplayForm]}],
                  DisplayForm]}],
              DisplayForm], ",", 
            TagBox[
              RowBox[{\("0"\^2\), "+", 
                TagBox[
                  RowBox[{\("1"\^2\), "+", 
                    TagBox[\("0"\^2 + "-1"\^2\),
                      DisplayForm]}],
                  DisplayForm]}],
              DisplayForm], ",", 
            TagBox[
              RowBox[{\("0"\^2\), "+", 
                TagBox[
                  RowBox[{\("1"\^2\), "+", 
                    TagBox[\("0"\^2 + "1"\^2\),
                      DisplayForm]}],
                  DisplayForm]}],
              DisplayForm], ",", 
            TagBox[
              RowBox[{\("0"\^2\), "+", 
                TagBox[
                  RowBox[{\("1"\^2\), "+", 
                    TagBox[\("1"\^2 + "0"\^2\),
                      DisplayForm]}],
                  DisplayForm]}],
              DisplayForm], ",", 
            TagBox[
              RowBox[{\("1"\^2\), "+", 
                TagBox[
                  RowBox[{\("-1"\^2\), "+", 
                    TagBox[\("0"\^2 + "0"\^2\),
                      DisplayForm]}],
                  DisplayForm]}],
              DisplayForm], ",", 
            TagBox[
              RowBox[{\("1"\^2\), "+", 
                TagBox[
                  RowBox[{\("0"\^2\), "+", 
                    TagBox[\("-1"\^2 + "0"\^2\),
                      DisplayForm]}],
                  DisplayForm]}],
              DisplayForm], ",", 
            TagBox[
              RowBox[{\("1"\^2\), "+", 
                TagBox[
                  RowBox[{\("0"\^2\), "+", 
                    TagBox[\("0"\^2 + "-1"\^2\),
                      DisplayForm]}],
                  DisplayForm]}],
              DisplayForm], ",", 
            TagBox[
              RowBox[{\("1"\^2\), "+", 
                TagBox[
                  RowBox[{\("0"\^2\), "+", 
                    TagBox[\("0"\^2 + "1"\^2\),
                      DisplayForm]}],
                  DisplayForm]}],
              DisplayForm], ",", 
            TagBox[
              RowBox[{\("1"\^2\), "+", 
                TagBox[
                  RowBox[{\("0"\^2\), "+", 
                    TagBox[\("1"\^2 + "0"\^2\),
                      DisplayForm]}],
                  DisplayForm]}],
              DisplayForm], ",", 
            TagBox[
              RowBox[{\("1"\^2\), "+", 
                TagBox[
                  RowBox[{\("1"\^2\), "+", 
                    TagBox[\("0"\^2 + "0"\^2\),
                      DisplayForm]}],
                  DisplayForm]}],
              DisplayForm]}], "}"}]}],
      SequenceForm[ 2, "  ", {
        DisplayForm[ 
          RowBox[ {
            Power[ "-1", 2], "+", 
            DisplayForm[ 
              RowBox[ {
                Power[ "-1", 2], "+", 
                DisplayForm[ 
                  RowBox[ {
                    Power[ "0", 2], "+", 
                    Power[ "0", 2]}]]}]]}]], 
        DisplayForm[ 
          RowBox[ {
            Power[ "-1", 2], "+", 
            DisplayForm[ 
              RowBox[ {
                Power[ "0", 2], "+", 
                DisplayForm[ 
                  RowBox[ {
                    Power[ "-1", 2], "+", 
                    Power[ "0", 2]}]]}]]}]], 
        DisplayForm[ 
          RowBox[ {
            Power[ "-1", 2], "+", 
            DisplayForm[ 
              RowBox[ {
                Power[ "0", 2], "+", 
                DisplayForm[ 
                  RowBox[ {
                    Power[ "0", 2], "+", 
                    Power[ "-1", 2]}]]}]]}]], 
        DisplayForm[ 
          RowBox[ {
            Power[ "-1", 2], "+", 
            DisplayForm[ 
              RowBox[ {
                Power[ "0", 2], "+", 
                DisplayForm[ 
                  RowBox[ {
                    Power[ "0", 2], "+", 
                    Power[ "1", 2]}]]}]]}]], 
        DisplayForm[ 
          RowBox[ {
            Power[ "-1", 2], "+", 
            DisplayForm[ 
              RowBox[ {
                Power[ "0", 2], "+", 
                DisplayForm[ 
                  RowBox[ {
                    Power[ "1", 2], "+", 
                    Power[ "0", 2]}]]}]]}]], 
        DisplayForm[ 
          RowBox[ {
            Power[ "-1", 2], "+", 
            DisplayForm[ 
              RowBox[ {
                Power[ "1", 2], "+", 
                DisplayForm[ 
                  RowBox[ {
                    Power[ "0", 2], "+", 
                    Power[ "0", 2]}]]}]]}]], 
        DisplayForm[ 
          RowBox[ {
            Power[ "0", 2], "+", 
            DisplayForm[ 
              RowBox[ {
                Power[ "-1", 2], "+", 
                DisplayForm[ 
                  RowBox[ {
                    Power[ "-1", 2], "+", 
                    Power[ "0", 2]}]]}]]}]], 
        DisplayForm[ 
          RowBox[ {
            Power[ "0", 2], "+", 
            DisplayForm[ 
              RowBox[ {
                Power[ "-1", 2], "+", 
                DisplayForm[ 
                  RowBox[ {
                    Power[ "0", 2], "+", 
                    Power[ "-1", 2]}]]}]]}]], 
        DisplayForm[ 
          RowBox[ {
            Power[ "0", 2], "+", 
            DisplayForm[ 
              RowBox[ {
                Power[ "-1", 2], "+", 
                DisplayForm[ 
                  RowBox[ {
                    Power[ "0", 2], "+", 
                    Power[ "1", 2]}]]}]]}]], 
        DisplayForm[ 
          RowBox[ {
            Power[ "0", 2], "+", 
            DisplayForm[ 
              RowBox[ {
                Power[ "-1", 2], "+", 
                DisplayForm[ 
                  RowBox[ {
                    Power[ "1", 2], "+", 
                    Power[ "0", 2]}]]}]]}]], 
        DisplayForm[ 
          RowBox[ {
            Power[ "0", 2], "+", 
            DisplayForm[ 
              RowBox[ {
                Power[ "0", 2], "+", 
                DisplayForm[ 
                  RowBox[ {
                    Power[ "-1", 2], "+", 
                    Power[ "-1", 2]}]]}]]}]], 
        DisplayForm[ 
          RowBox[ {
            Power[ "0", 2], "+", 
            DisplayForm[ 
              RowBox[ {
                Power[ "0", 2], "+", 
                DisplayForm[ 
                  RowBox[ {
                    Power[ "-1", 2], "+", 
                    Power[ "1", 2]}]]}]]}]], 
        DisplayForm[ 
          RowBox[ {
            Power[ "0", 2], "+", 
            DisplayForm[ 
              RowBox[ {
                Power[ "0", 2], "+", 
                DisplayForm[ 
                  RowBox[ {
                    Power[ "1", 2], "+", 
                    Power[ "-1", 2]}]]}]]}]], 
        DisplayForm[ 
          RowBox[ {
            Power[ "0", 2], "+", 
            DisplayForm[ 
              RowBox[ {
                Power[ "0", 2], "+", 
                DisplayForm[ 
                  RowBox[ {
                    Power[ "1", 2], "+", 
                    Power[ "1", 2]}]]}]]}]], 
        DisplayForm[ 
          RowBox[ {
            Power[ "0", 2], "+", 
            DisplayForm[ 
              RowBox[ {
                Power[ "1", 2], "+", 
                DisplayForm[ 
                  RowBox[ {
                    Power[ "-1", 2], "+", 
                    Power[ "0", 2]}]]}]]}]], 
        DisplayForm[ 
          RowBox[ {
            Power[ "0", 2], "+", 
            DisplayForm[ 
              RowBox[ {
                Power[ "1", 2], "+", 
                DisplayForm[ 
                  RowBox[ {
                    Power[ "0", 2], "+", 
                    Power[ "-1", 2]}]]}]]}]], 
        DisplayForm[ 
          RowBox[ {
            Power[ "0", 2], "+", 
            DisplayForm[ 
              RowBox[ {
                Power[ "1", 2], "+", 
                DisplayForm[ 
                  RowBox[ {
                    Power[ "0", 2], "+", 
                    Power[ "1", 2]}]]}]]}]], 
        DisplayForm[ 
          RowBox[ {
            Power[ "0", 2], "+", 
            DisplayForm[ 
              RowBox[ {
                Power[ "1", 2], "+", 
                DisplayForm[ 
                  RowBox[ {
                    Power[ "1", 2], "+", 
                    Power[ "0", 2]}]]}]]}]], 
        DisplayForm[ 
          RowBox[ {
            Power[ "1", 2], "+", 
            DisplayForm[ 
              RowBox[ {
                Power[ "-1", 2], "+", 
                DisplayForm[ 
                  RowBox[ {
                    Power[ "0", 2], "+", 
                    Power[ "0", 2]}]]}]]}]], 
        DisplayForm[ 
          RowBox[ {
            Power[ "1", 2], "+", 
            DisplayForm[ 
              RowBox[ {
                Power[ "0", 2], "+", 
                DisplayForm[ 
                  RowBox[ {
                    Power[ "-1", 2], "+", 
                    Power[ "0", 2]}]]}]]}]], 
        DisplayForm[ 
          RowBox[ {
            Power[ "1", 2], "+", 
            DisplayForm[ 
              RowBox[ {
                Power[ "0", 2], "+", 
                DisplayForm[ 
                  RowBox[ {
                    Power[ "0", 2], "+", 
                    Power[ "-1", 2]}]]}]]}]], 
        DisplayForm[ 
          RowBox[ {
            Power[ "1", 2], "+", 
            DisplayForm[ 
              RowBox[ {
                Power[ "0", 2], "+", 
                DisplayForm[ 
                  RowBox[ {
                    Power[ "0", 2], "+", 
                    Power[ "1", 2]}]]}]]}]], 
        DisplayForm[ 
          RowBox[ {
            Power[ "1", 2], "+", 
            DisplayForm[ 
              RowBox[ {
                Power[ "0", 2], "+", 
                DisplayForm[ 
                  RowBox[ {
                    Power[ "1", 2], "+", 
                    Power[ "0", 2]}]]}]]}]], 
        DisplayForm[ 
          RowBox[ {
            Power[ "1", 2], "+", 
            DisplayForm[ 
              RowBox[ {
                Power[ "1", 2], "+", 
                DisplayForm[ 
                  RowBox[ {
                    Power[ "0", 2], "+", 
                    Power[ "0", 2]}]]}]]}]]}],
      Editable->False]], "Print"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(Table[Length[sumFourSquares[n]], {n, 10}]\)], "Input"],

Cell[BoxData[
    \({8, 24, 32, 24, 48, 96, 64, 24, 104, 144}\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(\(ListPlot[Table[Length[sumFourSquares[n]]/8, {n, 100}]];\)\)], "Input"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.00952381 0.0147151 0.0025154 [
[.21429 .00222 -6 -9 ]
[.21429 .00222 6 0 ]
[.40476 .00222 -6 -9 ]
[.40476 .00222 6 0 ]
[.59524 .00222 -6 -9 ]
[.59524 .00222 6 0 ]
[.78571 .00222 -6 -9 ]
[.78571 .00222 6 0 ]
[.97619 .00222 -9 -9 ]
[.97619 .00222 9 0 ]
[.01131 .14049 -12 -4.5 ]
[.01131 .14049 0 4.5 ]
[.01131 .26626 -18 -4.5 ]
[.01131 .26626 0 4.5 ]
[.01131 .39203 -18 -4.5 ]
[.01131 .39203 0 4.5 ]
[.01131 .5178 -18 -4.5 ]
[.01131 .5178 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.21429 .01472 m
.21429 .02097 L
s
[(20)] .21429 .00222 0 1 Mshowa
.40476 .01472 m
.40476 .02097 L
s
[(40)] .40476 .00222 0 1 Mshowa
.59524 .01472 m
.59524 .02097 L
s
[(60)] .59524 .00222 0 1 Mshowa
.78571 .01472 m
.78571 .02097 L
s
[(80)] .78571 .00222 0 1 Mshowa
.97619 .01472 m
.97619 .02097 L
s
[(100)] .97619 .00222 0 1 Mshowa
.125 Mabswid
.07143 .01472 m
.07143 .01847 L
s
.11905 .01472 m
.11905 .01847 L
s
.16667 .01472 m
.16667 .01847 L
s
.2619 .01472 m
.2619 .01847 L
s
.30952 .01472 m
.30952 .01847 L
s
.35714 .01472 m
.35714 .01847 L
s
.45238 .01472 m
.45238 .01847 L
s
.5 .01472 m
.5 .01847 L
s
.54762 .01472 m
.54762 .01847 L
s
.64286 .01472 m
.64286 .01847 L
s
.69048 .01472 m
.69048 .01847 L
s
.7381 .01472 m
.7381 .01847 L
s
.83333 .01472 m
.83333 .01847 L
s
.88095 .01472 m
.88095 .01847 L
s
.92857 .01472 m
.92857 .01847 L
s
.25 Mabswid
0 .01472 m
1 .01472 L
s
.02381 .14049 m
.03006 .14049 L
s
[(50)] .01131 .14049 1 0 Mshowa
.02381 .26626 m
.03006 .26626 L
s
[(100)] .01131 .26626 1 0 Mshowa
.02381 .39203 m
.03006 .39203 L
s
[(150)] .01131 .39203 1 0 Mshowa
.02381 .5178 m
.03006 .5178 L
s
[(200)] .01131 .5178 1 0 Mshowa
.125 Mabswid
.02381 .03987 m
.02756 .03987 L
s
.02381 .06502 m
.02756 .06502 L
s
.02381 .09018 m
.02756 .09018 L
s
.02381 .11533 m
.02756 .11533 L
s
.02381 .16564 m
.02756 .16564 L
s
.02381 .19079 m
.02756 .19079 L
s
.02381 .21595 m
.02756 .21595 L
s
.02381 .2411 m
.02756 .2411 L
s
.02381 .29141 m
.02756 .29141 L
s
.02381 .31656 m
.02756 .31656 L
s
.02381 .34172 m
.02756 .34172 L
s
.02381 .36687 m
.02756 .36687 L
s
.02381 .41718 m
.02756 .41718 L
s
.02381 .44233 m
.02756 .44233 L
s
.02381 .46749 m
.02756 .46749 L
s
.02381 .49264 m
.02756 .49264 L
s
.02381 .54295 m
.02756 .54295 L
s
.02381 .5681 m
.02756 .5681 L
s
.02381 .59326 m
.02756 .59326 L
s
.25 Mabswid
.02381 0 m
.02381 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.008 w
.03333 .01723 Mdot
.04286 .02226 Mdot
.05238 .02478 Mdot
.0619 .02226 Mdot
.07143 .02981 Mdot
.08095 .0449 Mdot
.09048 .03484 Mdot
.1 .02226 Mdot
.10952 .04742 Mdot
.11905 .05999 Mdot
.12857 .0449 Mdot
.1381 .0449 Mdot
.14762 .04993 Mdot
.15714 .07508 Mdot
.16667 .07508 Mdot
.17619 .02226 Mdot
.18571 .05999 Mdot
.19524 .11282 Mdot
.20476 .06502 Mdot
.21429 .05999 Mdot
.22381 .09521 Mdot
.23333 .10527 Mdot
.24286 .07508 Mdot
.25238 .0449 Mdot
.2619 .09269 Mdot
.27143 .12036 Mdot
.28095 .11533 Mdot
.29048 .07508 Mdot
.3 .09018 Mdot
.30952 .19582 Mdot
.31905 .09521 Mdot
.32857 .02226 Mdot
.3381 .13545 Mdot
.34762 .15055 Mdot
.35714 .13545 Mdot
.36667 .11282 Mdot
.37619 .1103 Mdot
.38571 .16564 Mdot
.39524 .15558 Mdot
.40476 .05999 Mdot
.41429 .12036 Mdot
.42381 .25619 Mdot
.43333 .12539 Mdot
.44286 .10527 Mdot
.45238 .21092 Mdot
.4619 .19582 Mdot
.47143 .13545 Mdot
.48095 .0449 Mdot
.49048 .15809 Mdot
.5 .24865 Mdot
.50952 .19582 Mdot
.51905 .12036 Mdot
.52857 .15055 Mdot
.5381 .31656 Mdot
.54762 .19582 Mdot
.55714 .07508 Mdot
.56667 .21595 Mdot
.57619 .2411 Mdot
.58571 .16564 Mdot
.59524 .19582 Mdot
.60476 .17067 Mdot
.61429 .25619 Mdot
.62381 .27632 Mdot
.63333 .02226 Mdot
.64286 .22601 Mdot
.65238 .37693 Mdot
.6619 .18576 Mdot
.67143 .15055 Mdot
.68095 .25619 Mdot
.69048 .37693 Mdot
.7 .19582 Mdot
.70952 .11282 Mdot
.71905 .20085 Mdot
.72857 .30147 Mdot
.7381 .32662 Mdot
.74762 .16564 Mdot
.75714 .25619 Mdot
.76667 .4373 Mdot
.77619 .21595 Mdot
.78571 .05999 Mdot
.79524 .31908 Mdot
.80476 .33166 Mdot
.81429 .22601 Mdot
.82381 .25619 Mdot
.83333 .28638 Mdot
.84286 .34675 Mdot
.85238 .31656 Mdot
.8619 .10527 Mdot
.87143 .2411 Mdot
.88095 .60332 Mdot
.89048 .29644 Mdot
.9 .19582 Mdot
.90952 .33669 Mdot
.91905 .37693 Mdot
.92857 .31656 Mdot
.9381 .0449 Mdot
.94762 .26122 Mdot
.95714 .44485 Mdot
.96667 .40712 Mdot
.97619 .24865 Mdot
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{35, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0000gQ000`40O003h00Oof]JJF]J0000ofmk
JeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]j
JeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmk
JeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]j
JeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmk
JeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]j
JeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmk
JeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]j
JeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmk
JeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NP00J6]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][
FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[
FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][
FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgX1
JeX005=[FPD000A[FP@003M[FP<000=[FP@003E[FP<000A[FP@003A[FP@000A[FP@0031[FPD000=[
FP@000A[FP@000=[FP000?m[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[
FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][
FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[
FVmk001[NV]JKg/006]jJeY_N`00JgY[FVmkJeX006]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][
FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[
FVmkJeY[NV]JKg][FV]jJeY_Nf]J001[FVmkJeX006]JKg][FV]j001_Nf]JJgY[FVmkJeY[NV]JKg][
FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[
FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgX006mkJeY[NP00Kg][FP00JeY_Nf]JJgX006mkJeY[NV]JKg][
FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg/006Q[FV]jJeY_Nf]J
JgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeX006]JKg][FV]j001_Nf]J001[FVmkJeY[NP00
Kg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]J
JgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg/006]jJeY_Nf]J001[FVmkJeY[NP00
Kg][FP00JeY_Nf]JJgX006mk0F]J001DJeX00`00JeY[FP04JeX00`00JeY[FP02JeX00`00JeY[FP0e
JeX01@00JeY[FV]J000016]J00<006]JJeX0<F]J00D006]JJeY[FP00009[FP03001[FV]J009[FP03
001[FV]J031[FP03001[FV]J009[FP04001[FV]J0004JeX00`00JeY[FP0_JeX00`00JeY[FP02JeX0
0`00JeY[FP02JeX01000JeY[FP0016]J0@000F]J0F]J0000U6mkJeY[NV]JKg][FV]jJeY_Nf]JJgY[
FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][
FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[
FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmk001[NV]JKg][FV]j001_Nf]JJgY[FP00JeY[NV]JKg][
FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[
FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]J1P000<e[NV]J001[FV]jJeY_N`00JgY[FVmk
JeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]j
JeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmk001[NV]JKg/006]jJeX006]JJgY[FVmk
001[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]j
JeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]J001[FV]jJeY_N`00JgY[FP00
JeY[NV]JKg/006]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]j
JeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]j001_Nf]JJgY[FP00
JeY[NV]JKg/006]jJeX006]JJgY[FVmk001[NP01JeX005I[FP03001[FV]J009[FP03001[FV]J009[
FP03001[FV]J039[FP04001[FV]J0003JeX00`00JeY[FP02JeX00`00JeY[FP0aJeX40003JeX00`00
JeY[FP02JeX00`00JeY[FP0aJeX40003JeX00`00JeY[FP02JeX00`00JeY[FP0_JeX00`00JeY[FP02
JeX00`00JeY[FP02JeX01000JeY[FP0016]J0@000F]J0F]J0000of]jJeY_Nf]JJgY[FVmkJeY[NV]J
Kg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]J
JgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]J
Kg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_N`00JgY[FVmk001[NV]JKg][FP00JeY_Nf]J
JgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]J
Kg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgX006mkJeX006]JKg][FP00JeY_Nf]J
JgX006mkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]J
Kg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NP00Kg][FV]jJeY_Nf]J
001[FVmkJeY[NP00Kg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]J
Kg][FV]jJeY_N`00J6]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FP00JeY_
Nf]JJgX006mkJeX006]JKg][FV]j001_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[
NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_
N`00JgY[FVmkJeX006]JKg][FV]j001_Nf]J001[FVmkJeY[NP00Kg/1JeX005=[FP05001[FV]JJeX0
0003JeX00`00JeY[FP02JeX00`00JeY[FP0cJeX00`00JeX00003JeX00`00JeY[FP02JeX00`00JeY[
FP0bJeX00`00JeY[FP03JeX00`00JeY[FP02JeX00`00JeY[FP0`JeX00`00JeY[FP02JeX01000JeY[
FP0016]J00<006]JJeX0;F]J0`0016]J00<006]JJeX00V]J00@006]JJeX000A[FP40005[FP5[FP00
05A_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmk
JeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]j
JeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeX300001F]JKg][
FV]jJeX0100003M_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_
Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[
NP02000016]JJgY[FVmk100003I[FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmk
JeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]j
JeY_Nf]JJgX300000f]jJeY_N`040000=6]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[
NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_
Nf]JJgY[FVmk100000A[FV]jJeY_N`@0000hJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][
FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[
FVmkJeY[NP00Kg][FV]jJeY_N`@00004JeY[NV]JKg/40001JeX1JgX1JeX00?m[FVU[FP000?m[NV]J
Kg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]J
JgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]J
Kg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]J
JgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]J
Kg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]J
JgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]J
Kg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]J
JgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]J
Kg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg/006Q[FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_
Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[
NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_
Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmk0F]J
000JJeX00`00JeY[FP3oJeY<JeX0003oKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]J
JgY[FVmkJeY[NV]JKg][FP00JeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]J
Kg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]J
JgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]J
Kg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]J
JgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]J
Kg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]J
JgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]J
Kg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]j001XJeY_
Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[
NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_
Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[
NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NP5[FP006V]J00<006]JJeX0of]JC6]J0000of]jJeY_Nf]J
JgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeX006]JJgY[FVmkJeY[NV]J
Kg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]J
JgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]J
Kg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]J
JgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]J
Kg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]J
JgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]J
Kg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]J
JgY[FVmkJeY[NV]JKg][FV]jJeY_N`00J6]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[
NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_
Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[
NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg/1JeX001Y[
FP03001[FV]J0?m[FTa[FP00019_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJe[o001C
00000fmkJeY[NP01JeX001Y[FP03001[FV]J008000][FP03001[FV]J00e[FP03001[FV]J00e[FP03
001[FV]J00e[FP03001[FV]J00e[FP03001[FV]J00i[FP03001[FV]J00e[FP03001[FV]J00e[FP03
001[FV]J00e[FP03001[FV]J00e[FP03001[FV]J00e[FP03001[FV]J00e[FP03001[FV]J00e[FP03
001[FV]J00e[FP03001[FV]J00e[FP03001[FV]J00e[FP03001[FV]J00e[FP03001[FV]J00e[FP03
001[FV]J00e[FP03001[FV]J00e[FP03001[FV]J00Y[FP0001e[NV]JKg][FV]jJeY_Nf]JJgY[FVmk
JeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]J001[FV]j00800007JeX00000Kg][FV]jJeX00P00
00][NV]JKg][FV]jJeY_Nf]JJgY[FVmk0080000HJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]J
JgY[FVmkJeY[NV]JKg][FV]j0P00035[FV]jJeY_Nf]JJgY[FVmkJeY[NV]J001[FV]jJeY_Nf]JJgY[
FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][
FP020000IFmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmk001[
NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_
Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[
NV]JKg/006]jJeY_Nf]JJgY[FVmkJeY[NV]JKg/00P0007i[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[
FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][
FV]jJeY_Nf]JJgY[FVmk001[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[
FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][
FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg/006]jJeY_Nf]JJgY[FVmkJeY[NV]JKg/1JeX001Y[FP03001[
FV]J00=[FP800004JeX00000JeX2000;JeX2000HJeX2000aJeX2001UJeX2001oJeX0000SKg][FV]j
JeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FP00JeY_Nf]JJgY[FVmk
JeY[NP020000of]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]J
JgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]J
Kg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]J
JgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]J
Kg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]J
JgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]J
Kg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]J
JgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]J
Kg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FP00@fmkJeY[NV]JKg][FV]jJeY_
Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[
NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]j005[
FP006V]J00<006]JJeX036]J0P00of]J?V]J0000:F]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_
Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeX006]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgX00P0000E[
FV]jJeY_Nf]J0080003oKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[
NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_
Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[
NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_
Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[
NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_
Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[
NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_
Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]j000fJeY_Nf]JJgY[FVmk
JeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]j
JeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmk0F]J000JJeX00`00JeY[FP0CJeX2003o
JeXgJeX0000JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][
FP80003oKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]j
JeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmk
JeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]j
JeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmk
JeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]j
JeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmk
JeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]j
JeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmk
JeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]j001<JeY_Nf]JJgY[FVmkJeY[NV]JKg][
FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[
FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][
FV]jJeY_Nf]JJgX1JeX001Y[FP03001[FV]J0?m[FTa[FP0002e[NV]JKg][FV]jJeY_Nf]JJgY[FVmk
JeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]J001[FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]j
JeY_Nf]JJgX00P0000i[FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]j0P0002M[FP00001_Nf]JJgY[
FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][
FV]jJeX00P0004][NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[
NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_
Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg/00P0009U[FVmkJeY[NV]JKg][
FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[
FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][
FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[
FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][
FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeX00P0001M[
NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmk005[FP006V]J00<006]J
JeX046]J0P001f]J0P001F]J0P0000=[FP00000096]J0P00Bf]J0P00VF]J0P0066]J0000=VmkJeY[
NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeX006]JKg][FV]jJeY_
Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FP80000;Kg][FV]jJeY_Nf]J
JgY[FVmkJeY[NP020000of]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]j
JeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmk
JeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]j
JeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmk
JeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]j
JeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmk
JeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]j
JeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmk
JeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FP008fmkJeY[NV]JKg][
FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgX0
0F]J000JJeX00`00JeY[FP0VJeX2003oJeXTJeX0003oJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[
FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FP00JeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][
FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[
FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][
FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[
FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][
FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[
FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][
FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[
FVmk001XJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]J
Kg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]J
JgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]J
Kg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_N`5[FP006V]J00<006]JJeX07F]J0P0056]J
0P0026]J0P00?V]J0P00OV]J0P00C6]J0000>VmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]J
Kg][FV]jJeY_Nf]JJgY[FVmkJeX006]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]J
JgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]J0P0001A_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[
FVmkJeY[NV]J0P0000Q[NV]JKg][FV]jJeY_Nf]J0P0003i_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_
Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[
NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]J0P0007i_Nf]JJgY[FVmkJeY[NV]J
Kg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]J
JgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]J
Kg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]J
JgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeX20000
BfmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][
FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[
FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NP01JeX001Y[FP8003Y[FP800?m[FQ5[FP0005I[
NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]J001[FV]jJeY_
Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[
NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]J0P000?m[NV]J
Kg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]J
JgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]J
Kg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]J
JgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]J
Kg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]J
JgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]J
Kg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]J
JgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]J
Kg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg/0011[FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_
N`5[FP006V]J00<006]JJeX0of]JC6]J0000AVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]J
Kg][FV]jJeY_Nf]JJgY[FVmkJeX006]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]J
JgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]J0P0001]_Nf]J0000
06mkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgX00P0000i[FV]jJeY_
Nf]JJgY[FVmkJeY[NV]JKg][FV]j0P0005Q[FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]J
JgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]J
Kg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]J
JgY[FVmkJeY[NV]JKg][FV]jJeY_N`80002HJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[
FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][
FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[
FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][
FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[
FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NP5[FP006V]J00<006]JJeX0:F]J0P000V]J0P00
5f]J0P003V]J0P00F6]J0P00VF]J0000of]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[
FVmkJeY[NV]JKg][FV]jJeX006]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][
FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[
FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][
FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[
FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][
FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[
FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][
FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_N`00J6]J
JgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]J
Kg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]J
JgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]J
Kg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg/1JeX001Y[FP03001[FV]J0?m[FTa[FP000?m_Nf]JJgY[
FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]J001[FVmkJeY[NV]JKg][
FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[
FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][
FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[
FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][
FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[
FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][
FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[
FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgX006Q[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]J
Kg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]J
JgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]J
Kg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]j0F]J000J
JeX2001KJeX2003_JeX0001ZJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]j
JeY_Nf]JJgY[FP00JeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmk
JeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]j
JeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeX200002f]jJeY_
Nf]JJgY[FVmkJeY[NV]JKg/00P000>i[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][
FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[
FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][
FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[
FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][
FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[
FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][
FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[
FVmkJeY[NV]JKg][FV]jJeY_N`5[FP006V]J00<006]JJeX0@6]J0P002f]J0P004F]J0P00jF]J0000
GFmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeX006]JKg][
FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[
FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][
FV]jJeY_N`0200007V]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[
NV]JKg][FV]jJeY_N`80003XJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]J
Kg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]J
JgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]J
Kg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]J
JgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]J
Kg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]J
JgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]J
Kg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]J
JgX1JeX001Y[FP03001[FV]J0?m[FTa[FP00061[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][
FV]jJeY_Nf]JJgY[FVmkJeY[NV]J001[FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[
FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][
FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeX20000AFmkJeY[NV]JKg][FV]j
JeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmk
JeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]j
JeY_N`020000Rf]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]J
Kg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]J
JgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]J
Kg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]J
JgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]J0080000aKg][FV]j
JeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmk
JeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg/00F]J000JJeX00`00JeY[FP13JeX20015JeX2
002;JeX2000bJeX0002@Kg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[
NV]JKg][FP00JeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_
Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[
NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_
Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[
NV]J0P000=E[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]J
Kg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]J
JgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]J
Kg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]J
JgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]J
Kg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]J
JgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]J
Kg][FV]jJeY_Nf]JJgX00F]J000JJeX00`00JeY[FP0fJeX2000hJeX200000f]J0000001_JeX2001U
JeX0000JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FP80
000gJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[
NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg/00P0001][
FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeX00P0001]_
Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgX00P00079[
FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[
FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][
FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[
FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgX20000I6]JJgY[FVmk
JeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]j
JeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmk
JeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]j
JeY_Nf]JJgY[FVmk0F]J000JJeX00`00JeY[FP1@JeX200000f]J0000000[JeX2000QJeX2002VJeX0
001]Kg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FP00JeY_
Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[
NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_
Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg/00P0002i[FVmkJeY[NV]JKg][
FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[
FVmkJeY[NV]JKg][FV]jJeY_N`80000QJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmk
JeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]J0080002UJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]J
JgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]J
Kg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]J
JgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]J
Kg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]J
JgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]J
Kg][FV]j005[FP006V]J00<006]JJeX0QV]J0P00`f]J0000Xf]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][
FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeX006]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[
FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][
FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[
FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][
FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[
FVmk00800032JeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_
Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[
NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_
Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[
NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_
Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[
NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_N`5[FP0026]J100016]J10001V]J00<0
06]JJeX0of]JC6]J0000PfmkJeY[NV]JKg][FV]j001_Nf]JJgY[FP00JeY[NP00Kg][FV]jJeX006]J
JgY[FVmkJeX006]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]J
Kg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]J
JgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]J
Kg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgX00P0000E[FV]jJeY_Nf]J0080000T
Kg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]J
JgY[FVmkJeY[NV]J0P000;E[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[
FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][
FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[
FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][
FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[
FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][
FV]jJeY_Nf]JJgY[FVmkJeY[NP01JeX000a[FP04001[FV]J0004JeX00`00JeY[FP03JeX00`00JeY[
FP1VJeX20005JeX2000TJeX2002fJeX0000JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]J001[FVmk001[
NV]JKg][FP00JeY_Nf]JJgY[FP<0003oJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmk
JeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]j
JeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmk
JeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]j
JeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmk
JeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]j
JeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmk
JeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]j
JeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]J001;JgY[
FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][
FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[
FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmk005[FP0026]J10000f]J00<006]JJeX00V]J00<006]J
JeX00f]J00<006]JJeX0of]JC6]J0000ofmkJeY[NV]JKg][FV]jJeX006]JJgY[FVmkJeY[NP00Kg][
FV]jJeX006]JJgY[FVmkJeX006]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[
FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][
FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[
FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][
FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[
FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][
FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[
FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NP00J6]J
Kg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]J
JgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]J
Kg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]J
JgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgX1JeX000Q[FP03001[FV]J00A[FP03001[FV]J009[FP03
001[FV]J00=[FP03001[FV]J06Y[FP8003][FP8002i[FP80079[FP0000Q[NV]JKg][FV]jJeY_Nf]J
1@0000=[FVmkJeX0100007=[NV]JKg][FV]jJeX006]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[
FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][
FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[
FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][
FV]jJeY_N`020000>f]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[
NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_
Nf]JJgY[FVmkJeX00P0002i_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][
FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FP80001aKg][FV]j
JeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmk
JeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]j
JeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmk
JeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_N`01JeX001Y[FP03001[FV]J07Y[
FP800<m[FP0009M_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_
Nf]J001[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[
NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_
Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[
NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_
Nf]JJgY[FVmkJeY[NP0200007V]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][
FV]jJeY_Nf]JJgY[FVmkJeY[NP80002^JeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]j
JeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmk
JeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]j
JeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmk
JeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]j
JeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmk
JeY[NV]JKg][FV]j0F]J000JJeX00`00JeY[FP2JJeX2002_JeX0003oJgY[FVmkJeY[NV]JKg][FV]j
JeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FP00JeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmk
JeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]j
JeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmk
JeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]j
JeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmk
JeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]j
JeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmk
JeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]j
JeY_Nf]JJgY[FVmk001XJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[
FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][
FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[
FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_N`5[FP006V]J0P00Mf]J0P00
@V]J0P00=6]J0P00FF]J0000TfmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_
Nf]JJgY[FVmkJeX006]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[
NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_
Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[
NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_
Nf]JJgY[FVmkJeY[NP020000@V]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][
FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[
FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NP800004JeY[NV]JKg/20000;V]JKg][FV]jJeY_
Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[
NV]JKg][FV]jJeY_Nf]JJgY[FVmk0P0005Q[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]J
Kg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]J
JgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]J
Kg][FV]jJeY_Nf]JJgY[FVmkJeY[NP5[FP006V]J00<006]JJeX0`6]J0P00RF]J0000of]jJeY_Nf]J
JgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeX006]JJgY[FVmkJeY[NV]J
Kg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]J
JgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]J
Kg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]J
JgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]J
Kg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]J
JgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]J
Kg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]J
JgY[FVmkJeY[NV]JKg][FV]jJeY_N`00J6]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[
NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_
Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[
NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg/1JeX001Y[
FP03001[FV]J0?m[FTa[FP000?m_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]J
Kg][FV]jJeY_Nf]J001[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]J
JgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]J
Kg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]J
JgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]J
Kg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]J
JgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]J
Kg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]J
JgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgX006Q[FVmkJeY[
NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_
Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[
NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_
Nf]JJgY[FVmkJeY[NV]JKg][FV]j0F]J000JJeX00`00JeY[FP3CJeX2001fJeX0003`JgY[FVmkJeY[
NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FP00JeY[NV]JKg][FV]jJeY_
Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[
NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_
Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[
NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_
Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[
NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_
Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]J0P0007E_Nf]J
JgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]J
Kg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]J
JgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]J
Kg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg/00F]J000JJeX2
003oJeY=JeX0003oKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]J
Kg][FP00JeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]J
JgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]J
Kg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]J
JgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]J
Kg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]J
JgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]J
Kg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]J
JgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]j001XJeY_Nf]JJgY[FVmkJeY[
NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_
Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[
NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_
Nf]JJgY[FVmkJeY[NP5[FP006V]J00<006]JJeX0GF]J0P00<F]J0P003V]J0P002f]J0P003V]J0P00
8F]J0P00@V]J0P009F]J0000NV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[
NV]JKg][FV]jJeX006]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_
Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[
NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_
Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeX20000<F]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]J
JgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]J
Kg][FV]j0080000>JeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NP80000;JeY[NV]JKg][FV]jJeY_
Nf]JJgY[FP0200003V]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeX200008F]jJeY_Nf]JJgY[FVmk
JeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NP0200001F]J
JgY[FVmkJeX00P0003]_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]j
JeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmk
JeY[NV]JKg][FV]j0080000TJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]J
JgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmk0F]J000JJeX00`00JeY[FP3WJeX2001RJeX0003o
Kg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FP00JeY_Nf]J
JgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]J
Kg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]J
JgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]J
Kg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]J
JgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]J
Kg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]J
JgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]J
Kg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]j001XJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_
Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[
NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_
Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[
NP5[FP006V]J00<006]JJeX0of]JC6]J0000ZV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]J
JgY[FVmkJeY[NV]JKg][FV]jJeX006]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]J
Kg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]J
JgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]J
Kg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]J
JgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]J
Kg][FV]jJeX20000^f]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][
FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[
FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][
FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[
FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][
FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[
FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmk005[FP006V]J00<006]JJeX0SF]J0P00_6]J00006Vmk
JeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeX20000]6mkJeY[
NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_
Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[
NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_
Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[
NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_
Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FP800015
JgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]J
Kg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]J
JgY[FVmkJeY[NV]JKg][FV]j0080001>JeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]j
JeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmk
JeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]j
0F]J000JJeX00`00JeY[FP2cJeX20015JeX2001?JeX0003oJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]J
JgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FP00JeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]J
Kg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]J
JgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]J
Kg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]J
JgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]J
Kg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]J
JgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]J
Kg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]J
JgY[FVmk001XJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[
NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_
Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[
NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_N`5[FP006V]J00<006]JJeX0cF]J0P00
>6]J0P00@V]J0000jVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[
FVmkJeX006]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][
FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[
FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][
FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[
FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][
FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[
FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][
FP80000hKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]j
JeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FP80
0011JgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[
NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_
Nf]JJgY[FVmkJeY[NP01JeX001Y[FP03001[FV]J0?m[FTa[FP000?m[NV]JKg][FV]jJeY_Nf]JJgY[
FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]J001[FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][
FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[
FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][
FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[
FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][
FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[
FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][
FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[
FVmkJeY[NV]JKg/006Q[FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]J
Kg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]J
JgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]J
Kg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmk0F]J000JJeX00`00JeY[FP3o
JeY<JeX0000JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][
FP80002hKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]j
JeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmk
JeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]j
JeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmk
JeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]j
JeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmk
JeY[NV]JKg][FV]jJeX20000HF]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[
NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_
Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[
NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]j0080000^JeY[NV]JKg][FV]jJeY_Nf]JJgY[
FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][
FV]jJeY_Nf]JJgX1JeX001Y[FP03001[FV]J0;M[FP80065[FP8002m[FP000?m[NV]JKg][FV]jJeY_
Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]J001[FV]jJeY_Nf]JJgY[FVmkJeY[
NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_
Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[
NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_
Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[
NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_
Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[
NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_
Nf]JJgY[FVmkJeY[NV]JKg/006Q[FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmk
JeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]j
JeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmk
JeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmk0F]J000JJeX00`00
JeY[FP2MJeX2002NJeX2000<JeX0002jKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]J
JgY[FVmkJeY[NV]JKg][FP00JeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]J
Kg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]J
JgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]J
Kg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]J
JgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]J
Kg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]J0P0009i_Nf]JJgY[FVmkJeY[NV]JKg][
FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[
FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][
FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[
FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][
FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]J0P00
00]_Nf]JJgY[FVmkJeY[NV]JKg][FV]j005[FP006V]J00<006]JJeX0Pf]J0P00?V]J0P005F]J0P00
66]J0P0056]J0P00?f]J000500000f]JKg][FP04000016]jJeY_Nf]J100008a[NV]JKg][FV]jJeX0
06]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[
NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_
Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[
NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_
Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]J0P0003i_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]J
JgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]J
Kg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]J0P0001E_Nf]JJgY[FVmkJeY[NV]JKg][
FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg/00P0001Q[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[
NV]JKg][FV]jJeY_Nf]JJgX2000056]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]J
Kg/20000?V]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][
FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[
FVmkJeY[NV]JKg/1JeX0009[FP03001[FV]J009[FP03001[FV]J009[FP04001[FV]J0004JeX00`00
JeY[FP03JeX00`00JeY[FP3oJeXeJeX2000EJeX0003oKg][FP00JeY_Nf]JJgX006mkJeY[NV]J001[
FV]j001_Nf]JJgY[FP00JeY[NV]JKg][FP00JeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[
FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][
FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[
FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][
FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[
FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][
FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[
FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][
FV]j001BJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]J
JgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]J
Kg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg/2000056]JKg][
FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgX1JeX0009[FP03001[FV]J009[FP03001[
FV]J009[FP04001[FV]J0004JeX00`00JeY[FP03JeX3003oJeY<JeX0003oJgY[FP00JeY[NV]JKg/0
06]jJeY_Nf]J001[FVmk001[NV]JKg][FP00JeY_Nf]JJgY[FP00JeY[NV]JKg][FV]jJeY_Nf]JJgY[
FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][
FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[
FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][
FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[
FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][
FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[
FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][
FV]jJeY_Nf]JJgY[FVmk001XJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]J
JgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]J
Kg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]J
JgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_N`5[FP000V]J00<006]J
JeX00V]J00<006]JJeX00V]J00@006]JJeX000A[FP03001[FV]J00=[FP03001[FV]J0?m[FTa[FP00
0`000>5[FVmkJeY[NP00Kg][FV]jJeX006]JJgX006mkJeY[NV]J001[FV]jJeY_Nf]J001[FVmkJeY[
NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_
Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[
NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_
Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[
NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_
Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[
NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeX00P00085[NV]JKg][FV]jJeY_Nf]JJgY[
FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][
FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[
FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][
FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgX0
0F]J0002JeX00`00JeY[FP03JeX40004JeX40006JeX00`00JeY[FP37JeX20022JeX0003oJgY[FVmk
JeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FP00JeY[NV]JKg][FV]j
JeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmk
JeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]j
JeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmk
JeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]j
JeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmk
JeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]j
JeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmk
JeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmk001XJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][
FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[
FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][
FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_N`5[FP00
6V]J00<006]JJeX0of]J3V]J0P00?6]J0000ofmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]J
Kg][FV]jJeY_Nf]JJgY[FVmkJeX006]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]J
JgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]J
Kg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]J
JgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]J
Kg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]J
JgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]J
Kg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]J
JgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NP00
:f]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_
Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]J0080000kKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][
FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[
FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NP01JeX001Y[FP800?m[FTe[FP000?m[NV]JKg][
FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]J001[FV]jJeY_Nf]JJgY[
FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][
FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[
FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][
FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[
FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][
FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[
FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][
FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg/006Q[FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]J
JgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]J
Kg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]J
JgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmk0F]J000J
JeX00`00JeY[FP3oJeXRJeX2000XJeX0003oKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_
Nf]JJgY[FVmkJeY[NV]JKg][FP00JeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[
NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_
Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[
NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_
Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[
NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_
Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[
NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]j0008
JeY_Nf]JJgY[FVmkJeY[NP80000eJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_
Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[
NV]JKg][FP0200009fmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[
FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NP01JeX001Y[FP03001[FV]J0>Y[FP8005m[FP00
0?m[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]J001[FV]j
JeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmk
JeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]j
JeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmk
JeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]j
JeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmk
JeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]j
JeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmk
JeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg/006Q[FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][
FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[
FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][
FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[
FVmk0F]J000JJeX00`00JeY[FP3oJeY<JeX0003oKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]j
JeY_Nf]JJgY[FVmkJeY[NV]JKg][FP00JeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmk
JeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]j
JeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmk
JeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]j
JeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmk
JeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]j
JeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmk
JeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]j
001XJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[
FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][
FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[
FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NP5[FP006V]J00<006]JJeX0ZV]J0P00J6]J0P00
5f]J0P0076]J00006V]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][
FV]jJeX20000Zf]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]j
JeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmk
JeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]j
JeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmk
JeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]j
JeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_N`020000E6]J
Kg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]J
JgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]J
Kg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NP80000BJeY[NV]JKg][
FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]j0P0001M[FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]j
JeY_Nf]JJgY[FVmkJeY[NV]J0080000KJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]J
Kg][FV]jJeY_Nf]JJgY[FVmk005[FP006V]J00<006]JJeX0of]J0F]J0P00BF]J0000ofmkJeY[NV]J
Kg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeX006]JKg][FV]jJeY_Nf]J
JgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]J
Kg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]J
JgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]J
Kg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]J
JgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]J
Kg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]J
JgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]J
Kg][FV]jJeY_Nf]JJgY[FVmkJeY[NP00J6]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_
Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[
NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_
Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgX1JeX001Y[
FP03001[FV]J0>e[FP8005a[FP000?m[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_
Nf]JJgY[FVmkJeY[NV]J001[FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[
NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_
Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[
NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_
Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[
NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_
Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[
NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg/000][FV]j
JeY_Nf]JJgY[FVmkJeY[NV]J0080001KJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]J
Kg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]J
JgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]J
Kg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg/00F]J000JJeX00`00JeY[FP3oJeX5JeX20015JeX0003o
Kg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FP00JeY_Nf]J
JgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]J
Kg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]J
JgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]J
Kg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]J
JgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]J
Kg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]J
JgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]J
Kg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]j000RJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_
Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg/200008F]JKg][FV]jJeY_Nf]J
JgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FP0200008F]j
JeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmk
JeY[NP01JeX001Y[FP03001[FV]J0?m[FRQ[FP80029[FP0001Y[NV]JKg][FV]jJeY_Nf]JJgY[FVmk
JeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]J0P000?m[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[
NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_
Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[
NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_
Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[
NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_
Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[
NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_
Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[
NV]JKg/004a[FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]j
JeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmk
JeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_N`5[FP006V]J00<006]JJeX0of]J
C6]J0000ofmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeX0
06]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_
Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[
NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_
Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[
NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_
Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[
NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_
Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NP00;V]JKg][FV]jJeY_Nf]JJgY[FVmk
JeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]j
JeY_Nf]JJgY[FVmk0P0003Q[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_
Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[
NV]JKg][FV]j0F]J000JJeX00`00JeY[FP3oJeXAJeX2000iJeX0003oJgY[FVmkJeY[NV]JKg][FV]j
JeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FP00JeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmk
JeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]j
JeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmk
JeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]j
JeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmk
JeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]j
JeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmk
JeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]j
JeY_Nf]JJgY[FVmk001XJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[
FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][
FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[
FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_N`5[FP006V]J00<006]JJeX0
of]JC6]J0000ofmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmk
JeX006]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]j
JeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmk
JeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]j
JeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmk
JeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]j
JeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmk
JeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]j
JeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NP00J6]JKg][FV]jJeY_Nf]JJgY[
FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][
FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[
FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][
FV]jJeY_Nf]JJgX1JeX001Y[FP03001[FV]J0?m[FTa[FP000?m[NV]JKg][FV]jJeY_Nf]JJgY[FVmk
JeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]J001[FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]j
JeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmk
JeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]j
JeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmk
JeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]j
JeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmk
JeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]j
JeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmk
JeY[NV]JKg/006Q[FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][
FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[
FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][
FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmk0F]J000JJeX2003oJeY=JeX0003o
Kg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FP00JeY_Nf]J
JgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]J
Kg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]J
JgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]J
Kg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]J
JgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]J
Kg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]J
JgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]J
Kg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]j001XJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_
Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[
NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_
Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[
NP5[FP006V]J00<006]JJeX0of]JC6]J0000kF]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]J
JgY[FVmkJeY[NV]JKg][FV]jJeX006]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]J
Kg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]J
JgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]J
Kg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]J
JgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]J
Kg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]J
JgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]J
Kg][FV]jJeY_Nf]JJgY[FVmkJeY[NP0200002f]JJgY[FVmkJeY[NV]JKg][FV]jJeX00P0004][NV]J
Kg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]J
JgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]J
Kg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg/00P0001i[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmk
JeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg/1JeX001Y[FP03001[FV]J0=1[FP8000][FP80
04][FP8001m[FP001@0000=[FV]jJeX0100000A_Nf]JJgY[FP@0003oKg][FV]jJeY_Nf]J001[FVmk
JeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]j
JeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmk
JeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]j
JeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmk
JeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]j
JeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmk
JeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]j
JeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmk
JeY[NV]JKg][FV]j001DJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][
FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[
FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][
FV]j0F]J0002JeX00`00JeY[FP02JeX00`00JeY[FP02JeX01000JeY[FP0016]J00<006]JJeX00f]J
00<006]JJeX0of]JC6]J0000of]jJeX006]JJgY[FVmkJeY[NV]JKg][FP00JeY_N`00JgY[FVmkJeX0
06]JKg][FV]jJeX006]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_
Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[
NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_
Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[
NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_
Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[
NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_
Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_N`00J6]JJgY[FVmk
JeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]j
JeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmk
JeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]j
JeY_Nf]JJgY[FVmkJeY[NV]JKg/1JeX0009[FP03001[FV]J00M[FP04001[FV]J0004JeX00`00JeY[
FP03JeX3003oJeY<JeX00008Kg][FP00JeY_Nf]JJgY[FP@0003oKg][FV]j001_Nf]JJgY[FP00JeY[
NV]JKg][FP00JeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_
Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[
NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_
Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[
NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_
Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[
NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_
Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[
NV]JKg][FV]j001LJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]j
JeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmk
JeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]j
JeY_Nf]JJgY[FVmkJeY[NP5[FP000V]J00<006]JJeX00f]J00<006]JJeX016]J00<006]JJeX00V]J
00<006]JJeX00f]J00<006]JJeX0of]JC6]J00030000of]JJgY[FVmkJeX006]JKg][FV]jJeY_N`00
JgY[FVmkJeX006]JKg][FV]jJeX006]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]J
Kg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]J
JgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]J
Kg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]J
JgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]J
Kg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]J
JgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]J
Kg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]J
JgY[FP00IFmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[
NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_
Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[
NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg/00F]J0002JeX00`00JeY[FP03JeX50003JeX40006
JeX00`00JeY[FP3oJeY<JeX0003oKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[
FVmkJeY[NV]JKg][FP00JeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][
FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[
FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][
FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[
FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][
FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[
FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][
FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]j001HJeY_Nf]J
JgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]J
Kg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]J
JgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgX200003V]JJgY[
FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgX1JeX001Y[FP03001[FV]J0?m[FS][FP8000m[FP000?m[NV]J
Kg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]J001[FV]jJeY_Nf]J
JgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]J
Kg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]J
JgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]J
Kg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]J
JgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]J
Kg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]J
JgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]J
Kg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg/006Q[FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_
Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[
NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_
Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmk0F]J
000JJeX00`00JeY[FP3oJeY<JeX0000JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]J
JgY[FVmkJeY[NV]JKg][FP80003oKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[
FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][
FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[
FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][
FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[
FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][
FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[
FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][
FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]j001<JeY_Nf]J
JgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]J
Kg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]J
JgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgX1JeX001Y[FP03001[FV]J0?m[FTa[FP000?m[NV]JKg][
FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]J001[FV]jJeY_Nf]JJgY[
FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][
FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[
FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][
FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[
FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][
FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[
FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][
FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg/006Q[FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]J
JgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]J
Kg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]J
JgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmk0F]J000J
JeX00`00JeY[FP3oJeY<JeX0003oKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[
FVmkJeY[NV]JKg][FP00JeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][
FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[
FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][
FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[
FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][
FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[
FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][
FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]j001XJeY_Nf]J
JgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]J
Kg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]J
JgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]J
Kg][FV]jJeY_Nf]JJgY[FVmkJeY[NP5[FP006V]J00<006]JJeX0of]JC6]J0000of]jJeY_Nf]JJgY[
FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeX006]JJgY[FVmkJeY[NV]JKg][
FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[
FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][
FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[
FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][
FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[
FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][
FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[
FVmkJeY[NV]JKg][FV]jJeY_N`005F]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]J
Kg][FP020000DFmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmk
JeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]j
JeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_N`01JeX001Y[
FP03001[FV]J0?M[FP80059[FP0001Y_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[
NV]JKg][FV]jJeY_Nf]J0P000?m_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]J
Kg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]J
JgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]J
Kg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]J
JgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]J
Kg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]J
JgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]J
Kg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]J
JgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgX004a[FVmkJeY[
NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_
Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[
NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NP5[FP006V]J00<006]JJeX0of]J>6]J0P004V]J0000of]j
JeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeX006]JJgY[FVmk
JeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]j
JeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmk
JeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]j
JeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmk
JeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]j
JeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmk
JeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]j
JeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_N`00EF]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[
FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][
FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[
FVmkJeY[NV]JKg][FV]jJeY_Nf]J0080000AKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_
N`01JeX001Y[FP03001[FV]J0?m[FTa[FP000?m_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[
FVmkJeY[NV]JKg][FV]jJeY_Nf]J001[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][
FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[
FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][
FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[
FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][
FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[
FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][
FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgX0
06Q[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]J
Kg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]J
JgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]J
Kg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]j0F]J000JJeX00`00JeY[FP3oJeY<JeX0003oJgY[
FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FP00JeY[NV]JKg][
FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[
FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][
FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[
FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][
FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[
FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][
FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[
FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmk001XJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]J
Kg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]J
JgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]J
Kg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_N`5[
FP006V]J00<006]JJeX0of]JC6]J00006VmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][
FV]jJeY_Nf]JJgY[FVmkJeX20000ofmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]j
JeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmk
JeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]j
JeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmk
JeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]j
JeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmk
JeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]j
JeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmk
JeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NP00C6]JKg][
FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[
FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][
FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]j0F]J000JJeX00`00JeY[FP3oJeY<JeX0003oJgY[FVmk
JeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FP00JeY[NV]JKg][FV]j
JeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmk
JeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]j
JeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmk
JeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]j
JeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmk
JeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]j
JeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmk
JeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmk001XJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][
FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[
FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][
FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_N`5[FP00
6V]J00<006]JJeX0of]JC6]J0000ofmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]j
JeY_Nf]JJgY[FVmkJeX006]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmk
JeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]j
JeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmk
JeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]j
JeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmk
JeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]j
JeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmk
JeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NP00J6]JKg][
FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[
FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][
FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[
FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgX1JeX001Y[FP03001[FV]J0?m[FTa[FP000?m[NV]JKg][FV]j
JeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]J001[FV]jJeY_Nf]JJgY[FVmk
JeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]j
JeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmk
JeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]j
JeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmk
JeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]j
JeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmk
JeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]j
JeY_Nf]JJgY[FVmkJeY[NV]JKg/006Q[FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[
FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][
FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[
FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmk0F]J000JJeX0
0`00JeY[FP3oJeY<JeX0003oKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmk
JeY[NV]JKg][FP00JeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]j
JeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmk
JeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]j
JeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmk
JeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]j
JeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmk
JeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]j
JeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]j001XJeY_Nf]JJgY[
FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][
FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[
FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][
FV]jJeY_Nf]JJgY[FVmkJeY[NP5[FP006V]J0P00of]JCF]J0000of]jJeY_Nf]JJgY[FVmkJeY[NV]J
Kg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeX006]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]J
JgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]J
Kg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]J
JgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]J
Kg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]J
JgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]J
Kg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]J
JgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]J
Kg][FV]jJeY_N`00J6]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_
Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[
NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_
Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg/1JeX001Y[FP03001[FV]J0?m[
FTa[FP000?m_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]J
001[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]J
Kg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]J
JgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]J
Kg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]J
JgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]J
Kg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]J
JgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]J
Kg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgX006Q[FVmkJeY[NV]JKg][FV]jJeY_
Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[
NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_
Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[
NV]JKg][FV]j0F]J000JJeX00`00JeY[FP3oJeY<JeX000@00004JgY[FVmkJeX4000016]jJeY_Nf]J
10000?m[NV]JKg][FV]jJeX006]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][
FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[
FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][
FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[
FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][
FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[
FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][
FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[
FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg/005A[FV]jJeY_Nf]JJgY[FVmkJeY[NV]J
Kg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]J
JgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]J
Kg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg/1JeX000=[FP05001[FV]JJeX00004JeX01000JeY[FP00
16]J00<006]JJeX00f]J00<006]JJeX0of]JC6]J0000o`00JeY[NV]JKg][FV]j001_Nf]JJgY[FP00
JeY[NP00Kg][FV]jJeX006]JJgY[FVmkJeX006]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]j
JeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmk
JeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]j
JeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmk
JeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]j
JeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmk
JeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]j
JeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmk
JeY[NP00J6]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][
FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[
FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][
FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgX1JeX00003JeX006]J00A[FP03001[FV]J
009[FP04001[FV]J0004JeX00`00JeY[FP03JeX3003oJeY<JeX0003oJgY[FP00JeY[NV]JKg/006]j
JeY_Nf]J001[FVmk001[NV]JKg][FP00JeY_Nf]JJgY[FP00JeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmk
JeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]j
JeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmk
JeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]j
JeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmk
JeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]j
JeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmk
JeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]j
JeY_Nf]JJgY[FVmk001XJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[
FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][
FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[
FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_N`5[FP000f]J00D006]JJeY[
FP0000A[FP04001[FV]J0004JeX00`00JeY[FP03JeX00`00JeY[FP3oJeY<JeX0003oKg][FV]j001_
Nf]JJgX006mkJeY[NV]J001[FV]j001_Nf]JJgY[FP00JeY[NV]JKg][FP00JeY_Nf]JJgY[FVmkJeY[
NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_
Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[
NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_
Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[
NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_
Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[
NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_
Nf]JJgY[FVmkJeY[NV]JKg][FV]j001XJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmk
JeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]j
JeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmk
JeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NP5[FP000`00
1F]J100016]J10001V]J00<006]JJeX0of]JC6]J0000of]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]j
JeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeX006]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmk
JeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]j
JeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmk
JeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]j
JeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmk
JeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]j
JeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmk
JeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]j
JeY_N`00J6]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[
FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][
FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[
FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg/1JeX001Y[FP03001[FV]J0?m[FTa[FP00
0?m_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]J001[FVmk
JeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]j
JeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmk
JeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]j
JeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmk
JeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]j
JeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmk
JeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]j
JeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgX006Q[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[
FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][
FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[
FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][
FV]j0F]J000JJeX00`00JeY[FP3oJeY<JeX0000JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmk
JeY[NV]JKg][FV]jJeY_Nf]JJgY[FP80003oJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[
NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_
Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[
NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_
Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[
NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_
Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[
NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_
Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmk001<
JeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]j
JeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmk
JeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg/1JeX001Y[FP03001[FV]J0?m[FTa[FP000?m_
Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]J001[FVmkJeY[
NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_
Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[
NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_
Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[
NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_
Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[
NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_
Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgX006Q[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmk
JeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]j
JeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmk
JeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]j
0F]J000JJeX00`00JeY[FP3oJeY<JeX0003oJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[
NV]JKg][FV]jJeY_Nf]JJgY[FP00JeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_
Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[
NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_
Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[
NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_
Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[
NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_
Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmk001X
JeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]j
JeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmk
JeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]j
JeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_N`5[FP006V]J00<006]JJeX0of]JC6]J0000ofmkJeY[
NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeX006]JKg][FV]jJeY_
Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[
NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_
Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[
NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_
Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[
NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_
Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[
NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NP00J6]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]j
JeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmk
JeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]j
JeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgX1JeX0
01Y[FP03001[FV]J0?m[FTa[FP0001Y[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_
Nf]JJgY[FVmkJeY[NV]J0P000?m[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]J
JgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]J
Kg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]J
JgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]J
Kg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]J
JgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]J
Kg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]J
JgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]J
Kg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg/004a[FV]jJeY_
Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[
NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_
Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_N`5[FP006V]J00<006]JJeX0of]JC6]J0000ofmkJeY[NV]J
Kg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeX006]JKg][FV]jJeY_Nf]J
JgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]J
Kg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]J
JgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]J
Kg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]J
JgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]J
Kg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]J
JgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]J
Kg][FV]jJeY_Nf]JJgY[FVmkJeY[NP00J6]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_
Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[
NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_
Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgX1JeX001Y[
FP03001[FV]J0?m[FTa[FP000?m[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]J
JgY[FVmkJeY[NV]J001[FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]J
Kg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]J
JgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]J
Kg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]J
JgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]J
Kg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]J
JgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]J
Kg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg/006Q[FV]jJeY_
Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[
NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_
Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[
NV]JKg][FV]jJeY_Nf]JJgY[FVmk0F]J000JJeX00`00JeY[FP3oJeY<JeX0003oKg][FV]jJeY_Nf]J
JgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FP00JeY_Nf]JJgY[FVmkJeY[NV]J
Kg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]J
JgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]J
Kg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]J
JgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]J
Kg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]J
JgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]J
Kg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]J
JgY[FVmkJeY[NV]JKg][FV]j001XJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[
NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_
Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[
NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NP5[FP006V]J00<0
06]JJeX0of]JC6]J0000of]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]J
Kg][FV]jJeX006]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]J
JgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]J
Kg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]J
JgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]J
Kg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]J
JgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]J
Kg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]J
JgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_N`00J6]JJgY[FVmkJeY[
NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_
Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[
NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_
Nf]JJgY[FVmkJeY[NV]JKg/1JeX001Y[FP800?m[FTe[FP000?m_Nf]JJgY[FVmkJeY[NV]JKg][FV]j
JeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]J001[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmk
JeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]j
JeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmk
JeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]j
JeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmk
JeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]j
JeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmk
JeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]j
JeY_Nf]JJgX006Q[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[
FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][
FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[
FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]j0F]J000JJeX00`00JeY[FP3oJeY<
JeX0003oJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FP00
JeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]j
JeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmk
JeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]j
JeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmk
JeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]j
JeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmk
JeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]j
JeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmk000kJeY[NV]JKg][FV]jJeY_Nf]JJgY[
FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][
FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FP020000:f]jJeY_Nf]JJgY[FVmkJeY[
NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_
Nf]JJgY[FVmk005[FP006V]J00<006]JJeX0of]J7V]J0P00;6]J0000ofmkJeY[NV]JKg][FV]jJeY_
Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeX006]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[
NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_
Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[
NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_
Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[
NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_
Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[
NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_
Nf]JJgY[FVmkJeY[NP00J6]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmk
JeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]j
JeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmk
JeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgX1JeX001Y[FP03001[FV]J
0?m[FTa[FP000?m[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[
NV]J001[FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_
Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[
NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_
Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[
NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_
Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[
NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_
Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg/006Q[FV]jJeY_Nf]JJgY[FVmk
JeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]j
JeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmk
JeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]j
JeY_Nf]JJgY[FVmk0F]J000JJeX00`00JeY[FP3oJeY<JeX0003oKg][FV]jJeY_Nf]JJgY[FVmkJeY[
NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_
Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[
NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_
Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[
NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_
Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[
NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_
Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[
NV]JKg][FV]j001XJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]j
JeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmk
JeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]j
JeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NP5[FP00\
\>"],
  ImageRangeCache->{{{140.063, 427.063}, {284, 107.063}} -> {-62.9047, \
138.234, 0.389667, 1.47536}}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(8\ Table[
        Plus\  @@ \ Select[Divisors[n], \((Mod[#, 4] \[NotEqual] 0)\) &], {n, 
          10}]\)], "Input"],

Cell[BoxData[
    \({8, 24, 32, 24, 48, 96, 64, 24, 104, 144}\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(\((1 + 2  Plus @@ \(x\^\(Range[10]\^2\)\))\)\^4 + O[x]\^11\)], "Input"],

Cell[BoxData[
    InterpretationBox[
      RowBox[{
      "1", "+", \(8\ x\), "+", \(24\ x\^2\), "+", \(32\ x\^3\), 
        "+", \(24\ x\^4\), "+", \(48\ x\^5\), "+", \(96\ x\^6\), 
        "+", \(64\ x\^7\), "+", \(24\ x\^8\), "+", \(104\ x\^9\), 
        "+", \(144\ x\^10\), "+", 
        InterpretationBox[\(O[x]\^11\),
          SeriesData[ x, 0, {}, 0, 11, 1]]}],
      SeriesData[ 
      x, 0, {1, 8, 24, 32, 24, 48, 96, 64, 24, 104, 144}, 0, 11, 
        1]]], "Output"]
}, Open  ]],

Cell["\<\
Every positive integer, with the twelve exceptions below, is a sum of five \
positive squares.\
\>", "Text"],

Cell[BoxData[
    \(sumFiveSquares[n_] := 
      Module[{ans = False, i, j, k, l, 
          m}, \[IndentingNewLine]Do[\[IndentingNewLine]m = \@\(n - i\^2 - \
j\^2 - k\^2 - l\^2\); \[IndentingNewLine]If[IntegerQ[m] && \((m > 0)\), 
            Return[ans = True]], {i, \[LeftFloor]\@n\[RightFloor]}, {j, 
            i, \[LeftFloor]\@\(n - i\^2\)\[RightFloor]}, {k, 
            j, \[LeftFloor]\@\(n - i\^2 - j\^2\)\[RightFloor]}, {l, 
            k, \[LeftFloor]\@\(n - i\^2 - j\^2 - k\^2\)\[RightFloor]}]; \
\[IndentingNewLine]ans]\)], "Input"],

Cell[CellGroupData[{

Cell[BoxData[
    \(Select[Range[1000], Not[sumFiveSquares[#]] &] // Timing\)], "Input"],

Cell[BoxData[
    \({19.329999999999927`\ Second, {1, 2, 3, 4, 6, 7, 9, 10, 12, 15, 18, 
        33}}\)], "Output"]
}, Open  ]],

Cell["\<\
The same finite condition applies also to sums of six squares.\
\>", "Text"]
}, Closed]],

Cell[CellGroupData[{

Cell["SUMS OF MANY SQUARES", "Subsection"],

Cell[BoxData[{
    \(powersSum[0, i_] := {{}}\[IndentingNewLine]\), "\n", 
    \(powersSum[n_, i_] := 
      Module[{j, k}, \[IndentingNewLine]k = 
          Map[\((j = #; \[IndentingNewLine]Map[Join[{j}, #] &, 
                  powersSum[n - j\^i, i]])\) &, 
            Range[\@n\%i]]; \[IndentingNewLine]Union[
          Sort\  /@ \ Flatten[k, 1]]]\)}], "Input",
  InitializationCell->True],

Cell[CellGroupData[{

Cell[BoxData[
    \(Do[Print[n, "\<  \>", \(asSum[#, 2] &\)\  /@ \ powersSum[n, 2]], {n, 
        10}]\)], "Input"],

Cell[BoxData[
    InterpretationBox[\(1\[InvisibleSpace]"  "\[InvisibleSpace]{"1"\^2}\),
      SequenceForm[ 1, "  ", {
        Power[ "1", 2]}],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      RowBox[{"2", "\[InvisibleSpace]", "\<\"  \"\>", "\[InvisibleSpace]", 
        RowBox[{"{", 
          TagBox[\("1"\^2 + "1"\^2\),
            DisplayForm], "}"}]}],
      SequenceForm[ 2, "  ", {
        DisplayForm[ 
          RowBox[ {
            Power[ "1", 2], "+", 
            Power[ "1", 2]}]]}],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      RowBox[{"3", "\[InvisibleSpace]", "\<\"  \"\>", "\[InvisibleSpace]", 
        RowBox[{"{", 
          TagBox[
            RowBox[{\("1"\^2\), "+", 
              TagBox[\("1"\^2 + "1"\^2\),
                DisplayForm]}],
            DisplayForm], "}"}]}],
      SequenceForm[ 3, "  ", {
        DisplayForm[ 
          RowBox[ {
            Power[ "1", 2], "+", 
            DisplayForm[ 
              RowBox[ {
                Power[ "1", 2], "+", 
                Power[ "1", 2]}]]}]]}],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      RowBox[{"4", "\[InvisibleSpace]", "\<\"  \"\>", "\[InvisibleSpace]", 
        RowBox[{"{", 
          RowBox[{\("2"\^2\), ",", 
            TagBox[
              RowBox[{\("1"\^2\), "+", 
                TagBox[
                  RowBox[{\("1"\^2\), "+", 
                    TagBox[\("1"\^2 + "1"\^2\),
                      DisplayForm]}],
                  DisplayForm]}],
              DisplayForm]}], "}"}]}],
      SequenceForm[ 4, "  ", {
        Power[ "2", 2], 
        DisplayForm[ 
          RowBox[ {
            Power[ "1", 2], "+", 
            DisplayForm[ 
              RowBox[ {
                Power[ "1", 2], "+", 
                DisplayForm[ 
                  RowBox[ {
                    Power[ "1", 2], "+", 
                    Power[ "1", 2]}]]}]]}]]}],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      RowBox[{"5", "\[InvisibleSpace]", "\<\"  \"\>", "\[InvisibleSpace]", 
        RowBox[{"{", 
          RowBox[{
            TagBox[\("1"\^2 + "2"\^2\),
              DisplayForm], ",", 
            TagBox[
              RowBox[{\("1"\^2\), "+", 
                TagBox[
                  RowBox[{\("1"\^2\), "+", 
                    TagBox[
                      RowBox[{\("1"\^2\), "+", 
                        TagBox[\("1"\^2 + "1"\^2\),
                          DisplayForm]}],
                      DisplayForm]}],
                  DisplayForm]}],
              DisplayForm]}], "}"}]}],
      SequenceForm[ 5, "  ", {
        DisplayForm[ 
          RowBox[ {
            Power[ "1", 2], "+", 
            Power[ "2", 2]}]], 
        DisplayForm[ 
          RowBox[ {
            Power[ "1", 2], "+", 
            DisplayForm[ 
              RowBox[ {
                Power[ "1", 2], "+", 
                DisplayForm[ 
                  RowBox[ {
                    Power[ "1", 2], "+", 
                    DisplayForm[ 
                      RowBox[ {
                        Power[ "1", 2], "+", 
                        Power[ "1", 2]}]]}]]}]]}]]}],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      RowBox[{"6", "\[InvisibleSpace]", "\<\"  \"\>", "\[InvisibleSpace]", 
        RowBox[{"{", 
          RowBox[{
            TagBox[
              RowBox[{\("1"\^2\), "+", 
                TagBox[\("1"\^2 + "2"\^2\),
                  DisplayForm]}],
              DisplayForm], ",", 
            TagBox[
              RowBox[{\("1"\^2\), "+", 
                TagBox[
                  RowBox[{\("1"\^2\), "+", 
                    TagBox[
                      RowBox[{\("1"\^2\), "+", 
                        TagBox[
                          RowBox[{\("1"\^2\), "+", 
                            TagBox[\("1"\^2 + "1"\^2\),
                              DisplayForm]}],
                          DisplayForm]}],
                      DisplayForm]}],
                  DisplayForm]}],
              DisplayForm]}], "}"}]}],
      SequenceForm[ 6, "  ", {
        DisplayForm[ 
          RowBox[ {
            Power[ "1", 2], "+", 
            DisplayForm[ 
              RowBox[ {
                Power[ "1", 2], "+", 
                Power[ "2", 2]}]]}]], 
        DisplayForm[ 
          RowBox[ {
            Power[ "1", 2], "+", 
            DisplayForm[ 
              RowBox[ {
                Power[ "1", 2], "+", 
                DisplayForm[ 
                  RowBox[ {
                    Power[ "1", 2], "+", 
                    DisplayForm[ 
                      RowBox[ {
                        Power[ "1", 2], "+", 
                        DisplayForm[ 
                          RowBox[ {
                            Power[ "1", 2], "+", 
                            Power[ "1", 2]}]]}]]}]]}]]}]]}],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      RowBox[{"7", "\[InvisibleSpace]", "\<\"  \"\>", "\[InvisibleSpace]", 
        RowBox[{"{", 
          RowBox[{
            TagBox[
              RowBox[{\("1"\^2\), "+", 
                TagBox[
                  RowBox[{\("1"\^2\), "+", 
                    TagBox[\("1"\^2 + "2"\^2\),
                      DisplayForm]}],
                  DisplayForm]}],
              DisplayForm], ",", 
            TagBox[
              RowBox[{\("1"\^2\), "+", 
                TagBox[
                  RowBox[{\("1"\^2\), "+", 
                    TagBox[
                      RowBox[{\("1"\^2\), "+", 
                        TagBox[
                          RowBox[{\("1"\^2\), "+", 
                            TagBox[
                              RowBox[{\("1"\^2\), "+", 
                                TagBox[\("1"\^2 + "1"\^2\),
                                  DisplayForm]}],
                              DisplayForm]}],
                          DisplayForm]}],
                      DisplayForm]}],
                  DisplayForm]}],
              DisplayForm]}], "}"}]}],
      SequenceForm[ 7, "  ", {
        DisplayForm[ 
          RowBox[ {
            Power[ "1", 2], "+", 
            DisplayForm[ 
              RowBox[ {
                Power[ "1", 2], "+", 
                DisplayForm[ 
                  RowBox[ {
                    Power[ "1", 2], "+", 
                    Power[ "2", 2]}]]}]]}]], 
        DisplayForm[ 
          RowBox[ {
            Power[ "1", 2], "+", 
            DisplayForm[ 
              RowBox[ {
                Power[ "1", 2], "+", 
                DisplayForm[ 
                  RowBox[ {
                    Power[ "1", 2], "+", 
                    DisplayForm[ 
                      RowBox[ {
                        Power[ "1", 2], "+", 
                        DisplayForm[ 
                          RowBox[ {
                            Power[ "1", 2], "+", 
                            DisplayForm[ 
                              RowBox[ {
                                Power[ "1", 2], "+", 
                                Power[ "1", 2]}]]}]]}]]}]]}]]}]]}],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      RowBox[{"8", "\[InvisibleSpace]", "\<\"  \"\>", "\[InvisibleSpace]", 
        RowBox[{"{", 
          RowBox[{
            TagBox[\("2"\^2 + "2"\^2\),
              DisplayForm], ",", 
            TagBox[
              RowBox[{\("1"\^2\), "+", 
                TagBox[
                  RowBox[{\("1"\^2\), "+", 
                    TagBox[
                      RowBox[{\("1"\^2\), "+", 
                        TagBox[\("1"\^2 + "2"\^2\),
                          DisplayForm]}],
                      DisplayForm]}],
                  DisplayForm]}],
              DisplayForm], ",", 
            TagBox[
              RowBox[{\("1"\^2\), "+", 
                TagBox[
                  RowBox[{\("1"\^2\), "+", 
                    TagBox[
                      RowBox[{\("1"\^2\), "+", 
                        TagBox[
                          RowBox[{\("1"\^2\), "+", 
                            TagBox[
                              RowBox[{\("1"\^2\), "+", 
                                TagBox[
                                  RowBox[{\("1"\^2\), "+", 
                                    TagBox[\("1"\^2 + "1"\^2\),
                                      DisplayForm]}],
                                  DisplayForm]}],
                              DisplayForm]}],
                          DisplayForm]}],
                      DisplayForm]}],
                  DisplayForm]}],
              DisplayForm]}], "}"}]}],
      SequenceForm[ 8, "  ", {
        DisplayForm[ 
          RowBox[ {
            Power[ "2", 2], "+", 
            Power[ "2", 2]}]], 
        DisplayForm[ 
          RowBox[ {
            Power[ "1", 2], "+", 
            DisplayForm[ 
              RowBox[ {
                Power[ "1", 2], "+", 
                DisplayForm[ 
                  RowBox[ {
                    Power[ "1", 2], "+", 
                    DisplayForm[ 
                      RowBox[ {
                        Power[ "1", 2], "+", 
                        Power[ "2", 2]}]]}]]}]]}]], 
        DisplayForm[ 
          RowBox[ {
            Power[ "1", 2], "+", 
            DisplayForm[ 
              RowBox[ {
                Power[ "1", 2], "+", 
                DisplayForm[ 
                  RowBox[ {
                    Power[ "1", 2], "+", 
                    DisplayForm[ 
                      RowBox[ {
                        Power[ "1", 2], "+", 
                        DisplayForm[ 
                          RowBox[ {
                            Power[ "1", 2], "+", 
                            DisplayForm[ 
                              RowBox[ {
                                Power[ "1", 2], "+", 
                                DisplayForm[ 
                                  RowBox[ {
                                    Power[ "1", 2], "+", 
                                    Power[ "1", 2]}]]}]]}]]}]]}]]}]]}]]}],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      RowBox[{"9", "\[InvisibleSpace]", "\<\"  \"\>", "\[InvisibleSpace]", 
        RowBox[{"{", 
          RowBox[{\("3"\^2\), ",", 
            TagBox[
              RowBox[{\("1"\^2\), "+", 
                TagBox[\("2"\^2 + "2"\^2\),
                  DisplayForm]}],
              DisplayForm], ",", 
            TagBox[
              RowBox[{\("1"\^2\), "+", 
                TagBox[
                  RowBox[{\("1"\^2\), "+", 
                    TagBox[
                      RowBox[{\("1"\^2\), "+", 
                        TagBox[
                          RowBox[{\("1"\^2\), "+", 
                            TagBox[\("1"\^2 + "2"\^2\),
                              DisplayForm]}],
                          DisplayForm]}],
                      DisplayForm]}],
                  DisplayForm]}],
              DisplayForm], ",", 
            TagBox[
              RowBox[{\("1"\^2\), "+", 
                TagBox[
                  RowBox[{\("1"\^2\), "+", 
                    TagBox[
                      RowBox[{\("1"\^2\), "+", 
                        TagBox[
                          RowBox[{\("1"\^2\), "+", 
                            TagBox[
                              RowBox[{\("1"\^2\), "+", 
                                TagBox[
                                  RowBox[{\("1"\^2\), "+", 
                                    TagBox[
                                      RowBox[{\("1"\^2\), "+", 
                                        TagBox[\("1"\^2 + "1"\^2\),
                                        DisplayForm]}],
                                      DisplayForm]}],
                                  DisplayForm]}],
                              DisplayForm]}],
                          DisplayForm]}],
                      DisplayForm]}],
                  DisplayForm]}],
              DisplayForm]}], "}"}]}],
      SequenceForm[ 9, "  ", {
        Power[ "3", 2], 
        DisplayForm[ 
          RowBox[ {
            Power[ "1", 2], "+", 
            DisplayForm[ 
              RowBox[ {
                Power[ "2", 2], "+", 
                Power[ "2", 2]}]]}]], 
        DisplayForm[ 
          RowBox[ {
            Power[ "1", 2], "+", 
            DisplayForm[ 
              RowBox[ {
                Power[ "1", 2], "+", 
                DisplayForm[ 
                  RowBox[ {
                    Power[ "1", 2], "+", 
                    DisplayForm[ 
                      RowBox[ {
                        Power[ "1", 2], "+", 
                        DisplayForm[ 
                          RowBox[ {
                            Power[ "1", 2], "+", 
                            Power[ "2", 2]}]]}]]}]]}]]}]], 
        DisplayForm[ 
          RowBox[ {
            Power[ "1", 2], "+", 
            DisplayForm[ 
              RowBox[ {
                Power[ "1", 2], "+", 
                DisplayForm[ 
                  RowBox[ {
                    Power[ "1", 2], "+", 
                    DisplayForm[ 
                      RowBox[ {
                        Power[ "1", 2], "+", 
                        DisplayForm[ 
                          RowBox[ {
                            Power[ "1", 2], "+", 
                            DisplayForm[ 
                              RowBox[ {
                                Power[ "1", 2], "+", 
                                DisplayForm[ 
                                  RowBox[ {
                                    Power[ "1", 2], "+", 
                                    DisplayForm[ 
                                      RowBox[ {
                                        Power[ "1", 2], "+", 
                                        Power[ 
                                        "1", 2]}]]}]]}]]}]]}]]}]]}]]}]]}],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      RowBox[{"10", "\[InvisibleSpace]", "\<\"  \"\>", "\[InvisibleSpace]", 
        RowBox[{"{", 
          RowBox[{
            TagBox[\("1"\^2 + "3"\^2\),
              DisplayForm], ",", 
            TagBox[
              RowBox[{\("1"\^2\), "+", 
                TagBox[
                  RowBox[{\("1"\^2\), "+", 
                    TagBox[\("2"\^2 + "2"\^2\),
                      DisplayForm]}],
                  DisplayForm]}],
              DisplayForm], ",", 
            TagBox[
              RowBox[{\("1"\^2\), "+", 
                TagBox[
                  RowBox[{\("1"\^2\), "+", 
                    TagBox[
                      RowBox[{\("1"\^2\), "+", 
                        TagBox[
                          RowBox[{\("1"\^2\), "+", 
                            TagBox[
                              RowBox[{\("1"\^2\), "+", 
                                TagBox[\("1"\^2 + "2"\^2\),
                                  DisplayForm]}],
                              DisplayForm]}],
                          DisplayForm]}],
                      DisplayForm]}],
                  DisplayForm]}],
              DisplayForm], ",", 
            TagBox[
              RowBox[{\("1"\^2\), "+", 
                TagBox[
                  RowBox[{\("1"\^2\), "+", 
                    TagBox[
                      RowBox[{\("1"\^2\), "+", 
                        TagBox[
                          RowBox[{\("1"\^2\), "+", 
                            TagBox[
                              RowBox[{\("1"\^2\), "+", 
                                TagBox[
                                  RowBox[{\("1"\^2\), "+", 
                                    TagBox[
                                      RowBox[{\("1"\^2\), "+", 
                                        TagBox[
                                        RowBox[{\("1"\^2\), "+", 
                                        TagBox[\("1"\^2 + "1"\^2\),
                                        DisplayForm]}],
                                        DisplayForm]}],
                                      DisplayForm]}],
                                  DisplayForm]}],
                              DisplayForm]}],
                          DisplayForm]}],
                      DisplayForm]}],
                  DisplayForm]}],
              DisplayForm]}], "}"}]}],
      SequenceForm[ 10, "  ", {
        DisplayForm[ 
          RowBox[ {
            Power[ "1", 2], "+", 
            Power[ "3", 2]}]], 
        DisplayForm[ 
          RowBox[ {
            Power[ "1", 2], "+", 
            DisplayForm[ 
              RowBox[ {
                Power[ "1", 2], "+", 
                DisplayForm[ 
                  RowBox[ {
                    Power[ "2", 2], "+", 
                    Power[ "2", 2]}]]}]]}]], 
        DisplayForm[ 
          RowBox[ {
            Power[ "1", 2], "+", 
            DisplayForm[ 
              RowBox[ {
                Power[ "1", 2], "+", 
                DisplayForm[ 
                  RowBox[ {
                    Power[ "1", 2], "+", 
                    DisplayForm[ 
                      RowBox[ {
                        Power[ "1", 2], "+", 
                        DisplayForm[ 
                          RowBox[ {
                            Power[ "1", 2], "+", 
                            DisplayForm[ 
                              RowBox[ {
                                Power[ "1", 2], "+", 
                                Power[ "2", 2]}]]}]]}]]}]]}]]}]], 
        DisplayForm[ 
          RowBox[ {
            Power[ "1", 2], "+", 
            DisplayForm[ 
              RowBox[ {
                Power[ "1", 2], "+", 
                DisplayForm[ 
                  RowBox[ {
                    Power[ "1", 2], "+", 
                    DisplayForm[ 
                      RowBox[ {
                        Power[ "1", 2], "+", 
                        DisplayForm[ 
                          RowBox[ {
                            Power[ "1", 2], "+", 
                            DisplayForm[ 
                              RowBox[ {
                                Power[ "1", 2], "+", 
                                DisplayForm[ 
                                  RowBox[ {
                                    Power[ "1", 2], "+", 
                                    DisplayForm[ 
                                      RowBox[ {
                                        Power[ "1", 2], "+", 
                                        DisplayForm[ 
                                        RowBox[ {
                                        Power[ "1", 2], "+", 
                                        Power[ 
                                        "1", 2]}]]}]]}]]}]]}]]}]]}]]}]]}]]}],
      Editable->False]], "Print"]
}, Open  ]],

Cell["\<\
(Jeffrey Shallit) Call a set of string sparse if, as n \[Rule] \[Infinity], \
it contains a vanishingly small fraction of all possible strings of length n. \
Then can one find a sparse set S of strings of 0's and 1's such that every \
string of 0's and 1's can be written as the concatenation of two strings from \
S? One solution is to let S be the set of all strings of 0's and 1's such \
that the number of 1's is a sum of two squares. Lagrange's theorem \
establishes that every number is a sum of four squares (of non-negative \
integers), so every string of 0's and 1's is a concatenation of two strings \
chosen from S.\
\>", "Commentary"]
}, Closed]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Sums of Powers", "Section"],

Cell[CellGroupData[{

Cell["SUMS OF CUBES", "Subsection"],

Cell[CellGroupData[{

Cell[BoxData[
    \(Do[Print[n, "\<  \>", \(asSum[#, 3] &\)\  /@ \ powersSum[n, 3]], {n, 
        10}]\)], "Input"],

Cell[BoxData[
    InterpretationBox[\(1\[InvisibleSpace]"  "\[InvisibleSpace]{"1"\^3}\),
      SequenceForm[ 1, "  ", {
        Power[ "1", 3]}],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      RowBox[{"2", "\[InvisibleSpace]", "\<\"  \"\>", "\[InvisibleSpace]", 
        RowBox[{"{", 
          TagBox[\("1"\^3 + "1"\^3\),
            DisplayForm], "}"}]}],
      SequenceForm[ 2, "  ", {
        DisplayForm[ 
          RowBox[ {
            Power[ "1", 3], "+", 
            Power[ "1", 3]}]]}],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      RowBox[{"3", "\[InvisibleSpace]", "\<\"  \"\>", "\[InvisibleSpace]", 
        RowBox[{"{", 
          TagBox[
            RowBox[{\("1"\^3\), "+", 
              TagBox[\("1"\^3 + "1"\^3\),
                DisplayForm]}],
            DisplayForm], "}"}]}],
      SequenceForm[ 3, "  ", {
        DisplayForm[ 
          RowBox[ {
            Power[ "1", 3], "+", 
            DisplayForm[ 
              RowBox[ {
                Power[ "1", 3], "+", 
                Power[ "1", 3]}]]}]]}],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      RowBox[{"4", "\[InvisibleSpace]", "\<\"  \"\>", "\[InvisibleSpace]", 
        RowBox[{"{", 
          TagBox[
            RowBox[{\("1"\^3\), "+", 
              TagBox[
                RowBox[{\("1"\^3\), "+", 
                  TagBox[\("1"\^3 + "1"\^3\),
                    DisplayForm]}],
                DisplayForm]}],
            DisplayForm], "}"}]}],
      SequenceForm[ 4, "  ", {
        DisplayForm[ 
          RowBox[ {
            Power[ "1", 3], "+", 
            DisplayForm[ 
              RowBox[ {
                Power[ "1", 3], "+", 
                DisplayForm[ 
                  RowBox[ {
                    Power[ "1", 3], "+", 
                    Power[ "1", 3]}]]}]]}]]}],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      RowBox[{"5", "\[InvisibleSpace]", "\<\"  \"\>", "\[InvisibleSpace]", 
        RowBox[{"{", 
          TagBox[
            RowBox[{\("1"\^3\), "+", 
              TagBox[
                RowBox[{\("1"\^3\), "+", 
                  TagBox[
                    RowBox[{\("1"\^3\), "+", 
                      TagBox[\("1"\^3 + "1"\^3\),
                        DisplayForm]}],
                    DisplayForm]}],
                DisplayForm]}],
            DisplayForm], "}"}]}],
      SequenceForm[ 5, "  ", {
        DisplayForm[ 
          RowBox[ {
            Power[ "1", 3], "+", 
            DisplayForm[ 
              RowBox[ {
                Power[ "1", 3], "+", 
                DisplayForm[ 
                  RowBox[ {
                    Power[ "1", 3], "+", 
                    DisplayForm[ 
                      RowBox[ {
                        Power[ "1", 3], "+", 
                        Power[ "1", 3]}]]}]]}]]}]]}],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      RowBox[{"6", "\[InvisibleSpace]", "\<\"  \"\>", "\[InvisibleSpace]", 
        RowBox[{"{", 
          TagBox[
            RowBox[{\("1"\^3\), "+", 
              TagBox[
                RowBox[{\("1"\^3\), "+", 
                  TagBox[
                    RowBox[{\("1"\^3\), "+", 
                      TagBox[
                        RowBox[{\("1"\^3\), "+", 
                          TagBox[\("1"\^3 + "1"\^3\),
                            DisplayForm]}],
                        DisplayForm]}],
                    DisplayForm]}],
                DisplayForm]}],
            DisplayForm], "}"}]}],
      SequenceForm[ 6, "  ", {
        DisplayForm[ 
          RowBox[ {
            Power[ "1", 3], "+", 
            DisplayForm[ 
              RowBox[ {
                Power[ "1", 3], "+", 
                DisplayForm[ 
                  RowBox[ {
                    Power[ "1", 3], "+", 
                    DisplayForm[ 
                      RowBox[ {
                        Power[ "1", 3], "+", 
                        DisplayForm[ 
                          RowBox[ {
                            Power[ "1", 3], "+", 
                            Power[ "1", 3]}]]}]]}]]}]]}]]}],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      RowBox[{"7", "\[InvisibleSpace]", "\<\"  \"\>", "\[InvisibleSpace]", 
        RowBox[{"{", 
          TagBox[
            RowBox[{\("1"\^3\), "+", 
              TagBox[
                RowBox[{\("1"\^3\), "+", 
                  TagBox[
                    RowBox[{\("1"\^3\), "+", 
                      TagBox[
                        RowBox[{\("1"\^3\), "+", 
                          TagBox[
                            RowBox[{\("1"\^3\), "+", 
                              TagBox[\("1"\^3 + "1"\^3\),
                                DisplayForm]}],
                            DisplayForm]}],
                        DisplayForm]}],
                    DisplayForm]}],
                DisplayForm]}],
            DisplayForm], "}"}]}],
      SequenceForm[ 7, "  ", {
        DisplayForm[ 
          RowBox[ {
            Power[ "1", 3], "+", 
            DisplayForm[ 
              RowBox[ {
                Power[ "1", 3], "+", 
                DisplayForm[ 
                  RowBox[ {
                    Power[ "1", 3], "+", 
                    DisplayForm[ 
                      RowBox[ {
                        Power[ "1", 3], "+", 
                        DisplayForm[ 
                          RowBox[ {
                            Power[ "1", 3], "+", 
                            DisplayForm[ 
                              RowBox[ {
                                Power[ "1", 3], "+", 
                                Power[ "1", 3]}]]}]]}]]}]]}]]}]]}],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      RowBox[{"8", "\[InvisibleSpace]", "\<\"  \"\>", "\[InvisibleSpace]", 
        RowBox[{"{", 
          RowBox[{\("2"\^3\), ",", 
            TagBox[
              RowBox[{\("1"\^3\), "+", 
                TagBox[
                  RowBox[{\("1"\^3\), "+", 
                    TagBox[
                      RowBox[{\("1"\^3\), "+", 
                        TagBox[
                          RowBox[{\("1"\^3\), "+", 
                            TagBox[
                              RowBox[{\("1"\^3\), "+", 
                                TagBox[
                                  RowBox[{\("1"\^3\), "+", 
                                    TagBox[\("1"\^3 + "1"\^3\),
                                      DisplayForm]}],
                                  DisplayForm]}],
                              DisplayForm]}],
                          DisplayForm]}],
                      DisplayForm]}],
                  DisplayForm]}],
              DisplayForm]}], "}"}]}],
      SequenceForm[ 8, "  ", {
        Power[ "2", 3], 
        DisplayForm[ 
          RowBox[ {
            Power[ "1", 3], "+", 
            DisplayForm[ 
              RowBox[ {
                Power[ "1", 3], "+", 
                DisplayForm[ 
                  RowBox[ {
                    Power[ "1", 3], "+", 
                    DisplayForm[ 
                      RowBox[ {
                        Power[ "1", 3], "+", 
                        DisplayForm[ 
                          RowBox[ {
                            Power[ "1", 3], "+", 
                            DisplayForm[ 
                              RowBox[ {
                                Power[ "1", 3], "+", 
                                DisplayForm[ 
                                  RowBox[ {
                                    Power[ "1", 3], "+", 
                                    Power[ "1", 3]}]]}]]}]]}]]}]]}]]}]]}],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      RowBox[{"9", "\[InvisibleSpace]", "\<\"  \"\>", "\[InvisibleSpace]", 
        RowBox[{"{", 
          RowBox[{
            TagBox[\("1"\^3 + "2"\^3\),
              DisplayForm], ",", 
            TagBox[
              RowBox[{\("1"\^3\), "+", 
                TagBox[
                  RowBox[{\("1"\^3\), "+", 
                    TagBox[
                      RowBox[{\("1"\^3\), "+", 
                        TagBox[
                          RowBox[{\("1"\^3\), "+", 
                            TagBox[
                              RowBox[{\("1"\^3\), "+", 
                                TagBox[
                                  RowBox[{\("1"\^3\), "+", 
                                    TagBox[
                                      RowBox[{\("1"\^3\), "+", 
                                        TagBox[\("1"\^3 + "1"\^3\),
                                        DisplayForm]}],
                                      DisplayForm]}],
                                  DisplayForm]}],
                              DisplayForm]}],
                          DisplayForm]}],
                      DisplayForm]}],
                  DisplayForm]}],
              DisplayForm]}], "}"}]}],
      SequenceForm[ 9, "  ", {
        DisplayForm[ 
          RowBox[ {
            Power[ "1", 3], "+", 
            Power[ "2", 3]}]], 
        DisplayForm[ 
          RowBox[ {
            Power[ "1", 3], "+", 
            DisplayForm[ 
              RowBox[ {
                Power[ "1", 3], "+", 
                DisplayForm[ 
                  RowBox[ {
                    Power[ "1", 3], "+", 
                    DisplayForm[ 
                      RowBox[ {
                        Power[ "1", 3], "+", 
                        DisplayForm[ 
                          RowBox[ {
                            Power[ "1", 3], "+", 
                            DisplayForm[ 
                              RowBox[ {
                                Power[ "1", 3], "+", 
                                DisplayForm[ 
                                  RowBox[ {
                                    Power[ "1", 3], "+", 
                                    DisplayForm[ 
                                      RowBox[ {
                                        Power[ "1", 3], "+", 
                                        Power[ 
                                        "1", 3]}]]}]]}]]}]]}]]}]]}]]}]]}],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      RowBox[{"10", "\[InvisibleSpace]", "\<\"  \"\>", "\[InvisibleSpace]", 
        RowBox[{"{", 
          RowBox[{
            TagBox[
              RowBox[{\("1"\^3\), "+", 
                TagBox[\("1"\^3 + "2"\^3\),
                  DisplayForm]}],
              DisplayForm], ",", 
            TagBox[
              RowBox[{\("1"\^3\), "+", 
                TagBox[
                  RowBox[{\("1"\^3\), "+", 
                    TagBox[
                      RowBox[{\("1"\^3\), "+", 
                        TagBox[
                          RowBox[{\("1"\^3\), "+", 
                            TagBox[
                              RowBox[{\("1"\^3\), "+", 
                                TagBox[
                                  RowBox[{\("1"\^3\), "+", 
                                    TagBox[
                                      RowBox[{\("1"\^3\), "+", 
                                        TagBox[
                                        RowBox[{\("1"\^3\), "+", 
                                        TagBox[\("1"\^3 + "1"\^3\),
                                        DisplayForm]}],
                                        DisplayForm]}],
                                      DisplayForm]}],
                                  DisplayForm]}],
                              DisplayForm]}],
                          DisplayForm]}],
                      DisplayForm]}],
                  DisplayForm]}],
              DisplayForm]}], "}"}]}],
      SequenceForm[ 10, "  ", {
        DisplayForm[ 
          RowBox[ {
            Power[ "1", 3], "+", 
            DisplayForm[ 
              RowBox[ {
                Power[ "1", 3], "+", 
                Power[ "2", 3]}]]}]], 
        DisplayForm[ 
          RowBox[ {
            Power[ "1", 3], "+", 
            DisplayForm[ 
              RowBox[ {
                Power[ "1", 3], "+", 
                DisplayForm[ 
                  RowBox[ {
                    Power[ "1", 3], "+", 
                    DisplayForm[ 
                      RowBox[ {
                        Power[ "1", 3], "+", 
                        DisplayForm[ 
                          RowBox[ {
                            Power[ "1", 3], "+", 
                            DisplayForm[ 
                              RowBox[ {
                                Power[ "1", 3], "+", 
                                DisplayForm[ 
                                  RowBox[ {
                                    Power[ "1", 3], "+", 
                                    DisplayForm[ 
                                      RowBox[ {
                                        Power[ "1", 3], "+", 
                                        DisplayForm[ 
                                        RowBox[ {
                                        Power[ "1", 3], "+", 
                                        Power[ 
                                        "1", 3]}]]}]]}]]}]]}]]}]]}]]}]]}]]}],
      Editable->False]], "Print"]
}, Open  ]],

Cell["\<\
There are only five positive integers equal to the sum of the cubes of their \
digits\
\>", "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(\(Do[
        If[Plus\  @@ \(IntegerDigits[i]\^3\) == i, Print[i]], {i, 
          10000}];\)\)], "Input"],

Cell[BoxData[
    \(1\)], "Print"],

Cell[BoxData[
    \(153\)], "Print"],

Cell[BoxData[
    \(370\)], "Print"],

Cell[BoxData[
    \(371\)], "Print"],

Cell[BoxData[
    \(407\)], "Print"]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{

Cell["SUMS OF UNEQUAL POWERS. ", "Subsection"],

Cell["\<\
Those sums include powers with the same exponent and unequal base\
\>", "Text"],

Cell[BoxData[
    \(unEqualPowersSum[n_, k_] := 
      Select[powersSum[n, 
          k], \((Length[Union[#]] \[Equal] Length[#])\) &]\)], "Input"],

Cell[CellGroupData[{

Cell[BoxData[
    \(Do[Print[
        n, "\<  \>", \(asSum[#, 2] &\)\  /@ \ unEqualPowersSum[n, 2]], {n, 
        10}]\)], "Input"],

Cell[BoxData[
    InterpretationBox[\(1\[InvisibleSpace]"  "\[InvisibleSpace]{"1"\^2}\),
      SequenceForm[ 1, "  ", {
        Power[ "1", 2]}],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[\(2\[InvisibleSpace]"  "\[InvisibleSpace]{}\),
      SequenceForm[ 2, "  ", {}],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[\(3\[InvisibleSpace]"  "\[InvisibleSpace]{}\),
      SequenceForm[ 3, "  ", {}],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[\(4\[InvisibleSpace]"  "\[InvisibleSpace]{"2"\^2}\),
      SequenceForm[ 4, "  ", {
        Power[ "2", 2]}],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      RowBox[{"5", "\[InvisibleSpace]", "\<\"  \"\>", "\[InvisibleSpace]", 
        RowBox[{"{", 
          TagBox[\("1"\^2 + "2"\^2\),
            DisplayForm], "}"}]}],
      SequenceForm[ 5, "  ", {
        DisplayForm[ 
          RowBox[ {
            Power[ "1", 2], "+", 
            Power[ "2", 2]}]]}],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[\(6\[InvisibleSpace]"  "\[InvisibleSpace]{}\),
      SequenceForm[ 6, "  ", {}],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[\(7\[InvisibleSpace]"  "\[InvisibleSpace]{}\),
      SequenceForm[ 7, "  ", {}],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[\(8\[InvisibleSpace]"  "\[InvisibleSpace]{}\),
      SequenceForm[ 8, "  ", {}],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[\(9\[InvisibleSpace]"  "\[InvisibleSpace]{"3"\^2}\),
      SequenceForm[ 9, "  ", {
        Power[ "3", 2]}],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      RowBox[{"10", "\[InvisibleSpace]", "\<\"  \"\>", "\[InvisibleSpace]", 
        RowBox[{"{", 
          TagBox[\("1"\^2 + "3"\^2\),
            DisplayForm], "}"}]}],
      SequenceForm[ 10, "  ", {
        DisplayForm[ 
          RowBox[ {
            Power[ "1", 2], "+", 
            Power[ "3", 2]}]]}],
      Editable->False]], "Print"]
}, Open  ]],

Cell["Every integer larger than 128 is a sum of unequal squares. ", "Text"],

Cell[CellGroupData[{

Cell[BoxData[{
    \(\(m = Table[0, {40}];\)\), "\[IndentingNewLine]", 
    \(\((Map[\((m\[LeftDoubleBracket]#\[RightDoubleBracket] = 
                Length[unEqualPowersSum[#, 2]])\) &, 
          Select[Range[40], sum2Squares]]; \[IndentingNewLine]m)\) // 
      Timing\)}], "Input"],

Cell[BoxData[
    \({1742.0699999999997`\ Second, {1, 0, 0, 1, 1, 0, 0, 0, 1, 1, 0, 0, 1, 
        0, 0, 1, 1, 0, 0, 1, 0, 0, 0, 0, 2, 2, 0, 0, 2, 0, 0, 0, 0, 1, 0, 1, 
        1, 0, 0, 1}}\)], "Output"]
}, Open  ]],

Cell["\<\
Can you spot the one coming from the Phytagorean triangle (3, 4, 5) in the \
previous answer?\
\>", "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(Do[Print[
        n, "\<  \>", \(asSum[#, 3] &\)\  /@ \ unEqualPowersSum[n, 3]], {n, 
        10}]\)], "Input"],

Cell[BoxData[
    InterpretationBox[\(1\[InvisibleSpace]"  "\[InvisibleSpace]{"1"\^3}\),
      SequenceForm[ 1, "  ", {
        Power[ "1", 3]}],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[\(2\[InvisibleSpace]"  "\[InvisibleSpace]{}\),
      SequenceForm[ 2, "  ", {}],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[\(3\[InvisibleSpace]"  "\[InvisibleSpace]{}\),
      SequenceForm[ 3, "  ", {}],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[\(4\[InvisibleSpace]"  "\[InvisibleSpace]{}\),
      SequenceForm[ 4, "  ", {}],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[\(5\[InvisibleSpace]"  "\[InvisibleSpace]{}\),
      SequenceForm[ 5, "  ", {}],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[\(6\[InvisibleSpace]"  "\[InvisibleSpace]{}\),
      SequenceForm[ 6, "  ", {}],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[\(7\[InvisibleSpace]"  "\[InvisibleSpace]{}\),
      SequenceForm[ 7, "  ", {}],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[\(8\[InvisibleSpace]"  "\[InvisibleSpace]{"2"\^3}\),
      SequenceForm[ 8, "  ", {
        Power[ "2", 3]}],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      RowBox[{"9", "\[InvisibleSpace]", "\<\"  \"\>", "\[InvisibleSpace]", 
        RowBox[{"{", 
          TagBox[\("1"\^3 + "2"\^3\),
            DisplayForm], "}"}]}],
      SequenceForm[ 9, "  ", {
        DisplayForm[ 
          RowBox[ {
            Power[ "1", 3], "+", 
            Power[ "2", 3]}]]}],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[\(10\[InvisibleSpace]"  "\[InvisibleSpace]{}\),
      SequenceForm[ 10, "  ", {}],
      Editable->False]], "Print"]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{

Cell["FERMAT'S EQUATION", "Subsection"],

Cell["Let n>2 be a fixed integer. Consider the series", "Text"],

Cell[BoxData[
    \(f \((x)\)\  = \ \(\(x\^n + x\^\(n\^2\) + x\^\(n\^3\) +  ... \)\
\[IndentingNewLine][f \((x)\)]\^2 = \(c\_1\) x + \(c\_2\) x\^2 + \(c\_3\) 
              x\^3 +  ... \)\)], "Text",
  TextAlignment->Center,
  TextJustification->0],

Cell["The number of integer solutions to Fermat's equation", "Text"],

Cell[BoxData[
    \(x\^n + y\^n = z\^n\)], "Text",
  TextAlignment->Center,
  TextJustification->0],

Cell[TextData[{
  "is equal to ",
  Cell[BoxData[
      \(TraditionalForm\`c\_k\)]],
  ", where k = ",
  Cell[BoxData[
      \(TraditionalForm\`z\^n\)]],
  "\nFor instance, in finding the number of integer solutions of the equation \
",
  Cell[BoxData[
      \(TraditionalForm\`x\^3\)]],
  " +",
  Cell[BoxData[
      \(TraditionalForm\`\(\(\ \)\(y\^3\)\)\)]],
  " = ",
  Cell[BoxData[
      \(TraditionalForm\`z\^3\)]],
  ","
}], "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(F = \((Plus\  @@ \(x\^\(3\^Range[15]\)\))\)\^2 + 
        O[x]\^500000\)], "Input"],

Cell[BoxData[
    InterpretationBox[
      RowBox[{\(x\^6\), "+", \(2\ x\^12\), "+", \(x\^18\), "+", \(2\ x\^30\), 
        "+", \(2\ x\^36\), "+", \(x\^54\), "+", \(2\ x\^84\), 
        "+", \(2\ x\^90\), "+", \(2\ x\^108\), "+", \(x\^162\), 
        "+", \(2\ x\^246\), "+", \(2\ x\^252\), "+", \(2\ x\^270\), 
        "+", \(2\ x\^324\), "+", \(x\^486\), "+", \(2\ x\^732\), 
        "+", \(2\ x\^738\), "+", \(2\ x\^756\), "+", \(2\ x\^810\), 
        "+", \(2\ x\^972\), "+", \(x\^1458\), "+", \(2\ x\^2190\), 
        "+", \(2\ x\^2196\), "+", \(2\ x\^2214\), "+", \(2\ x\^2268\), 
        "+", \(2\ x\^2430\), "+", \(2\ x\^2916\), "+", \(x\^4374\), 
        "+", \(2\ x\^6564\), "+", \(2\ x\^6570\), "+", \(2\ x\^6588\), 
        "+", \(2\ x\^6642\), "+", \(2\ x\^6804\), "+", \(2\ x\^7290\), 
        "+", \(2\ x\^8748\), "+", \(x\^13122\), "+", \(2\ x\^19686\), 
        "+", \(2\ x\^19692\), "+", \(2\ x\^19710\), "+", \(2\ x\^19764\), 
        "+", \(2\ x\^19926\), "+", \(2\ x\^20412\), "+", \(2\ x\^21870\), 
        "+", \(2\ x\^26244\), "+", \(x\^39366\), "+", \(2\ x\^59052\), 
        "+", \(2\ x\^59058\), "+", \(2\ x\^59076\), "+", \(2\ x\^59130\), 
        "+", \(2\ x\^59292\), "+", \(2\ x\^59778\), "+", \(2\ x\^61236\), 
        "+", \(2\ x\^65610\), "+", \(2\ x\^78732\), "+", \(x\^118098\), 
        "+", \(2\ x\^177150\), "+", \(2\ x\^177156\), "+", \(2\ x\^177174\), 
        "+", \(2\ x\^177228\), "+", \(2\ x\^177390\), "+", \(2\ x\^177876\), 
        "+", \(2\ x\^179334\), "+", \(2\ x\^183708\), "+", \(2\ x\^196830\), 
        "+", \(2\ x\^236196\), "+", \(x\^354294\), "+", 
        InterpretationBox[\(O[x]\^500000\),
          SeriesData[ x, 0, {}, 6, 500000, 1]]}],
      SeriesData[ 
      x, 0, {1, 0, 0, 0, 0, 0, 2, 0, 0, 0, 0, 0, 1, 0, 0, 0, 0, 0, 0, 0, 0, 0,
         0, 0, 2, 0, 0, 0, 0, 0, 2, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 
        0, 0, 0, 1, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 
        0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 2, 0, 0, 0, 0, 0, 2, 0, 0, 0, 0, 0, 0, 
        0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 2, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 
        0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 
        0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 1, 0, 0, 0, 
        0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 
        0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 
        0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 
        0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 2, 0, 0, 0, 0, 0, 2, 0, 0, 0, 0, 0, 
        0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 2, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 
        0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 
        0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 2, 0, 0, 
        0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 
        0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 
        0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 
        0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 
        0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 
        0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 
        0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 1, 0, 
        0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 
        0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 
        0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 
        0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 
        0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 
        0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 
        0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 
        0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 
        0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 
        0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 
        0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 2, 0, 0, 0, 0, 0, 2, 0, 0, 
        0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 2, 0, 0, 0, 0, 0, 0, 0, 
        0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 
        0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 
        2, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 
        0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 
        0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 
        0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 
        0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 
        0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 
        0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 
        0, 2, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 
        0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 
        0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 
        0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 
        0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 
        0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 
        0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 
        0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 
        0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 
        0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 
        0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 
        0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 
        0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 
        0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 
        0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 
        0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 
        0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 
        0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 
        0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 
        0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 
        0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 
        0, 0, 0, 0, 1, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 
        0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 
        0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 
        0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 
        0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 
        0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 
        0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 
        0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 
        0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 
        0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 
        0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 
        0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 
        0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 
        0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 
        0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 
        0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 
        0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 
        0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 
        0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 
        0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 
        0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 
        0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 
        0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 
        0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 
        0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 
        0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 
        0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 
        0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 
        0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 
        0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 
        0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 
        0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 
        2, 0, 0, 0, 0, 0, 2, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 
        0, 2, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 
        0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 
        0, 0, 0, 0, 0, 0, 0, 0, 0, 2, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 
        0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 
        0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 
        0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 
        0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 
        0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 
        0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 
        0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 2, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 
        0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 
        0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 
        0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 
        0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 
        0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 
        0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 
        0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 
        0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 
        0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 
        0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 
        0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 
        0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 
        0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 
        0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 
        0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 
        0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 
        0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 
        0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 
        0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 
        0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 
        0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 2, 0, 0, 0, 0, 0, 0, 0, 0, 0, 
        0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 
        0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 
        0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 
        0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 
        0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 
        0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 
        0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 
        0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 
        0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 
        0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 
        0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 
        0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 
        0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 
        0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 
        0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 
        0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 
        0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 
        0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 
        0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 
        0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 
        0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 
        0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 
        0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 
        0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 
        0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 
        0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 
        0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 
        0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 
        0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 
        0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 
        0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 
        0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 
        0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 
        0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 
        0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 
        0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 
        0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 
        0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 
        0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 
        0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 
        0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 
        0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 
        0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 
        0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 
        0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 
        0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 
        0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 
        0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 
        0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 
        0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 
        0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 
        0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 
        0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 
        0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 
        0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 
        0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 
        0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 
        0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 
        0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 
        0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 
        0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 
        0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 
        0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 1, 
        0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 
        0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 
        0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 
        0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 
        0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 
        0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 
        0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 
        0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 
        0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 
        0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 
        0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 
        0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 
        0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 
        0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 
        0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 
        0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 
        0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 
        0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 
        0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 
        0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 
        0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 
        0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 
        0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 
        0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 
        0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 
        0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 
        0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 
        0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 
        0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 
        0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 
        0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 
        0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 
        0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 
        0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 
        0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 
        0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 
        0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 
        0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 
        0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 
        0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 
        0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 
        0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 
        0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 
        0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 
        0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 
        0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 
        0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 
        0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 
        0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 
        0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 
        0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 
        0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 
        0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 
        0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 
        0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 
        0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 
        0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 
        0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 
        0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 
        0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 
        0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 
        0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 
        0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 
        0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 
        0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 
        0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 
        0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 
        0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 
        0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 
        0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 
        0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 
        0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 
        0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 
        0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 
        0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 
        0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 
        0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 
        0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 
        0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 
        0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 
        0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 
        0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 
        0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 
        0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 
        0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 
        0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 
        0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 
        0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 
        0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 
        0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 
        0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 
        0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 
        0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 
        0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 
        0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 
        0, 0, 0, 0, 2, 0, 0, 0, 0, 0, 2, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 
        0, 0, 0, 0, 0, 2, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 
        0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 
        0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 2, 0, 0, 0, 0, 0, 0, 0, 0, 0, 
        0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 
        0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 
        0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 
        0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 
        0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 
        0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 
        0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 2, 0, 0, 0, 0, 0, 0, 0, 0, 
        0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 
        0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 
        0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 
        0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 
        0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 
        0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 
        0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 
        0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 
        0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 
        0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 
        0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 
        0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 
        0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 
        0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 
        0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 
        0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 
        0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 
        0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 
        0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 
        0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 
        0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 2, 0, 0, 0, 0, 0, 
        0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 
        0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 
        0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 
        0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 
        0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 
        0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 
        0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 
        0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 
        0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 
        0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 
        0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 
        0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 
        0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 
        0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 
        0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 
        0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 
        0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 
        0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 
        0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 
        0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 
        0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 
        0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 
        0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 
        0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 
        0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 
        0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 
        0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 
        0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 
        0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 
        0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 
        0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 
        0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 
        0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 
        0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 
        0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 
        0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 
        0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 
        0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 
        0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 
        0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 
        0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 
        0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 
        0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 
        0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 
        0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 
        0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 
        0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 
        0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 
        0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 
        0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 
        0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 
        0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 
        0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 
        0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 
        0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 
        0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 
        0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 
        0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 
        0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 
        0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 
        0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 
        0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 
        0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 
        0, 0, 0, 2, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 
        0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 
        0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 
        0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 
        0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 
        0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 
        0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 
        0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 
        0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 
        0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 
        0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 
        0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 
        0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 
        0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 
        0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 
        0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 
        0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 
        0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 
        0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 
        0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 
        0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 
        0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 
        0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 
        0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 
        0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 
        0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 
        0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 
        0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 
        0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 
        0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 
        0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 
        0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 
        0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 
        0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 
        0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 
        0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 
        0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 
        0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 
        0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 
        0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 
        0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 
        0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 
        0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 
        0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 
        0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 
        0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 
        0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 
        0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 
        0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 
        0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 
        0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 
        0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 
        0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 
        0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 
        0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 
        0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 
        0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 
        0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 
        0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 
        0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 
        0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 
        0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 
        0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 
        0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 
        0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 
        0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 
        0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 
        0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 
        0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 
        0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 
        0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 
        0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 
        0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 
        0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 
        0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 
        0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 
        0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 
        0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 
        0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 
        0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 
        0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 
        0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 
        0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 
        0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 
        0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 
        0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 
        0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 
        0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 
        0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 
        0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 
        0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 
        0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 
        0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 
        0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 
        0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 
        0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 
        0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 
        0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 
        0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 
        0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 
        0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 
        0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 
        0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 
        0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 
        0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 
        0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 
        0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 
        0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 
        0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 
        0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 
        0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 
        0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 
        0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 
        0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 
        0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 
        0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 
        0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 
        0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 
        0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 
        0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 
        0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 
        0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 
        0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 
        0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 
        0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 
        0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 
        0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 
        0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 
        0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 
        0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 
        0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 
        0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 
        0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 
        0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 
        0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 
        0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 
        0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 
        0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 
        0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 
        0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 
        0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 
        0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 
        0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 
        0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 
        0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 
        0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 
        0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 
        0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 
        0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 
        0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 
        0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 
        0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 
        0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 
        0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 
        0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 
        0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 
        0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 
        0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 
        0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 
        0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 
        0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 
        0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 
        0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 
        0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 
        0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 
        0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 
        0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 
        0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 
        0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 
        0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 
        0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 
        0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 
        0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 
        0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 
        0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 
        0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 
        0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 
        0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 
        0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 
        0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 
        0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 
        0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 
        0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 
        0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 
        0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 
        0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 
        0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 
        0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 
        0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 
        0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 
        0, 0, 0, 0, 0, 0, 0, 1, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 
        0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 
        0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 
        0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 
        0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 
        0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 
        0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 
        0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 
        0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 
        0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 
        0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 
        0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 
        0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 
        0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 
        0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 
        0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 
        0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 
        0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 
        0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 
        0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 
        0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 
        0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 
        0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 
        0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 
        0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 
        0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 
        0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 
        0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 
        0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 
        0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 
        0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 
        0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 
        0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 
        0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 
        0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 
        0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 
        0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 
        0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 
        0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 
        0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 
        0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 
        0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 
        0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 
        0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 
        0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 
        0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 
        0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 
        0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 
        0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 
        0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 
        0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 
        0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 
        0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 
        0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 
        0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 
        0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 
        0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 
        0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 
        0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 
        0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 
        0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 
        0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 
        0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 
        0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 
        0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 
        0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 
        0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 
        0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 
        0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 
        0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 
        0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 
        0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 
        0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 
        0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 
        0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 
        0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 
        0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 
        0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 
        0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 
        0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 
        0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 
        0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 
        0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 
        0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 
        0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 
        0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 
        0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 
        0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 
        0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 
        0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 
        0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 
        0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 
        0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 
        0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 
        0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 
        0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 
        0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 
        0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 
        0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 
        0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 
        0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 
        0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 
        0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 
        0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 
        0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 
        0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 
        0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 
        0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 
        0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 
        0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 
        0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 
        0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 
        0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 
        0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 
        0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 
        0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 
        0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 
        0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 
        0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 
        0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 
        0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 
        0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 
        0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 
        0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 
        0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 
        0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 
        0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 
        0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 
        0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 
        0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 
        0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 
        0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 
        0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 
        0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 
        0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 
        0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 
        0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 
        0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 
        0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 
        0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 
        0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 
        0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 
        0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 
        0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 
        0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 
        0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 
        0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 
        0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 
        0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 
        0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 
        0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 
        0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 
        0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 
        0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 
        0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 
        0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 
        0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 
        0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 
        0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 
        0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 
        0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 
        0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 
        0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 
        0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 
        0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 
        0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 
        0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 
        0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 
        0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 
        0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 
        0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 
        0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 
        0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 
        0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 
        0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 
        0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 
        0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 
        0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 
        0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 
        0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 
        0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 
        0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 
        0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 
        0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 
        0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 
        0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 
        0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 
        0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 
        0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 
        0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 
        0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 
        0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 
        0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 
        0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 
        0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 
        0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 
        0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 
        0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 
        0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 
        0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 
        0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 
        0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 
        0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 
        0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 
        0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 
        0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 
        0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 
        0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 
        0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 
        0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 
        0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 
        0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 
        0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 
        0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 
        0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 
        0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 
        0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 
        0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 
        0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 
        0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 
        0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 
        0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 
        0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 
        0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 
        0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 
        0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 
        0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 
        0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 
        0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 
        0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 
        0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 
        0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 
        0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 
        0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 
        0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 
        0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 
        0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 
        0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 
        0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 
        0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 
        0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 
        0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 
        0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 
        0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 
        0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 
        0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 
        0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 
        0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 
        0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 
        0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 
        0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 
        0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 
        0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 
        0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 
        0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 
        0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 
        0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 
        0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 
        0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 
        0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 
        0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 
        0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 
        0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 
        0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 
        0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 
        0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 
        0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 
        0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 
        0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 
        0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 
        0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 
        0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 
        0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 
        0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 
        0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 
        0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 
        0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 
        0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 
        0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 
        0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 
        0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 
        0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 
        0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 
        0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 
        0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 
        0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 2, 0, 0, 0, 0, 0, 2, 
        0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 2, 0, 0, 0, 0, 0, 
        0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 
        0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 
        0, 0, 2, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 
        0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 
        0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 
        0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 
        0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 
        0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 
        0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 
        0, 0, 0, 2, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 
        0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 
        0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 
        0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 
        0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 
        0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 
        0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 
        0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 
        0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 
        0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 
        0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 
        0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 
        0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 
        0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 
        0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 
        0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 
        0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 
        0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 
        0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 
        0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 
        0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 
        0, 0, 0, 0, 0, 0, 2, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 
        0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 
        0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 
        0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 
        0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 
        0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 
        0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 
        0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 
        0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 
        0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 
        0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 
        0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 
        0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 
        0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 
        0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 
        0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 
        0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 
        0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 
        0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 
        0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 
        0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 
        0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 
        0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 
        0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 
        0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 
        0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 
        0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 
        0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 
        0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 
        0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 
        0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 
        0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 
        0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 
        0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 
        0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 
        0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 
        0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 
        0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 
        0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 
        0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 
        0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 
        0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 
        0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 
        0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 
        0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 
        0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 
        0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 
        0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 
        0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 
        0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 
        0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 
        0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 
        0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 
        0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 
        0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 
        0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 
        0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 
        0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 
        0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 
        0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 
        0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 
        0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 
        0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 
        0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 2, 0, 0, 0, 0, 0, 0, 0, 
        0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 
        0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 
        0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 
        0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 
        0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 
        0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 
        0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 
        0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 
        0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 
        0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 
        0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 
        0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 
        0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 
        0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 
        0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 
        0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 
        0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 
        0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 
        0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 
        0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 
        0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 
        0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 
        0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 
        0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 
        0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 
        0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 
        0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 
        0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 
        0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 
        0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 
        0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 
        0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 
        0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 
        0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 
        0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 
        0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 
        0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 
        0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 
        0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 
        0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 
        0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 
        0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 
        0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 
        0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 
        0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 
        0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 
        0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 
        0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 
        0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 
        0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 
        0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 
        0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 
        0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 
        0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 
        0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 
        0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 
        0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 
        0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 
        0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 
        0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 
        0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 
        0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 
        0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 
        0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 
        0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 
        0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 
        0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 
        0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 
        0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 
        0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 
        0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 
        0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 
        0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 
        0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 
        0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 
        0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 
        0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 
        0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 
        0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 
        0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 
        0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 
        0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 
        0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 
        0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 
        0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 
        0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 
        0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 
        0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 
        0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 
        0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 
        0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 
        0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 
        0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 
        0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 
        0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 
        0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 
        0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 
        0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 
        0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 
        0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 
        0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 
        0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 
        0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 
        0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 
        0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 
        0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 
        0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 
        0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 
        0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 
        0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 
        0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 
        0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 
        0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 
        0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 
        0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 
        0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 
        0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 
        0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 
        0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 
        0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 
        0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 
        0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 
        0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 
        0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 
        0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 
        0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 
        0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 
        0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 
        0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 
        0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 
        0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 
        0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 
        0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 
        0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 
        0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 
        0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 
        0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 
        0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 
        0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 
        0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 
        0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 
        0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 
        0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 
        0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 
        0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 
        0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 
        0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 
        0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 
        0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 
        0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 
        0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 
        0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 
        0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 
        0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 
        0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 
        0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 
        0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 
        0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 
        0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 
        0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 
        0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 
        0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 
        0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 
        0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 
        0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 
        0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 
        0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 
        0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 
        0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 
        0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 
        0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 
        0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 
        0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 
        0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 
        0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 
        0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 
        0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 
        0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 
        0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 
        0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 
        0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 
        0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 
        0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 
        0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 
        0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 
        0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 
        0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 
        0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 
        0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 
        0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 2, 0, 0, 0, 
        0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 
        0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 
        0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 
        0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 
        0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 
        0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 
        0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 
        0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 
        0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 
        0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 
        0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 
        0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 
        0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 
        0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 
        0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 
        0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0}, 6, 
        500000, 1]]], "Output"]
}, Open  ]],

Cell[TextData[{
  "we realize that ",
  Cell[BoxData[
      \(TraditionalForm\`z\^3\)]],
  " has to be a member of the list"
}], "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(Exponent[Normal[F], x, List]\)], "Input"],

Cell[BoxData[
    \({6, 12, 18, 30, 36, 54, 84, 90, 108, 162, 246, 252, 270, 324, 486, 732, 
      738, 756, 810, 972, 1458, 2190, 2196, 2214, 2268, 2430, 2916, 4374, 
      6564, 6570, 6588, 6642, 6804, 7290, 8748, 13122, 19686, 19692, 19710, 
      19764, 19926, 20412, 21870, 26244, 39366, 59052, 59058, 59076, 59130, 
      59292, 59778, 61236, 65610, 78732, 118098, 177150, 177156, 177174, 
      177228, 177390, 177876, 179334, 183708, 196830, 236196, 
      354294}\)], "Output"]
}, Open  ]],

Cell["that is, z has to be", "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(Select[%, IntegerQ[\@#\%3] &]\)], "Input"],

Cell[BoxData[
    \({}\)], "Output"]
}, Open  ]],

Cell["which comes as no surprise as proved by Andrew Wiles.", "Text"]
}, Closed]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Sums of Different Powers", "Section"],

Cell[TextData[{
  "In order to avoid trivial solutions, we agreed in including only powers \
above 2, only integers >2 as bases, except for the summand ",
  Cell[BoxData[
      \(TraditionalForm\`1\^1\)]],
  ", if needed."
}], "Text"],

Cell[BoxData[{
    \(diffPowerSum[
        n_] := \(\(diffPowerSum[{}, {}, n]\)\(\[Union]\)\(Map[
          Join[{{1, 1}}, #] &, 
          diffPowerSum[{}, {}, 
            n - 1]]\)\(\[IndentingNewLine]\)\)\), "\[IndentingNewLine]", 
    \(diffPowerSum[_, _, 0] := {{}}\), "\[IndentingNewLine]", 
    \(diffPowerSum[bas_, ex_, n_] := 
      Module[{ans = {}, b, e, 
          p}, \[IndentingNewLine]Do[\[IndentingNewLine]If[
            Not[MemberQ[bas, b]] && 
              Not[MemberQ[ex, e]] && \((b\^e \[LessEqual] 
                  n)\), \[IndentingNewLine]p = 
              diffPowerSum[Join[bas, {b}], Join[ex, {e}], 
                n - b\^e]; \[IndentingNewLine]AppendTo[ans, 
              Map[Join[{{b, e}}, #] &, p]]]\[IndentingNewLine], {b, 2, 
            n}, {e, 2, n}]; \[IndentingNewLine]ans = 
          Flatten[ans, 1]; \[IndentingNewLine]ans = 
          DeleteCases[ans, {}]; \[IndentingNewLine]Union[
          Sort\  /@ \ \((\(Partition[Flatten[#], 2] &\) /@ 
                ans)\)]]\[IndentingNewLine]\), "\[IndentingNewLine]", 
    \(showS[{{a_, k_}}] := ToString[a]\^k\), "\n", 
    \(showS[{{a_, k_}, b__}] := 
      DisplayForm[RowBox[{showS[{{a, k}}], "\<+\>", showS[{b}]}]]\)}], "Input",\

  PageWidth->WindowWidth],

Cell["Note that the bases are computed in increasing order. ", "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(Do[\[IndentingNewLine]d = diffPowerSum[n]; \[IndentingNewLine]If[
        d \[NotEqual] {}, Print[n, "\<\t\>", showS\  /@ d]], {n, 
        50}]\)], "Input"],

Cell[BoxData[
    InterpretationBox[\(1\[InvisibleSpace]"\t"\[InvisibleSpace]{"1"}\),
      SequenceForm[ 1, "\t", {"1"}],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[\(4\[InvisibleSpace]"\t"\[InvisibleSpace]{"2"\^2}\),
      SequenceForm[ 4, "\t", {
        Power[ "2", 2]}],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      RowBox[{"5", "\[InvisibleSpace]", "\<\"\\t\"\>", "\[InvisibleSpace]", 
        RowBox[{"{", 
          TagBox[\(1 + "2"\^2\),
            DisplayForm], "}"}]}],
      SequenceForm[ 5, "\t", {
        DisplayForm[ 
          RowBox[ {"1", "+", 
            Power[ "2", 2]}]]}],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[\(8\[InvisibleSpace]"\t"\[InvisibleSpace]{"2"\^3}\),
      SequenceForm[ 8, "\t", {
        Power[ "2", 3]}],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      RowBox[{"9", "\[InvisibleSpace]", "\<\"\\t\"\>", "\[InvisibleSpace]", 
        RowBox[{"{", 
          RowBox[{\("3"\^2\), ",", 
            TagBox[\(1 + "2"\^3\),
              DisplayForm]}], "}"}]}],
      SequenceForm[ 9, "\t", {
        Power[ "3", 2], 
        DisplayForm[ 
          RowBox[ {"1", "+", 
            Power[ "2", 3]}]]}],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      RowBox[{"10", "\[InvisibleSpace]", "\<\"\\t\"\>", "\[InvisibleSpace]", 
        RowBox[{"{", 
          TagBox[\(1 + "3"\^2\),
            DisplayForm], "}"}]}],
      SequenceForm[ 10, "\t", {
        DisplayForm[ 
          RowBox[ {"1", "+", 
            Power[ "3", 2]}]]}],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[\(16\[InvisibleSpace]"\t"\[InvisibleSpace]{"2"\^4, 
          "4"\^2}\),
      SequenceForm[ 16, "\t", {
        Power[ "2", 4], 
        Power[ "4", 2]}],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      RowBox[{"17", "\[InvisibleSpace]", "\<\"\\t\"\>", "\[InvisibleSpace]", 
        RowBox[{"{", 
          RowBox[{
            TagBox[\(1 + "2"\^4\),
              DisplayForm], ",", 
            TagBox[\(1 + "4"\^2\),
              DisplayForm], ",", 
            TagBox[\("2"\^3 + "3"\^2\),
              DisplayForm]}], "}"}]}],
      SequenceForm[ 17, "\t", {
        DisplayForm[ 
          RowBox[ {"1", "+", 
            Power[ "2", 4]}]], 
        DisplayForm[ 
          RowBox[ {"1", "+", 
            Power[ "4", 2]}]], 
        DisplayForm[ 
          RowBox[ {
            Power[ "2", 3], "+", 
            Power[ "3", 2]}]]}],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      RowBox[{"18", "\[InvisibleSpace]", "\<\"\\t\"\>", "\[InvisibleSpace]", 
        RowBox[{"{", 
          TagBox[
            RowBox[{"1", "+", 
              TagBox[\("2"\^3 + "3"\^2\),
                DisplayForm]}],
            DisplayForm], "}"}]}],
      SequenceForm[ 18, "\t", {
        DisplayForm[ 
          RowBox[ {"1", "+", 
            DisplayForm[ 
              RowBox[ {
                Power[ "2", 3], "+", 
                Power[ "3", 2]}]]}]]}],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      RowBox[{"24", "\[InvisibleSpace]", "\<\"\\t\"\>", "\[InvisibleSpace]", 
        RowBox[{"{", 
          TagBox[\("2"\^3 + "4"\^2\),
            DisplayForm], "}"}]}],
      SequenceForm[ 24, "\t", {
        DisplayForm[ 
          RowBox[ {
            Power[ "2", 3], "+", 
            Power[ "4", 2]}]]}],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      RowBox[{"25", "\[InvisibleSpace]", "\<\"\\t\"\>", "\[InvisibleSpace]", 
        RowBox[{"{", 
          RowBox[{\("5"\^2\), ",", 
            TagBox[\("2"\^4 + "3"\^2\),
              DisplayForm], ",", 
            TagBox[
              RowBox[{"1", "+", 
                TagBox[\("2"\^3 + "4"\^2\),
                  DisplayForm]}],
              DisplayForm]}], "}"}]}],
      SequenceForm[ 25, "\t", {
        Power[ "5", 2], 
        DisplayForm[ 
          RowBox[ {
            Power[ "2", 4], "+", 
            Power[ "3", 2]}]], 
        DisplayForm[ 
          RowBox[ {"1", "+", 
            DisplayForm[ 
              RowBox[ {
                Power[ "2", 3], "+", 
                Power[ "4", 2]}]]}]]}],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      RowBox[{"26", "\[InvisibleSpace]", "\<\"\\t\"\>", "\[InvisibleSpace]", 
        RowBox[{"{", 
          RowBox[{
            TagBox[\(1 + "5"\^2\),
              DisplayForm], ",", 
            TagBox[
              RowBox[{"1", "+", 
                TagBox[\("2"\^4 + "3"\^2\),
                  DisplayForm]}],
              DisplayForm]}], "}"}]}],
      SequenceForm[ 26, "\t", {
        DisplayForm[ 
          RowBox[ {"1", "+", 
            Power[ "5", 2]}]], 
        DisplayForm[ 
          RowBox[ {"1", "+", 
            DisplayForm[ 
              RowBox[ {
                Power[ "2", 4], "+", 
                Power[ "3", 2]}]]}]]}],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[\(27\[InvisibleSpace]"\t"\[InvisibleSpace]{"3"\^3}\),
      SequenceForm[ 27, "\t", {
        Power[ "3", 3]}],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      RowBox[{"28", "\[InvisibleSpace]", "\<\"\\t\"\>", "\[InvisibleSpace]", 
        RowBox[{"{", 
          TagBox[\(1 + "3"\^3\),
            DisplayForm], "}"}]}],
      SequenceForm[ 28, "\t", {
        DisplayForm[ 
          RowBox[ {"1", "+", 
            Power[ "3", 3]}]]}],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      RowBox[{"31", "\[InvisibleSpace]", "\<\"\\t\"\>", "\[InvisibleSpace]", 
        RowBox[{"{", 
          TagBox[\("2"\^2 + "3"\^3\),
            DisplayForm], "}"}]}],
      SequenceForm[ 31, "\t", {
        DisplayForm[ 
          RowBox[ {
            Power[ "2", 2], "+", 
            Power[ "3", 3]}]]}],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      RowBox[{"32", "\[InvisibleSpace]", "\<\"\\t\"\>", "\[InvisibleSpace]", 
        RowBox[{"{", 
          RowBox[{\("2"\^5\), ",", 
            TagBox[\("2"\^4 + "4"\^2\),
              DisplayForm], ",", 
            TagBox[
              RowBox[{"1", "+", 
                TagBox[\("2"\^2 + "3"\^3\),
                  DisplayForm]}],
              DisplayForm]}], "}"}]}],
      SequenceForm[ 32, "\t", {
        Power[ "2", 5], 
        DisplayForm[ 
          RowBox[ {
            Power[ "2", 4], "+", 
            Power[ "4", 2]}]], 
        DisplayForm[ 
          RowBox[ {"1", "+", 
            DisplayForm[ 
              RowBox[ {
                Power[ "2", 2], "+", 
                Power[ "3", 3]}]]}]]}],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      RowBox[{"33", "\[InvisibleSpace]", "\<\"\\t\"\>", "\[InvisibleSpace]", 
        RowBox[{"{", 
          RowBox[{
            TagBox[\(1 + "2"\^5\),
              DisplayForm], ",", 
            TagBox[\("2"\^3 + "5"\^2\),
              DisplayForm], ",", 
            TagBox[
              RowBox[{"1", "+", 
                TagBox[\("2"\^4 + "4"\^2\),
                  DisplayForm]}],
              DisplayForm]}], "}"}]}],
      SequenceForm[ 33, "\t", {
        DisplayForm[ 
          RowBox[ {"1", "+", 
            Power[ "2", 5]}]], 
        DisplayForm[ 
          RowBox[ {
            Power[ "2", 3], "+", 
            Power[ "5", 2]}]], 
        DisplayForm[ 
          RowBox[ {"1", "+", 
            DisplayForm[ 
              RowBox[ {
                Power[ "2", 4], "+", 
                Power[ "4", 2]}]]}]]}],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      RowBox[{"34", "\[InvisibleSpace]", "\<\"\\t\"\>", "\[InvisibleSpace]", 
        RowBox[{"{", 
          TagBox[
            RowBox[{"1", "+", 
              TagBox[\("2"\^3 + "5"\^2\),
                DisplayForm]}],
            DisplayForm], "}"}]}],
      SequenceForm[ 34, "\t", {
        DisplayForm[ 
          RowBox[ {"1", "+", 
            DisplayForm[ 
              RowBox[ {
                Power[ "2", 3], "+", 
                Power[ "5", 2]}]]}]]}],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[\(36\[InvisibleSpace]"\t"\[InvisibleSpace]{"6"\^2}\),
      SequenceForm[ 36, "\t", {
        Power[ "6", 2]}],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      RowBox[{"37", "\[InvisibleSpace]", "\<\"\\t\"\>", "\[InvisibleSpace]", 
        RowBox[{"{", 
          TagBox[\(1 + "6"\^2\),
            DisplayForm], "}"}]}],
      SequenceForm[ 37, "\t", {
        DisplayForm[ 
          RowBox[ {"1", "+", 
            Power[ "6", 2]}]]}],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      RowBox[{"41", "\[InvisibleSpace]", "\<\"\\t\"\>", "\[InvisibleSpace]", 
        RowBox[{"{", 
          RowBox[{
            TagBox[\("2"\^4 + "5"\^2\),
              DisplayForm], ",", 
            TagBox[\("2"\^5 + "3"\^2\),
              DisplayForm]}], "}"}]}],
      SequenceForm[ 41, "\t", {
        DisplayForm[ 
          RowBox[ {
            Power[ "2", 4], "+", 
            Power[ "5", 2]}]], 
        DisplayForm[ 
          RowBox[ {
            Power[ "2", 5], "+", 
            Power[ "3", 2]}]]}],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      RowBox[{"42", "\[InvisibleSpace]", "\<\"\\t\"\>", "\[InvisibleSpace]", 
        RowBox[{"{", 
          RowBox[{
            TagBox[
              RowBox[{"1", "+", 
                TagBox[\("2"\^4 + "5"\^2\),
                  DisplayForm]}],
              DisplayForm], ",", 
            TagBox[
              RowBox[{"1", "+", 
                TagBox[\("2"\^5 + "3"\^2\),
                  DisplayForm]}],
              DisplayForm]}], "}"}]}],
      SequenceForm[ 42, "\t", {
        DisplayForm[ 
          RowBox[ {"1", "+", 
            DisplayForm[ 
              RowBox[ {
                Power[ "2", 4], "+", 
                Power[ "5", 2]}]]}]], 
        DisplayForm[ 
          RowBox[ {"1", "+", 
            DisplayForm[ 
              RowBox[ {
                Power[ "2", 5], "+", 
                Power[ "3", 2]}]]}]]}],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      RowBox[{"43", "\[InvisibleSpace]", "\<\"\\t\"\>", "\[InvisibleSpace]", 
        RowBox[{"{", 
          RowBox[{
            TagBox[\("2"\^4 + "3"\^3\),
              DisplayForm], ",", 
            TagBox[\("3"\^3 + "4"\^2\),
              DisplayForm]}], "}"}]}],
      SequenceForm[ 43, "\t", {
        DisplayForm[ 
          RowBox[ {
            Power[ "2", 4], "+", 
            Power[ "3", 3]}]], 
        DisplayForm[ 
          RowBox[ {
            Power[ "3", 3], "+", 
            Power[ "4", 2]}]]}],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      RowBox[{"44", "\[InvisibleSpace]", "\<\"\\t\"\>", "\[InvisibleSpace]", 
        RowBox[{"{", 
          RowBox[{
            TagBox[\("2"\^3 + "6"\^2\),
              DisplayForm], ",", 
            TagBox[
              RowBox[{"1", "+", 
                TagBox[\("2"\^4 + "3"\^3\),
                  DisplayForm]}],
              DisplayForm], ",", 
            TagBox[
              RowBox[{"1", "+", 
                TagBox[\("3"\^3 + "4"\^2\),
                  DisplayForm]}],
              DisplayForm]}], "}"}]}],
      SequenceForm[ 44, "\t", {
        DisplayForm[ 
          RowBox[ {
            Power[ "2", 3], "+", 
            Power[ "6", 2]}]], 
        DisplayForm[ 
          RowBox[ {"1", "+", 
            DisplayForm[ 
              RowBox[ {
                Power[ "2", 4], "+", 
                Power[ "3", 3]}]]}]], 
        DisplayForm[ 
          RowBox[ {"1", "+", 
            DisplayForm[ 
              RowBox[ {
                Power[ "3", 3], "+", 
                Power[ "4", 2]}]]}]]}],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      RowBox[{"45", "\[InvisibleSpace]", "\<\"\\t\"\>", "\[InvisibleSpace]", 
        RowBox[{"{", 
          TagBox[
            RowBox[{"1", "+", 
              TagBox[\("2"\^3 + "6"\^2\),
                DisplayForm]}],
            DisplayForm], "}"}]}],
      SequenceForm[ 45, "\t", {
        DisplayForm[ 
          RowBox[ {"1", "+", 
            DisplayForm[ 
              RowBox[ {
                Power[ "2", 3], "+", 
                Power[ "6", 2]}]]}]]}],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      RowBox[{"48", "\[InvisibleSpace]", "\<\"\\t\"\>", "\[InvisibleSpace]", 
        RowBox[{"{", 
          TagBox[\("2"\^5 + "4"\^2\),
            DisplayForm], "}"}]}],
      SequenceForm[ 48, "\t", {
        DisplayForm[ 
          RowBox[ {
            Power[ "2", 5], "+", 
            Power[ "4", 2]}]]}],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      RowBox[{"49", "\[InvisibleSpace]", "\<\"\\t\"\>", "\[InvisibleSpace]", 
        RowBox[{"{", 
          RowBox[{\("7"\^2\), ",", 
            TagBox[
              RowBox[{"1", "+", 
                TagBox[\("2"\^5 + "4"\^2\),
                  DisplayForm]}],
              DisplayForm]}], "}"}]}],
      SequenceForm[ 49, "\t", {
        Power[ "7", 2], 
        DisplayForm[ 
          RowBox[ {"1", "+", 
            DisplayForm[ 
              RowBox[ {
                Power[ "2", 5], "+", 
                Power[ "4", 2]}]]}]]}],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      RowBox[{"50", "\[InvisibleSpace]", "\<\"\\t\"\>", "\[InvisibleSpace]", 
        RowBox[{"{", 
          TagBox[\(1 + "7"\^2\),
            DisplayForm], "}"}]}],
      SequenceForm[ 50, "\t", {
        DisplayForm[ 
          RowBox[ {"1", "+", 
            Power[ "7", 2]}]]}],
      Editable->False]], "Print"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(t = Table[Length[diffPowerSum[n]], {n, 50}]\)], "Input"],

Cell[BoxData[
    \({1, 0, 0, 1, 1, 0, 0, 1, 2, 1, 0, 0, 0, 0, 0, 2, 3, 1, 0, 0, 0, 0, 0, 
      1, 3, 2, 1, 1, 0, 0, 1, 3, 3, 1, 0, 1, 1, 0, 0, 0, 2, 2, 2, 3, 1, 0, 0, 
      1, 2, 1}\)], "Output"]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{

Cell["Sums of Differences of Squares. ", "Section"],

Cell[BoxData[
    \(diffOfSquares[n_] := 
      Module[{a = {}, u, v, 
          s = Select[
              Divisors[
                n], # > \@n &]}, \[IndentingNewLine]Map[\[IndentingNewLine]If[
              Mod[u = # + n/#, 2] == 0\  && \ Mod[v = # - n/#, 2] == 0, 
              u = u/2; \ 
              v = v/2; \[IndentingNewLine]AppendTo[
                a, {#, u\^"\<2\>" - v\^"\<2\>"}]] &, 
          s]; \[IndentingNewLine]Last\  /@ \ a]\)], "Input"],

Cell["Those congruent to 2 mod 4 cannot be so expressed", "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(r = Select[Range[1, 50], Mod[#, 4] \[NotEqual] 2 &]\)], "Input"],

Cell[BoxData[
    \({1, 3, 4, 5, 7, 8, 9, 11, 12, 13, 15, 16, 17, 19, 20, 21, 23, 24, 25, 
      27, 28, 29, 31, 32, 33, 35, 36, 37, 39, 40, 41, 43, 44, 45, 47, 48, 
      49}\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(\(Map[Print[#, "\<   \>", diffOfSquares[#]] &, r];\)\)], "Input"],

Cell[BoxData[
    InterpretationBox[\(1\[InvisibleSpace]"   "\[InvisibleSpace]{}\),
      SequenceForm[ 1, "   ", {}],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[\(3\[InvisibleSpace]"   "\[InvisibleSpace]{\(-1\) + 
            2\^"2"}\),
      SequenceForm[ 3, "   ", {
        Plus[ -1, 
          Power[ 2, "2"]]}],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[\(4\[InvisibleSpace]"   "\[InvisibleSpace]{}\),
      SequenceForm[ 4, "   ", {}],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[\(5\[InvisibleSpace]"   "\[InvisibleSpace]{\(-2\^"2"\) \
+ 3\^"2"}\),
      SequenceForm[ 5, "   ", {
        Plus[ 
          Times[ -1, 
            Power[ 2, "2"]], 
          Power[ 3, "2"]]}],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[\(7\[InvisibleSpace]"   "\[InvisibleSpace]{\(-3\^"2"\) \
+ 4\^"2"}\),
      SequenceForm[ 7, "   ", {
        Plus[ 
          Times[ -1, 
            Power[ 3, "2"]], 
          Power[ 4, "2"]]}],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[\(8\[InvisibleSpace]"   "\[InvisibleSpace]{\(-1\) + 
            3\^"2"}\),
      SequenceForm[ 8, "   ", {
        Plus[ -1, 
          Power[ 3, "2"]]}],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[\(9\[InvisibleSpace]"   "\[InvisibleSpace]{\(-4\^"2"\) \
+ 5\^"2"}\),
      SequenceForm[ 9, "   ", {
        Plus[ 
          Times[ -1, 
            Power[ 4, "2"]], 
          Power[ 5, "2"]]}],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[\(11\[InvisibleSpace]"   "\[InvisibleSpace]{\(-5\^"2"\) \
+ 6\^"2"}\),
      SequenceForm[ 11, "   ", {
        Plus[ 
          Times[ -1, 
            Power[ 5, "2"]], 
          Power[ 6, "2"]]}],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[\(12\[InvisibleSpace]"   "\[InvisibleSpace]{\(-2\^"2"\) \
+ 4\^"2"}\),
      SequenceForm[ 12, "   ", {
        Plus[ 
          Times[ -1, 
            Power[ 2, "2"]], 
          Power[ 4, "2"]]}],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[\(13\[InvisibleSpace]"   "\[InvisibleSpace]{\(-6\^"2"\) \
+ 7\^"2"}\),
      SequenceForm[ 13, "   ", {
        Plus[ 
          Times[ -1, 
            Power[ 6, "2"]], 
          Power[ 7, "2"]]}],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[\(15\[InvisibleSpace]"   "\[InvisibleSpace]{\(-1\) + 
            4\^"2", \(-7\^"2"\) + 8\^"2"}\),
      SequenceForm[ 15, "   ", {
        Plus[ -1, 
          Power[ 4, "2"]], 
        Plus[ 
          Times[ -1, 
            Power[ 7, "2"]], 
          Power[ 8, "2"]]}],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[\(16\[InvisibleSpace]"   "\[InvisibleSpace]{\(-3\^"2"\) \
+ 5\^"2"}\),
      SequenceForm[ 16, "   ", {
        Plus[ 
          Times[ -1, 
            Power[ 3, "2"]], 
          Power[ 5, "2"]]}],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[\(17\[InvisibleSpace]"   "\[InvisibleSpace]{\(-8\^"2"\) \
+ 9\^"2"}\),
      SequenceForm[ 17, "   ", {
        Plus[ 
          Times[ -1, 
            Power[ 8, "2"]], 
          Power[ 9, "2"]]}],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[\(19\[InvisibleSpace]"   "\[InvisibleSpace]{\(-9\^"2"\) \
+ 10\^"2"}\),
      SequenceForm[ 19, "   ", {
        Plus[ 
          Times[ -1, 
            Power[ 9, "2"]], 
          Power[ 10, "2"]]}],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[\(20\[InvisibleSpace]"   "\[InvisibleSpace]{\(-4\^"2"\) \
+ 6\^"2"}\),
      SequenceForm[ 20, "   ", {
        Plus[ 
          Times[ -1, 
            Power[ 4, "2"]], 
          Power[ 6, "2"]]}],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[\(21\[InvisibleSpace]"   "\[InvisibleSpace]{\(-2\^"2"\) \
+ 5\^"2", \(-10\^"2"\) + 11\^"2"}\),
      SequenceForm[ 21, "   ", {
        Plus[ 
          Times[ -1, 
            Power[ 2, "2"]], 
          Power[ 5, "2"]], 
        Plus[ 
          Times[ -1, 
            Power[ 10, "2"]], 
          Power[ 11, "2"]]}],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[\(23\[InvisibleSpace]"   \
"\[InvisibleSpace]{\(-11\^"2"\) + 12\^"2"}\),
      SequenceForm[ 23, "   ", {
        Plus[ 
          Times[ -1, 
            Power[ 11, "2"]], 
          Power[ 12, "2"]]}],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[\(24\[InvisibleSpace]"   "\[InvisibleSpace]{\(-1\) + 
            5\^"2", \(-5\^"2"\) + 7\^"2"}\),
      SequenceForm[ 24, "   ", {
        Plus[ -1, 
          Power[ 5, "2"]], 
        Plus[ 
          Times[ -1, 
            Power[ 5, "2"]], 
          Power[ 7, "2"]]}],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[\(25\[InvisibleSpace]"   \
"\[InvisibleSpace]{\(-12\^"2"\) + 13\^"2"}\),
      SequenceForm[ 25, "   ", {
        Plus[ 
          Times[ -1, 
            Power[ 12, "2"]], 
          Power[ 13, "2"]]}],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[\(27\[InvisibleSpace]"   "\[InvisibleSpace]{\(-3\^"2"\) \
+ 6\^"2", \(-13\^"2"\) + 14\^"2"}\),
      SequenceForm[ 27, "   ", {
        Plus[ 
          Times[ -1, 
            Power[ 3, "2"]], 
          Power[ 6, "2"]], 
        Plus[ 
          Times[ -1, 
            Power[ 13, "2"]], 
          Power[ 14, "2"]]}],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[\(28\[InvisibleSpace]"   "\[InvisibleSpace]{\(-6\^"2"\) \
+ 8\^"2"}\),
      SequenceForm[ 28, "   ", {
        Plus[ 
          Times[ -1, 
            Power[ 6, "2"]], 
          Power[ 8, "2"]]}],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[\(29\[InvisibleSpace]"   \
"\[InvisibleSpace]{\(-14\^"2"\) + 15\^"2"}\),
      SequenceForm[ 29, "   ", {
        Plus[ 
          Times[ -1, 
            Power[ 14, "2"]], 
          Power[ 15, "2"]]}],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[\(31\[InvisibleSpace]"   \
"\[InvisibleSpace]{\(-15\^"2"\) + 16\^"2"}\),
      SequenceForm[ 31, "   ", {
        Plus[ 
          Times[ -1, 
            Power[ 15, "2"]], 
          Power[ 16, "2"]]}],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[\(32\[InvisibleSpace]"   "\[InvisibleSpace]{\(-2\^"2"\) \
+ 6\^"2", \(-7\^"2"\) + 9\^"2"}\),
      SequenceForm[ 32, "   ", {
        Plus[ 
          Times[ -1, 
            Power[ 2, "2"]], 
          Power[ 6, "2"]], 
        Plus[ 
          Times[ -1, 
            Power[ 7, "2"]], 
          Power[ 9, "2"]]}],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[\(33\[InvisibleSpace]"   "\[InvisibleSpace]{\(-4\^"2"\) \
+ 7\^"2", \(-16\^"2"\) + 17\^"2"}\),
      SequenceForm[ 33, "   ", {
        Plus[ 
          Times[ -1, 
            Power[ 4, "2"]], 
          Power[ 7, "2"]], 
        Plus[ 
          Times[ -1, 
            Power[ 16, "2"]], 
          Power[ 17, "2"]]}],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[\(35\[InvisibleSpace]"   "\[InvisibleSpace]{\(-1\) + 
            6\^"2", \(-17\^"2"\) + 18\^"2"}\),
      SequenceForm[ 35, "   ", {
        Plus[ -1, 
          Power[ 6, "2"]], 
        Plus[ 
          Times[ -1, 
            Power[ 17, "2"]], 
          Power[ 18, "2"]]}],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[\(36\[InvisibleSpace]"   "\[InvisibleSpace]{\(-8\^"2"\) \
+ 10\^"2"}\),
      SequenceForm[ 36, "   ", {
        Plus[ 
          Times[ -1, 
            Power[ 8, "2"]], 
          Power[ 10, "2"]]}],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[\(37\[InvisibleSpace]"   \
"\[InvisibleSpace]{\(-18\^"2"\) + 19\^"2"}\),
      SequenceForm[ 37, "   ", {
        Plus[ 
          Times[ -1, 
            Power[ 18, "2"]], 
          Power[ 19, "2"]]}],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[\(39\[InvisibleSpace]"   "\[InvisibleSpace]{\(-5\^"2"\) \
+ 8\^"2", \(-19\^"2"\) + 20\^"2"}\),
      SequenceForm[ 39, "   ", {
        Plus[ 
          Times[ -1, 
            Power[ 5, "2"]], 
          Power[ 8, "2"]], 
        Plus[ 
          Times[ -1, 
            Power[ 19, "2"]], 
          Power[ 20, "2"]]}],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[\(40\[InvisibleSpace]"   "\[InvisibleSpace]{\(-3\^"2"\) \
+ 7\^"2", \(-9\^"2"\) + 11\^"2"}\),
      SequenceForm[ 40, "   ", {
        Plus[ 
          Times[ -1, 
            Power[ 3, "2"]], 
          Power[ 7, "2"]], 
        Plus[ 
          Times[ -1, 
            Power[ 9, "2"]], 
          Power[ 11, "2"]]}],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[\(41\[InvisibleSpace]"   \
"\[InvisibleSpace]{\(-20\^"2"\) + 21\^"2"}\),
      SequenceForm[ 41, "   ", {
        Plus[ 
          Times[ -1, 
            Power[ 20, "2"]], 
          Power[ 21, "2"]]}],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[\(43\[InvisibleSpace]"   \
"\[InvisibleSpace]{\(-21\^"2"\) + 22\^"2"}\),
      SequenceForm[ 43, "   ", {
        Plus[ 
          Times[ -1, 
            Power[ 21, "2"]], 
          Power[ 22, "2"]]}],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[\(44\[InvisibleSpace]"   \
"\[InvisibleSpace]{\(-10\^"2"\) + 12\^"2"}\),
      SequenceForm[ 44, "   ", {
        Plus[ 
          Times[ -1, 
            Power[ 10, "2"]], 
          Power[ 12, "2"]]}],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[\(45\[InvisibleSpace]"   "\[InvisibleSpace]{\(-2\^"2"\) \
+ 7\^"2", \(-6\^"2"\) + 9\^"2", \(-22\^"2"\) + 23\^"2"}\),
      SequenceForm[ 45, "   ", {
        Plus[ 
          Times[ -1, 
            Power[ 2, "2"]], 
          Power[ 7, "2"]], 
        Plus[ 
          Times[ -1, 
            Power[ 6, "2"]], 
          Power[ 9, "2"]], 
        Plus[ 
          Times[ -1, 
            Power[ 22, "2"]], 
          Power[ 23, "2"]]}],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[\(47\[InvisibleSpace]"   \
"\[InvisibleSpace]{\(-23\^"2"\) + 24\^"2"}\),
      SequenceForm[ 47, "   ", {
        Plus[ 
          Times[ -1, 
            Power[ 23, "2"]], 
          Power[ 24, "2"]]}],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[\(48\[InvisibleSpace]"   "\[InvisibleSpace]{\(-1\) + 
            7\^"2", \(-4\^"2"\) + 8\^"2", \(-11\^"2"\) + 13\^"2"}\),
      SequenceForm[ 48, "   ", {
        Plus[ -1, 
          Power[ 7, "2"]], 
        Plus[ 
          Times[ -1, 
            Power[ 4, "2"]], 
          Power[ 8, "2"]], 
        Plus[ 
          Times[ -1, 
            Power[ 11, "2"]], 
          Power[ 13, "2"]]}],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[\(49\[InvisibleSpace]"   \
"\[InvisibleSpace]{\(-24\^"2"\) + 25\^"2"}\),
      SequenceForm[ 49, "   ", {
        Plus[ 
          Times[ -1, 
            Power[ 24, "2"]], 
          Power[ 25, "2"]]}],
      Editable->False]], "Print"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(Table[Length[diffOfSquares[n]], {n, 100}]\)], "Input"],

Cell[BoxData[
    \({0, 0, 1, 0, 1, 0, 1, 1, 1, 0, 1, 1, 1, 0, 2, 1, 1, 0, 1, 1, 2, 0, 1, 
      2, 1, 0, 2, 1, 1, 0, 1, 2, 2, 0, 2, 1, 1, 0, 2, 2, 1, 0, 1, 1, 3, 0, 1, 
      3, 1, 0, 2, 1, 1, 0, 2, 2, 2, 0, 1, 2, 1, 0, 3, 2, 2, 0, 1, 1, 2, 0, 1, 
      3, 1, 0, 3, 1, 2, 0, 1, 3, 2, 0, 1, 2, 2, 0, 2, 2, 1, 0, 2, 1, 2, 0, 2, 
      4, 1, 0, 3, 1}\)], "Output"]
}, Open  ]],

Cell["\<\
If n exceeds the sum of two unequal positive squares by k>0, then every power \
of n is the sum of k+2 positive squares.In other words, every power of 6 is \
the sum of three squares, every power of 7 is the sum of four squares, every \
power of 8 is the sum of five squares, etc.\
\>", "Text"]
}, Closed]],

Cell[CellGroupData[{

Cell["A Problem Involving Sums", "Section"],

Cell[CellGroupData[{

Cell["THE PROBLEM", "Subsection"],

Cell["\<\
A customer at a 7-11 store selected four items to buy, and was told that the \
cost was $7.11.  He was curious that the cost was the same as the store name, \
so he inquired as to how the figure was derived.
The clerk said that he had simply multiplied the prices of the four \
individual  items. The customer  protested  that  the four  prices should \
have been ADDED,  not MULTIPLIED. The  clerk said that that was OK with him, \
but, the result was still the same: exactly $7.11. What were the costs \
involved?\
\>", "Text"],

Cell[CellGroupData[{

Cell[BoxData[{
    \(\(u = \@7.11\%4;\)\ \ \), "\n", 
    \(\(Do[\[IndentingNewLine]l = 
            7.11 - i - j - 
              k; \[IndentingNewLine]If[\((l > 0)\)\  && \ \((i\ j\ k\ l == 
                  7.11)\), \ Print[{i, j, k, l}]], {i, 0.01, u, 0.01}, {j, i, 
            u, 0.01}, {k, j, u, 0.01}];\)\  // \ Timing\)}], "Input"],

Cell[BoxData[
    \({1.2`, 1.25`, 1.5`, 3.16`}\)], "Print"],

Cell[BoxData[
    \({47.789999999999964`\ Second, Null}\)], "Output"]
}, Open  ]],

Cell["\<\
So, the items were 1.2, 1.25, 1.5 and 3.16 worth.
However, in order to generalize we need to dwelve into factorizing a \
number.\
\>", "Text"]
}, Closed]],

Cell[CellGroupData[{

Cell["FACTORING A NUMBER INTO UNORDERED PRODUCTS", "Subsection"],

Cell["\<\
To obtain all possible lists of r elements multiplying up to n.\
\>", "Text"],

Cell[BoxData[{
    \(products[n_, r_] := products[n, r, 1]\n\t\t\), "\n", 
    \(products[n_, r_, from_] := {}\  /; \ from\^r > n\), "\n", 
    \(products[n_, r_, 
        from_] := {Table[from, {r}]}\  /; \ \ from\^r == n\), "\n", 
    \(products[n_, 1, from_] := {{n}}\ \), "\n", 
    \(products[n_, r_, from_] := 
      Module[{a, p, 
          ans = {}}, \[IndentingNewLine]Do[\[IndentingNewLine]If[
            Mod[n, a] == 0, \[IndentingNewLine]p = 
              products[n/a, r - 1, a]; \[IndentingNewLine]If[p != {}, 
              AppendTo[ans, Map[Join[{a}, #] &, p]]]], {a, 
            from, \@n\%r}]; \[IndentingNewLine]Flatten[ans, 
          1]]\t\t\)}], "Input"],

Cell[CellGroupData[{

Cell[BoxData[
    \(products[12, 5]\)], "Input"],

Cell[BoxData[
    \({{1, 1, 1, 1, 12}, {1, 1, 1, 2, 6}, {1, 1, 1, 3, 4}, {1, 1, 2, 2, 
        3}}\)], "Output"]
}, Open  ]],

Cell["\<\
To obtain all possible lists of r elements multiplying up to n and adding up \
to s.\
\>", "Text"],

Cell[BoxData[{
    \(prodSum[p_, s_, r_] := prodSum[p, s, r, 1]\n\t\t\), "\n", 
    \(prodSum[p_, s_, r_, 
        from_] := {}\  /; \ \((from\^r > 
              p)\)\  || \ \((p > \((s\/r)\)\^r)\)\), "\n", 
    \(prodSum[p_, s_, r_, 
        from_] := {Table[
            from, {r}]}\  /; \ \ \((from\^r == p)\)\  && \ \((r\ from == 
              s)\)\), "\n", 
    \(prodSum[p_, _, r_, 
        from_] := {}\  /; \ \ \(\(from\^r\)\(==\)\(p\)\(\t\)\)\), "\n", 
    \(prodSum[p_, p_, 1, from_] := {{p}}\ \), "\n", 
    \(prodSum[_, _, 1, _] := {}\ \), "\n", 
    \(prodSum[p_, s_, r_, from_] := 
      Module[{a, q, 
          ans = {}}, \[IndentingNewLine]Do[\[IndentingNewLine]If[
            Mod[p, a] == 0, \[IndentingNewLine]q = 
              prodSum[p/a, s - a, r - 1, a]; \[IndentingNewLine]If[q != {}, 
              AppendTo[ans, Map[Join[{a}, #] &, q]]]], {a, 
            from, \@p\%r}]; \[IndentingNewLine]Flatten[ans, 
          1]]\t\t\)}], "Input"],

Cell[CellGroupData[{

Cell[BoxData[
    \(prodSum[12, 10, 5]\)], "Input"],

Cell[BoxData[
    \({{1, 1, 1, 3, 4}}\)], "Output"]
}, Open  ]],

Cell["Regarding our problem:", "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(prodSum[711000000, 711, 4]\  // \ Timing\)], "Input"],

Cell[BoxData[
    \({0.160000000000025`\ Second, {{120, 125, 150, 316}}}\)], "Output"]
}, Open  ]],

Cell["Given a product of r numbers, what are their possible sums ?", "Text"],

Cell[CellGroupData[{

Cell[BoxData[{
    \(\(t = 
        Table[Table[Length[prodSum[p, s, r]], {p, 25}, {s, 25}], {r, 
            25}];\)\), "\n", 
    \(t\[LeftDoubleBracket]5\[RightDoubleBracket] // MatrixForm\)}], "Input"],

Cell[BoxData[
    TagBox[
      RowBox[{"(", "\[NoBreak]", GridBox[{
            {"0", "0", "0", "0", "1", "0", "0", "0", "0", "0", "0", "0", "0", 
              "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0"},
            {"0", "0", "0", "0", "0", "1", "0", "0", "0", "0", "0", "0", "0", 
              "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0"},
            {"0", "0", "0", "0", "0", "0", "1", "0", "0", "0", "0", "0", "0", 
              "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0"},
            {"0", "0", "0", "0", "0", "0", "1", "1", "0", "0", "0", "0", "0", 
              "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0"},
            {"0", "0", "0", "0", "0", "0", "0", "0", "1", "0", "0", "0", "0", 
              "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0"},
            {"0", "0", "0", "0", "0", "0", "0", "1", "0", "1", "0", "0", "0", 
              "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0"},
            {"0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "1", "0", "0", 
              "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0"},
            {"0", "0", "0", "0", "0", "0", "0", "1", "1", "0", "0", "1", "0", 
              "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0"},
            {"0", "0", "0", "0", "0", "0", "0", "0", "1", "0", "0", "0", "1", 
              "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0"},
            {"0", "0", "0", "0", "0", "0", "0", "0", "0", "1", "0", "0", "0", 
              "1", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0"},
            {"0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", 
              "0", "1", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0"},
            {"0", "0", "0", "0", "0", "0", "0", "0", "1", "1", "1", "0", "0", 
              "0", "0", "1", "0", "0", "0", "0", "0", "0", "0", "0", "0"},
            {"0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", 
              "0", "0", "0", "1", "0", "0", "0", "0", "0", "0", "0", "0"},
            {"0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "1", "0", 
              "0", "0", "0", "0", "1", "0", "0", "0", "0", "0", "0", "0"},
            {"0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "1", "0", "0", 
              "0", "0", "0", "0", "0", "1", "0", "0", "0", "0", "0", "0"},
            {"0", "0", "0", "0", "0", "0", "0", "0", "1", "1", "1", "0", "1", 
              "0", "0", "0", "0", "0", "0", "1", "0", "0", "0", "0", "0"},
            {"0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", 
              "0", "0", "0", "0", "0", "0", "0", "1", "0", "0", "0", "0"},
            {"0", "0", "0", "0", "0", "0", "0", "0", "0", "1", "0", "1", "0", 
              "1", "0", "0", "0", "0", "0", "0", "0", "1", "0", "0", "0"},
            {"0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", 
              "0", "0", "0", "0", "0", "0", "0", "0", "0", "1", "0", "0"},
            {"0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "1", "1", "0", 
              "0", "1", "0", "0", "0", "0", "0", "0", "0", "0", "1", "0"},
            {"0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "1", 
              "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "1"},
            {"0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", 
              "0", "0", "1", "0", "0", "0", "0", "0", "0", "0", "0", "0"},
            {"0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", 
              "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0"},
            {"0", "0", "0", "0", "0", "0", "0", "0", "0", "1", "1", "1", "1", 
              "1", "0", "0", "1", "0", "0", "0", "0", "0", "0", "0", "0"},
            {"0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "1", 
              "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0"}
            }], "\[NoBreak]", ")"}],
      (MatrixForm[ #]&)]], "Output"]
}, Open  ]],

Cell["\<\
Reading the 12th row above we learn that the possible size-5 sums for 12 are \
9, 10 ,11 and 16.\
\>", "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(Plus\  @@ \ t // MatrixForm\)], "Input"],

Cell[BoxData[
    TagBox[
      RowBox[{"(", "\[NoBreak]", GridBox[{
            {"1", "1", "1", "1", "1", "1", "1", "1", "1", "1", "1", "1", "1", 
              "1", "1", "1", "1", "1", "1", "1", "1", "1", "1", "1", "1"},
            {"0", "1", "1", "1", "1", "1", "1", "1", "1", "1", "1", "1", "1", 
              "1", "1", "1", "1", "1", "1", "1", "1", "1", "1", "1", "1"},
            {"0", "0", "1", "1", "1", "1", "1", "1", "1", "1", "1", "1", "1", 
              "1", "1", "1", "1", "1", "1", "1", "1", "1", "1", "1", "1"},
            {"0", "0", "0", "2", "2", "2", "2", "2", "2", "2", "2", "2", "2", 
              "2", "2", "2", "2", "2", "2", "2", "2", "2", "2", "2", "2"},
            {"0", "0", "0", "0", "1", "1", "1", "1", "1", "1", "1", "1", "1", 
              "1", "1", "1", "1", "1", "1", "1", "1", "1", "1", "1", "1"},
            {"0", "0", "0", "0", "1", "2", "2", "2", "2", "2", "2", "2", "2", 
              "2", "2", "2", "2", "2", "2", "2", "2", "2", "2", "2", "2"},
            {"0", "0", "0", "0", "0", "0", "1", "1", "1", "1", "1", "1", "1", 
              "1", "1", "1", "1", "1", "1", "1", "1", "1", "1", "1", "1"},
            {"0", "0", "0", "0", "0", "2", "2", "3", "3", "3", "3", "3", "3", 
              "3", "3", "3", "3", "3", "3", "3", "3", "3", "3", "3", "3"},
            {"0", "0", "0", "0", "0", "1", "1", "1", "2", "2", "2", "2", "2", 
              "2", "2", "2", "2", "2", "2", "2", "2", "2", "2", "2", "2"},
            {"0", "0", "0", "0", "0", "0", "1", "1", "1", "2", "2", "2", "2", 
              "2", "2", "2", "2", "2", "2", "2", "2", "2", "2", "2", "2"},
            {"0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "1", "1", "1", 
              "1", "1", "1", "1", "1", "1", "1", "1", "1", "1", "1", "1"},
            {"0", "0", "0", "0", "0", "0", "2", "3", "3", "3", "3", "4", "4", 
              "4", "4", "4", "4", "4", "4", "4", "4", "4", "4", "4", "4"},
            {"0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "1", 
              "1", "1", "1", "1", "1", "1", "1", "1", "1", "1", "1", "1"},
            {"0", "0", "0", "0", "0", "0", "0", "0", "1", "1", "1", "1", "1", 
              "2", "2", "2", "2", "2", "2", "2", "2", "2", "2", "2", "2"},
            {"0", "0", "0", "0", "0", "0", "0", "1", "1", "1", "1", "1", "1", 
              "1", "2", "2", "2", "2", "2", "2", "2", "2", "2", "2", "2"},
            {"0", "0", "0", "0", "0", "0", "0", "3", "3", "4", "4", "4", "4", 
              "4", "4", "5", "5", "5", "5", "5", "5", "5", "5", "5", "5"},
            {"0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", 
              "0", "0", "0", "1", "1", "1", "1", "1", "1", "1", "1", "1"},
            {"0", "0", "0", "0", "0", "0", "0", "1", "2", "2", "3", "3", "3", 
              "3", "3", "3", "3", "4", "4", "4", "4", "4", "4", "4", "4"},
            {"0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", 
              "0", "0", "0", "0", "0", "1", "1", "1", "1", "1", "1", "1"},
            {"0", "0", "0", "0", "0", "0", "0", "0", "2", "2", "2", "3", "3", 
              "3", "3", "3", "3", "3", "3", "4", "4", "4", "4", "4", "4"},
            {"0", "0", "0", "0", "0", "0", "0", "0", "0", "1", "1", "1", "1", 
              "1", "1", "1", "1", "1", "1", "1", "2", "2", "2", "2", "2"},
            {"0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "1", 
              "1", "1", "1", "1", "1", "1", "1", "1", "2", "2", "2", "2"},
            {"0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", 
              "0", "0", "0", "0", "0", "0", "0", "0", "0", "1", "1", "1"},
            {"0", "0", "0", "0", "0", "0", "0", "0", "2", "4", "5", "5", "5", 
              "6", "6", "6", "6", "6", "6", "6", "6", "6", "6", "7", "7"},
            {"0", "0", "0", "0", "0", "0", "0", "0", "0", "1", "1", "1", "1", 
              "1", "1", "1", "1", "1", "1", "1", "1", "1", "1", "1", "2"}
            }], "\[NoBreak]", ")"}],
      (MatrixForm[ #]&)]], "Output"]
}, Open  ]],

Cell["\<\
There is a 4 at the 16th row and 10th column. Hence, there are 4 ways of \
finding  numbers adding to 10 and multiplying to 16, namely:\
\>", "Text"],

Cell[CellGroupData[{

Cell[BoxData[{
    \(prodSum[16, 10, 2]\), "\n", 
    \(prodSum[16, 10, 4]\), "\n", 
    \(prodSum[16, 10, 5]\), "\n", 
    \(prodSum[16, 10, 6]\)}], "Input"],

Cell[BoxData[
    \({{2, 8}}\)], "Output"],

Cell[BoxData[
    \({{1, 1, 4, 4}}\)], "Output"],

Cell[BoxData[
    \({{1, 1, 2, 2, 4}}\)], "Output"],

Cell[BoxData[
    \({{1, 1, 2, 2, 2, 2}}\)], "Output"]
}, Open  ]],

Cell["\<\
Note also that, if the product p is prime, the above matrix correctly asserts \
that there is only one solution of the equation s = p + r - 1 for r>0 and no \
solution for any other value of s.

For what other amounts are there unique solutions involving four items?\
\>", "Text"],

Cell[CellGroupData[{

Cell[BoxData[{
    \(\(t = Table[{n, prodSum[n\ 1000000, n, 4]}, {n, 800}];\)\), "\n", 
    \(\(q = Select[t, \((Last[#] \[NotEqual] {})\) &];\)\), "\n", 
    \(Select[q, \((Length[Last[#]] == 1)\) &]\)}], "Input"],

Cell[BoxData[
    \({{644, {{125, 160, 175, 184}}}, {651, {{125, 140, 186, 
            200}}}, {660, {{110, 150, 200, 200}}}, {663, {{125, 125, 192, 
            221}}}, {665, {{100, 175, 190, 200}}}, {672, {{112, 150, 160, 
            250}}}, {678, {{113, 125, 200, 240}}}, {680, {{100, 160, 170, 
            250}}}, {686, {{100, 140, 196, 250}}}, {689, {{106, 125, 208, 
            250}}}, {702, {{117, 125, 160, 300}}}, {705, {{100, 120, 235, 
            250}}}, {708, {{100, 118, 240, 250}}}, {711, {{120, 125, 150, 
            316}}}, {713, {{100, 115, 248, 250}}}, {725, {{80, 145, 250, 
            250}}}, {726, {{75, 176, 200, 275}}}, {729, {{100, 125, 180, 
            324}}}, {737, {{67, 200, 220, 250}}}, {747, {{90, 125, 200, 
            332}}}, {750, {{100, 100, 250, 300}}}, {752, {{64, 188, 250, 
            250}}}, {762, {{100, 127, 160, 375}}}, {767, {{59, 208, 250, 
            250}}}, {777, {{80, 125, 222, 350}}}, {779, {{76, 125, 250, 
            328}}}, {782, {{92, 100, 250, 340}}}, {783, {{58, 200, 225, 
            300}}}, {786, {{80, 131, 200, 375}}}, {800, {{100, 100, 200, 
            400}}}}\)], "Output"]
}, Open  ]]
}, Closed]]
}, Open  ]],

Cell[CellGroupData[{

Cell["References", "Section"],

Cell[TextData[{
  "A Pathway into Number Theory \nR.P. Burn \nCambridge University Press\n\n\
An Introduction to the Theory of Numbers\nI. Niven, H.S. Zuckerman, H.L. \
Montgomery\nJohn Wiley & Sons\n\nAn Introduction to the Theory of Numbers\n\
G.H. Hardy\nOxford Science Publications\n\nElementary Number Theory\nJ. \
Roberts\nThe MIT Press\n\nThe Theory of Partitions\nG. E. Andrews\nCambridge \
",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  "l Library\n\nEric Weisstein's World of Mathematics\n\
http://mathworld.wolfram.com/\n\nPartial Fractions and Four Classical \
Theorems of Number Theory\nM.D. Hirschhorn\nAmerican Mathematical Monthly \
107,3, March 2000, pp. 260-264\n\nHandbook of Number Theory\nD.S. Mitrinovic, \
J. Sandor, B. Crstici\nKluwer Academic Publishers, 1996\n\nA Combinatorial \
Approach to Sums of Integer Powers\nG. Mackiw\nMathematics Magazine 73, 1, \
February 2000\n\nThe Impossible Problem\nL. Sallows\nThe ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  "l Intelligencer 17, 1, 1995 pp. 27-33\n"
}], "Reference"]
}, Closed]]
}, Open  ]]
},
FrontEndVersion->"4.0 for Microsoft Windows",
ScreenRectangle->{{0, 1280}, {0, 979}},
AutoGeneratedPackage->None,
WindowToolbars->"EditBar",
WindowSize->{811, 807},
WindowMargins->{{109, Automatic}, {Automatic, 72}},
Visible->True,
PrintingCopies->1,
PrintingPageRange->{Automatic, Automatic},
PrivateNotebookOptions->{"ColorPalette"->{RGBColor, -1}},
ShowCellLabel->True,
ShowCellTags->False,
InputAliases->{"notation"->RowBox[ {"Notation", "[", 
        RowBox[ {
          TagBox[ 
          "\[Placeholder]", NotationBoxTag, TagStyle -> 
            "NotationTemplateStyle"], " ", "\[DoubleLongLeftRightArrow]", " ",
           
          TagBox[ 
          "\[Placeholder]", NotationBoxTag, TagStyle -> 
            "NotationTemplateStyle"]}], "]"}], 
    "notation>"->RowBox[ {"Notation", "[", 
        RowBox[ {
          TagBox[ 
          "\[Placeholder]", NotationBoxTag, TagStyle -> 
            "NotationTemplateStyle"], " ", "\[DoubleLongRightArrow]", " ", 
          TagBox[ 
          "\[Placeholder]", NotationBoxTag, TagStyle -> 
            "NotationTemplateStyle"]}], "]"}], 
    "notation<"->RowBox[ {"Notation", "[", 
        RowBox[ {
          TagBox[ 
          "\[Placeholder]", NotationBoxTag, TagStyle -> 
            "NotationTemplateStyle"], " ", "\[DoubleLongLeftArrow]", " ", 
          TagBox[ 
          "\[Placeholder]", NotationBoxTag, TagStyle -> 
            "NotationTemplateStyle"]}], "]"}], 
    "symb"->RowBox[ {"Symbolize", "[", 
        TagBox[ 
        "\[Placeholder]", NotationBoxTag, TagStyle -> 
          "NotationTemplateStyle"], "]"}], 
    "infixnotation"->RowBox[ {"InfixNotation", "[", 
        RowBox[ {
          TagBox[ 
          "\[Placeholder]", NotationBoxTag, TagStyle -> 
            "NotationTemplateStyle"], ",", "\[Placeholder]"}], "]"}], 
    "addia"->RowBox[ {"AddInputAlias", "[", 
        RowBox[ {
          TagBox[ 
          "\[Placeholder]", NotationBoxTag, TagStyle -> 
            "NotationTemplateStyle"], ",", "\[Placeholder]"}], "]"}], 
    "pattwraper"->TagBox[ 
      "\[Placeholder]", NotationPatternTag, TagStyle -> 
        "NotationPatternWrapperStyle"], 
    "madeboxeswraper"->TagBox[ 
      "\[Placeholder]", NotationMadeBoxesTag, TagStyle -> 
        "NotationMadeBoxesWrapperStyle"]},
RenderingOptions->{"ObjectDithering"->True,
"RasterDithering"->False},
Magnification->1.25,
StyleDefinitions -> "Report.nb"
]


(***********************************************************************
Cached data follows.  If you edit this Notebook file directly, not using
Mathematica, you must remove the line containing CacheID at the top of 
the file.  The cache data will then be recreated when you save this file 
from within Mathematica.
***********************************************************************)

(*CellTagsOutline
CellTagsIndex->{}
*)

(*CellTagsIndex
CellTagsIndex->{}
*)

(*NotebookFileOutline
Notebook[{

Cell[CellGroupData[{
Cell[1739, 51, 101, 2, 166, "Title"],
Cell[1843, 55, 98, 2, 84, "Author"],
Cell[1944, 59, 388, 15, 202, "Caption"],
Cell[2335, 76, 272, 5, 67, "Quote"],
Cell[2610, 83, 109, 2, 41, "Input",
  InitializationCell->True],
Cell[2722, 87, 584, 17, 290, "Commentary"],

Cell[CellGroupData[{
Cell[3331, 108, 37, 0, 87, "Section 1"],
Cell[3371, 110, 341, 6, 78, "Text"]
}, Open  ]],

Cell[CellGroupData[{
Cell[3749, 121, 33, 0, 84, "Section"],
Cell[3785, 123, 350, 6, 78, "Text"],

Cell[CellGroupData[{
Cell[4160, 133, 385, 9, 124, "Input"],
Cell[4548, 144, 235190, 3075, 380, 3257, 207, "GraphicsData", "PostScript", \
"Graphics"]
}, Open  ]],
Cell[239753, 3222, 1215, 19, 225, "Text"]
}, Open  ]],

Cell[CellGroupData[{
Cell[241005, 3246, 30, 0, 84, "Section"],

Cell[CellGroupData[{
Cell[241060, 3250, 34, 0, 49, "Subsection"],
Cell[241097, 3252, 110, 3, 36, "Text"],
Cell[241210, 3257, 369, 7, 146, "Input",
  InitializationCell->True],

Cell[CellGroupData[{
Cell[241604, 3268, 51, 1, 41, "Input"],
Cell[241658, 3271, 334, 11, 60, "Output"]
}, Open  ]],
Cell[242007, 3285, 74, 0, 36, "Text"],
Cell[242084, 3287, 577, 10, 146, "Input"],

Cell[CellGroupData[{
Cell[242686, 3301, 118, 2, 41, "Input"],
Cell[242807, 3305, 202003, 2583, 380, 1255, 100, "GraphicsData", \
"PostScript", "Graphics"]
}, Open  ]],
Cell[444825, 5891, 159, 3, 57, "Text"],
Cell[444987, 5896, 793, 15, 272, "Input",
  InitializationCell->True],

Cell[CellGroupData[{
Cell[445805, 5915, 76, 1, 41, "Input"],
Cell[445884, 5918, 2182, 73, 164, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[448103, 5996, 70, 1, 41, "Input"],
Cell[448176, 5999, 69, 1, 60, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[448282, 6005, 179, 3, 62, "Input"],
Cell[448464, 6010, 22739, 663, 48, 6347, 456, "GraphicsData", "PostScript", \
"Graphics"]
}, Open  ]],
Cell[471218, 6676, 122, 4, 37, "Text"],
Cell[471343, 6682, 123, 3, 56, "Input",
  InitializationCell->True],

Cell[CellGroupData[{
Cell[471491, 6689, 56, 1, 42, "Input"],
Cell[471550, 6692, 444, 9, 60, "Output"]
}, Open  ]],
Cell[472009, 6704, 222, 5, 58, "Text"],

Cell[CellGroupData[{
Cell[472256, 6713, 134, 3, 42, "Input"],
Cell[472393, 6718, 127233, 2064, 243, 8450, 593, "GraphicsData", \
"PostScript", "Graphics"]
}, Open  ]],

Cell[CellGroupData[{
Cell[599663, 8787, 76, 1, 41, "Input"],
Cell[599742, 8790, 7065, 200, 218, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[606844, 8995, 73, 1, 41, "Input"],
Cell[606920, 8998, 112, 2, 60, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[607069, 9005, 62, 1, 42, "Input"],
Cell[607134, 9008, 433, 9, 60, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[607604, 9022, 76, 1, 41, "Input"],
Cell[607683, 9025, 2363, 83, 218, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[610083, 9113, 73, 1, 41, "Input"],
Cell[610159, 9116, 112, 2, 60, "Output"]
}, Open  ]],
Cell[610286, 9121, 139, 3, 36, "Text"]
}, Closed]],

Cell[CellGroupData[{
Cell[610462, 9129, 56, 0, 28, "Subsection"],

Cell[CellGroupData[{
Cell[610543, 9133, 44, 0, 36, "Subsubsection"],
Cell[610590, 9135, 46, 0, 36, "Text"],

Cell[CellGroupData[{
Cell[610661, 9139, 82, 1, 42, "Input"],
Cell[610746, 9142, 12129, 337, 290, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[622912, 9484, 358, 6, 126, "Input"],
Cell[623273, 9492, 52500, 745, 380, 5740, 163, "GraphicsData", "PostScript", \
"Graphics"]
}, Open  ]],

Cell[CellGroupData[{
Cell[675810, 10242, 81, 1, 42, "Input"],
Cell[675894, 10245, 114, 2, 60, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[676045, 10252, 61, 1, 42, "Input"],
Cell[676109, 10255, 440, 9, 60, "Output"]
}, Open  ]],
Cell[676564, 10267, 119, 4, 37, "Text"],
Cell[676686, 10273, 149, 3, 62, "Input"],

Cell[CellGroupData[{
Cell[676860, 10280, 53, 1, 41, "Input"],
Cell[676916, 10283, 71, 1, 60, "Output"]
}, Open  ]],
Cell[677002, 10287, 242, 5, 90, "Commentary"],
Cell[677247, 10294, 175, 6, 51, "Commentary"]
}, Closed]],

Cell[CellGroupData[{
Cell[677459, 10305, 51, 0, 28, "Subsubsection"],

Cell[CellGroupData[{
Cell[677535, 10309, 110, 2, 41, "Input"],
Cell[677648, 10313, 15300, 438, 434, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[692985, 10756, 399, 8, 125, "Input"],
Cell[693387, 10766, 8325, 203, 207, 2890, 132, "GraphicsData", "PostScript", \
"Graphics"]
}, Open  ]],

Cell[CellGroupData[{
Cell[701749, 10974, 116, 3, 41, "Input"],
Cell[701868, 10979, 118, 2, 60, "Output"]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{
Cell[702035, 10987, 52, 0, 28, "Subsubsection"],
Cell[702090, 10989, 72, 0, 36, "Text"],
Cell[702165, 10991, 114, 2, 41, "Input"],

Cell[CellGroupData[{
Cell[702304, 10997, 61, 1, 41, "Input"],
Cell[702368, 11000, 485, 17, 60, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[702890, 11022, 73, 1, 41, "Input"],
Cell[702966, 11025, 101, 2, 60, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[703104, 11032, 87, 1, 42, "Input"],
Cell[703194, 11035, 657, 13, 81, "Output"]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{
Cell[703900, 11054, 61, 0, 28, "Subsubsection"],
Cell[703964, 11056, 149, 3, 83, "Input"],

Cell[CellGroupData[{
Cell[704138, 11063, 77, 1, 41, "Input"],
Cell[704218, 11066, 916, 33, 128, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[705171, 11104, 77, 1, 41, "Input"],
Cell[705251, 11107, 109, 2, 60, "Output"]
}, Open  ]],
Cell[705375, 11112, 169, 3, 57, "Text"],

Cell[CellGroupData[{
Cell[705569, 11119, 202, 5, 62, "Input"],
Cell[705774, 11126, 3556, 100, 128, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[709367, 11231, 161, 4, 65, "Input"],
Cell[709531, 11237, 676, 13, 81, "Output"]
}, Open  ]],
Cell[710222, 11253, 201, 4, 57, "Text"]
}, Closed]],

Cell[CellGroupData[{
Cell[710460, 11262, 79, 0, 28, "Subsubsection"],
Cell[710542, 11264, 266, 9, 41, "Input"],

Cell[CellGroupData[{
Cell[710833, 11277, 58, 1, 41, "Input"],
Cell[710894, 11280, 1655, 59, 81, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[712586, 11344, 71, 1, 41, "Input"],
Cell[712660, 11347, 118, 2, 60, "Output"]
}, Open  ]]
}, Closed]]
}, Open  ]],

Cell[CellGroupData[{
Cell[712839, 11356, 40, 0, 49, "Subsection"],
Cell[712882, 11358, 800, 23, 85, "Text"],
Cell[713685, 11383, 362, 8, 130, "Input"],

Cell[CellGroupData[{
Cell[714072, 11395, 109, 3, 42, "Input"],
Cell[714184, 11400, 2895, 107, 102, "Output"]
}, Open  ]],
Cell[717094, 11510, 44, 0, 36, "Text"],
Cell[717141, 11512, 1010, 20, 296, "Input"],

Cell[CellGroupData[{
Cell[718176, 11536, 93, 1, 41, "Input"],
Cell[718272, 11539, 2895, 107, 102, "Output"]
}, Open  ]],
Cell[721182, 11649, 86, 2, 36, "Text"],

Cell[CellGroupData[{
Cell[721293, 11655, 68, 1, 41, "Input"],
Cell[721364, 11658, 408, 14, 60, "Output"]
}, Open  ]],
Cell[721787, 11675, 35, 0, 36, "Text"],

Cell[CellGroupData[{
Cell[721847, 11679, 156, 3, 63, "Input"],
Cell[722006, 11684, 794, 23, 60, "Output"]
}, Open  ]],
Cell[722815, 11710, 238, 4, 57, "Text"],
Cell[723056, 11716, 136, 2, 62, "Input"],

Cell[CellGroupData[{
Cell[723217, 11722, 75, 1, 41, "Input"],
Cell[723295, 11725, 460, 16, 60, "Output"]
}, Open  ]],
Cell[723770, 11744, 104, 3, 36, "Text"],

Cell[CellGroupData[{
Cell[723899, 11751, 86, 1, 41, "Input"],
Cell[723988, 11754, 121, 2, 60, "Output"]
}, Open  ]],
Cell[724124, 11759, 87, 2, 36, "Text"],
Cell[724214, 11763, 155, 3, 62, "Input"],

Cell[CellGroupData[{
Cell[724394, 11770, 51, 1, 42, "Input"],
Cell[724448, 11773, 703, 14, 81, "Output"]
}, Open  ]],
Cell[725166, 11790, 126, 3, 36, "Text"],

Cell[CellGroupData[{
Cell[725317, 11797, 86, 1, 41, "Input"],
Cell[725406, 11800, 64, 1, 60, "Output"]
}, Open  ]],
Cell[725485, 11804, 187, 6, 36, "Text"],

Cell[CellGroupData[{
Cell[725697, 11814, 86, 1, 41, "Input"],
Cell[725786, 11817, 67, 1, 60, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[725890, 11823, 74, 1, 58, "Input"],
Cell[725967, 11826, 67, 1, 60, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[726071, 11832, 364, 6, 125, "Input"],
Cell[726438, 11840, 15122, 273, 260, 1102, 96, "GraphicsData", "PostScript", \
"Graphics"]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{
Cell[741609, 12119, 59, 0, 28, "Subsection"],
Cell[741671, 12121, 96, 2, 36, "Text"],
Cell[741770, 12125, 155, 3, 30, "Commentary"],
Cell[741928, 12130, 1080, 16, 247, "Text"],
Cell[743011, 12148, 1928, 34, 419, "Input"],

Cell[CellGroupData[{
Cell[744964, 12186, 93, 1, 41, "Input"],
Cell[745060, 12189, 91, 1, 60, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[745188, 12195, 93, 1, 41, "Input"],
Cell[745284, 12198, 119, 2, 60, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[745440, 12205, 103, 2, 41, "Input"],
Cell[745546, 12209, 124, 2, 60, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[745707, 12216, 78, 1, 41, "Input"],
Cell[745788, 12219, 93, 1, 60, "Output"]
}, Open  ]],
Cell[745896, 12223, 90, 2, 36, "Text"],

Cell[CellGroupData[{
Cell[746011, 12229, 323, 6, 125, "Input"],
Cell[746337, 12237, 86612, 1986, 704, "Output"],
Cell[832952, 14225, 26775, 851, 704, "Output"]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{
Cell[859776, 15082, 34, 0, 28, "Subsection"],
Cell[859813, 15084, 75, 0, 36, "Text"],
Cell[859891, 15086, 267, 6, 83, "Input"],

Cell[CellGroupData[{
Cell[860183, 15096, 101, 2, 41, "Input"],
Cell[860287, 15100, 4961, 168, 326, "Output"]
}, Open  ]],
Cell[865263, 15271, 1260, 33, 129, "Text"],

Cell[CellGroupData[{
Cell[866548, 15308, 72, 1, 41, "Input"],
Cell[866623, 15311, 73, 1, 60, "Output"]
}, Open  ]],
Cell[866711, 15315, 166, 3, 57, "Text"],
Cell[866880, 15320, 1071, 23, 356, "Input"],

Cell[CellGroupData[{
Cell[867976, 15347, 158, 2, 62, "Input"],
Cell[868137, 15351, 1173, 20, 326, "Output"]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{
Cell[869359, 15377, 43, 0, 28, "Subsection"],
Cell[869405, 15379, 272, 5, 78, "Text"],
Cell[869680, 15386, 242, 5, 104, "Input"],

Cell[CellGroupData[{
Cell[869947, 15395, 91, 1, 41, "Input"],
Cell[870041, 15398, 2065, 79, 470, "Output"]
}, Open  ]]
}, Closed]]
}, Open  ]],

Cell[CellGroupData[{
Cell[872167, 15484, 34, 0, 84, "Section"],

Cell[CellGroupData[{
Cell[872226, 15488, 41, 0, 49, "Subsection"],
Cell[872270, 15490, 887, 27, 162, "Text"],
Cell[873160, 15519, 409, 11, 56, "Text"],
Cell[873572, 15532, 328, 8, 120, "Text"],
Cell[873903, 15542, 234, 5, 62, "Input",
  InitializationCell->True],

Cell[CellGroupData[{
Cell[874162, 15551, 64, 1, 41, "Input"],
Cell[874229, 15554, 215, 3, 102, "Output"]
}, Open  ]],
Cell[874459, 15560, 423, 8, 144, "Input"],

Cell[CellGroupData[{
Cell[874907, 15572, 116, 2, 41, "Input"],
Cell[875026, 15576, 590, 18, 48, "Print"],
Cell[875619, 15596, 776, 24, 48, "Print"],
Cell[876398, 15622, 150, 3, 48, "Print"],
Cell[876551, 15627, 590, 18, 48, "Print"],
Cell[877144, 15647, 960, 30, 48, "Print"],
Cell[878107, 15679, 150, 3, 48, "Print"],
Cell[878260, 15684, 150, 3, 48, "Print"],
Cell[878413, 15689, 776, 24, 48, "Print"],
Cell[879192, 15715, 590, 18, 48, "Print"],
Cell[879785, 15735, 962, 30, 48, "Print"]
}, Open  ]],

Cell[CellGroupData[{
Cell[880784, 15770, 73, 1, 41, "Input"],
Cell[880860, 15773, 146, 2, 81, "Output"],
Cell[881009, 15777, 132, 2, 81, "Output"]
}, Open  ]],
Cell[881156, 15782, 240, 6, 57, "Text"],
Cell[881399, 15790, 237, 4, 84, "Input"],

Cell[CellGroupData[{
Cell[881661, 15798, 113, 2, 41, "Input"],
Cell[881777, 15802, 381, 11, 48, "Print"],
Cell[882161, 15815, 381, 11, 48, "Print"],
Cell[882545, 15828, 150, 3, 48, "Print"],
Cell[882698, 15833, 381, 11, 48, "Print"],
Cell[883082, 15846, 381, 11, 48, "Print"],
Cell[883466, 15859, 150, 3, 48, "Print"],
Cell[883619, 15864, 150, 3, 48, "Print"],
Cell[883772, 15869, 381, 11, 48, "Print"],
Cell[884156, 15882, 381, 11, 48, "Print"],
Cell[884540, 15895, 383, 11, 48, "Print"]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{
Cell[884972, 15912, 54, 0, 28, "Subsection"],
Cell[885029, 15914, 300, 7, 78, "Text"],
Cell[885332, 15923, 231, 10, 36, "Text"],
Cell[885566, 15935, 118, 2, 42, "Input"],

Cell[CellGroupData[{
Cell[885709, 15941, 92, 1, 41, "Input"],
Cell[885804, 15944, 132, 2, 81, "Output"]
}, Open  ]],
Cell[885951, 15949, 66, 0, 36, "Text"],
Cell[886020, 15951, 254, 8, 39, "Text"],

Cell[CellGroupData[{
Cell[886299, 15963, 55, 1, 55, "Input"],
Cell[886357, 15966, 38, 1, 60, "Output"]
}, Open  ]],
Cell[886410, 15970, 258, 6, 78, "Text"],
Cell[886671, 15978, 379, 16, 36, "Text"],

Cell[CellGroupData[{
Cell[887075, 15998, 423, 8, 145, "Input"],
Cell[887501, 16008, 515, 14, 60, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[888053, 16027, 142, 3, 41, "Input"],
Cell[888198, 16032, 101, 2, 60, "Output"]
}, Open  ]],
Cell[888314, 16037, 141, 3, 36, "Text"],
Cell[888458, 16042, 378, 16, 36, "Text"],

Cell[CellGroupData[{
Cell[888861, 16062, 424, 8, 145, "Input"],
Cell[889288, 16072, 515, 14, 60, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[889840, 16091, 148, 3, 41, "Input"],
Cell[889991, 16096, 101, 2, 60, "Output"]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{
Cell[890141, 16104, 43, 0, 28, "Subsection"],
Cell[890187, 16106, 209, 5, 36, "Text"],
Cell[890399, 16113, 495, 9, 172, "Input"],

Cell[CellGroupData[{
Cell[890919, 16126, 118, 2, 41, "Input"],
Cell[891040, 16130, 976, 30, 48, "Print"],
Cell[892019, 16162, 1355, 42, 48, "Print"],
Cell[893377, 16206, 1355, 42, 48, "Print"],
Cell[894735, 16250, 976, 30, 48, "Print"],
Cell[895714, 16282, 1732, 54, 48, "Print"],
Cell[897449, 16338, 2111, 66, 48, "Print"],
Cell[899563, 16406, 150, 3, 48, "Print"],
Cell[899716, 16411, 1355, 42, 48, "Print"],
Cell[901074, 16455, 2863, 90, 69, "Print"],
Cell[903940, 16547, 1734, 54, 48, "Print"]
}, Open  ]],

Cell[CellGroupData[{
Cell[905711, 16606, 75, 1, 41, "Input"],
Cell[905789, 16609, 149, 2, 81, "Output"]
}, Open  ]],
Cell[905953, 16614, 48, 0, 36, "Text"],

Cell[CellGroupData[{
Cell[906026, 16618, 134, 3, 41, "Input"],
Cell[906163, 16623, 61, 1, 60, "Output"]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{
Cell[906273, 16630, 42, 0, 28, "Subsection"],
Cell[906318, 16632, 168, 3, 57, "Text"],
Cell[906489, 16637, 154, 6, 36, "Text"],
Cell[906646, 16645, 98, 2, 36, "Text"],
Cell[906747, 16649, 658, 12, 195, "Input"],

Cell[CellGroupData[{
Cell[907430, 16665, 116, 2, 41, "Input"],
Cell[907549, 16669, 4968, 150, 69, "Print"],
Cell[912520, 16821, 14480, 438, 153, "Print"]
}, Open  ]],

Cell[CellGroupData[{
Cell[927037, 17264, 74, 1, 41, "Input"],
Cell[927114, 17267, 75, 1, 60, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[927226, 17273, 92, 1, 41, "Input"],
Cell[927321, 17276, 118703, 1717, 243, 4750, 306, "GraphicsData", \
"PostScript", "Graphics"]
}, Open  ]],

Cell[CellGroupData[{
Cell[1046061, 18998, 136, 3, 41, "Input"],
Cell[1046200, 19003, 75, 1, 60, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[1046312, 19009, 91, 1, 48, "Input"],
Cell[1046406, 19012, 479, 11, 60, "Output"]
}, Open  ]],
Cell[1046900, 19026, 118, 3, 36, "Text"],
Cell[1047021, 19031, 546, 9, 170, "Input"],

Cell[CellGroupData[{
Cell[1047592, 19044, 88, 1, 41, "Input"],
Cell[1047683, 19047, 115, 2, 60, "Output"]
}, Open  ]],
Cell[1047813, 19052, 86, 2, 36, "Text"]
}, Closed]],

Cell[CellGroupData[{
Cell[1047936, 19059, 42, 0, 28, "Subsection"],
Cell[1047981, 19061, 394, 8, 163, "Input",
  InitializationCell->True],

Cell[CellGroupData[{
Cell[1048400, 19073, 115, 2, 41, "Input"],
Cell[1048518, 19077, 179, 4, 48, "Print"],
Cell[1048700, 19083, 381, 11, 48, "Print"],
Cell[1049084, 19096, 568, 17, 48, "Print"],
Cell[1049655, 19115, 858, 25, 48, "Print"],
Cell[1050516, 19142, 1239, 36, 48, "Print"],
Cell[1051758, 19180, 1697, 48, 48, "Print"],
Cell[1053458, 19230, 2203, 60, 48, "Print"],
Cell[1055664, 19292, 2939, 78, 48, "Print"],
Cell[1058606, 19372, 3815, 98, 48, "Print"],
Cell[1062424, 19472, 4802, 121, 69, "Print"]
}, Open  ]],
Cell[1067241, 19596, 656, 10, 110, "Commentary"]
}, Closed]]
}, Open  ]],

Cell[CellGroupData[{
Cell[1067946, 19612, 33, 0, 84, "Section"],

Cell[CellGroupData[{
Cell[1068004, 19616, 35, 0, 49, "Subsection"],

Cell[CellGroupData[{
Cell[1068064, 19620, 115, 2, 41, "Input"],
Cell[1068182, 19624, 179, 4, 48, "Print"],
Cell[1068364, 19630, 381, 11, 48, "Print"],
Cell[1068748, 19643, 568, 17, 48, "Print"],
Cell[1069319, 19662, 779, 23, 48, "Print"],
Cell[1070101, 19687, 1014, 29, 48, "Print"],
Cell[1071118, 19718, 1273, 35, 48, "Print"],
Cell[1072394, 19755, 1556, 41, 48, "Print"],
Cell[1073953, 19798, 1966, 49, 48, "Print"],
Cell[1075922, 19849, 2482, 61, 48, "Print"],
Cell[1078407, 19912, 3016, 73, 48, "Print"]
}, Open  ]],
Cell[1081438, 19988, 109, 3, 36, "Text"],

Cell[CellGroupData[{
Cell[1081572, 19995, 126, 3, 42, "Input"],
Cell[1081701, 20000, 34, 1, 48, "Print"],
Cell[1081738, 20003, 36, 1, 48, "Print"],
Cell[1081777, 20006, 36, 1, 48, "Print"],
Cell[1081816, 20009, 36, 1, 48, "Print"],
Cell[1081855, 20012, 36, 1, 48, "Print"]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{
Cell[1081940, 20019, 46, 0, 28, "Subsection"],
Cell[1081989, 20021, 89, 2, 36, "Text"],
Cell[1082081, 20025, 147, 3, 62, "Input"],

Cell[CellGroupData[{
Cell[1082253, 20032, 131, 3, 41, "Input"],
Cell[1082387, 20037, 179, 4, 48, "Print"],
Cell[1082569, 20043, 150, 3, 48, "Print"],
Cell[1082722, 20048, 150, 3, 48, "Print"],
Cell[1082875, 20053, 179, 4, 48, "Print"],
Cell[1083057, 20059, 381, 11, 48, "Print"],
Cell[1083441, 20072, 150, 3, 48, "Print"],
Cell[1083594, 20077, 150, 3, 48, "Print"],
Cell[1083747, 20082, 150, 3, 48, "Print"],
Cell[1083900, 20087, 179, 4, 48, "Print"],
Cell[1084082, 20093, 383, 11, 48, "Print"]
}, Open  ]],
Cell[1084480, 20107, 75, 0, 36, "Text"],

Cell[CellGroupData[{
Cell[1084580, 20111, 286, 5, 104, "Input"],
Cell[1084869, 20118, 203, 3, 81, "Output"]
}, Open  ]],
Cell[1085087, 20124, 117, 3, 36, "Text"],

Cell[CellGroupData[{
Cell[1085229, 20131, 131, 3, 41, "Input"],
Cell[1085363, 20136, 179, 4, 48, "Print"],
Cell[1085545, 20142, 150, 3, 48, "Print"],
Cell[1085698, 20147, 150, 3, 48, "Print"],
Cell[1085851, 20152, 150, 3, 48, "Print"],
Cell[1086004, 20157, 150, 3, 48, "Print"],
Cell[1086157, 20162, 150, 3, 48, "Print"],
Cell[1086310, 20167, 150, 3, 48, "Print"],
Cell[1086463, 20172, 179, 4, 48, "Print"],
Cell[1086645, 20178, 381, 11, 48, "Print"],
Cell[1087029, 20191, 152, 3, 48, "Print"]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{
Cell[1087230, 20200, 39, 0, 28, "Subsection"],
Cell[1087272, 20202, 63, 0, 36, "Text"],
Cell[1087338, 20204, 248, 5, 66, "Text"],
Cell[1087589, 20211, 68, 0, 36, "Text"],
Cell[1087660, 20213, 99, 3, 35, "Text"],
Cell[1087762, 20218, 438, 18, 57, "Text"],

Cell[CellGroupData[{
Cell[1088225, 20240, 103, 2, 48, "Input"],
Cell[1088331, 20244, 92001, 1184, 207, "Output"]
}, Open  ]],
Cell[1180347, 21431, 136, 5, 36, "Text"],

Cell[CellGroupData[{
Cell[1180508, 21440, 61, 1, 41, "Input"],
Cell[1180572, 21443, 486, 7, 165, "Output"]
}, Open  ]],
Cell[1181073, 21453, 36, 0, 36, "Text"],

Cell[CellGroupData[{
Cell[1181134, 21457, 62, 1, 48, "Input"],
Cell[1181199, 21460, 36, 1, 60, "Output"]
}, Open  ]],
Cell[1181250, 21464, 69, 0, 36, "Text"]
}, Closed]]
}, Open  ]],

Cell[CellGroupData[{
Cell[1181368, 21470, 43, 0, 84, "Section"],
Cell[1181414, 21472, 234, 6, 57, "Text"],
Cell[1181651, 21480, 1251, 25, 399, "Input"],
Cell[1182905, 21507, 70, 0, 36, "Text"],

Cell[CellGroupData[{
Cell[1183000, 21511, 177, 3, 83, "Input"],
Cell[1183180, 21516, 156, 3, 48, "Print"],
Cell[1183339, 21521, 179, 4, 48, "Print"],
Cell[1183521, 21527, 353, 10, 48, "Print"],
Cell[1183877, 21539, 179, 4, 48, "Print"],
Cell[1184059, 21545, 420, 12, 48, "Print"],
Cell[1184482, 21559, 355, 10, 48, "Print"],
Cell[1184840, 21571, 225, 6, 48, "Print"],
Cell[1185068, 21579, 715, 22, 48, "Print"],
Cell[1185786, 21603, 540, 16, 48, "Print"],
Cell[1186329, 21621, 384, 11, 48, "Print"],
Cell[1186716, 21634, 795, 24, 48, "Print"],
Cell[1187514, 21660, 724, 22, 48, "Print"],
Cell[1188241, 21684, 181, 4, 48, "Print"],
Cell[1188425, 21690, 355, 10, 48, "Print"],
Cell[1188783, 21702, 384, 11, 48, "Print"],
Cell[1189170, 21715, 795, 24, 48, "Print"],
Cell[1189968, 21741, 906, 28, 48, "Print"],
Cell[1190877, 21771, 540, 16, 48, "Print"],
Cell[1191420, 21789, 181, 4, 48, "Print"],
Cell[1191604, 21795, 355, 10, 48, "Print"],
Cell[1191962, 21807, 591, 18, 48, "Print"],
Cell[1192556, 21827, 915, 28, 48, "Print"],
Cell[1193474, 21857, 591, 18, 48, "Print"],
Cell[1194068, 21877, 1097, 34, 48, "Print"],
Cell[1195168, 21913, 540, 16, 48, "Print"],
Cell[1195711, 21931, 384, 11, 48, "Print"],
Cell[1196098, 21944, 613, 18, 48, "Print"],
Cell[1196714, 21964, 355, 10, 48, "Print"]
}, Open  ]],

Cell[CellGroupData[{
Cell[1197106, 21979, 76, 1, 41, "Input"],
Cell[1197185, 21982, 198, 3, 81, "Output"]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{
Cell[1197432, 21991, 51, 0, 50, "Section"],
Cell[1197486, 21993, 461, 10, 177, "Input"],
Cell[1197950, 22005, 65, 0, 36, "Text"],

Cell[CellGroupData[{
Cell[1198040, 22009, 84, 1, 41, "Input"],
Cell[1198127, 22012, 189, 3, 81, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[1198353, 22020, 85, 1, 41, "Input"],
Cell[1198441, 22023, 152, 3, 48, "Print"],
Cell[1198596, 22028, 225, 6, 48, "Print"],
Cell[1198824, 22036, 152, 3, 48, "Print"],
Cell[1198979, 22041, 267, 8, 48, "Print"],
Cell[1199249, 22051, 267, 8, 48, "Print"],
Cell[1199519, 22061, 225, 6, 48, "Print"],
Cell[1199747, 22069, 267, 8, 48, "Print"],
Cell[1200017, 22079, 269, 8, 48, "Print"],
Cell[1200289, 22089, 269, 8, 48, "Print"],
Cell[1200561, 22099, 269, 8, 48, "Print"],
Cell[1200833, 22109, 344, 10, 48, "Print"],
Cell[1201180, 22121, 269, 8, 48, "Print"],
Cell[1201452, 22131, 269, 8, 48, "Print"],
Cell[1201724, 22141, 271, 8, 48, "Print"],
Cell[1201998, 22151, 269, 8, 48, "Print"],
Cell[1202270, 22161, 390, 12, 48, "Print"],
Cell[1202663, 22175, 273, 8, 48, "Print"],
Cell[1202939, 22185, 344, 10, 48, "Print"],
Cell[1203286, 22197, 273, 8, 48, "Print"],
Cell[1203562, 22207, 390, 12, 48, "Print"],
Cell[1203955, 22221, 269, 8, 48, "Print"],
Cell[1204227, 22231, 273, 8, 48, "Print"],
Cell[1204503, 22241, 273, 8, 48, "Print"],
Cell[1204779, 22251, 386, 12, 48, "Print"],
Cell[1205168, 22265, 390, 12, 48, "Print"],
Cell[1205561, 22279, 348, 10, 48, "Print"],
Cell[1205912, 22291, 271, 8, 48, "Print"],
Cell[1206186, 22301, 273, 8, 48, "Print"],
Cell[1206462, 22311, 390, 12, 48, "Print"],
Cell[1206855, 22325, 388, 12, 48, "Print"],
Cell[1207246, 22339, 273, 8, 48, "Print"],
Cell[1207522, 22349, 273, 8, 48, "Print"],
Cell[1207798, 22359, 273, 8, 48, "Print"],
Cell[1208074, 22369, 507, 16, 48, "Print"],
Cell[1208584, 22387, 273, 8, 48, "Print"],
Cell[1208860, 22397, 465, 14, 48, "Print"],
Cell[1209328, 22413, 273, 8, 48, "Print"]
}, Open  ]],

Cell[CellGroupData[{
Cell[1209638, 22426, 74, 1, 41, "Input"],
Cell[1209715, 22429, 362, 5, 123, "Output"]
}, Open  ]],
Cell[1210092, 22437, 304, 5, 78, "Text"]
}, Closed]],

Cell[CellGroupData[{
Cell[1210433, 22447, 43, 0, 50, "Section"],

Cell[CellGroupData[{
Cell[1210501, 22451, 33, 0, 49, "Subsection"],
Cell[1210537, 22453, 539, 9, 120, "Text"],

Cell[CellGroupData[{
Cell[1211101, 22466, 341, 6, 132, "Input"],
Cell[1211445, 22474, 59, 1, 48, "Print"],
Cell[1211507, 22477, 69, 1, 60, "Output"]
}, Open  ]],
Cell[1211591, 22481, 152, 4, 57, "Text"]
}, Closed]],

Cell[CellGroupData[{
Cell[1211780, 22490, 64, 0, 28, "Subsection"],
Cell[1211847, 22492, 87, 2, 36, "Text"],
Cell[1211937, 22496, 679, 13, 266, "Input"],

Cell[CellGroupData[{
Cell[1212641, 22513, 48, 1, 41, "Input"],
Cell[1212692, 22516, 112, 2, 60, "Output"]
}, Open  ]],
Cell[1212819, 22521, 108, 3, 36, "Text"],
Cell[1212930, 22526, 966, 20, 342, "Input"],

Cell[CellGroupData[{
Cell[1213921, 22550, 51, 1, 41, "Input"],
Cell[1213975, 22553, 51, 1, 60, "Output"]
}, Open  ]],
Cell[1214041, 22557, 38, 0, 36, "Text"],

Cell[CellGroupData[{
Cell[1214104, 22561, 73, 1, 41, "Input"],
Cell[1214180, 22564, 86, 1, 60, "Output"]
}, Open  ]],
Cell[1214281, 22568, 76, 0, 36, "Text"],

Cell[CellGroupData[{
Cell[1214382, 22572, 205, 4, 62, "Input"],
Cell[1214590, 22578, 3991, 54, 488, "Output"]
}, Open  ]],
Cell[1218596, 22635, 120, 3, 36, "Text"],

Cell[CellGroupData[{
Cell[1218741, 22642, 60, 1, 41, "Input"],
Cell[1218804, 22645, 3991, 54, 488, "Output"]
}, Open  ]],
Cell[1222810, 22702, 159, 3, 57, "Text"],

Cell[CellGroupData[{
Cell[1222994, 22709, 158, 4, 104, "Input"],
Cell[1223155, 22715, 42, 1, 60, "Output"],
Cell[1223200, 22718, 48, 1, 60, "Output"],
Cell[1223251, 22721, 51, 1, 60, "Output"],
Cell[1223305, 22724, 54, 1, 60, "Output"]
}, Open  ]],
Cell[1223374, 22728, 290, 6, 99, "Text"],

Cell[CellGroupData[{
Cell[1223689, 22738, 214, 3, 83, "Input"],
Cell[1223906, 22743, 1148, 16, 354, "Output"]
}, Open  ]]
}, Closed]]
}, Open  ]],

Cell[CellGroupData[{
Cell[1225115, 22766, 29, 0, 84, "Section"],
Cell[1225147, 22768, 1065, 19, 678, "Reference"]
}, Closed]]
}, Open  ]]
}
]
*)




(***********************************************************************
End of Mathematica Notebook file.
***********************************************************************)

